//
// org.osid.Identifiable
//
//     The OSID Java specification for org.osid.Identifiable.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> </code> A marker interface for objects uniquely identified with 
 *  an OSID <code> Id. </code> </p>
 */

public interface Identifiable {


    /**
     *  Gets the Id associated with this instance of this OSID object. 
     *  Persisting any reference to this object is done by persisting the Id 
     *  returned from this method. The Id returned may be different than the 
     *  Id used to query this object. In this case, the new Id should be 
     *  preferred over the old one for future queries. 
     *
     *  @return the <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  The <code> Id </code> is intended to be constant and 
     *          persistent. A consumer may at any time persist the <code> Id 
     *          </code> for retrieval at any future time. Ideally, the Id 
     *          should consistently resolve into the designated object and not 
     *          be reused. In cases where objects are deactivated after a 
     *          certain lifetime the provider should endeavor not to 
     *          obliterate the object or its <code> Id </code> but instead 
     *          should update the properties of the object including the 
     *          deactiavted status and the elimination of any unwanted pieces 
     *          of data. As such, there is no means for updating an <code> Id 
     *          </code> and providers should consider carefully the 
     *          identification scheme to implement. 
     *          
     *          <code> Id </code> assignments for objects are strictly in the 
     *          realm of the provider and any errors should be fixed directly 
     *          with the backend supporting system. Once an Id has been 
     *          assigned in a production service it should be honored such 
     *          that it may be necessary for the backend system to support Id 
     *          aliasing to redirect the lookup to the current <code> Id. 
     *          </code> Use of an Id OSID may be helpful to accomplish this 
     *          task in a modular manner. 
     */

    public org.osid.id.Id getId();


    /**
     *  Tests to see if the last method invoked retrieved up-to-date data. 
     *  Simple retrieval methods do not specify errors as, generally, the data 
     *  is retrieved once at the time this object is instantiated. Some 
     *  implementations may provide real-time data though the application may 
     *  not always care. An implementation providing a real-time service may 
     *  fall back to a previous snapshot in case of error. This method returns 
     *  false if the data last retrieved was stale. 
     *
     *  @return <code> true </code> if the last data retrieval was up to date, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  Providers should return false unless all getters are 
     *          implemented using real-time queries, or some trigger process 
     *          keeps the data in this object current. Providers should 
     *          populate basic data elements at the time this object is 
     *          instantiated, or set an error, to ensure some data 
     *          availability. 
     */

    public boolean isCurrent();
}
