//
// org.osid.Operable
//
//     The OSID Java specification for org.osid.Operable.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> Operable </code> is used to indicate an <code> OsidObject 
 *  </code> performs operations. The active status indicates if the <code> 
 *  Operable </code> is on or off. The active status is determined from the 
 *  operational status and the enabling rules. </p> 
 *  
 *  <p> The operational status indicates the Operable is functioning. This 
 *  status is not set administratively but instead refelects suitable 
 *  conditions for operation. </p> 
 *  
 *  <p> Operables may be administratively turned on of off through the enabled 
 *  and disabled administrative overrides. If there are no related <code> 
 *  OsidEnabler </code> rules, then <code> isEnabled() </code> should be set 
 *  to <code> true </code> and <code> isDisabled() </code> set to <code> false 
 *  </code> for the <code> Operable </code> to be on and <code> isEnabled() 
 *  </code> set to <code> false </code> and <code> isDisabled() </code> set to 
 *  true for the <code> Operable </code> to be <code> off. </code> <code> 
 *  isEnabled() </code> and <code> isDisabled() </code> cannot both be <code> 
 *  tru </code> e. </p> 
 *  
 *  <p> If there are related <code> OsidEnabler </code> rules, the active 
 *  status of at least one <code> OsidEnabler </code> results in a <code> true 
 *  </code> value for <code> isOperational(). </code> This active status can 
 *  be overridden by setting <code> isDisabled() </code> to <code> true. 
 *  </code> If there are no active <code> OsidEnabler </code> rules, <code> 
 *  isOperational() </code> is false resulting in an <code> off </code> <code> 
 *  Operable </code> unless <code> isEnabled() </code> is <code> true </code> 
 *  . </p> 
 *  
 *  <p> For the active status to be completely determined by the <code> 
 *  OsidEnablers, </code> both <code> isEnabled() </code> and <code> 
 *  isDisabled() </code> should be <code> false </code> where the <code> 
 *  isActive() </code> status is completely driven from <code> 
 *  isOperational(). </code> </p>
 */

public interface Operable {


    /**
     *  Tests if this operable is active. <code> isActive() </code> is <code> 
     *  true </code> if <code> isOperational() </code> is <code> true </code> 
     *  and <code> isDisabled() </code> is <code> false, </code> or <code> 
     *  isEnabled() </code> is <code> true. </code> 
     *
     *  @return <code> true </code> if this operable is on, <code> false 
     *          </code> if it is off 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isActive();


    /**
     *  Tests if this operable is administravely enabled. Administratively 
     *  enabling overrides any applied <code> OsidEnabler. </code> If this 
     *  method returns <code> true </code> then <code> isDisabled() </code> 
     *  must return <code> false. </code> 
     *
     *  @return <code> true </code> if this operable is enabled, <code> false 
     *          </code> if the active status is determined by other rules 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isEnabled();


    /**
     *  Tests if this operable is administravely disabled. Administratively 
     *  disabling overrides any applied <code> OsidEnabler. </code> If this 
     *  method returns <code> true </code> then <code> isEnabled() </code> 
     *  must return <code> false. </code> 
     *
     *  @return <code> true </code> if this operable is disabled, <code> false 
     *          </code> if the active status is determined by other rules 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDisabled();


    /**
     *  Tests if this <code> Operable </code> is operational. This Operable is 
     *  operational if any of the applied <code> OsidEnablers </code> are 
     *  <code> true. </code> 
     *
     *  @return <code> true </code> if this operable is operational, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOperational();
}
