//
// org.osid.OsidCatalog
//
//     The OSID Java specification for org.osid.OsidCatalog.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> OsidCatalog </code> is the top level interface for all OSID 
 *  catalog-like objects. A catalog relates to other OSID objects for the 
 *  purpose of organization and federation and almost always are hierarchical. 
 *  An example catalog is a <code> Repository </code> that relates to a 
 *  collection of <code> Assets. </code> </p> 
 *  
 *  <p> <code> OsidCatalogs </code> allow for the retrieval of a provider 
 *  identity and branding. </p> 
 *  
 *  <p> Collections visible through an <code> OsidCatalog </code> may be the 
 *  output of a dynamic query or some other rules-based evaluation. The facts 
 *  surrounding the evaluation are the <code> OsidObjects </code> visible to 
 *  the <code> OsidCatalog </code> from its position in the federated 
 *  hierarchy. The input conditions may satisifed on a service-wide basis 
 *  using an <code> OsidQuery </code> or environmental conditions supplied to 
 *  the services via a <code> Proxy </code> . </p> 
 *  
 *  <p> Often, the selection of an <code> OsidCatalog </code> in instantiating 
 *  an <code> OsidSession </code> provides access to a set of <code> 
 *  OsidObjects </code> . Because the view inside an <code> OsidCatalog 
 *  </code> can also be produced behaviorally using a rules evaluation, the 
 *  <code> Id </code> (or well-known alias) of the <code> OsidCatalog </code> 
 *  may be used as an abstract means of requesting a predefined set of 
 *  behaviors or data constraints from an OSID Provider. </p> 
 *  
 *  <p> The flexibility of interpretation together with its central role in 
 *  federation to build a rich and complex service from a set of individual 
 *  OSID Providers makes cataloging an essential pattern to achieve 
 *  abstraction from implementations in the OSIDs without loss of 
 *  functionality. Most OSIDs include a cataloging pattern. </p>
 */

public interface OsidCatalog
    extends org.osid.OsidObject,
            org.osid.Sourceable,
            org.osid.Federateable {
}
