//
// org.osid.OsidCompendium
//
//     The OSID Java specification for org.osid.OsidCompendium.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> OsidCompendium </code> is the top level interface for reports 
 *  based on measurements, calculations, summaries, or views of transactional 
 *  activity within periods of time. This time dimension of this report may 
 *  align with managed time periods, specific dates, or both. Oh my. </p> 
 *  
 *  <p> Reports are often derived dynamically based on an examination of data 
 *  managed elsewhere in an OSID. Reports may also be directly managed outside 
 *  where it is desirable to capture summaries without the detail of the 
 *  implied evaluated data. The behavior of a direct create or update of a 
 *  report is not specified but is not limited to an override or a cascading 
 *  update of underlying data. </p> 
 *  
 *  <p> The start and end date represents the date range used in the 
 *  evaluation of the transactional data on which this report is based. The 
 *  start and end date may be the same indicating that the evaluation occurred 
 *  at a point in time rather than across a date range. The start and end date 
 *  requested may differ from the start and end date indicated in this report 
 *  because of the inability to interpolate or extrapolate the date. These 
 *  dates should be examined to understand what actually occurred and to what 
 *  dates the information in this report pertains. </p> 
 *  
 *  <p> These dates differ from the dates the report itself was requested, 
 *  created, or modified. The dates refer to the context of the evaluation. In 
 *  a managed report, the dates are simply the dates to which the report 
 *  information pertains. The history of a single report may be examined in 
 *  the Journaling OSID. </p> 
 *  
 *  <p> For example, the Location of a Resource at 12:11pm is reported to be 
 *  in Longwood and at 12:23pm is reported to be at Chestnut Hill. A request 
 *  of a <code> ResourceLocation...... </code> A data correction may update 
 *  the Longwood time to be 12:09pm. The update of the <code> ResourceLocation 
 *  </code> from 12:11pm to 12:09pm may be examined in the Journaling OSID 
 *  while the 12:11pm time would not longer be visible in current versions of 
 *  this report. </p> 
 *  
 *  <p> Reports may be indexed by a managed time period such as a <code> Term 
 *  </code> or <code> FiscalPeriod. </code> The evaluation dates may map to 
 *  the opening and closing dates of the time period. Evaluation dates that 
 *  differ from the time period may indicate that the transactional data is 
 *  incomplete for that time period or that the report was calculated using a 
 *  requested date range. </p> 
 *  
 *  <p> <code> OsidCompendiums </code> are subjugates to other <code> 
 *  OsidObjects </code> in that what is reported is tied to an instance of a 
 *  dimension such as a person, account, or an <code> OsidCatalog </code> . 
 *  </p>
 */

public interface OsidCompendium
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the start date used in the evaluation of the transactional data 
     *  on which this report is based. 
     *
     *  @return the date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getStartDate();


    /**
     *  Gets the end date used in the evaluation of the transactional data on 
     *  which this report is based. 
     *
     *  @return the date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getEndDate();


    /**
     *  Tests if this report is interpolated within measured data or known 
     *  transactions. Interpolation may occur if the start or end date fall 
     *  between two known facts or managed time period. 
     *
     *  @return <code> true </code> if this report is interpolated, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isInterpolated();


    /**
     *  Tests if this report is extrapolated outside measured data or known 
     *  transactions. Extrapolation may occur if the start or end date fall 
     *  outside two known facts or managed time period. Extrapolation may 
     *  occur within a managed time period in progress where the results of 
     *  the entire time period are projected. 
     *
     *  @return <code> true </code> if this report is extrapolated, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isExtrapolated();
}
