//
// org.osid.OsidEnabler
//
//     The OSID Java specification for org.osid.OsidEnabler.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> OsidEnabler </code> is used to manage the effectiveness, 
 *  enabledness, or operation of an <code> OsidObejct. </code> The <code> 
 *  OsidEnabler </code> itself is active or inactive When an <code> 
 *  OsidEnabler </code> is active, any <code> OsidObject </code> mapped to it 
 *  is "on." When all <code> OsidEnablers </code> mapped to an <code> 
 *  OsidObject </code> are inactive, then the <code> OsidObject </code> is 
 *  "off." </p> 
 *  
 *  <p> The managed <code> OsidObject </code> may have varying semantics as to 
 *  what its on/off status means and in particular, which methods are used to 
 *  indicate the effect of an <code> OsidEnabler. </code> Some axamples: </p> 
 *  
 *  <ul>
 *      <li> <code> Operables: </code> <code> OsidEnablers </code> effect the 
 *      operational status. </li> 
 *      <li> <code> Temporals: </code> <code> OsidEnablers </code> may be used 
 *      to extend or shorten the effectiveness of a <code> Temporal </code> 
 *      such as an <code> OsidRelationship. </code> </li> 
 *  </ul>
 *  
 *  
 *  <p> In the case where an <code> OsidEnabler </code> may cause a 
 *  discontinuity in a <code> Temporal, </code> the <code> OsidEnabler </code> 
 *  may cause the creation of new <code> Temporals </code> to capture the gap 
 *  in effectiveness. </p> 
 *  
 *  <p> For example, An <code> OsidRelationship </code> that began in 2007 may 
 *  be brought to an end in 2008 due to the absence of any active <code> 
 *  OsidEnablers. </code> When an effective <code> OsidEnabler </code> appears 
 *  in 2009, a new <code> OsidRelationship </code> is created with a starting 
 *  effective date of 2009 leaving the existing <code> OsidRelationship 
 *  </code> with effective dates from 2007 to 2008. </p> 
 *  
 *  <p> An <code> OsidEnabler </code> itself is both a <code> Temporal </code> 
 *  and an <code> OsidRule </code> whose activity status of the object may be 
 *  controlled administratively, using a span of effective dates, through an 
 *  external rule, or all three. The <code> OsidEnabler </code> defines a set 
 *  of canned rules based on dates, events, and cyclic events. </p>
 */

public interface OsidEnabler
    extends org.osid.OsidRule,
            org.osid.Temporal {


    /**
     *  Tests if the effectiveness of the enabler is governed by a <code> 
     *  Schedule. </code> If a schedule exists, it is bounded by the effective 
     *  dates of this enabler. If <code> isEffectiveBySchedule() </code> is 
     *  <code> true, </code> <code> isEffectiveByEvent() </code> and <code> 
     *  isEffectiveByCyclicEvent() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if the enabler is governed by schedule, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isEffectiveBySchedule();


    /**
     *  Gets the schedule <code> Id </code> . 
     *
     *  @return the schedule <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isEffectiveBySchedule() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getScheduleId();


    /**
     *  Gets the schedule. 
     *
     *  @return the schedule 
     *  @throws org.osid.IllegalStateException <code> isEffectiveBySchedule() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Schedule getSchedule()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the effectiveness of the enabler is governed by an <code> 
     *  Event </code> such that the start and end dates of the event govern 
     *  the effectiveness. The event may also be a <code> RecurringEvent 
     *  </code> in which case the enabler is effective for start and end dates 
     *  of each event in the series If an event exists, it is bounded by the 
     *  effective dates of this enabler. If <code> isEffectiveByEvent() 
     *  </code> is <code> true, </code> <code> isEffectiveBySchedule() </code> 
     *  and <code> isEffectiveByCyclicEvent() </code> must be <code> false. 
     *  </code> 
     *
     *  @return <code> true </code> if the enabler is governed by an event, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isEffectiveByEvent();


    /**
     *  Gets the event <code> Id </code> . 
     *
     *  @return the event <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isEffectiveByEvent() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEventId();


    /**
     *  Gets the event. 
     *
     *  @return the event 
     *  @throws org.osid.IllegalStateException <code> isEffectiveByEvent() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Event getEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the effectiveness of the enabler is governed by a <code> 
     *  CyclicEvent. </code> If a cyclic event exists, it is evaluated by the 
     *  accompanying cyclic time period. If <code> isEffectiveByCyclicEvent() 
     *  </code> is <code> true, </code> <code> isEffectiveBySchedule() </code> 
     *  and <code> isEffectiveByEvent() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if the enabler is governed by a cyclic 
     *          event, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isEffectiveByCyclicEvent();


    /**
     *  Gets the cyclic event <code> Id </code> . 
     *
     *  @return the cyclic event <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          isEffectiveByCyclicEvent() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCyclicEventId();


    /**
     *  Gets the cyclic event. 
     *
     *  @return the cyclic event 
     *  @throws org.osid.IllegalStateException <code> 
     *          isEffectiveByCyclicEvent() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEvent getCyclicEvent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the effectiveness of the enabler applies to a demographic 
     *  resource. 
     *
     *  @return <code> true </code> if the rule apples to a demographic. 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isEffectiveForDemographic();


    /**
     *  Gets the demographic resource <code> Id </code> . 
     *
     *  @return the resource <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          isEffectiveForDemographic() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDemographicId();


    /**
     *  Gets the demographic resource. 
     *
     *  @return the resource representing the demographic 
     *  @throws org.osid.IllegalStateException <code> 
     *          isEffectiveForDemographic() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getDemographic()
        throws org.osid.OperationFailedException;
}
