//
// org.osid.OsidIdentifiableQuery
//
//     The OSID Java specification for org.osid.OsidIdentifiableQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>The <code> OsidIdentiableQuery </code> is used to assemble search 
 *  queries for <code> Identifiable </code> objects. An <code> 
 *  OsidIdentifiableQuery </code> is available from an <code> OsidQuerySession 
 *  </code> and defines methods to match objects. Once the desired parameters 
 *  are set, the <code> OsidIdentifiableQuery </code> is given to the 
 *  designated search method. The same <code> OsidIdentifiableQuery </code> 
 *  returned from the session must be used in the search as the provider may 
 *  utilize implementation-specific data wiithin the object. </p> 
 *  
 *  <p> If multiple data elements are set in this interface, the results 
 *  matching all the given data (eg: AND) are returned. </p>
 */

public interface OsidIdentifiableQuery
    extends org.osid.OsidQuery {


    /**
     *  Adds an <code> Id </code> to match. Multiple <code> Ids </code> can be 
     *  added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  id <code> Id </code> to match 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchId(org.osid.id.Id id, boolean match);


    /**
     *  Clears all <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIdTerms();
}
