//
// org.osid.OsidNode
//
//     The OSID Java specification for org.osid.OsidNode.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>A node interface for hierarchical objects. The <code> Id </code> of the 
 *  node is the <code> Id </code> of the object represented at this node. </p>
 */

public interface OsidNode
    extends org.osid.Identifiable,
            org.osid.Containable {


    /**
     *  Tests if this node is a root in the hierarchy (has no parents). A node 
     *  may have no more parents available in this node structure but is not a 
     *  root in the hierarchy. If both <code> isRoot() </code> and <code> 
     *  hasParents() </code> is false, the parents of this node may be 
     *  accessed thorugh another node structure retrieval. 
     *
     *  @return <code> true </code> if this node is a root in the hierarchy, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isRoot();


    /**
     *  Tests if any parents are available in this node structure. There may 
     *  be no more parents in this node structure however there may be parents 
     *  that exist in the hierarchy. 
     *
     *  @return <code> true </code> if this node has parents, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParents();


    /**
     *  Gets the parents of this node. 
     *
     *  @return the parents of this node 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentIds();


    /**
     *  Tests if this node is a leaf in the hierarchy (has no children). A 
     *  node may have no more children available in this node structure but is 
     *  not a leaf in the hierarchy. If both <code> isLeaf() </code> and 
     *  <code> hasChildren() </code> is false, the children of this node may 
     *  be accessed thorugh another node structure retrieval. 
     *
     *  @return <code> true </code> if this node is a leaf in the hierarchy, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isLeaf();


    /**
     *  Tests if any children are available in this node structure. There may 
     *  be no more children available in this node structure but this node may 
     *  have children in the hierarchy. 
     *
     *  @return <code> true </code> if this node has children, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildren();


    /**
     *  Gets the children of this node. 
     *
     *  @return the children of this node 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildIds();
}
