//
// org.osid.OsidObjectSearchOrder
//
//     The OSID Java specification for org.osid.OsidObjectSearchOrder.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p><code> OsidObjectSearchOrder </code> specifies preferred ordering of 
 *  search results. An <code> OsidSearchOrder </code> is available from an 
 *  search session and supplied to an <code> OsidSearch. </code> </p> 
 *  
 *  <pre>
 *       
 *       
 *       OsidObjectSearch os = session.getObjectSearch();
 *       os.limitResultSet(1, 25);
 *       
 *       OsidObjectSearchOrder order = session.getObjectSearchOrder();
 *       order.orderByDisplayName();
 *       os.orderResults(order);
 *       
 *       OsidObjectQuery query;
 *       query = session.getObjectQuery();
 *       query.addDescriptionMatch("*food*", wildcardStringMatchType, true);
 *       
 *       ObjectSearchResults results = session.getObjectsBySearch(query, os);
 *       ObjectList list = results.getObjectList();
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface OsidObjectSearchOrder
    extends org.osid.OsidIdentifiableSearchOrder,
            org.osid.OsidExtensibleSearchOrder,
            org.osid.OsidBrowsableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the display 
     *  name. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDisplayName(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the description. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDescription(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the genus type. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByGenusType(org.osid.SearchOrderStyle style);


    /**
     *  Orders by the state in a given <code> Process. </code> 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> style </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByState(org.osid.id.Id processId, 
                             org.osid.SearchOrderStyle style);


    /**
     *  Orders by the cumulative rating in a given <code> Book. </code> 
     *
     *  @param  bookId a book <code> Id </code> 
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> bookId </code> or <code> 
     *          style </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCumulativeRating(org.osid.id.Id bookId, 
                                        org.osid.SearchOrderStyle style);


    /**
     *  Orders by a statistic for a given <code> Meter. </code> 
     *
     *  @param  meterId a meter <code> Id </code> 
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> meterId </code> or 
     *          <code> style </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByStatistic(org.osid.id.Id meterId, 
                                 org.osid.SearchOrderStyle style);


    /**
     *  Orders by the timestamp of the first journal entry. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCreateTime(org.osid.SearchOrderStyle style);


    /**
     *  Orders by the timestamp of the last journal entry. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLastModifiedTime(org.osid.SearchOrderStyle style);
}
