//
// org.osid.OsidProxyManager
//
//     The OSID Java specification for org.osid.OsidProxyManager.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>The <code> OsidProxyManager </code> is the top level interface for all 
 *  OSID proxy managers. A proxy manager accepts parameters to pass through 
 *  end-user authentication credentials and other necessary request parameters 
 *  in a server environment. Native applications should use an <code> 
 *  OsidManager </code> to maintain a higher degree of interoperability by 
 *  avoiding this coupling. </p> 
 *  
 *  <p> An OSID proxy manager is instantiated through the <code> 
 *  OsidRuntimeManager </code> and represents an instance of a service. An 
 *  OSID manager is responsible for defining clusters of interoperability 
 *  within a service and creating sessions that generally correspond to these 
 *  clusters, An application need only create a single <code> OsidProxyManager 
 *  </code> per service and implementors must ensure the <code> 
 *  OsidProxyManager </code> is thread-safe <code> . </code> The <code> 
 *  OsidSessions </code> spawned from an OSID manager are dedicated to single 
 *  processing threads. The <code> OsidProxyManager </code> defines methods in 
 *  common throughout all OSID managers which implement this interface. </p>
 */

public interface OsidProxyManager
    extends org.osid.OsidProfile,
            org.osid.binding.java.OsidProxyManager,
            java.io.Closeable {


    /**
     *  Initializes this manager. A manager is initialized once at the time of 
     *  creation. 
     *
     *  @param  runtime the runtime environment 
     *  @throws org.osid.ConfigurationErrorException an error with 
     *          implementation configuration 
     *  @throws org.osid.IllegalStateException this manager has already been 
     *          initialized by the <code> OsidRuntime </code> 
     *  @throws org.osid.NullArgumentException <code> runtime </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  In addition to loading its runtime configuration an 
     *          implementation may create shared resources such as connection 
     *          pools to be shared among all sessions of this service and 
     *          released when this manager is closed. Providers must 
     *          thread-protect any data stored in the manager. 
     *          
     *          To maximize interoperability, providers should not honor a 
     *          second call to <code> initialize() </code> and must set an 
     *          <code> ILLEGAL_STATE </code> error. 
     */

    public void initialize(org.osid.OsidRuntimeManager runtime)
        throws org.osid.ConfigurationErrorException,
               org.osid.OperationFailedException;


    /**
     *  Rolls back this service to a point in time. 
     *
     *  @param  rollbackTime the requested time 
     *  @param  proxy a proxy 
     *  @return the journal entry corresponding to the actual state of this 
     *          service 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalRollback() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntry rollbackService(java.util.Date rollbackTime, 
                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Changes the service branch. 
     *
     *  @param  branchId the new service branch 
     *  @param  proxy a proxy 
     *  @throws org.osid.NotFoundException <code> branchId </code> not found 
     *  @throws org.osid.NullArgumentException <code> branchId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalBranching() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changeBranch(org.osid.id.Id branchId, 
                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
