//
// org.osid.OsidQuery
//
//     The OSID Java specification for org.osid.OsidQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>The <code> OsidQuery </code> is used to assemble search queries. An 
 *  <code> OsidQuery </code> is available from an <code> OsidQuerySession 
 *  </code> and defines methods to match objects. Once the desired parameters 
 *  are set, the <code> OsidQuery </code> is given to the designated search 
 *  method. The same <code> OsidQuery </code> returned from the session must 
 *  be used in the search as the provider may utilize implementation-specific 
 *  data wiithin the object. </p> 
 *  
 *  <p> If multiple data elements are set in this interface, the results 
 *  matching all the given data (eg: AND) are returned. </p> 
 *  
 *  <p> Any match method inside an <code> OsidQuery </code> may be invoked 
 *  multiple times. In the case of a match method, each invocation adds an 
 *  element to an <code> OR </code> expression. Any of these terms may also be 
 *  negated through the <code> match </code> flag. </p> 
 *  
 *  <pre>
 *       
 *       
 *       OsidQuery { OsidQuery.matchDisplayName AND (OsidQuery.matchDescription OR OsidQuery.matchDescription)}
 *       
 *                   
 *       
 *  </pre>
 *  
 *  
 *  <p> <code> OsidObjects </code> allow for the definition of an additonal 
 *  records and the <code> OsidQuery </code> parallels this mechanism. An 
 *  interface type of an <code> OsidObject </code> record must also define the 
 *  corresponding <code> OsidQuery </code> record which is available through 
 *  query interfaces. Multiple requests of these typed interfaces may return 
 *  the same underlying object and thus it is only useful to request once. 
 *  </p> 
 *  
 *  <p> An <code> OsidQuery </code> may be used to query for set or unset 
 *  values using the "match any" methods. A field that has not bee explicitly 
 *  assigned may default to a value. If multiple language translations exist 
 *  and the query session is placed in a non-default locale, fields that have 
 *  not been explicitly assigned in the non-default locale are considered 
 *  unset even if the values from the default locale appear in the objects. 
 *  </p>
 */

public interface OsidQuery
    extends org.osid.Suppliable {


    /**
     *  Gets the string matching types supported. A string match type 
     *  specifies the syntax of the string query, such as matching a word or 
     *  including a wildcard or regular expression. 
     *
     *  @return a list containing the supported string match types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStringMatchTypes();


    /**
     *  Tests if the given string matching type is supported. 
     *
     *  @param  stringMatchType a <code> Type </code> indicating a string 
     *          match type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> stringMatchType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStringMatchType(org.osid.type.Type stringMatchType);


    /**
     *  Adds a keyword to match. Multiple keywords can be added to perform a 
     *  boolean <code> OR </code> among them. A keyword may be applied to any 
     *  of the elements defined in this object such as the display name, 
     *  description or any method defined in an interface implemented by this 
     *  object. 
     *
     *  @param  keyword keyword to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> keyword </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> keyword </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchKeyword(String keyword, 
                             org.osid.type.Type stringMatchType, boolean match);


    /**
     *  Clears all keyword terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKeywordTerms();


    /**
     *  Matches any object. 
     *
     *  @param  match <code> true </code> to match any object <code> , </code> 
     *          <code> false </code> to match no objects 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAny(boolean match);


    /**
     *  Clears the match any terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAnyTerms();
}
