//
// org.osid.OsidRuleQuery
//
//     The OSID Java specification for org.osid.OsidRuleQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>This is the query interface for searching rules. Each method specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface OsidRuleQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidOperableQuery {


    /**
     *  Match the <code> Id </code> of the rule. 
     *
     *  @param  ruleId <code> Id </code> to match 
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> ruleId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuleId(org.osid.id.Id ruleId, boolean match);


    /**
     *  Clears all rule <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuleIdTerms();


    /**
     *  Tests if a <code> RuleQuery </code> for the rule is available. 
     *
     *  @return <code> true </code> if a rule query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuleQuery();


    /**
     *  Gets the query for the rule. Each retrieval performs a boolean <code> 
     *  OR. </code> 
     *
     *  @param  match <code> true </code> if for a positive match, <code> 
     *          false </code> for a negative match 
     *  @return the rule query 
     *  @throws org.osid.UnimplementedException <code> supportsRuleQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.RuleQuery getRuleQuery(boolean match);


    /**
     *  Match any associated rule. 
     *
     *  @param  match <code> true </code> to match any rule, <code> false 
     *          </code> to match no rules 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRule(boolean match);


    /**
     *  Clears all rule terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuleTerms();
}
