//
// org.osid.OsidSearchResults
//
//     The OSID Java specification for org.osid.OsidSearchResults.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>This interface provides a means to capture results of a search. An 
 *  example of searching withina result set: </p> 
 *  
 *  <pre>
 *       
 *       
 *       OsidSearch os = session.getObjectSearch();
 *       
 *       OsidQuery query;
 *       query = session.getObjectQuery();
 *       query.matchDescription("*food*", wildcardStringMatchType, true);
 *       ObjectSearchResults results = session.getObjectBySearch(query, os);
 *       
 *       // get information about search
 *       ObjectList objects = results.getObjects();
 *       int size = results.getResultSize();
 *       
 *       SearchPerformanceRecord record = (SearchPerformanceRecord) results.getObjectSearchResultsRecord(performanceRecodType);
 *       Duration duration = record.getTimeForSearch();
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface OsidSearchResults
    extends org.osid.OsidResult {


    /**
     *  Returns the size of a result set from a search query. This number 
     *  serves as an estimate to provide feedback for refining search queries 
     *  and may not be the number of elements available through an <code> 
     *  OsidList. </code> 
     *
     *  @return the result size 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getResultSize();
}
