//
// org.osid.OsidSession
//
//     The OSID Java specification for org.osid.OsidSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  <p>The <code> OsidSession </code> is the top level interface for all OSID 
 *  sessions. An <code> OsidSession </code> is created through its 
 *  corresponding <code> OsidManager. </code> A new <code> OsidSession </code> 
 *  should be created for each user of a service and for each processing 
 *  thread. A session maintains a single authenticated user and is not 
 *  required to ensure thread-protection. A typical OSID session defines a set 
 *  of service methods corresponding to some compliance level as defined by 
 *  the service and is generally responsible for the management and retrieval 
 *  of <code> OsidObjects. </code> </p> 
 *  
 *  <p> <code> OsidSession </code> defines a set of common methods used 
 *  throughout all OSID sessions. An OSID session may optionally support 
 *  transactions through the transaction interface. </p>
 */

public interface OsidSession
    extends org.osid.binding.java.OsidSession,
            java.io.Closeable {


    /**
     *  Gets the locale indicating the localization preferences in effect for 
     *  this session. 
     *
     *  @return the locale 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.Locale getLocale();


    /**
     *  Tests if an agent is authenticated to this session. 
     *
     *  @return <code> true </code> if valid authentication credentials exist, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAuthenticated();


    /**
     *  Gets the <code> Id </code> of the agent authenticated to this session. 
     *  This is the agent for which credentials are used either acquired 
     *  natively or via an <code> OsidProxyManager. </code> 
     *
     *  @return the authenticated agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isAuthenticated() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuthenticatedAgentId();


    /**
     *  Gets the agent authenticated to this session. This is the agent for 
     *  which credentials are used either acquired natively or via an <code> 
     *  OsidProxyManager. </code> 
     *
     *  @return the authenticated agent 
     *  @throws org.osid.IllegalStateException <code> isAuthenticated() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getAuthenticatedAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the effective agent in use by this 
     *  session. If <code> isAuthenticated() </code> is true, then the 
     *  effective agent may be the same as the agent returned by <code> 
     *  getAuthenticatedAgent(). </code> If <code> isAuthenticated() </code> 
     *  is <code> false, </code> then the effective agent may be a default 
     *  agent used for authorization by an unknwon or anonymous user. 
     *
     *  @return the effective agent 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEffectiveAgentId();


    /**
     *  Gets the effective agent in use by this session. If <code> 
     *  isAuthenticated() </code> is true, then the effective agent may be the 
     *  same as the agent returned by <code> getAuthenticatedAgent(). </code> 
     *  If <code> isAuthenticated() </code> is <code> false, </code> then the 
     *  effective agent may be a default agent used for authorization by an 
     *  unknwon or anonymous user. 
     *
     *  @return the effective agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getEffectiveAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the service date which may be the current date or the effective 
     *  date in which this session exists. 
     *
     *  @return the service date 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.util.Date getDate();


    /**
     *  Gets the rate of the service clock. 
     *
     *  @return the clock rate 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getClockRate();


    /**
     *  Gets the <code> DisplayText </code> format <code> Type </code> 
     *  preference in effect for this session. 
     *
     *  @return the effective <code> DisplayText </code> format <code> Type 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getFormatType();


    /**
     *  Tests for the availability of transactions. 
     *
     *  @return <code> true </code> if transaction methods are available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTransactions();


    /**
     *  Starts a new transaction for this sesson. Transactions are a means for 
     *  an OSID to provide an all-or-nothing set of operations within a 
     *  session and may be used to coordinate this service from an external 
     *  transaction manager. A session supports one transaction at a time. 
     *  Starting a second transaction before the previous has been committed 
     *  or aborted results in an <code> ILLEGAL_STATE </code> error. 
     *
     *  @return a new transaction 
     *  @throws org.osid.IllegalStateException a transaction is already open 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException transactions not supported 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTransactions() </code> is true. 
     *  @notes  Ideally, a provider that supports transactions should 
     *          guarantee atomicity, consistency, isolation and durability in 
     *          a 2 phase commit process. This is not always possible in 
     *          distributed systems and a transaction provider may simply 
     *          allow for a means of processing bulk updates. 
     *          
     *          To maximize interoperability, providers should honor the 
     *          one-transaction-at-a-time rule. 
     */

    public org.osid.transaction.Transaction startTransaction()
        throws org.osid.OperationFailedException;
}
