//
// org.osid.Syntax
//
//     Specifies the OSID definition for org.osid.Syntax.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid;


/**
 *  This enumeration contains the possible value types. 
 */

public enum Syntax {

    /** No value available. */
    NONE("None", "No value available."),

    /** A truth value of <code> true </code> or <code> false. </code> */
    BOOLEAN("Boolean", "A truth value of true or false. "),

    /** A byte value. */
    BYTE("Byte", "A byte value."),

    /** A non-negative number supporting a 64-bit value ( <code> 
        0..9,223,372,036,854,775,808 </code> ). <code> Cardinal </code> 
        numbers should be used to represent numbers such as sizes and counters 
        where negative numbers have no meaning. */
    CARDINAL("Cardinal", "A non-negative number supporting a 64-bit value (0..9,223,372,036,854,775,808). Cardinal numbers should be used to represent numbers such as sizes and counters where negative numbers have no meaning."),

    /** A point in space. */
    COORDINATE("Coordinate", "A point in space."),

    /** An amount of money. */
    CURRENCY("Currency", "An amount of money."),

    /** A point in time. */
    DATETIME("Datetime", "A point in time."),

    /** A signed arbitrary precision decimal number. */
    DECIMAL("Decimal", "A signed arbitrary precision decimal number."),

    /** A localizable display string. */
    DISPLAYTEXT("Displaytext", "A localizable display string."),

    /** A measure between two <code> Coordinates. </code> */
    DISTANCE("Distance", "A measure between two Coordinates. "),

    /** A measure between two <code> DateTimes. </code> */
    DURATION("Duration", "A measure between two DateTimes. "),

    /** A direction of motion. */
    HEADING("Heading", "A direction of motion."),

    /** An OSID <code> Id </code> . */
    ID("Id", "An OSID Id ."),

    /** A number supporting a 64-bit value 
        
        ( <code> -9,223,372,036,854,775,808.. 9,223,372,036,854,775,808 
        </code> ). */
    INTEGER("Integer", "A number supporting a 64-bit value (-9,223,372,036,854,775,808.. 9,223,372,036,854,775,808)."),

    /** An arbitrary object. */
    OBJECT("Object", "An arbitrary object."),

    /** An OSID <code> SpatialUnit. </code> */
    SPATIALUNIT("Spatialunit", "An OSID SpatialUnit. "),

    /** How fast something moves. */
    SPEED("Speed", "How fast something moves."),

    /** A string of characters. */
    STRING("String", "A string of characters."),

    /** A time of day. */
    TIME("Time", "A time of day."),

    /** An OSID <code> Type. </code> */
    TYPE("Type", "An OSID Type. "),

    /** A version. */
    VERSION("Version", "A version.");


    private final String displayName;
    private final String description;

    Syntax(String displayName, String description) {
        this.displayName = displayName;
        this.description = description;
    }

    public String getDisplayName() {
        return (this.displayName);
    }

    public String getDescription() {
        return (this.description);
    }
}
