//
// org.osid.acknowledgement.AcknowledgementProfile
//
//     The OSID Java specification for org.osid.acknowledgement.AcknowledgementProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>The acknowledgement profile describes the interoperability among 
 *  acknowledgement services. </p>
 */

public interface AcknowledgementProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any billing federation is exposed. Federation is exposed when 
     *  a specific billing may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  billings appears as a single billing. 
     *
     *  @return <code> true </code> if visible federation is supproted, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a credit lookup service. 
     *
     *  @return <code> true </code> if credit lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditLookup();


    /**
     *  Tests for the availability of a credit query service. 
     *
     *  @return <code> true </code> if credit query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditQuery();


    /**
     *  Tests if searching for credits is available. 
     *
     *  @return <code> true </code> if credit search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditSearch();


    /**
     *  Tests if managing for credits is available. 
     *
     *  @return <code> true </code> if a credit adminstrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditAdmin();


    /**
     *  Tests if credit notification is available. 
     *
     *  @return <code> true </code> if credit notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditNotification();


    /**
     *  Tests if a credit to billing lookup session is available. 
     *
     *  @return <code> true </code> if credit billing lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditBilling();


    /**
     *  Tests if a credit to billing assignment session is available. 
     *
     *  @return <code> true </code> if credit billing assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditBillingAssignment();


    /**
     *  Tests if a credit smart billing session is available. 
     *
     *  @return <code> true </code> if credit smart billing is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditSmartBilling();


    /**
     *  Tests for the availability of an billing lookup service. 
     *
     *  @return <code> true </code> if billing lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingLookup();


    /**
     *  Tests if querying billings is available. 
     *
     *  @return <code> true </code> if billing query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingQuery();


    /**
     *  Tests if searching for billings is available. 
     *
     *  @return <code> true </code> if billing search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingSearch();


    /**
     *  Tests for the availability of a billing administrative service for 
     *  creating and deleting billings. 
     *
     *  @return <code> true </code> if billing administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingAdmin();


    /**
     *  Tests for the availability of a billing notification service. 
     *
     *  @return <code> true </code> if billing notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsBillingNotification();


    /**
     *  Tests for the availability of a billing hierarchy traversal service. 
     *
     *  @return <code> true </code> if billing hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingHierarchy();


    /**
     *  Tests for the availability of a billing hierarchy design service. 
     *
     *  @return <code> true </code> if billing hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsBillingHierarchyDesign();


    /**
     *  Tests for the availability of an acknowledgement batch service. 
     *
     *  @return <code> true </code> if an acknowledgement batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAcknowledgementBatch();


    /**
     *  Gets the supported <code> Credit </code> record types. 
     *
     *  @return a list containing the supported credit record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCreditRecordTypes();


    /**
     *  Tests if the given <code> Credit </code> record type is supported. 
     *
     *  @param  creditRecordType a <code> Type </code> indicating a <code> 
     *          Credit </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> creditRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditRecordType(org.osid.type.Type creditRecordType);


    /**
     *  Gets the supported credit search record types. 
     *
     *  @return a list containing the supported credit search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCreditSearchRecordTypes();


    /**
     *  Tests if the given credit search record type is supported. 
     *
     *  @param  creditSearchRecordType a <code> Type </code> indicating a 
     *          credit record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> creditSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditSearchRecordType(org.osid.type.Type creditSearchRecordType);


    /**
     *  Gets the supported <code> Billing </code> record types. 
     *
     *  @return a list containing the supported billing record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBillingRecordTypes();


    /**
     *  Tests if the given <code> Billing </code> record type is supported. 
     *
     *  @param  billingRecordType a <code> Type </code> indicating a <code> 
     *          Billing </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> billingRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingRecordType(org.osid.type.Type billingRecordType);


    /**
     *  Gets the supported billing search record types. 
     *
     *  @return a list containing the supported billing search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBillingSearchRecordTypes();


    /**
     *  Tests if the given billing search record type is supported. 
     *
     *  @param  billingSearchRecordType a <code> Type </code> indicating a 
     *          billing record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> billingSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingSearchRecordType(org.osid.type.Type billingSearchRecordType);
}
