//
// org.osid.acknowledgement.BillingHierarchySession
//
//     The OSID Java specification for org.osid.acknowledgement.BillingHierarchySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> 
 *  Billing </code> objects. Each node in the hierarchy is a unique <code> 
 *  Billing. </code> The hierarchy may be traversed recursively to establish 
 *  the tree structure through <code> getParentBillings() </code> and <code> 
 *  getChildBillings(). </code> To relate these <code> Ids </code> to another 
 *  OSID, <code> getBillingNodes() </code> can be used for retrievals that can 
 *  be used for bulk lookups in other OSIDs. Any <code> Billing </code> 
 *  available in the Acknowledgement OSID is known to this hierarchy but does 
 *  not appear in the hierarchy traversal until added as a root node or a 
 *  child of another node. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentBillings() </code> or <code> getChildBillings() </code> 
 *  in lieu of a <code> PERMISSION_DENIED </code> error that may disrupt the 
 *  traversal through authorized pathways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: billing elements may be silently omitted or 
 *      re-ordered </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *  </ul>
 *  
 */

public interface BillingHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBillingHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getBillingHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessBillingHierarchy();


    /**
     *  The returns from the billing methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBillingView();


    /**
     *  A complete view of the <code> Billing </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBillingView();


    /**
     *  Gets the root billing <code> Ids </code> in this hierarchy. 
     *
     *  @return the root billing <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootBillingIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root billings in the billing hierarchy. A node with no 
     *  parents is an orphan. While all billing <code> Ids </code> are known 
     *  to the hierarchy, an orphan does not appear in the hierarchy unless 
     *  explicitly added as a root node or child of another node. 
     *
     *  @return the root billings 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.acknowledgement.BillingList getRootBillings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> Billing </code> has any parents. 
     *
     *  @param  billingId a billing <code> Id </code> 
     *  @return <code> true </code> if the billing has parents, f <code> alse 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentBillings(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of billing. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  billingId the <code> Id </code> of a billing 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> billingId, </code> f <code> alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          billingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfBilling(org.osid.id.Id id, 
                                     org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given billing. 
     *
     *  @param  billingId a billing <code> Id </code> 
     *  @return the parent <code> Ids </code> of the billing 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentBillingIds(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent billings of the given <code> id. </code> 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *          to query 
     *  @return the parent billings of the <code> id </code> 
     *  @throws org.osid.NotFoundException a <code> Billing </code> identified 
     *          by <code> Id is </code> not found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingList getParentBillings(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of a billing. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  billingId the <code> Id </code> of a billing 
     *  @return <code> tru </code> e if this <code> id </code> is an ancestor 
     *          of <code> billingId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          billingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfBilling(org.osid.id.Id id, 
                                       org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a billing has any children. 
     *
     *  @param  billingId a billing <code> Id </code> 
     *  @return <code> true </code> if the <code> billingId </code> has 
     *          children, <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> bobillingId is null okId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildBillings(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a billing is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  billingId the <code> Id </code> of a billing 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> billingId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          billingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfBilling(org.osid.id.Id id, 
                                    org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given billing. 
     *
     *  @param  billingId the <code> Id </code> to query 
     *  @return the children of the billing 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildBillingIds(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child billings of the given <code> id. </code> 
     *
     *  @param  billingId the <code> Id </code> of the <code> Billing </code> 
     *          to query 
     *  @return the child billings of the <code> id </code> 
     *  @throws org.osid.NotFoundException a <code> Billing </code> identified 
     *          by <code> Id is </code> not found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingList getChildBillings(org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of a billing. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  billingId the <code> Id </code> of a billing 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> billingId, </code> <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          billingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfBilling(org.osid.id.Id id, 
                                         org.osid.id.Id billingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given billing. 
     *
     *  @param  billingId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the node. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the node. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given node, <code> false </code> to omit the siblings 
     *  @return a billing node 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getBillingNodeIds(org.osid.id.Id billingId, 
                                                     long ancestorLevels, 
                                                     long descendantLevels, 
                                                     boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given billing. 
     *
     *  @param  billingId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the node. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the node. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given node, <code> false </code> to omit the siblings 
     *  @return a billing node 
     *  @throws org.osid.NotFoundException <code> billingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.BillingNode getBillingNodes(org.osid.id.Id billingId, 
                                                                long ancestorLevels, 
                                                                long descendantLevels, 
                                                                boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
