//
// org.osid.acknowledgement.BillingQuery
//
//     The OSID Java specification for org.osid.acknowledgement.BillingQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This is the query for searching for billings. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface BillingQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the credit <code> Id </code> for this query to match credits 
     *  assigned to billings. 
     *
     *  @param  creditId a credit <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> creditId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreditId(org.osid.id.Id creditId, boolean match);


    /**
     *  Clears all credit <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditIdTerms();


    /**
     *  Tests if a credit query is available. 
     *
     *  @return <code> true </code> if a credit query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreditQuery();


    /**
     *  Gets the query for a billing. 
     *
     *  @return the credit query 
     *  @throws org.osid.UnimplementedException <code> supportsCreditQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreditQuery() </code> is <code> true. </code> 
     */

    public org.osid.acknowledgement.CreditQuery getCreditQuery();


    /**
     *  Matches billings with any credit. 
     *
     *  @param  match <code> true </code> to match billings with any credit, 
     *          <code> false </code> to match billings with no credits 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCredit(boolean match);


    /**
     *  Clears all credit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditTerms();


    /**
     *  Sets the billing <code> Id </code> for this query to match billings 
     *  that have the specified billing as an ancestor. 
     *
     *  @param  billingId a billing <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorBillingId(org.osid.id.Id billingId, boolean match);


    /**
     *  Clears all ancestor billing <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBillingIdTerms();


    /**
     *  Tests if a <code> BillingQuery </code> is available. 
     *
     *  @return <code> true </code> if a billing query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorBillingQuery();


    /**
     *  Gets the query for a billing. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the billing query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorBillingQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorBillingQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.BillingQuery getAncestorBillingQuery();


    /**
     *  Matches billings with any ancestor. 
     *
     *  @param  match <code> true </code> to match billings with any ancestor, 
     *          <code> false </code> to match root billings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorBilling(boolean match);


    /**
     *  Clears all ancestor billing terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBillingTerms();


    /**
     *  Sets the billing <code> Id </code> for this query to match billings 
     *  that have the specified billing as a descendant. 
     *
     *  @param  billingId a billing <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> billingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantBillingId(org.osid.id.Id billingId, 
                                         boolean match);


    /**
     *  Clears all descendant billing <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBillingIdTerms();


    /**
     *  Tests if a <code> BillingQuery </code> is available. 
     *
     *  @return <code> true </code> if a billing query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantBillingQuery();


    /**
     *  Gets the query for a billing. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the billing query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantBillingQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantBillingQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.acknowledgement.BillingQuery getDescendantBillingQuery();


    /**
     *  Matches billings with any descendant. 
     *
     *  @param  match <code> true </code> to match billings with any 
     *          descendant, <code> false </code> to match leaf billings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantBilling(boolean match);


    /**
     *  Clears all descendant billing terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBillingTerms();


    /**
     *  Gets the record query corresponding to the given <code> Billing 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  billingRecordType a billing record type 
     *  @return the billing query record 
     *  @throws org.osid.NullArgumentException <code> billingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(billingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.records.BillingQueryRecord getBillingQueryRecord(org.osid.type.Type billingRecordType)
        throws org.osid.OperationFailedException;
}
