//
// org.osid.acknowledgement.CreditLookupSession
//
//     The OSID Java specification for org.osid.acknowledgement.CreditLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session defines methods for retrieving credits. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated billing view: All credit methods in this session 
 *      operate, retrieve and pertain to credits defined explicitly in the 
 *      current billing. Using an isolated view is useful for managing credits 
 *      with the <code> CreditAdminSession. </code> </li> 
 *      <li> federated billing view: All credit lookup methods in this session 
 *      operate, retrieve and pertain to all credits defined in this billing 
 *      and any other billings implicitly available in this billing through 
 *      billing inheritence. </li> 
 *      <li> effective credit view: All credit lookup methods return credits 
 *      where the current date falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective credit view: Credits of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBillingView() </code> and <code> 
 *  useIsolatedBillingView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface CreditLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Billing </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Billing Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBillingId();


    /**
     *  Gets the <code> Billing </code> associated with this session. 
     *
     *  @return the billing 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.Billing getBilling()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this billing. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if billing reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCredits();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCreditView();


    /**
     *  A complete view of the <code> Credit </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCreditView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include credits in billings which are children of this billing in the 
     *  billing hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBillingView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this billing only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBillingView();


    /**
     *  Only credits whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveCreditView();


    /**
     *  All credits of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveCreditView();


    /**
     *  Gets the <code> Credit </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Credit </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Credit </code> and retained for compatibility. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> to 
     *          retrieve 
     *  @return the returned <code> Credit </code> 
     *  @throws org.osid.NotFoundException no <code> Credit </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> creditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.Credit getCredit(org.osid.id.Id creditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  credits specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible credits may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  creditIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Credit list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> creditIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByIds(org.osid.id.IdList creditIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> corresponding to the given credit 
     *  genus <code> Type </code> which does not include credits of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  credits or an error results. Otherwise, the returned list may contain 
     *  only those credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  creditGenusType a credits genus type 
     *  @return the returned <code> Credit list </code> 
     *  @throws org.osid.NullArgumentException <code> creditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusType(org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> corresponding to the given credit 
     *  genus <code> Type </code> and include any additional credits with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  credits or an error results. Otherwise, the returned list may contain 
     *  only those credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  creditGenusType a credit genus type 
     *  @return the returned <code> Credit list </code> 
     *  @throws org.osid.NullArgumentException <code> creditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByParentGenusType(org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> containing the given credit record 
     *  <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  creditRecordType a credit record type 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.NullArgumentException <code> creditRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByRecordType(org.osid.type.Type creditRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective credits and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from or to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsOnDate(org.osid.calendaring.DateTime from, 
                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of credits of the given genus type and effective entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective credits and those currently expired are 
     *  returned. 
     *
     *  @param  creditGenusType a credit genus <code> Type </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> creditGenusType, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusTypeOnDate(org.osid.type.Type creditGenusType, 
                                                                           org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> for the given resource <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  credits corresponding to the given peer, including duplicates, or an 
     *  error results if a credit is inaccessible. Otherwise, inaccessible 
     *  <code> Credits </code> may be omitted from the list. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of credits for a resource and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective credits and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsForResourceOnDate(org.osid.id.Id resourceId, 
                                                                           org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of credits by a genus type for a resource. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  creditGenusType a credit genus <code> Type </code> 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.NullArgumentException <code> creditGenusType </code> 
     *          or <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusTypeForResource(org.osid.id.Id resourceId, 
                                                                                org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of credits by genus type for a resource and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective credits and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  creditGenusType a credit genus <code> Type </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          creditGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusTypeForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                      org.osid.type.Type creditGenusType, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> for the given reference <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  credits corresponding to the given peer, including duplicates, or an 
     *  error results if a credit is inaccessible. Otherwise, inaccessible 
     *  <code> Credits </code> may be omitted from the list. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsForReference(org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of credits for a reference and effective entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective credits and those currently expired are 
     *  returned. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsForReferenceOnDate(org.osid.id.Id referenceId, 
                                                                            org.osid.calendaring.DateTime from, 
                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of credits by a genus type for a reference. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  creditGenusType a credit genus <code> Type </code> 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> creditGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusTypeForReference(org.osid.id.Id referenceId, 
                                                                                 org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of credits of the given genus type for a reference and 
     *  effective entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective credits and those currently expired are 
     *  returned. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  creditGenusType a credit genus <code> Type </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId, 
     *          creditGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusTypeForReferenceOnDate(org.osid.id.Id referenceId, 
                                                                                       org.osid.type.Type creditGenusType, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> for the given resource and reference. 
     *  
     *  In plenary mode, the returned list contains all of the credits 
     *  corresponding to the given resource and reference, including 
     *  duplicates, or an error results if a credit is inaccessible. 
     *  Otherwise, inaccessible <code> Credits </code> may be omitted from the 
     *  list. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  referenceId a reference <code> Id </code> 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsForResourceAndReference(org.osid.id.Id resourceId, 
                                                                                 org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> corresponding to the given resource 
     *  and reference and effective entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the credits 
     *  corresponding to the given peer, including duplicates, or an error 
     *  results if a credit is inaccessible. Otherwise, inaccessible <code> 
     *  Credits </code> may be omitted from the list. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsForResourceAndReferenceOnDate(org.osid.id.Id resourceId, 
                                                                                       org.osid.id.Id referenceId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> of the given genus type for the given 
     *  resource and reference. 
     *  
     *  In plenary mode, the returned list contains all of the credits 
     *  corresponding to the given resource and reference, including 
     *  duplicates, or an error results if a credit is inaccessible. 
     *  Otherwise, inaccessible <code> Credits </code> may be omitted from the 
     *  list. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  creditGenusType a credit genus <code> Type </code> 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, </code> 
     *          <code> referenceId, </code> or <code> creditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusTypeForResourceAndReference(org.osid.id.Id resourceId, 
                                                                                            org.osid.id.Id referenceId, 
                                                                                            org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CreditList </code> of the given genus type corresponding 
     *  to the given resource and reference and effective entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the credits 
     *  corresponding to the given peer, including duplicates, or an error 
     *  results if a credit is inaccessible. Otherwise, inaccessible <code> 
     *  Credits </code> may be omitted from the list. 
     *  
     *  In effective mode, credits are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective credits and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  creditGenusType a credit genus <code> Type </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> CreditList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, referenceId, 
     *          </code> <code> creditGenusType, </code> <code> from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCreditsByGenusTypeForResourceAndReferenceOnDate(org.osid.id.Id resourceId, 
                                                                                                  org.osid.id.Id referenceId, 
                                                                                                  org.osid.type.Type creditGenusType, 
                                                                                                  org.osid.calendaring.DateTime from, 
                                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all credits. 
     *  
     *  In plenary mode, the returned list contains all known credits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  credits that are accessible through this session. 
     *  
     *  In effective mode, credits are returned that are currently effective. 
     *  In any effective mode, effective credits and those currently expired 
     *  are returned. 
     *
     *  @return a list of credits 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditList getCredits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
