//
// org.osid.acknowledgement.CreditNotificationSession
//
//     The OSID Java specification for org.osid.acknowledgement.CreditNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Credit </code> objects. This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p>
 */

public interface CreditNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Billing </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Billing Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBillingId();


    /**
     *  Gets the <code> Billing </code> associated with this session. 
     *
     *  @return the billing 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.Billing getBilling()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Credit </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForCreditNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for credits in billings which are children of 
     *  this billing in the billing hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBillingView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this billing only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBillingView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeCreditNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableCreditNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableCreditNotifications();


    /**
     *  Acknowledge a credit notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeCreditNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new credits. <code> 
     *  CreditReceiver.newCredits() </code> is invoked when a new <code> 
     *  Credit </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCredits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new credits by the given credit genus 
     *  <code> Type. </code> <code> CreditReceiver.newCredits() </code> is 
     *  invoked when a new <code> Credit </code> appears in this billing. 
     *
     *  @param  creditGenusType the <code> Id </code> of the reference to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> creditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCreditsByGenusType(org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new credits for the given reference 
     *  <code> Id. </code> <code> CreditReceiver.newCredits() </code> is 
     *  invoked when a new <code> Credit </code> appears in this billing. 
     *
     *  @param  referenceId the reference to monitor 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCreditsForReference(org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new credits for the given resource 
     *  <code> Id. </code> <code> CreditReceiver.newCredits() </code> is 
     *  invoked when a new <code> Credit </code> appears in this billing. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCreditsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated credits. <code> 
     *  CreditReceiver.changedCredits() </code> is invoked when a credit in 
     *  this billing is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCredits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed credits by the given credit 
     *  gfenus <code> Type. </code> <code> CreditReceiver.changedCredits() 
     *  </code> is invoked when a <code> Credit </code> for the reference in 
     *  this billing is changed. 
     *
     *  @param  creditGenusType the genus type of the credit to monitor 
     *  @throws org.osid.NullArgumentException <code> creditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCreditsByGenusType(org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed credits for the given reference 
     *  <code> Id. </code> <code> CreditReceiver.changedCredits() </code> is 
     *  invoked when a <code> Credit </code> for the reference in this billing 
     *  is changed. 
     *
     *  @param  referenceId the <code> Id </code> of the reference to monitor 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCreditsForReference(org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed credits for the given resource 
     *  <code> Id. </code> <code> CreditReceiver.changedCredits() </code> is 
     *  invoked when a <code> Credit </code> for the resource is changed in 
     *  this billing. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCreditsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated credit. <code> 
     *  CreditReceiver.changedCredits() </code> is invoked when the specified 
     *  credit in this billing is changed. 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> to 
     *          monitor 
     *  @throws org.osid.NotFoundException a credit was not found identified 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> creditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCredit(org.osid.id.Id creditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted credits. <code> 
     *  CreditReceiver.deletedCredit() </code> is invoked when a credit is 
     *  removed from this billing. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCredits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted credits by the credit genus 
     *  <code> Type. </code> <code> CreditReceiver.deletedCredit() </code> is 
     *  invoked when a <code> Credit </code> for the reference is removed from 
     *  this billing. 
     *
     *  @param  creditGenusType the genus type of the credit to monitor 
     *  @throws org.osid.NullArgumentException <code> creditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCreditsByGenusType(org.osid.type.Type creditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted credits for the given reference 
     *  <code> Id. </code> <code> CreditReceiver.deletedCredit() </code> is 
     *  invoked when a <code> Credit </code> for the reference is removed from 
     *  this billing. 
     *
     *  @param  referenceId the <code> Id </code> of the reference to monitor 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCreditsForReference(org.osid.id.Id referenceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted credits for the given resource 
     *  <code> Id. </code> <code> CreditReceiver.deletedCredit() </code> is 
     *  invoked when a <code> Credit </code> for the resource is removed from 
     *  this billing. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCreditsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted credit. <code> 
     *  CreditReceiver.deletedCredit() </code> is invoked when the specified 
     *  credit is removed from this billing. 
     *
     *  @param  creditId the <code> Id </code> of the <code> Credit </code> to 
     *          monitor 
     *  @throws org.osid.NotFoundException a credit was not found identified 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> creditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCredit(org.osid.id.Id creditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
