//
// org.osid.acknowledgement.CreditSearchSession
//
//     The OSID Java specification for org.osid.acknowledgement.CreditSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.acknowledgement;


/**
 *  <p>This session provides methods for searching <code> Credit </code> 
 *  objects. The search query is constructed using the <code> CreditQuery. 
 *  </code> The credit record <code> Type </code> also specifies the record 
 *  for the credit query. </p> 
 *  
 *  <p> <code> getCreditsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Credit </code> elements. A more advanced search 
 *  may be performed with <code> getCreditsBySearch(). </code> It accepts a 
 *  <code> CreditSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCreditsBySearch() </code> returns a <code> 
 *  CreditSearchResults </code> that can be used to access the resulting 
 *  <code> CreditList </code> or be used to perform a search within the result 
 *  set through <code> CreditSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated billing view: searches include credits in billings of 
 *      which this billing is a ancestor in the billing hierarchy </li> 
 *      <li> isolated billing view: searches are restricted to credits in this 
 *      billing </li> 
 *  </ul>
 *  
 *  
 *  <p> Credits may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> CreditQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface CreditSearchSession
    extends org.osid.acknowledgement.CreditQuerySession {


    /**
     *  Gets a credit search. 
     *
     *  @return the credit search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditSearch getCreditSearch();


    /**
     *  Gets a credit search order. The <code> CreditSearchOrder </code> is 
     *  supplied to a <code> CreditSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the credit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditSearchOrder getCreditSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  creditQuery the credit query 
     *  @param  creditSearch the credit search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> creditQuery </code> or 
     *          <code> creditSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> creditQuery </code> or 
     *          <code> creditSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditSearchResults getCreditsBySearch(org.osid.acknowledgement.CreditQuery creditQuery, 
                                                                           org.osid.acknowledgement.CreditSearch creditSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a credit query from an inspector. The inspector is available from 
     *  a <code> CreditSearchResults. </code> 
     *
     *  @param  creditQueryInspector a credit query inspector 
     *  @return the credit query 
     *  @throws org.osid.NullArgumentException <code> creditQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> creditQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.acknowledgement.CreditQuery getCreditQueryFromInspector(org.osid.acknowledgement.CreditQueryInspector creditQueryInspector);
}
