//
// org.osid.assessment.AssessmentBasicAuthoringSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentBasicAuthoringSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session defines methods to manage assessment items in an 
 *  assessment. This session is used for simple assessments without sections 
 *  or parts. Updating the items on an assessment authored with sections and 
 *  parts may result in an error. </p>
 */

public interface AssessmentBasicAuthoringSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can author assessments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known mapping methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer authoring operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAuthorAssessments();


    /**
     *  Gets the items in sequence from an assessment. 
     *
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @return list of items 
     *  @throws org.osid.NotFoundException <code> assessmentid </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.ItemList getItems(org.osid.id.Id assessmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an existing <code> Item </code> to an assessment. 
     *
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @param  itemId the <code> Id </code> of the <code> Item </code> 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> or 
     *          <code> itemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> itemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addItem(org.osid.id.Id assessmentId, org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Item </code> from this assessment. 
     *
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @param  itemId the <code> Id </code> of the <code> Item </code> 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> or 
     *          <code> itemId </code> not found or <code> itemId </code> not 
     *          on <code> assessmentid </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> itemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeItem(org.osid.id.Id assessmentId, org.osid.id.Id itemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an existing item to follow another item in an assessment. 
     *
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @param  itemId the <code> Id </code> of an <code> Item </code> 
     *  @param  preceedingItemId the <code> Id </code> of a preceeding <code> 
     *          Item </code> in the sequence 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> is not 
     *          found, or <code> itemId </code> or <code> preceedingItemId 
     *          </code> not on <code> assessmentId </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentId, itemId 
     *          </code> or <code> preceedingItemId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveItem(org.osid.id.Id assessmentId, org.osid.id.Id itemId, 
                         org.osid.id.Id preceedingItemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Sequences existing items in an assessment. 
     *
     *  @param  itemIds the <code> Id </code> of the <code> Items </code> 
     *  @param  assessmentId the <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> is not 
     *          found or an <code> itemId </code> is not on <code> 
     *          assessmentId </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> itemIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderItems(org.osid.id.Id[] itemIds, 
                           org.osid.id.Id assessmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
