//
// org.osid.assessment.AssessmentLookupSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session defines methods for retrieving assessments. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated bank view: All assessment methods in this session 
 *      operate, retrieve and pertain to assessments defined explicitly in the 
 *      current bank. Using an isolated view is useful for managing <code> 
 *      Assessments </code> with the <code> AssessmentAdminSession. </code> 
 *      </li> 
 *      <li> federated bank view: All assessment methods in this session 
 *      operate, retrieve and pertain to all assessments defined in this bank 
 *      and any other assessments implicitly available in this bank through 
 *      bank inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBankView() </code> and <code> 
 *  useIsolatedBankView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Assessments may have a record indicated by their respective types. The 
 *  record is accessed via the <code> Assessment. </code> The returns may not 
 *  be cast directly from the returns in the lookup methods. </p>
 */

public interface AssessmentLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Assessment </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAssessments();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as assessment, and not result in an error. 
     *  This view is used when greater interoperability is desired at the 
     *  expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAssessmentView();


    /**
     *  A complete view of the <code> Assessment </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAssessmentView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include assessments in banks which are children of this bank in the 
     *  bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Gets the <code> Assessment </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Assessment 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Assessment </code> and retained for compatibility. 
     *
     *  @param  assessmentId <code> Id </code> of the <code> Assessment 
     *          </code> 
     *  @return the assessment 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.assessment.Assessment getAssessment(org.osid.id.Id assessmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the assessments specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> Assessments </code> may be omitted from 
     *  the list and may present the elements in any order including returning 
     *  a unique set. 
     *
     *  @param  assessmentIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Assessment </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException assessment failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAssessmentsByIds(org.osid.id.IdList assessmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentList </code> corresponding to the given 
     *  assessment genus <code> Type </code> which does not include 
     *  assessments of types derived from the specified <code> Type. </code> 
     *  In plenary mode, the returned list contains all known assessments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  assessments that are accessible through this session. 
     *
     *  @param  assessmentGenusType an assessment genus type 
     *  @return the returned <code> Assessment </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAssessmentsByGenusType(org.osid.type.Type assessmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentList </code> corresponding to the given 
     *  assessment genus <code> Type </code> and include any additional 
     *  assessments with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  assessments or an error results. Otherwise, the returned list may 
     *  contain only those assessments that are accessible through this 
     *  session. 
     *
     *  @param  assessmentGenusType an assessment genus type 
     *  @return the returned <code> Assessment </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAssessmentsByParentGenusType(org.osid.type.Type assessmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentList </code> corresponding to the given 
     *  assessment record <code> Type. </code> The set of assessments 
     *  implementing the given record type is returned. In plenary mode, the 
     *  returned list contains all known assessments or an error results. 
     *  Otherwise, the returned list may contain only those assessments that 
     *  are accessible through this session. 
     *
     *  @param  assessmentRecordType an assessment record type 
     *  @return the returned <code> Assessment </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAssessmentsByRecordType(org.osid.type.Type assessmentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Assessments. </code> In plenary mode, the returned 
     *  list contains all known assessments or an error results. Otherwise, 
     *  the returned list may contain only those assessments that are 
     *  accessible through this session. 
     *
     *  @return a list of <code> Assessments </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAssessments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
