//
// org.osid.assessment.AssessmentOfferedAdminSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentOfferedAdminSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session creates, updates, and deletes <code> AssessmentsOffered. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AssessmentOffered, </code> an <code> AssessmentOfferedForm </code> 
 *  is requested using <code> getAssessmentOfferedFormForCreate() </code> 
 *  specifying the assessment and desired record <code> Types </code> or none 
 *  if no record <code> Types </code> are needed. The returned <code> 
 *  AssessmentOfferedForm </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once the <code> AssessmentOfferedForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> 
 *  AssessmentOfferedForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> AssessmentOfferedForms </code> are requested to 
 *  the <code> AssessmentOffered </code> <code> Id </code> that is to be 
 *  updated using <code> getAssessmentOfferedFormForUpdate(). </code> 
 *  Similarly, the <code> AssessmentOfferedForm </code> has metadata about the 
 *  data that can be updated and it can perform validation before submitting 
 *  the update. The <code> AssessmentOfferedForm </code> can only be used once 
 *  for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> AssessmentsOffered. </code> To 
 *  unmap an <code> AssessmentOffered </code> from the current <code> Bank, 
 *  </code> the <code> AssessmentOfferedBankAssignmentSession </code> should 
 *  be used. These delete operations attempt to remove the <code> 
 *  AssessmentOffered </code> itself thus removing it from all known <code> 
 *  Bank </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AssessmentOfferedAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> AssessmentOffered </code> 
     *  objects. A return of true does not guarantee successful 
     *  authoriization. A return of false indicates that it is known creating 
     *  an <code> AssessmentOffered </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentOffered </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentsOffered();


    /**
     *  Tests if this user can create a single <code> AssessmentOffered 
     *  </code> using the desired record types. While <code> 
     *  AssessmentManager.getAssessmentOfferedRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  AssessmentOffered. </code> Providing an empty array tests if an <code> 
     *  AssessmentOffered </code> can be created with no records. 
     *
     *  @param  assessmentOfferedRecordTypes array of assessment offered 
     *          record types 
     *  @return <code> true </code> if <code> AssessmentOffered </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentOfferedWithRecordTypes(org.osid.type.Type[] assessmentOfferedRecordTypes);


    /**
     *  Gets the assessment offered form for creating new assessments offered. 
     *  A new form should be requested for each create transaction. 
     *
     *  @param  assessmentId the <code> Id </code> of the related <code> 
     *          Assessment </code> 
     *  @param  assessmentOfferedRecordTypes array of assessment offered 
     *          record types to be included in the create operation or an 
     *          empty list if none 
     *  @return the assessment offered form 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> assessmentOfferedRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedForm getAssessmentOfferedFormForCreate(org.osid.id.Id assessmentId, 
                                                                                       org.osid.type.Type[] assessmentOfferedRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AssessmentOffered. </code> 
     *
     *  @param  assessmentOfferedForm the form for this <code> 
     *          AssessmentOffered </code> 
     *  @return the new <code> AssessmentOffered </code> 
     *  @throws org.osid.IllegalStateException <code> assessmentOffreredForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> assessmentForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentForm </code> 
     *          did not originate from <code> getAssessmentFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOffered createAssessmentOffered(org.osid.assessment.AssessmentOfferedForm assessmentOfferedForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AssessmentOffered </code> 
     *  objects. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known updating an <code> 
     *  AssessmentOffered </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer update operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Assessment </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAssessmentsOffered();


    /**
     *  Gets the assessment offered form for updating an existing assessment 
     *  offered. A new assessment offered form should be requested for each 
     *  update transaction. 
     *
     *  @param  assessmentOfferedId the <code> Id </code> of the <code> 
     *          AssessmentOffered </code> 
     *  @return the assessment offered form 
     *  @throws org.osid.NotFoundException <code> assessmentOfferedId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedForm getAssessmentOfferedFormForUpdate(org.osid.id.Id assessmentOfferedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing assessment offered. 
     *
     *  @param  assessmentOfferedForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> assessmentOffreredForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentForm </code> 
     *          did not originate from <code> getAssessmentFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAssessmentOffered(org.osid.assessment.AssessmentOfferedForm assessmentOfferedForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AssessmentsOffered. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting an <code> 
     *  AssessmentOffered </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer a delete operations to unauthorized users. 
     *
     *  @return <code> false </code> if <code> AssessmentOffered </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAssessmentsOffered();


    /**
     *  Deletes an <code> AssessmentOffered. </code> 
     *
     *  @param  assessmentOfferedId the <code> Id </code> of the <code> 
     *          AssessmentOffered </code> to remove 
     *  @throws org.osid.NotFoundException <code> assessmentOfferedId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAssessmentOffered(org.osid.id.Id assessmentOfferedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  AssessmentsOffered. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentOffered </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAssessmentOfferedAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentOffered </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> AssessmentOffered </code> is determined by the provider. 
     *  The new <code> Id </code> is an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another assessment offered, it is 
     *  reassigned to the given assessment offered <code> Id. </code> 
     *
     *  @param  assessmentOfferedId the <code> Id </code> of an <code> 
     *          AssessmentOffered </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> assessmentOfferedId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAssessmentOffered(org.osid.id.Id assessmentOfferedId, 
                                       org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
