//
// org.osid.assessment.AssessmentOfferedSearchSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentOfferedSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AssessmentOffered </code> objects. The search query is constructed using 
 *  the <code> AssessmentOfferedQuery. </code> </p> 
 *  
 *  <p> <code> getAssessmentsOfferedByQuery() </code> is the basic search 
 *  method and returns a list of <code> AssessmentOffered </code> elements. A 
 *  more advanced search may be performed with <code> 
 *  getAssessmentsOfferedBySearch(). </code> It accepts an <code> 
 *  AssessmentOfferedSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAssessmentsOfferedBySearch() </code> returns an <code> 
 *  AssessmentOfferedSearchResults </code> that can be used to access the 
 *  resulting <code> AssessmentOfferedList </code> or be used to perform a 
 *  search within the result set through <code> AssessmentOfferedSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bank view: searches include assessments offered in 
 *      banks of which this bank is an ancestor in the bank hierarchy </li> 
 *      <li> isolated bank view: searches are restricted to assessments 
 *      offered in this bank </li> 
 *  </ul>
 *  
 *  
 *  <p> Assessments offered may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  AssessmentOfferedQuery. </code> </p>
 */

public interface AssessmentOfferedSearchSession
    extends org.osid.assessment.AssessmentOfferedQuerySession {


    /**
     *  Gets an assessment offered search. 
     *
     *  @return the assessment offered search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedSearch getAssessmentOfferedSearch();


    /**
     *  Gets an assessment offered search order. The <code> 
     *  AssessmentOfferedSearchOrder </code> is supplied to an <code> 
     *  AssessmentOfferedSearch </code> to specify the ordering of results. 
     *
     *  @return the assessment offered search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedSearchOrder getAssessmentOfferedSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  assessmentOfferedQuery the assessment offered query 
     *  @param  assessmentOfferedSearch the assessment offered search 
     *  @return the assessment offered search results 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedQuery 
     *          </code> or <code> assessmentOfferedSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentOfferedQuery 
     *          </code> or <code> assessmentOfferedSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedSearchResults getAssessmentsOfferedBySearch(org.osid.assessment.AssessmentOfferedQuery assessmentOfferedQuery, 
                                                                                            org.osid.assessment.AssessmentOfferedSearch assessmentOfferedSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessment offered query from an inspector. The inspector is 
     *  available from an <code> AssessmentOfferedSearchResults. </code> 
     *
     *  @param  assessmentOfferedQueryInspector an assessment offered query 
     *          inspector 
     *  @return the assessment offered query 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          assessmentOfferedQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOfferedQuery getAssessmentOfferedQueryFromInspector(org.osid.assessment.AssessmentOfferedQueryInspector assessmentOfferedQueryInspector);
}
