//
// org.osid.assessment.AssessmentProfile
//
//     The OSID Java specification for org.osid.assessment.AssessmentProfile.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>The <code> AssessmentProfile </code> describes the interoperability 
 *  among assessment services. </p>
 */

public interface AssessmentProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a session is available to lookup taken assessments for the 
     *  authenticated agent. 
     *
     *  @return <code> true </code> if my assessment taken session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyAssessmentTaken();


    /**
     *  Tests for the availability of a assessment service which is the 
     *  service for taking and examining assessments taken. 
     *
     *  @return <code> true </code> if assessment is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessment();


    /**
     *  Tests for the availability of an assessment rsults service. 
     *
     *  @return <code> true </code> if assessment results is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentResults();


    /**
     *  Tests if an item lookup service is supported. 
     *
     *  @return true if item lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemLookup();


    /**
     *  Tests if an item query service is supported. 
     *
     *  @return <code> true </code> if item query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Tests if an item search service is supported. 
     *
     *  @return <code> true </code> if item search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSearch();


    /**
     *  Tests if an item administrative service is supported. 
     *
     *  @return <code> true </code> if item admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemAdmin();


    /**
     *  Tests if item notification is supported. Messages may be sent when 
     *  items are created, modified, or deleted. 
     *
     *  @return <code> true </code> if item notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemNotification();


    /**
     *  Tests if an item to bank lookup session is available. 
     *
     *  @return <code> true </code> if item bank lookup session is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemBank();


    /**
     *  Tests if an item to bank assignment session is available. 
     *
     *  @return <code> true </code> if item bank assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemBankAssignment();


    /**
     *  Tests if an item smart bank session is available. 
     *
     *  @return <code> true </code> if item smart bank session is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSmartBank();


    /**
     *  Tests if an assessment lookup service is supported. An assessment 
     *  lookup service defines methods to access assessments. 
     *
     *  @return true if assessment lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentLookup();


    /**
     *  Tests if an assessment query service is supported. 
     *
     *  @return <code> true </code> if assessment query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentQuery();


    /**
     *  Tests if an assessment search service is supported. 
     *
     *  @return <code> true </code> if assessment search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentSearch();


    /**
     *  Tests if an assessment administrative service is supported. 
     *
     *  @return <code> true </code> if assessment admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentAdmin();


    /**
     *  Tests if assessment notification is supported. Messages may be sent 
     *  when assessments are created, modified, or deleted. 
     *
     *  @return <code> true </code> if assessment notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentNotification();


    /**
     *  Tests if an assessment to bank lookup session is available. 
     *
     *  @return <code> true </code> if assessment bank lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentBank();


    /**
     *  Tests if an assessment to bank assignment session is available. 
     *
     *  @return <code> true </code> if assessment bank assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentBankAssignment();


    /**
     *  Tests if an assessment smart bank session is available. 
     *
     *  @return <code> true </code> if assessment smart bank session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentSmartBank();


    /**
     *  Tests if an assessment basic authoring session is available. 
     *
     *  @return <code> true </code> if assessment basic authoring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentBasicAuthoring();


    /**
     *  Tests if an assessment offered lookup service is supported. 
     *
     *  @return true if assessment offered lookup is supported, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedLookup();


    /**
     *  Tests if an assessment offered query service is supported. 
     *
     *  @return <code> true </code> if assessment offered query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedQuery();


    /**
     *  Tests if an assessment offered search service is supported. 
     *
     *  @return <code> true </code> if assessment offered search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedSearch();


    /**
     *  Tests if an assessment offered administrative service is supported. 
     *
     *  @return <code> true </code> if assessment offered admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedAdmin();


    /**
     *  Tests if assessment offered notification is supported. Messages may be 
     *  sent when offered assessments are created, modified, or deleted. 
     *
     *  @return <code> true </code> if assessment offered notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedNotification();


    /**
     *  Tests if an assessment offered to bank lookup session is available. 
     *
     *  @return <code> true </code> if assessment offered bank lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedBank();


    /**
     *  Tests if an assessment offered to bank assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if assessment offered bank assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedBankAssignment();


    /**
     *  Tests if an assessment offered smart bank session is available. 
     *
     *  @return <code> true </code> if assessment offered smart bank session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedSmartBank();


    /**
     *  Tests if an assessment taken lookup service is supported. 
     *
     *  @return <code> true </code> if assessment taken lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenLookup();


    /**
     *  Tests if an assessment taken query service is supported. 
     *
     *  @return <code> true </code> if assessment taken query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenQuery();


    /**
     *  Tests if an assessment taken search service is supported. 
     *
     *  @return <code> true </code> if assessment taken search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenSearch();


    /**
     *  Tests if an assessment taken administrative service is supported which 
     *  is used to instantiate an assessment offered. 
     *
     *  @return <code> true </code> if assessment taken admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenAdmin();


    /**
     *  Tests if assessment taken notification is supported. Messages may be 
     *  sent when items are created, modified, or deleted. 
     *
     *  @return <code> true </code> if assessment taken notification is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenNotification();


    /**
     *  Tests if an assessment taken to bank lookup session is available. 
     *
     *  @return <code> true </code> if assessment taken bank lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenBank();


    /**
     *  Tests if an assessment taken to bank assignment session is available. 
     *
     *  @return <code> true </code> if assessment taken bank assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenBankAssignment();


    /**
     *  Tests if an assessment taken smart bank session is available. 
     *
     *  @return <code> true </code> if assessment taken smart bank session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenSmartBank();


    /**
     *  Tests if a bank lookup service is supported. A bank lookup service 
     *  defines methods to access assessment banks. 
     *
     *  @return <code> true </code> if bank lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankLookup();


    /**
     *  Tests if a bank query service is supported. 
     *
     *  @return <code> true </code> if bank query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankQuery();


    /**
     *  Tests if a bank search service is supported. 
     *
     *  @return <code> true </code> if bank search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankSearch();


    /**
     *  Tests if a banlk administrative service is supported. 
     *
     *  @return <code> true </code> if bank admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankAdmin();


    /**
     *  Tests if bank notification is supported. Messages may be sent when 
     *  items are created, modified, or deleted. 
     *
     *  @return <code> true </code> if bank notification is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankNotification();


    /**
     *  Tests if a bank hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a bank hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankHierarchy();


    /**
     *  Tests if bank hierarchy design is supported. 
     *
     *  @return <code> true </code> if a bank hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankHierarchyDesign();


    /**
     *  Tests if an assessment authoring service is supported. 
     *
     *  @return <code> true </code> if an assessment authoring is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentAuthoring();


    /**
     *  Tests if an assessment batch service is supported. 
     *
     *  @return <code> true </code> if an assessment batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentBatch();


    /**
     *  Gets the supported <code> Item </code> record types. 
     *
     *  @return a list containing the supported <code> Item </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getItemRecordTypes();


    /**
     *  Tests if the given <code> Item </code> record type is supported. 
     *
     *  @param  itemRecordType a <code> Type </code> indicating a <code> Item 
     *          </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemRecordType(org.osid.type.Type itemRecordType);


    /**
     *  Gets the supported <code> Item </code> search record types. 
     *
     *  @return a list containing the supported <code> Item </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getItemSearchRecordTypes();


    /**
     *  Tests if the given <code> Item </code> search record type is 
     *  supported. 
     *
     *  @param  itemSearchRecordType a <code> Type </code> indicating an 
     *          <code> Item </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> itemSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSearchRecordType(org.osid.type.Type itemSearchRecordType);


    /**
     *  Gets the supported <code> Assessment </code> record types. 
     *
     *  @return a list containing the supported <code> Assessment </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentRecordTypes();


    /**
     *  Tests if the given <code> Assessment </code> record type is supported. 
     *
     *  @param  assessmentRecordType a <code> Type </code> indicating an 
     *          <code> Assessment </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assessmentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentRecordType(org.osid.type.Type assessmentRecordType);


    /**
     *  Gets the supported <code> Assessment </code> search record types. 
     *
     *  @return a list containing the supported assessment search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentSearchRecordTypes();


    /**
     *  Tests if the given assessment search record type is supported. 
     *
     *  @param  assessmentSearchRecordType a <code> Type </code> indicating an 
     *          assessment search record type 
     *  @return <code> true </code> if the given search record Type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentSearchRecordType(org.osid.type.Type assessmentSearchRecordType);


    /**
     *  Gets the supported <code> AssessmentOffered </code> record types. 
     *
     *  @return a list containing the supported <code> AssessmentOffered 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentOfferedRecordTypes();


    /**
     *  Tests if the given <code> AssessmentOffered </code> record type is 
     *  supported. 
     *
     *  @param  assessmentOfferedRecordType a <code> Type </code> indicating 
     *          an <code> AssessmentOffered </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedRecordType(org.osid.type.Type assessmentOfferedRecordType);


    /**
     *  Gets the supported <code> AssessmentOffered </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> AssessmentOffered 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentOfferedSearchRecordTypes();


    /**
     *  Tests if the given <code> AssessmentOffered </code> search record type 
     *  is supported. 
     *
     *  @param  assessmentOfferedSearchRecordType a <code> Type </code> 
     *          indicating an <code> AssessmentOffered </code> search record 
     *          type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedSearchRecordType(org.osid.type.Type assessmentOfferedSearchRecordType);


    /**
     *  Gets the supported <code> AssessmentTaken </code> record types. 
     *
     *  @return a list containing the supported <code> AssessmentTaken </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentTakenRecordTypes();


    /**
     *  Tests if the given <code> AssessmentTaken </code> record type is 
     *  supported. 
     *
     *  @param  assessmentTakenRecordType a <code> Type </code> indicating an 
     *          <code> AssessmentTaken </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenRecordType(org.osid.type.Type assessmentTakenRecordType);


    /**
     *  Gets the supported <code> AssessmentTaken </code> search record types. 
     *
     *  @return a list containing the supported <code> AssessmentTaken </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentTakenSearchRecordTypes();


    /**
     *  Tests if the given <code> AssessmentTaken </code> search record type 
     *  is supported. 
     *
     *  @param  assessmentTakenSearchRecordType a <code> Type </code> 
     *          indicating an <code> AssessmentTaken </code> search record 
     *          type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenSearchRecordType(org.osid.type.Type assessmentTakenSearchRecordType);


    /**
     *  Gets the supported <code> AssessmentSection </code> record types. 
     *
     *  @return a list containing the supported <code> AssessmentSection 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentSectionRecordTypes();


    /**
     *  Tests if the given <code> AssessmentSection </code> record type is 
     *  supported. 
     *
     *  @param  assessmentSectionRecordType a <code> Type </code> indicating 
     *          an <code> AssessmentSection </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentSectionRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentSectionRecordType(org.osid.type.Type assessmentSectionRecordType);


    /**
     *  Gets the supported <code> Bank </code> record types. 
     *
     *  @return a list containing the supported <code> Bank </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBankRecordTypes();


    /**
     *  Tests if the given <code> Bank </code> record type is supported. 
     *
     *  @param  bankRecordType a <code> Type </code> indicating a <code> Bank 
     *          </code> type 
     *  @return <code> true </code> if the given key record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bankRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankRecordType(org.osid.type.Type bankRecordType);


    /**
     *  Gets the supported bank search record types. 
     *
     *  @return a list containing the supported <code> Bank </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBankSearchRecordTypes();


    /**
     *  Tests if the given bank search record type is supported. 
     *
     *  @param  bankSearchRecordType a <code> Type </code> indicating a <code> 
     *          Bank </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bankSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankSearchRecordType(org.osid.type.Type bankSearchRecordType);
}
