//
// org.osid.assessment.AssessmentProxyManager
//
//     The OSID Java specification for org.osid.assessment.AssessmentProxyManager.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>The assessment manager provides access to assessment sessions and 
 *  provides interoperability tests for various aspects of this service. 
 *  Methods in this manager support the passing of a <code> Proxy </code> 
 *  object. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> MyAssessmentTakenSession: </code> a session to get taken 
 *      or in progress assessments for the current agent </li> 
 *      <li> <code> AssessmentSession: </code> a session to be assessed and 
 *      examine assessments taken </li> 
 *      <li> <code> AssessmentResultsSession: </code> a session to retrieve 
 *      assessment results </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ItemLookupSession: </code> a session to look up <code> 
 *      Items </code> </li> 
 *      <li> <code> ItemQuerySession </code> : a session to query <code> Items 
 *      </code> </li> 
 *      <li> <code> ItemSearchSession: </code> a session to search <code> 
 *      Items </code> </li> 
 *      <li> <code> ItemAdminSession: </code> a session to create, modify and 
 *      delete <code> Items </code> </li> 
 *      <li> <code> ItemNotificationSession: a </code> session to receive 
 *      messages pertaining to <code> Item </code> changes </li> 
 *      <li> <code> ItemBankSession: </code> a session for looking up item and 
 *      bank mappings </li> 
 *      <li> <code> ItemBankAssignmentSession: </code> a session for managing 
 *      item and bank mappings </li> 
 *      <li> <code> ItemSmartBankSession: </code> a session for managing 
 *      dynamic banks </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AssessmentLookupSession: </code> a session to look up 
 *      <code> Assessments </code> </li> 
 *      <li> <code> AssessmentQuerySession: </code> a session to query <code> 
 *      Assessments </code> </li> 
 *      <li> <code> AssessmentSearchSession: </code> a session to search 
 *      <code> Assessments </code> </li> 
 *      <li> <code> AssessmentAdminSession: </code> a session to create, 
 *      modify and delete <code> Assessments </code> </li> 
 *      <li> <code> AssessmentNotificationSession: a </code> session to 
 *      receive messages pertaining to <code> Assessment </code> changes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AssessmentBankSession: </code> a session for looking up 
 *      assessment and bank mappings </li> 
 *      <li> <code> AssessmentBankAssignmentSession: </code> a session for 
 *      managing assessment and bank mappings </li> 
 *      <li> <code> AssessmentSmartBankSession: </code> a session for managing 
 *      dynamic banks </li> 
 *      <li> <code> AssessmentBasicAuthoringSession: </code> a session for 
 *      making simple mappings of assessment items to assessments </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AssessmentOfferedLookupSession: </code> a session to look 
 *      up <code> Assessments </code> </li> 
 *      <li> <code> AssessmentOfferedQuerySession: </code> a session to query 
 *      <code> Assessments </code> </li> 
 *      <li> <code> AssessmentOfferedSearchSession </code> : a session to 
 *      search <code> Assessments </code> </li> 
 *      <li> <code> AssessmentOfferedAdminSession: </code> a session to 
 *      create, modify and delete <code> Assessments </code> </li> 
 *      <li> <code> AssessmentOfferedNotificationSession: a </code> session to 
 *      receive messages pertaining to <code> Assessment </code> changes </li> 
 *      <li> <code> AssessmentOfferedBankSession: </code> a session for 
 *      looking up assessment and bank mappings </li> 
 *      <li> <code> AssessmentOfferedBankAssignmentSession: </code> a session 
 *      for managing assessment and bank mappings </li> 
 *      <li> <code> AssessmentOfferedSmartBankSession </code> : a session to 
 *      manage dynamic banks </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AssessmentTakenLookupSession: </code> a session to look up 
 *      <code> Assessments </code> </li> 
 *      <li> <code> AssessmentTakenQuerySession: </code> a session to query 
 *      <code> Assessments </code> </li> 
 *      <li> <code> AssessmentTakenSearchSession: </code> a session to search 
 *      Assessments </li> 
 *      <li> <code> AssessmentTakenAdminSession: </code> a session to create, 
 *      modify and delete <code> AssessmentsTaken </code> </li> 
 *      <li> <code> AssessmentTakenNotificationSession: a </code> session to 
 *      receive messages pertaining to <code> AssessmentTaken </code> changes 
 *      </li> 
 *      <li> <code> AssessmentTakenBankSession: </code> a session for looking 
 *      up assessments taken and bank mappings </li> 
 *      <li> <code> AssessmenttTakenBankAssignmentSession: </code> a session 
 *      for managing assessments taken and bank mappings </li> 
 *      <li> <code> AssessmentTakenSmartBankSession: </code> a session to 
 *      manage dynamic banks of assessments taken </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BankLookupSession: </code> a session to lookup banks </li> 
 *      <li> <code> BankQuerySession </code> : a session to query banks </li> 
 *      <li> <code> BankSearchSession: </code> a session to search banks </li> 
 *      <li> <code> BankAdminSession </code> : a session to create, modify and 
 *      delete banks </li> 
 *      <li> <code> BankNotificationSession </code> : a session to receive 
 *      messages pertaining to <code> Bank </code> changes </li> 
 *      <li> <code> BankHierarchySession </code> : a session to traverse the 
 *      <code> Bank </code> hierarchy </li> 
 *      <li> <code> BankHierarchyDesignSession </code> : a session to manage 
 *      the <code> Bank </code> hierarchy </li> 
 *  </ul>
 *  
 */

public interface AssessmentProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.assessment.AssessmentProfile {


    /**
     *  Gets a <code> MyAssessmentTakenSession </code> to retrieve assessments 
     *  taken for the current agent. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> MyAssessmentTakenSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyAssessmentTaken() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyAssessmentTaken() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.MyAssessmentTakenSession getMyAssessmentTakenSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> MyAssessmentTakenSession </code> to retrieve assessments 
     *  taken for the current agent for the given bank <code> Id. </code> 
     *
     *  @param  bankId the <code> Id </code> of a bank 
     *  @param  proxy a proxy 
     *  @return a <code> MyAssessmentTakenSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMyAssessmentTaken() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMyAssessmentTaken() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.MyAssessmentTakenSession getMyAssessmentTakenSessionForBank(org.osid.id.Id bankId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an <code> AssessmentSession </code> which is responsible for 
     *  taking assessments and examining responses from assessments taken. 
     *
     *  @param  proxy a proxy 
     *  @return an assessment session for this service 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssessment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessment() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentSession getAssessmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AssessmentSession </code> which is responsible for 
     *  performing assessments for the given bank <code> Id. </code> 
     *
     *  @param  bankId the <code> Id </code> of a bank 
     *  @param  proxy a proxy 
     *  @return an assessment session for this service 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssessment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessment() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentSession getAssessmentSessionForBank(org.osid.id.Id bankId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an <code> AssessmentResultsSession </code> to retrieve assessment 
     *  results. 
     *
     *  @param  proxy a proxy 
     *  @return an assessment results session for this service 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentResults() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentResults() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentResultsSession getAssessmentResultsSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AssessmentResultsSession </code> to retrieve assessment 
     *  results for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the assessment taken 
     *  @param  proxy a proxy 
     *  @return an assessment results session for this service 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentResults() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentResults() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentResultsSession getAssessmentResultsSessionForBank(org.osid.id.Id bankId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ItemLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemLookup() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemLookupSession getItemLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item lookup 
     *  service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an ItemLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsItemLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.ItemLookupSession getItemLookupSessionForBank(org.osid.id.Id bankId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ItemQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemQuerySession getItemQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item query 
     *  service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an ItemQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.ItemQuerySession getItemQuerySessionForBank(org.osid.id.Id bankId, 
                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ItemSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemSearch() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemSearchSession getItemSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item search 
     *  service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an ItemSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          porxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsItemSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.ItemSearchSession getItemSearchSessionForBank(org.osid.id.Id bankId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ItemAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemAdmin() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemAdminSession getItemAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item admin 
     *  service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an ItemAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsItemAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.ItemAdminSession getItemAdminSessionForBank(org.osid.id.Id bankId, 
                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to item 
     *  changes. 
     *
     *  @param  itemReceiver the item receiver interface 
     *  @param  proxy a proxy 
     *  @return an <code> ItemNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> itemReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemNotification() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemNotificationSession getItemNotificationSession(org.osid.assessment.ItemReceiver itemReceiver, 
                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item 
     *  notification service for the given bank. 
     *
     *  @param  itemReceiver the item receiver interface 
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an ItemNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> itemReceiver, bankId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentNotificationSession getItemNotificationSessionForBank(org.osid.assessment.ItemReceiver itemReceiver, 
                                                                                               org.osid.id.Id bankId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item banking 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ItemBankSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemBank() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemBank() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemBankSession getItemBankSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item bank 
     *  assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ItemBankAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemBankAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemBankAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.ItemBankAssignmentSession getItemBankAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item smart 
     *  banking service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> ItemSmartBankSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemSmartBank() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemSmartBank() </code> and <code> 
     *              supportsVisibeFederation() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemSmartBankSession getItemSmartBankSession(org.osid.id.Id bankId, 
                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentLookup() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentLookupSession getAssessmentLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  lookup service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an AssessmentLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentLookupSession getAssessmentLookupSessionForBank(org.osid.id.Id bankId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentQuerySession getAssessmentQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  query service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an AssessmentQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentQuerySession getAssessmentQuerySessionForBank(org.osid.id.Id bankId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentSearch() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentSearchSession getAssessmentSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  search service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an AssessmentSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentSearchSession getAssessmentSearchSessionForBank(org.osid.id.Id bankId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentAdmin() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentAdminSession getAssessmentAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  admin service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an AssessmentAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentAdminSession getAssessmentAdminSessionForBank(org.osid.id.Id bankId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  assessment changes. 
     *
     *  @param  assessmentReceiver the assessment receiver interface 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentNotificationSession getAssessmentNotificationSession(org.osid.assessment.AssessmentReceiver assessmentReceiver, 
                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  notification service for the given bank. 
     *
     *  @param  assessmentReceiver the assessment receiver interface 
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return <code> an AssessmentNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentReceiver, 
     *          bankId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentNotificationSession getAssessmentNotificationSessionForBank(org.osid.assessment.AssessmentReceiver assessmentReceiver, 
                                                                                                     org.osid.id.Id bankId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  banking service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentBankSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentBank() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentBank() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentBankSession getAssessmentBankSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  bank assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentBankAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentBankAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentBankAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentBankAssignmentSession getAssessmentBankAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  smart banking service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentSmartBankSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentSmartBank() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentSmartBank() </code> and <code> 
     *              supportsVisibeFederation() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentSmartBankSession getAssessmentSmartBankSession(org.osid.id.Id bankId, 
                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  authoring service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentBasicAuthoringSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentBasicAuthoring() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentBasicAuthoring() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentBasicAuthoringSession getAssessmentBasicAuthoringSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  authoring service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of a bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentBasicAuthoringSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentBasicAuthoring() </code> or <code> 
     *          supportsVisibeFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentBasicAuthoring() </code> and <code> 
     *              supportsVisibeFederation() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentBasicAuthoringSession getAssessmentBasicAuthoringSessionForBank(org.osid.id.Id bankId, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedLookupSession getAssessmentOfferedLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered lookup service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedLookupSession getAssessmentOfferedLookupSessionForBank(org.osid.id.Id bankId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedQuerySession getAssessmentOfferedQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered query service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedQuerySession getAssessmentOfferedQuerySessionForBank(org.osid.id.Id bankId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedSearchSession getAssessmentOfferedSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered search service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or proxy 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedSearchSession getAssessmentOfferedSearchSessionForBank(org.osid.id.Id bankId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedAdminSession getAssessmentOfferedAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered admin service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedAdminSession getAssessmentOfferedAdminSessionForBank(org.osid.id.Id bankId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to offered 
     *  assessment changes. 
     *
     *  @param  assessmentOfferedReceiver the assessment offered receiver 
     *          interface 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.AssessmentOfferedNotificationSession getAssessmentOfferedNotificationSession(org.osid.assessment.AssessmentOfferedReceiver assessmentOfferedReceiver, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offered 
     *  assessment notification service for the given bank. 
     *
     *  @param  assessmentOfferedReceiver the assessment offered receiver 
     *          interface 
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return a <code> AssessmentOfferedNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> or <code> 
     *          proxy </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentOfferedReceiver, bankId </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedNotificationSession getAssessmentOfferedNotificationSessionForBank(org.osid.assessment.AssessmentOfferedReceiver assessmentOfferedReceiver, 
                                                                                                                   org.osid.id.Id bankId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving offered assessments to bank mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedBankSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedBankSession getAssessmentOfferedBankSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning offered assessments to bank mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedBankAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedBankAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedBankAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.assessment.AssessmentOfferedBankAssignmentSession getAssessmentOfferedBankAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  offered smart banking service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentOfferedSmartBankSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedSmartBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedSmartBank() </code> and <code> 
     *              supportsVisibeFederation() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentOfferedSmartBankSession getAssessmentOfferedSmartBankSession(org.osid.id.Id bankId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  taken lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenLookupSession getAssessmentTakenLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  taken lookup service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenLookupSession getAssessmentTakenLookupSessionForBank(org.osid.id.Id bankId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  taken query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenQuerySession getAssessmentTakenQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  taken query service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenQuerySession getAssessmentTakenQuerySessionForBank(org.osid.id.Id bankId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  taken search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenSearchSession getAssessmentTakenSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  taken search service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> bankId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenSearchSession getAssessmentTakenSearchSessionForBank(org.osid.id.Id bankId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to taken 
     *  assessment changes. 
     *
     *  @param  assessmentTakenReceiver the assessment taken receiver 
     *          interface 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.AssessmentTakenNotificationSession getAssessmentTakenNotificationSession(org.osid.assessment.AssessmentTakenReceiver assessmentTakenReceiver, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the taken 
     *  assessment notification service for the given bank. 
     *
     *  @param  assessmentTakenReceiver the assessment taken receiver 
     *          interface 
     *  @param  bankId the <code> Id </code> of the bank 
     *  @param  proxy a proxy 
     *  @return an <code> AssessmentTakenNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> bankId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenReceiver, 
     *          bankId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentTakenNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentTakenNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenNotificationSession getAssessmentTakenNotificationSessionForBank(org.osid.assessment.AssessmentTakenReceiver assessmentTakenReceiver, 
                                                                                                               org.osid.id.Id bankId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the bank lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BankLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBankLookup() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankLookup() </code> is true. 
     */

    public org.osid.assessment.BankLookupSession getBankLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the bank query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BankQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBankQuery() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankQuery() </code> is true. 
     */

    public org.osid.assessment.BankQuerySession getBankQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the bank search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BankSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBankSearch() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankSearch() </code> is true. 
     */

    public org.osid.assessment.BankSearchSession getBankSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the bank administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BankAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBankAdmin() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankAdmin() </code> is true. 
     */

    public org.osid.assessment.BankAdminSession getBankAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to bank 
     *  service changes. 
     *
     *  @param  bankReceiver the bank receiver interface 
     *  @param  proxy a proxy 
     *  @return a <code> BankNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> bankReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBankNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankNotification() </code> is true. 
     */

    public org.osid.assessment.BankNotificationSession getBankNotificationSession(org.osid.assessment.BankReceiver bankReceiver, 
                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing bank hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BankHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBankHierarchy() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankHierarchy() </code> is true. 
     */

    public org.osid.assessment.BankHierarchySession getBankHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing bank hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BankHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBankHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankHierarchyDesign() </code> is true. 
     */

    public org.osid.assessment.BankHierarchyDesignSession getBankHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AssessmentAuthoringProxyManager. </code> 
     *
     *  @return an <code> AssessmentAuthoringProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentAuthoring() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentAuthoring() </code> is true. 
     */

    public org.osid.assessment.authoring.AssessmentAuthoringProxyManager getAssessmentAuthoringProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AssessmentBatchProxyManager. </code> 
     *
     *  @return an <code> AssessmentBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentBatch() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentBatch() </code> is true. 
     */

    public org.osid.assessment.batch.AssessmentBatchProxyManager getAssessmentBatchProxyManager()
        throws org.osid.OperationFailedException;
}
