//
// org.osid.assessment.AssessmentSearchSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session provides methods for searching among <code> Assessment 
 *  </code> objects. The search query is constructed using the <code> 
 *  AssessmentQuery. </code> </p> 
 *  
 *  <p> <code> getAssessmentsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Assessments. </code> A more advanced search may 
 *  be performed with <code> getAssessmentsBySearch(). </code> It accepts an 
 *  <code> AssessmentSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAssessmentsBySearch() </code> returns an <code> 
 *  AssessmentSearchResults </code> that can be used to access the resulting 
 *  <code> AssessmentList </code> or be used to perform a search within the 
 *  result set through <code> AssessmentSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bank view: searches include assessments in banks of 
 *      which this bank is an ancestor in the bank hierarchy </li> 
 *      <li> isolated bank view: searches are restricted to assessments in 
 *      this bank </li> 
 *  </ul>
 *  
 *  
 *  <p> Assessments may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> AssessmentQuery. 
 *  </code> </p>
 */

public interface AssessmentSearchSession
    extends org.osid.assessment.AssessmentQuerySession {


    /**
     *  Gets an assessment search. 
     *
     *  @return the assessment search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSearch getAssessmentSearch();


    /**
     *  Gets an assessment search order. The <code> AssessmentSearchOrder 
     *  </code> is supplied to an <code> AssessmentSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the assessment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSearchOrder getAssessmentSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  assessmentQuery the assessment query 
     *  @param  assessmentSearch the assessment search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> assessmentQuery </code> 
     *          or <code> assessmentSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentQuery </code> 
     *          or <code> assessmentSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSearchResults getAssessmentsBySearch(org.osid.assessment.AssessmentQuery assessmentQuery, 
                                                                              org.osid.assessment.AssessmentSearch assessmentSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessment query from an inspector. The inspector is available 
     *  from an <code> AssessmentSearchResults. </code> 
     *
     *  @param  assessmentQueryInspector an assessment query inspector 
     *  @return the assessment query 
     *  @throws org.osid.NullArgumentException <code> assessmentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> assessmentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQueryFromInspector(org.osid.assessment.AssessmentQueryInspector assessmentQueryInspector);
}
