//
// org.osid.assessment.AssessmentSmartBankSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentSmartBankSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> AssessmentQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Bank </code> to create a virtual 
 *  collection of <code> Assessments. </code> The assessments may be sequenced 
 *  using the <code> AssessmentSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Bank </code> has a default query that matches any 
 *  assessment and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> AssessmentQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to an <code> 
 *  AssessmentQuery. </code> </p>
 */

public interface AssessmentSmartBankSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException assessment failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart banks. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart bank management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartBanks();


    /**
     *  Gets an assessment query. 
     *
     *  @return the assessment query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQuery();


    /**
     *  Gets an assessment search order. 
     *
     *  @return the assessment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentSearchOrder getAssessmentSearchOrder();


    /**
     *  Applies an assessment query to this bank. 
     *
     *  @param  assessmentQuery the assessment query 
     *  @throws org.osid.NullArgumentException <code> assessmentQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAssessmentQuery(org.osid.assessment.AssessmentQuery assessmentQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessment query inspector for this bank. 
     *
     *  @return the assessment query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQueryInspector inspectAssessmentQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an assessment search order to this bank. 
     *
     *  @param  assessmentSearchOrder the assessment search order 
     *  @throws org.osid.NullArgumentException <code> assessmentSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAssessmentSequencing(org.osid.assessment.AssessmentSearchOrder assessmentSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessment query from an inspector. 
     *
     *  @param  assessmentQueryInspector an assessment query inspector 
     *  @return the assessment query 
     *  @throws org.osid.NullArgumentException <code> assessmentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> assessmentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQueryFromInspector(org.osid.assessment.AssessmentQueryInspector assessmentQueryInspector);
}
