//
// org.osid.assessment.AssessmentTaken
//
//     The OSID Java specification for org.osid.assessment.AssessmentTaken.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>Represents a taken assessment or an assessment in progress. </p>
 */

public interface AssessmentTaken
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Id </code> of the <code> AssessmentOffered. </code> 
     *
     *  @return the assessment offered <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssessmentOfferedId();


    /**
     *  Gets the <code> AssessmentOffered. </code> 
     *
     *  @return the assessment offered 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentOffered getAssessmentOffered()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the resource who took or is taking this 
     *  assessment. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTakerId();


    /**
     *  Gets the <code> Resource </code> taking this assessment. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getTaker()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Agent </code> who took or is 
     *  taking the assessment. 
     *
     *  @return the agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTakingAgentId();


    /**
     *  Gets the <code> Agent. </code> 
     *
     *  @return the agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getTakingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this assessment has begun. 
     *
     *  @return <code> true </code> if the assessment has begun, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasStarted();


    /**
     *  Gets the time this assessment was started. 
     *
     *  @return the start time 
     *  @throws org.osid.IllegalStateException <code> hasStarted() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getActualStartTime();


    /**
     *  Tests if this assessment has ended. 
     *
     *  @return <code> true </code> if the assessment has ended, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasEnded();


    /**
     *  Gets the time of this assessment was completed. 
     *
     *  @return the end time 
     *  @throws org.osid.IllegalStateException <code> hasEnded() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCompletionTime();


    /**
     *  Gets the total time spent taking this assessment. 
     *
     *  @return the total time spent 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTimeSpent();


    /**
     *  Gets a completion percentage of the assessment. 
     *
     *  @return the percent complete (0-100) 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getCompletion();


    /**
     *  Tests if a score is available for this assessment. 
     *
     *  @return <code> true </code> if a score is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isScored();


    /**
     *  Gets a score system <code> Id </code> for the assessment. 
     *
     *  @return the grade system 
     *  @throws org.osid.IllegalStateException <code> isScore() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getScoreSystemId();


    /**
     *  Gets a grade system for the score. 
     *
     *  @return the grade system 
     *  @throws org.osid.IllegalStateException <code> isScored() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getScoreSystem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a score for the assessment. 
     *
     *  @return the score 
     *  @throws org.osid.IllegalStateException <code> isScored() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getScore();


    /**
     *  Tests if a grade is available for this assessment. 
     *
     *  @return <code> true </code> if a grade is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isGraded();


    /**
     *  Gets a grade <code> Id </code> for the assessment. 
     *
     *  @return the grade 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradeId();


    /**
     *  Gets a grade for the assessment. 
     *
     *  @return the grade 
     *  @throws org.osid.IllegalStateException <code> isGraded() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getGrade()
        throws org.osid.OperationFailedException;


    /**
     *  Gets any overall comments available for this assessment by the grader. 
     *
     *  @return comments 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getFeedback();


    /**
     *  Tests if a rubric assessment is associated with this assessment. 
     *
     *  @return <code> true </code> if a rubric is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRubric();


    /**
     *  Gets the <code> Id </code> of the rubric. 
     *
     *  @return an assessment taken <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasRubric() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRubricId();


    /**
     *  Gets the rubric. 
     *
     *  @return the assessment taken 
     *  @throws org.osid.IllegalStateException <code> hasRubric() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTaken getRubric()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the assessment taken record corresponding to the given <code> 
     *  AssessmentTaken </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> assessmentTakenRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(assessmentTakenRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  assessmentTakenRecordType an assessment taken record type 
     *  @return the assessment taken record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentTakenRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentTakenRecord getAssessmentTakenRecord(org.osid.type.Type assessmentTakenRecordType)
        throws org.osid.OperationFailedException;
}
