//
// org.osid.assessment.AssessmentTakenAdminSession
//
//     The OSID Java specification for org.osid.assessment.AssessmentTakenAdminSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This session creates, updates, and deletes <code> AssessmentsTaken. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AssessmentTaken, </code> an <code> AssessmentTakenForm </code> is 
 *  requested using <code> getAssessmentTakenFormForCreate() </code> 
 *  specifying the assessment offered and desired record <code> Types </code> 
 *  or none if no record <code> Types </code> are needed. The returned <code> 
 *  AssessmentTakenForm </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once the <code> AssessmentTakenForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> AssessmentTakenForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AssessmentTakenForms </code> are requested to the 
 *  <code> AssessmentTaken </code> <code> Id </code> that is to be updated 
 *  using <code> getAssessmentTakenFormForUpdate(). </code> Similarly, the 
 *  <code> AssessmentTakenForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> AssessmentTakenForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> AssessmentsTaken. </code> To unmap 
 *  an <code> AssessmentTakenForm </code> from the current <code> Bank, 
 *  </code> the <code> AssessmentTakenFormBankAssignmentSession </code> should 
 *  be used. These delete operations attempt to remove the <code> 
 *  AssessmentTakenForm </code> itself thus removing it from all known <code> 
 *  Bank </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AssessmentTakenAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> AssessmentTaken </code> objects. 
     *  A return of true does not guarantee successful authoriization. A 
     *  return of false indicates that it is known creating an <code> 
     *  AssessmentTaken </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer create operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentTaken </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentsTaken();


    /**
     *  Tests if this user can create a single <code> AssessmentTaken </code> 
     *  using the desired record types. While <code> 
     *  AssessmentManager.getAssessmentTakenRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> AssessmentTaken. 
     *  </code> Providing an empty array tests if an <code> AssessmentTaken 
     *  </code> can be created with no records. 
     *
     *  @param  assessmentTakenRecordTypes array of assessment taken record 
     *          types 
     *  @return <code> true </code> if <code> AssessmentTaken </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentTakenWithRecordTypes(org.osid.type.Type[] assessmentTakenRecordTypes);


    /**
     *  Gets the assessment taken form for creating new assessments taken. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  assessmentOfferedId the <code> Id </code> of the related 
     *          <code> AssessmentOffered </code> 
     *  @param  assessmentTakenRecordTypes array of assessment taken record 
     *          types to be included in the create operation or an empty list 
     *          if none 
     *  @return the assessment taken form 
     *  @throws org.osid.NotFoundException <code> assessmentOfferedId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> or <code> assessmentTakenRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTakenForm getAssessmentTakenFormForCreate(org.osid.id.Id assessmentOfferedId, 
                                                                                   org.osid.type.Type[] assessmentTakenRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AssessmentTaken. </code> 
     *
     *  @param  assessmentTakenForm the form for this <code> AssessmentTaken 
     *          </code> 
     *  @return the new <code> AssessmentTaken </code> 
     *  @throws org.osid.IllegalStateException <code> assessmentTakenForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentOfferedForm 
     *          </code> did not originate from <code> 
     *          getAssessmentTakenFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTaken createAssessmentTaken(org.osid.assessment.AssessmentForm assessmentTakenForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AssessmentTaken </code> objects. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating an <code> AssessmentTaken 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentTaken </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAssessmentsTaken();


    /**
     *  Gets the assessment taken form for updating an existing assessment 
     *  taken. A new assessment taken form should be requested for each update 
     *  transaction. 
     *
     *  @param  assessmentTakenId the <code> Id </code> of the <code> 
     *          AssessmentTaken </code> 
     *  @return the assessment taken form 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentTakenForm getAssessmentTakenFormForUpdate(org.osid.id.Id assessmentTakenId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing assessment taken. 
     *
     *  @param  assessmentTakenForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> assessmentTakenForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> assessmentOfferedForm 
     *          </code> did not originate from <code> 
     *          getAssessmentTakenFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAssessmentTaken(org.osid.assessment.AssessmentTakenForm assessmentTakenForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AssessmentsTaken. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting an <code> AssessmentTaken 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer a 
     *  delete operations to unauthorized users. 
     *
     *  @return <code> false </code> if <code> AssessmentTaken </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAssessmentsTaken();


    /**
     *  Deletes an <code> AssessmentTaken. </code> 
     *
     *  @param  assessmentTakenId the <code> Id </code> of the <code> 
     *          AssessmentTaken </code> to remove 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAssessmentTaken(org.osid.id.Id assessmentTakenId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  AssessmentsTaken. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentTaken </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAssessmentTakenAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentTaken </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AssessmentTaken </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another assessment taken, it is reassigned 
     *  to the given assessment taken <code> Id. </code> 
     *
     *  @param  assessmentTakenId the <code> Id </code> of an <code> 
     *          AssessmentTaken </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> assessmentTakenId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAssessmentTaken(org.osid.id.Id assessmentTakenId, 
                                     org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
