//
// org.osid.assessment.AssessmentTakenQuery
//
//     The OSID Java specification for org.osid.assessment.AssessmentTakenQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This is the query for searching assessments. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface AssessmentTakenQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the assessment offered <code> Id </code> for this query. 
     *
     *  @param  assessmentOfferedId an assessment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentOfferedId(org.osid.id.Id assessmentOfferedId, 
                                         boolean match);


    /**
     *  Clears all assessment offered <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentOfferedIdTerms();


    /**
     *  Tests if an <code> AssessmentOfferedQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment offered query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedQuery();


    /**
     *  Gets the query for an assessment. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the assessment offered query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedQuery getAssessmentOfferedQuery();


    /**
     *  Clears all assessment offered terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentOfferedTerms();


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTakerId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears all resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTakerIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTakerQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsTakerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTakerQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getTakerQuery();


    /**
     *  Clears all resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTakerTerms();


    /**
     *  Sets the agent <code> Id </code> for this query. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTakingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears all agent <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTakingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTakingAgentQuery();


    /**
     *  Gets the query for an agent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTakingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTakingAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuery getTakingAgentQuery();


    /**
     *  Clears all taking agent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTakingAgentTerms();


    /**
     *  Matches assessments whose start time falls between the specified range 
     *  inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActualStartTime(org.osid.calendaring.DateTime start, 
                                     org.osid.calendaring.DateTime end, 
                                     boolean match);


    /**
     *  Matches taken assessments taken that have begun. 
     *
     *  @param  match <code> true </code> to match assessments taken started, 
     *          <code> false </code> to match assessments taken that have not 
     *          begun 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActualStartTime(boolean match);


    /**
     *  Clears all start time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualStartTimeTerms();


    /**
     *  Matches assessments whose completion time falls between the specified 
     *  range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompletionTime(org.osid.calendaring.DateTime start, 
                                    org.osid.calendaring.DateTime end, 
                                    boolean match);


    /**
     *  Matches taken assessments taken that have completed. 
     *
     *  @param  match <code> true </code> to match assessments taken 
     *          completed, <code> false </code> to match assessments taken 
     *          that are incomplete 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCompletionTime(boolean match);


    /**
     *  Clears all in completion time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompletionTimeTerms();


    /**
     *  Matches assessments where the time spent falls between the specified 
     *  range inclusive. 
     *
     *  @param  low start of duration range 
     *  @param  high end of duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeSpent(org.osid.calendaring.Duration low, 
                               org.osid.calendaring.Duration high, 
                               boolean match);


    /**
     *  Clears all in time spent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeSpentTerms();


    /**
     *  Sets the grade system <code> Id </code> for this query. 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true for a positive match, false for a negative 
     *          match </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScoreSystemId(org.osid.id.Id gradeSystemId, boolean match);


    /**
     *  Clears all grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreSystemIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScoreSystemQuery();


    /**
     *  Gets the query for a grade system. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScoreSystemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScoreSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuery getScoreSystemQuery();


    /**
     *  Matches taken assessments that have any grade system assigned. 
     *
     *  @param  match <code> true </code> to match assessments with any grade 
     *          system, <code> false </code> to match assessments with no 
     *          grade system 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScoreSystem(boolean match);


    /**
     *  Clears all grade system terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreSystemTerms();


    /**
     *  Matches assessments whose score falls between the specified range 
     *  inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScore(java.math.BigDecimal low, java.math.BigDecimal high, 
                           boolean match);


    /**
     *  Matches taken assessments that have any score assigned. 
     *
     *  @param  match <code> true </code> to match assessments with any score, 
     *          <code> false </code> to match assessments with no score 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScore(boolean match);


    /**
     *  Clears all score terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreTerms();


    /**
     *  Sets the grade <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true for a positive match, false for a negative 
     *          match </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears all grade <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeQuery();


    /**
     *  Gets the query for a grade. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> supportsGradeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getGradeQuery();


    /**
     *  Matches taken assessments that have any grade assigned. 
     *
     *  @param  match <code> true </code> to match assessments with any grade, 
     *          <code> false </code> to match assessments with no grade 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGrade(boolean match);


    /**
     *  Clears all grade terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeTerms();


    /**
     *  Sets the comment string for this query. 
     *
     *  @param  comments comment string 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.InvalidArgumentException <code> comments is </code> 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> comments </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFeedback(String comments, 
                              org.osid.type.Type stringMatchType, 
                              boolean match);


    /**
     *  Matches taken assessments that have any comments. 
     *
     *  @param  match <code> true </code> to match assessments with any 
     *          comments, <code> false </code> to match assessments with no 
     *          comments 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFeedback(boolean match);


    /**
     *  Clears all comment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFeedbackTerms();


    /**
     *  Sets the rubric assessment taken <code> Id </code> for this query. 
     *
     *  @param  assessmentTakenId an assessment taken <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentTakenId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRubricId(org.osid.id.Id assessmentTakenId, boolean match);


    /**
     *  Clears all rubric assessment taken <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRubricIdTerms();


    /**
     *  Tests if an <code> AssessmentTakenQuery </code> is available. 
     *
     *  @return <code> true </code> if a rubric assessment taken query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRubricQuery();


    /**
     *  Gets the query for a rubric assessment. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment taken query 
     *  @throws org.osid.UnimplementedException <code> supportsRubricQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRubricQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentTakenQuery getRubricQuery();


    /**
     *  Matches an assessment taken that has any rubric assessment assigned. 
     *
     *  @param  match <code> true </code> to match assessments taken with any 
     *          rubric, <code> false </code> to match assessments taken with 
     *          no rubric 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRubric(boolean match);


    /**
     *  Clears all rubric assessment taken terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRubricTerms();


    /**
     *  Sets the bank <code> Id </code> for this query. 
     *
     *  @param  bankId a bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears all bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankIdTerms();


    /**
     *  Tests if a <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankQuery();


    /**
     *  Gets the query for a bank. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> supportsBankQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.BankQuery getBankQuery();


    /**
     *  Clears all bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankTerms();


    /**
     *  Gets the assessment taken query record corresponding to the given 
     *  <code> AssessmentTaken </code> record <code> Type. </code> Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  assessmentTakenRecordType an assessment taken record type 
     *  @return the assessment taken query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentTakenRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentTakenQueryRecord getAssessmentTakenQueryRecord(org.osid.type.Type assessmentTakenRecordType)
        throws org.osid.OperationFailedException;
}
