//
// org.osid.assessment.AssessmentTakenSearchOrder
//
//     The OSID Java specification for org.osid.assessment.AssessmentTakenSearchOrder.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface AssessmentTakenSearchOrder
    extends org.osid.OsidObjectSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the assessment 
     *  offered. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAssessmentOffered(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an assessment search order is available. 
     *
     *  @return <code> true </code> if an assessment offered search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedSearchOrder();


    /**
     *  Gets an assessment offered search order. 
     *
     *  @return an assessment offered search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.AssessmentOfferedSearchOrder getAssessmentOfferedSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the resource. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTaker(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a resource search order is available. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTakerSearchOrder();


    /**
     *  Gets a resource search order. 
     *
     *  @return a resource search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTakerSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTakerSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceSearchOrder getTakerSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the agent. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTakingAgent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an agent search order is available. 
     *
     *  @return <code> true </code> if an agent search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTakingAgentSearchOrder();


    /**
     *  Gets an agent search order. 
     *
     *  @return an agent search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTakingAgentSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTakingAgentSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentSearchOrder getTakingAgentSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the assessment 
     *  start time. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByActualStartTime(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the assessment 
     *  deadline. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCompletionTime(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the time spent. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTimeSpent(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the grade 
     *  system. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByScoreSystem(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a grade system search order is available. 
     *
     *  @return <code> true </code> if a grade system search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScoreSystemSearchOrder();


    /**
     *  Gets a grade system search order. 
     *
     *  @return a grade system search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScoreSystemSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScoreSystemSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemSearchOrder getScoreSystemSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the score. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByScore(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the grade. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByGrade(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a grade search order is available. 
     *
     *  @return <code> true </code> if a grade search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSearchOrder();


    /**
     *  Gets a grade search order. 
     *
     *  @return a grade search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSearchOrder getGradeSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the comments. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByFeedback(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the rubric 
     *  assessment. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRubric(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an assessment taken search order is available. 
     *
     *  @return <code> true </code> if an assessment taken search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRubricSearchOrder();


    /**
     *  Gets an assessment taken search order. 
     *
     *  @return a rubric assessment taken search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRubricSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRubricSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentTakenSearchOrder getRubricSearchOrder();


    /**
     *  Gets the assessment taken search order record corresponding to the 
     *  given assessment record <code> Type. </code> Multiple retrievals 
     *  return the same underlying object. 
     *
     *  @param  assessmentTakenRecordType an assessment record type 
     *  @return the assessment taken search order record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentTakenRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentTakenRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.AssessmentTakenSearchOrderRecord getAssessmentTakenSearchOrderRecord(org.osid.type.Type assessmentTakenRecordType)
        throws org.osid.OperationFailedException;
}
