//
// org.osid.assessment.BankQuery
//
//     The OSID Java specification for org.osid.assessment.BankQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment;


/**
 *  <p>This is the query for searching banks Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface BankQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the item <code> Id </code> for this query. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears all item <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if a <code> ItemQuery </code> is available. 
     *
     *  @return <code> true </code> if an item query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for an item. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the item query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.ItemQuery getItemQuery();


    /**
     *  Matches assessment banks that have any item assigned. 
     *
     *  @param  match <code> true </code> to match banks with any item, <code> 
     *          false </code> to match assessments with no item 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears all item terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Sets the assessment <code> Id </code> for this query. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentId(org.osid.id.Id assessmentId, boolean match);


    /**
     *  Clears all assessment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentIdTerms();


    /**
     *  Tests if an <code> AssessmentQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentQuery();


    /**
     *  Gets the query for an assessment. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the assessment query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQuery();


    /**
     *  Matches assessment banks that have any assessment assigned. 
     *
     *  @param  match <code> true </code> to match banks with any assessment, 
     *          <code> false </code> to match banks with no assessment 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssessment(boolean match);


    /**
     *  Clears all assessment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTerms();


    /**
     *  Sets the assessment offered <code> Id </code> for this query. 
     *
     *  @param  assessmentOfferedId an assessment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentOfferedId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentOfferedId(org.osid.id.Id assessmentOfferedId, 
                                         boolean match);


    /**
     *  Clears all assessment offered <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentOfferedIdTerms();


    /**
     *  Tests if an <code> AssessmentOfferedQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment offered query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedQuery();


    /**
     *  Gets the query for an assessment offered. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the assessment offered query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentOfferedQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentOfferedQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentOfferedQuery getAssessmentOfferedQuery();


    /**
     *  Matches assessment banks that have any assessment offering assigned. 
     *
     *  @param  match <code> true </code> to match banks with any assessment 
     *          offering, <code> false </code> to match banks with no offering 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssessmentOffered(boolean match);


    /**
     *  Clears all assessment offered terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentOfferedTerms();


    /**
     *  Sets the bank <code> Id </code> for to match banks in which the 
     *  specified bank is an acestor. 
     *
     *  @param  bankId a bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears all ancestor bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBankIdTerms();


    /**
     *  Tests if a <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorBankQuery();


    /**
     *  Gets the query for an ancestor bank. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorBankQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorBankQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.BankQuery getAncestorBankQuery();


    /**
     *  Matches a bank that has any ancestor. 
     *
     *  @param  match <code> true </code> to match banks with any ancestor 
     *          banks, <code> false </code> to match root banks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorBank(boolean match);


    /**
     *  Clears all ancestor bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBankTerms();


    /**
     *  Sets the bank <code> Id </code> for to match banks in which the 
     *  specified bank is a descendant. 
     *
     *  @param  bankId a bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears all descendant bank <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBankIdTerms();


    /**
     *  Tests if a <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantBankQuery();


    /**
     *  Gets the query for a descendant bank. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantBankQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantBankQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.BankQuery getDescendantBankQuery();


    /**
     *  Matches a bank that has any descendant. 
     *
     *  @param  match <code> true </code> to match banks with any descendant 
     *          banks, <code> false </code> to match leaf banks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantBank(boolean match);


    /**
     *  Clears all descendant bank terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBankTerms();


    /**
     *  Gets the bank query record corresponding to the given <code> Bank 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  bankRecordType a bank record type 
     *  @return the bank query record 
     *  @throws org.osid.NullArgumentException <code> bankRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(bankRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.records.BankQueryRecord getBankQueryRecord(org.osid.type.Type bankRecordType)
        throws org.osid.OperationFailedException;
}
