//
// org.osid.assessment.authoring.AssessmentAuthoringManager
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentAuthoringManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>The assessment authoring manager provides access to assessment 
 *  authoring sessions and provides interoperability tests for various aspects 
 *  of this service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AssessmentPartLookupSession: </code> a session to retrieve 
 *      assessment part </li> 
 *      <li> <code> AssessmentPartQuerySession: </code> a session to query for 
 *      assessment part </li> 
 *      <li> <code> AssessmentPartSearchSession: </code> a session to search 
 *      for assessment part </li> 
 *      <li> <code> AssessmentPartAdminSession: </code> a session to create 
 *      and delete assessment part </li> 
 *      <li> <code> AssessmentPartNotificationSession: </code> a session to 
 *      receive notifications pertaining to assessment part changes </li> 
 *      <li> <code> AssessmentPartBankSession: </code> a session to look up 
 *      assessment part bank mappings </li> 
 *      <li> <code> AssessmentPartBankAssignmentSession: </code> a session to 
 *      manage assessment part to bank mappings </li> 
 *      <li> <code> AssessmentPartSmartBankSession: </code> a session to 
 *      manage dynamic bank of assessment part </li> 
 *      <li> <code> AssessmentPartItemSession: </code> a session to look up 
 *      assessment part to item mappings </li> 
 *      <li> <code> AssessmentPartItemDesignSession: </code> a session to map 
 *      items to assessment parts </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SequenceRuleLookupSession: </code> a session to retrieve 
 *      sequence rule </li> 
 *      <li> <code> SequenceRuleQuerySession: </code> a session to query for 
 *      sequence rule </li> 
 *      <li> <code> SequenceRuleSearchSession: </code> a session to search for 
 *      sequence rule </li> 
 *      <li> <code> SequenceRuleAdminSession: </code> a session to create and 
 *      delete sequence rule </li> 
 *      <li> <code> SequenceRuleNotificationSession: </code> a session to 
 *      receive notifications pertaining to sequence rule changes </li> 
 *      <li> <code> SequenceRuleBankSession: </code> a session to look up 
 *      sequence rule bank mappings </li> 
 *      <li> <code> SequenceRuleBankAssignmentSession: </code> a session to 
 *      manage sequence rule to bank mappings </li> 
 *      <li> <code> SequenceRuleSmartBankSession: </code> a session to manage 
 *      dynamic bank of sequence rule </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SequenceRuleEnablerLookupSession: </code> a session to 
 *      retrieve sequence rule enablers </li> 
 *      <li> <code> SequenceRuleEnablerQuerySession: </code> a session to 
 *      query for sequence rule enablers </li> 
 *      <li> <code> SequenceRuleEnablerSearchSession: </code> a session to 
 *      search for sequence rule enablers </li> 
 *      <li> <code> SequenceRuleEnablerAdminSession: </code> a session to 
 *      create and delete sequence rule enablers </li> 
 *      <li> <code> SequenceRuleEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to sequence rule enabler changes 
 *      </li> 
 *      <li> <code> SequenceRuleEnablerBankSession: </code> a session to look 
 *      up sequence rule enabler bank mappings </li> 
 *      <li> <code> SequenceRuleEnablerBankAssignmentSession: </code> a 
 *      session to manage sequence rule enabler to bank mappings </li> 
 *      <li> <code> SequenceRuleEnablerSmartBankSession: </code> a session to 
 *      manage dynamic bank of sequence rule enablers </li> 
 *      <li> <code> SequenceRuleEnableRuleLookupSession: </code> a session to 
 *      look up sequence rule enabler mappings </li> 
 *      <li> <code> SequenceRuleEnablerRuleApplicationSession: </code> a 
 *      session to apply sequence rule enablers </li> 
 *  </ul>
 *  
 */

public interface AssessmentAuthoringManager
    extends org.osid.OsidManager,
            org.osid.assessment.authoring.AssessmentAuthoringProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part lookup service. 
     *
     *  @return an <code> AssessmentPartLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartLookupSession getAssessmentPartLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part lookup service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return an <code> AssessmentPartLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartLookupSession getAssessmentPartLookupSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part query service. 
     *
     *  @return an <code> AssessmentPartQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartQuerySession getAssessmentPartQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part query service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return an <code> AssessmentPartQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartQuerySession getAssessmentPartQuerySessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part search service. 
     *
     *  @return an <code> AssessmentPartSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartSearchSession getAssessmentPartSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part earch service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return an <code> AssessmentPartSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartSearchSession getAssessmentPartSearchSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part administration service. 
     *
     *  @return an <code> AssessmentPartAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartAdminSession getAssessmentPartAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part administration service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return an <code> AssessmentPartAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartAdminSession getAssessmentPartAdminSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part notification service. 
     *
     *  @param  assessmentPartReceiver the notification callback 
     *  @return an <code> AssessmentPartNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentPartReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartNotificationSession getAssessmentPartNotificationSession(org.osid.assessment.authoring.AssessmentPartReceiver assessmentPartReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the assessment 
     *  part notification service for the given bank. 
     *
     *  @param  assessmentPartReceiver the notification callback 
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return an <code> AssessmentPartNotificationSession </code> 
     *  @throws org.osid.NotFoundException no bank found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentPartReceiver 
     *          </code> or <code> bankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartNotificationSession getAssessmentPartNotificationSessionForBank(org.osid.assessment.authoring.AssessmentPartReceiver assessmentPartReceiver, 
                                                                                                                       org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup assessment part/bank 
     *  mappings for assessment parts. 
     *
     *  @return an <code> AssessmentPartBankSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartBank() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartBankSession getAssessmentPartBankSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  assessment part to bank. 
     *
     *  @return an <code> AssessmentPartBankAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartBankAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartBankAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartBankAssignmentSession getAssessmentPartBankAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage assessment part smart 
     *  bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return an <code> AssessmentPartSmartBankSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartSmartBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartSmartBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartSmartBankSession getAssessmentPartSmartBankSession(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  lookup service. 
     *
     *  @return a <code> SequenceRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleLookupSession getSequenceRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  lookup service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleLookupSession getSequenceRuleLookupSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  query service. 
     *
     *  @return a <code> SequenceRuleQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleQuerySession getSequenceRuleQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  query service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleQuerySession getSequenceRuleQuerySessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  search service. 
     *
     *  @return a <code> SequenceRuleSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleSearchSession getSequenceRuleSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  earch service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleSearchSession getSequenceRuleSearchSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  administration service. 
     *
     *  @return a <code> SequenceRuleAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleAdminSession getSequenceRuleAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  administration service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleAdminSession getSequenceRuleAdminSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  notification service. 
     *
     *  @param  sequenceRuleReceiver the notification callback 
     *  @return a <code> SequenceRuleNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleNotificationSession getSequenceRuleNotificationSession(org.osid.assessment.authoring.SequenceRuleReceiver sequenceRuleReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  notification service for the given bank. 
     *
     *  @param  sequenceRuleReceiver the notification callback 
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleNotificationSession </code> 
     *  @throws org.osid.NotFoundException no bank found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleReceiver 
     *          </code> or <code> bankId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleNotificationSession getSequenceRuleNotificationSessionForBank(org.osid.assessment.authoring.SequenceRuleReceiver sequenceRuleReceiver, 
                                                                                                                   org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup sequence rule/bank 
     *  mappings for sequence rules. 
     *
     *  @return a <code> SequenceRuleBankSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleBank() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleBank() </code> is <code> true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleBankSession getSequenceRuleBankSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning sequence 
     *  rule to bank. 
     *
     *  @return a <code> SequenceRuleBankAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleBankAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleBankAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleBankAssignmentSession getSequenceRuleBankAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage sequence rule smart 
     *  bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleSmartBankSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleSmartBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleSmartBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleSmartBankSession getSequenceRuleSmartBankSession(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler lookup service. 
     *
     *  @return a <code> SequenceRuleEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerLookupSession getSequenceRuleEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler lookup service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerLookupSession getSequenceRuleEnablerLookupSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler query service. 
     *
     *  @return a <code> SequenceRuleEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerQuerySession getSequenceRuleEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler query service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerQuerySession getSequenceRuleEnablerQuerySessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler search service. 
     *
     *  @return a <code> SequenceRuleEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerSearchSession getSequenceRuleEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enablers earch service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerSearchSession getSequenceRuleEnablerSearchSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler administration service. 
     *
     *  @return a <code> SequenceRuleEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerAdminSession getSequenceRuleEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler administration service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerAdminSession getSequenceRuleEnablerAdminSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler notification service. 
     *
     *  @param  sequenceRuleEnablerReceiver the notification callback 
     *  @return a <code> SequenceRuleEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerNotificationSession getSequenceRuleEnablerNotificationSession(org.osid.assessment.authoring.SequenceRuleEnablerReceiver sequenceRuleEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler notification service for the given bank. 
     *
     *  @param  sequenceRuleEnablerReceiver the notification callback 
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no bank found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerReceiver </code> or <code> bankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerNotificationSession getSequenceRuleEnablerNotificationSessionForBank(org.osid.assessment.authoring.SequenceRuleEnablerReceiver sequenceRuleEnablerReceiver, 
                                                                                                                                 org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup sequence rule 
     *  enabler/bank mappings for sequence rule enablers. 
     *
     *  @return a <code> SequenceRuleEnablerBankSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerBank() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerBankSession getSequenceRuleEnablerBankSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning sequence 
     *  rule enablers to bank. 
     *
     *  @return a <code> SequenceRuleEnablerBankAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerBankAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerBankAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerBankAssignmentSession getSequenceRuleEnablerBankAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage sequence rule enabler 
     *  smart bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerSmartBankSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerSmartBank() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerSmartBank() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerSmartBankSession getSequenceRuleEnablerSmartBankSession(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler mapping lookup service. 
     *
     *  @return a <code> SequenceRuleEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerRuleLookupSession getSequenceRuleEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler mapping lookup service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerRuleLookupSession getSequenceRuleEnablerRuleLookupSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler assignment service. 
     *
     *  @return a <code> SequenceRuleEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerRuleApplicationSession getSequenceRuleEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequence rule 
     *  enabler assignment service for the given bank. 
     *
     *  @param  bankId the <code> Id </code> of the <code> Bank </code> 
     *  @return a <code> SequenceRuleEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bank </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSequenceRuleEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequenceRuleEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerRuleApplicationSession getSequenceRuleEnablerRuleApplicationSessionForBank(org.osid.id.Id bankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
