//
// org.osid.assessment.authoring.AssessmentPartForm
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This is the form for creating and updating <code> AssessmentParts. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  AssessmentAuthoringSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface AssessmentPartForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidContainableForm,
            org.osid.OsidOperableForm {


    /**
     *  Gets the metadata for the weight. 
     *
     *  @return metadata for the weight 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWeightMetadata();


    /**
     *  Sets the weight on a scale from 0-100. 
     *
     *  @param  weight the new weight 
     *  @throws org.osid.InvalidArgumentException <code> weight </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWeight(long weight);


    /**
     *  Clears the weight. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeight();


    /**
     *  Gets the metadata for the allocated time. 
     *
     *  @return metadata for the allocated time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAllocatedTimeMetadata();


    /**
     *  Sets the allocated time. 
     *
     *  @param  time the allocated time 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAllocatedTime(org.osid.calendaring.Duration time);


    /**
     *  Clears the allocated time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocatedTime();


    /**
     *  Gets the <code> AssessmentPartFormRecord </code> corresponding to the 
     *  given assessment record <code> Type. </code> 
     *
     *  @param  assessmentPartRecordType the assessment part record type 
     *  @return the assessment part record 
     *  @throws org.osid.NullArgumentException <code> assessmentPartRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentPartRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.AssessmentPartFormRecord getAssessmentPartFormRecord(org.osid.type.Type assessmentPartRecordType)
        throws org.osid.OperationFailedException;
}
