//
// org.osid.assessment.authoring.AssessmentPartItemDesignSession
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartItemDesignSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides the means for adding items to an assessment part. 
 *  The item is identified inside an assesment part using its own Id. To add 
 *  the same item to the assessment part, multiple assessment parts should be 
 *  used and placed at the same level in the <code> AssessmentPart </code> 
 *  hierarchy. </p>
 */

public interface AssessmentPartItemDesignSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage mapping of <code> Items </code> to 
     *  <code> AssessmentParts. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  all methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as an application hint that may opt not to 
     *  offer composition operations. 
     *
     *  @return <code> false </code> if assessment part composition is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDesignAssessmentParts();


    /**
     *  Appends an item to an assessment part. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @param  assessmentPartId <code> Id </code> of the <code> 
     *          AssessmentPart </code> 
     *  @throws org.osid.AlreadyExistsException <code> itemId </code> already 
     *          part of <code> assessmentPartId </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> or <code> 
     *          assessmentPartId </code> not found 
     *  @throws org.osid.NullArgumentException <code> itemId </code> or <code> 
     *          assessmentPartId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addItem(org.osid.id.Id itemId, org.osid.id.Id assessmentPartId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders items in an assessment part by moving the specified item in 
     *  front of a reference item. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @param  assessmentPartId <code> Id </code> of the <code> 
     *          AssessmentPartId </code> 
     *  @param  referenceId <code> Id </code> of the reference <code> Item 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> or <code> 
     *          referenceId </code> <code> not found in assessmentPartId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> itemId, referenceId 
     *          </code> or <code> assessmentPartId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveItemAhead(org.osid.id.Id itemId, 
                              org.osid.id.Id assessmentPartId, 
                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders items in an assessment part by moving the specified item 
     *  behind of a reference item. 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @param  assessmentPartId <code> Id of the AssessmentPartId </code> 
     *  @param  referenceId <code> Id </code> of the reference <code> Item 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> or <code> 
     *          referenceId </code> <code> not found in assessmentPartId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> itemId, referenceId 
     *          </code> or <code> assessmentPartId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveItemBehind(org.osid.id.Id itemId, 
                               org.osid.id.Id assessmentPartId, 
                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of items in an assessment part. 
     *
     *  @param  itemIds <code> Ids </code> for a set of <code> Items </code> 
     *  @param  assessmentPartId <code> Id </code> of the <code> 
     *          AssessmentPartId </code> 
     *  @throws org.osid.NotFoundException <code> assessmentPartId </code> not 
     *          found or, an <code> itemId </code> not related to <code> 
     *          assessmentPartId </code> 
     *  @throws org.osid.NullArgumentException <code> itemIds </code> or 
     *          <code> agendaId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderItems(org.osid.id.Id[] itemIds, 
                           org.osid.id.Id assessmentPartId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Item </code> from an <code> AssessmentPartId. 
     *  </code> 
     *
     *  @param  itemId <code> Id </code> of the <code> Item </code> 
     *  @param  assessmentPartId <code> Id </code> of the <code> 
     *          AssessmentPartId </code> 
     *  @throws org.osid.NotFoundException <code> itemId </code> <code> not 
     *          found in assessmentPartId </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> or <code> 
     *          assessmentPartId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeItem(org.osid.id.Id itemId, 
                           org.osid.id.Id assessmentPartId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
