//
// org.osid.assessment.authoring.AssessmentPartLookupSession
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session defines methods for retrieving assessment parts. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated bank view: All assessment part methods in this session 
 *      operate, retrieve and pertain to assessment parts defined explicitly 
 *      in the current bank. </li> 
 *      <li> federated bank view: All assessment part lookup methods in this 
 *      session operate, retrieve and pertain to all assessment part defined 
 *      in this bank and any other assessment parts implicitly available in 
 *      this bank through bank inheritence. </li> 
 *      <li> active assessment part view: All assessment part lookup methods 
 *      return active assessment parts. </li> 
 *      <li> any status assessment part view: Assessment parts of any active 
 *      or inactive status are returned from methods. </li> 
 *      <li> sequestered assessment part viiew: All assessment part methods 
 *      suppress sequestered assessment parts. </li> 
 *      <li> unsequestered assessment part view: All assessment part methods 
 *      return all assessment parts. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBankView() </code> and <code> 
 *  useIsolatedBankView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Assessment parts may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> AssessmentPart. </code> </p>
 */

public interface AssessmentPartLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the <code> Bank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AssessmentPart </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAssessmentParts();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAssessmentPartView();


    /**
     *  A complete view of the <code> AssessmentPart </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAssessmentPartView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include assessment parts in catalogs which are children of this 
     *  catalog in the bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Only active assessment parts are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveAssessmentPartView();


    /**
     *  All active and inactive assessment parts are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusAssessmentPartView();


    /**
     *  The methods in this session omit sequestered assessment parts. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredAssessmentPartView();


    /**
     *  The methods in this session return all assessment parts, including 
     *  sequestered assessment parts. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredAssessmentPartView();


    /**
     *  Gets the <code> AssessmentPart </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  AssessmentPart </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> AssessmentPart </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, assessment parts are returned that are currently 
     *  active. In any effective mode, active and inactive assessment parts 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered assessment parts are returned. In 
     *  unsequestered mode, all assessment parts are returned. 
     *
     *  @param  assessmentPartId the <code> Id </code> of the <code> 
     *          AssessmentPart </code> to retrieve 
     *  @return the returned <code> AssessmentPart </code> 
     *  @throws org.osid.NotFoundException no <code> AssessmentPart </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPart getAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentPartList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  assessment parts specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> AssessmentParts </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, assessment parts are returned that are currently 
     *  active. In any effective mode, active and inactive assessment parts 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered assessment parts are returned. In 
     *  unsequestered mode, all assessment parts are returned. 
     *
     *  @param  assessmentPartIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> AssessmentPart </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentPartIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentPartsByIds(org.osid.id.IdList assessmentPartIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentPartList </code> corresponding to the given 
     *  assessment part genus <code> Type </code> which does not include 
     *  assessment parts of types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  assessment parts or an error results. Otherwise, the returned list may 
     *  contain only those assessment parts that are accessible through this 
     *  session. 
     *  
     *  In active mode, assessment parts are returned that are currently 
     *  active. In any effective mode, active and inactive assessment parts 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered assessment parts are returned. In 
     *  unsequestered mode, all assessment parts are returned. 
     *
     *  @param  assessmentPartGenusType an assessment part genus type 
     *  @return the returned <code> AssessmentPart </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentPartGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentPartsByGenusType(org.osid.type.Type assessmentPartGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentPartList </code> corresponding to the given 
     *  assessment part genus <code> Type </code> and include any additional 
     *  assessment parts with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  assessment parts or an error results. Otherwise, the returned list may 
     *  contain only those assessment parts that are accessible through this 
     *  session. 
     *  
     *  In active mode, assessment parts are returned that are currently 
     *  active. In any effective mode, active and inactive assessment parts 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered assessment parts are returned. In 
     *  unsequestered mode, all assessment parts are returned. 
     *
     *  @param  assessmentGenusType an assessment part genus type 
     *  @return the returned <code> AssessmentPart </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentPartGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentPartsByParentGenusType(org.osid.type.Type assessmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentPart </code> containing the given assessment 
     *  part record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known assessment parts 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those assessment parts that are accessible through this session. 
     *  
     *  In active mode, assessment parts are returned that are currently 
     *  active. In any effective mode, active and inactive assessment parts 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered assessment parts are returned. In 
     *  unsequestered mode, all assessment parts are returned. 
     *
     *  @param  assessmentPartRecordType an assessment part record type 
     *  @return the returned <code> AssessmentPart </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentPartRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentPartsByRecordType(org.osid.type.Type assessmentPartRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentPart </code> for the given assessment. 
     *  
     *  In plenary mode, the returned list contains all known assessment parts 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those assessment parts that are accessible through this session. 
     *  
     *  In active mode, assessment parts are returned that are currently 
     *  active. In any effective mode, active and inactive assessment parts 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered assessment parts are returned. In 
     *  unsequestered mode, all assessment parts are returned. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @return the returned <code> AssessmentPart </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentPartsForAssessment(org.osid.id.Id assessmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> AssessmentParts. </code> 
     *  
     *  In plenary mode, the returned list contains all known assessment parts 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those assessment parts that are accessible through this session. 
     *  
     *  In active mode, assessment parts are returned that are currently 
     *  active. In any effective mode, active and inactive assessment parts 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered assessment parts are returned. In 
     *  unsequestered mode, all assessment parts are returned. 
     *
     *  @return a list of <code> AssessmentParts </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentParts()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
