//
// org.osid.assessment.authoring.AssessmentPartQuery
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This is the query for searching assessment parts. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface AssessmentPartQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidContainableQuery,
            org.osid.OsidOperableQuery {


    /**
     *  Sets the assessment <code> Id </code> for this query. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentId(org.osid.id.Id assessmentId, boolean match);


    /**
     *  Clears all assessment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentIdTerms();


    /**
     *  Tests if an <code> AssessmentQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentQuery();


    /**
     *  Gets the query for an assessment. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the assessment query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQuery();


    /**
     *  Clears all assessment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTerms();


    /**
     *  Sets the assessment part <code> Id </code> for this query. 
     *
     *  @param  assessmentPartId an assessment part <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchParentAssessmentPartId(org.osid.id.Id assessmentPartId, 
                                            boolean match);


    /**
     *  Clears all assessment part <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParentAssessmentPartIdTerms();


    /**
     *  Tests if an <code> AssessmentPartQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment part query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParentAssessmentPartQuery();


    /**
     *  Gets the query for an assessment part. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment part query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParentAssessmentPartQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParentAssessmentPartQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartQuery getParentAssessmentPartQuery();


    /**
     *  Matches assessment parts with any parent assessment part. 
     *
     *  @param  match <code> true </code> to match assessment parts with any 
     *          parent, <code> false </code> to match assessment parts with no 
     *          parents 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyParentAssessmentPart(boolean match);


    /**
     *  Clears all assessment part terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParentAssessmentPartTerms();


    /**
     *  Matches assessment parts that are also used as sections. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSection(boolean match);


    /**
     *  Clears all section terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSectionTerms();


    /**
     *  Matches assessment parts that fall in between the given weights 
     *  inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWeight(long low, long high, boolean match);


    /**
     *  Matches assessment parts with any weight assigned. 
     *
     *  @param  match <code> true </code> to match assessment parts with any 
     *          wieght, <code> false </code> to match assessment parts with no 
     *          weight 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWeight(boolean match);


    /**
     *  Clears all weight terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWeightTerms();


    /**
     *  Matches assessment parts hose allocated time falls in between the 
     *  given times inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAllocatedTime(org.osid.calendaring.Duration low, 
                                   org.osid.calendaring.Duration high, 
                                   boolean match);


    /**
     *  Matches assessment parts with any time assigned. 
     *
     *  @param  match <code> true </code> to match assessment parts with any 
     *          alloocated time, <code> false </code> to match assessment 
     *          parts with no allocated time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAllocatedTime(boolean match);


    /**
     *  Clears all allocated time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocatedTimeTerms();


    /**
     *  Sets the assessment part <code> Id </code> for this query. 
     *
     *  @param  assessmentPartId an assessment part <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchChildAssessmentPartId(org.osid.id.Id assessmentPartId, 
                                           boolean match);


    /**
     *  Clears all assessment part <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChildAssessmentPartIdTerms();


    /**
     *  Tests if an <code> AssessmentPartQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment part query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChildAssessmentPartQuery();


    /**
     *  Gets the query for an assessment part. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment part query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChildAssessmentPartQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChildAssessmentPartQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartQuery getChildAssessmentPartQuery();


    /**
     *  Matches assessment parts with any child assessment part. 
     *
     *  @param  match <code> true </code> to match assessment parts with any 
     *          children, <code> false </code> to match assessment parts with 
     *          no children 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyChildAssessmentPart(boolean match);


    /**
     *  Clears all assessment part terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChildAssessmentPartTerms();


    /**
     *  Matches constrainers mapped to the bank. 
     *
     *  @param  bankId the bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears the bank <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankIdTerms();


    /**
     *  Tests if an <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankQuery();


    /**
     *  Gets the query for a bank. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> supportsBankQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.BankQuery getBankQuery();


    /**
     *  Clears the bank query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankTerms();


    /**
     *  Gets the assessment part query record corresponding to the given 
     *  <code> AssessmentPart </code> record <code> Type. </code> Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  assessmentPartRecordType an assessment part record type 
     *  @return the assessment part query record 
     *  @throws org.osid.NullArgumentException <code> assessmentPartRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentPartRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.AssessmentPartQueryRecord getAssessmentPartQueryRecord(org.osid.type.Type assessmentPartRecordType)
        throws org.osid.OperationFailedException;
}
