//
// org.osid.assessment.authoring.AssessmentPartQueryInspector
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartQueryInspector.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This is the query inspector for examining assessment part queries. </p>
 */

public interface AssessmentPartQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidContainableQueryInspector,
            org.osid.OsidOperableQueryInspector {


    /**
     *  Gets the assessment <code> Id </code> query terms. 
     *
     *  @return the assessment <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssessmentIdTerms();


    /**
     *  Gets the assessment query terms. 
     *
     *  @return the assessment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQueryInspector[] getAssessmentTerms();


    /**
     *  Gets the assessment part <code> Id </code> query terms. 
     *
     *  @return the assessment parent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getParentAssessmentPartIdTerms();


    /**
     *  Gets the assessment part query terms. 
     *
     *  @return the assessment part terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartQueryInspector[] getParentAssessmentPartTerms();


    /**
     *  Gets the section query terms. 
     *
     *  @return the section terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getSectionTerms();


    /**
     *  Gets the weight terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalTerm[] getWeightTerms();


    /**
     *  Gets the allocated time terms. 
     *
     *  @return the time terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationTerm[] getAllocatedTimeTerms();


    /**
     *  Gets the assessment part <code> Id </code> query terms. 
     *
     *  @return the assessment parent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getChildAssessmentPartIdTerms();


    /**
     *  Gets the assessment part query terms. 
     *
     *  @return the assessment part terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartQueryInspector[] getChildAssessmentPartTerms();


    /**
     *  Gets the bank <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBankIdTerms();


    /**
     *  Gets the bank query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.BankQueryInspector[] getBankTerms();


    /**
     *  Gets the assessment part query inspector record corresponding to the 
     *  given <code> AssessmentPart </code> record <code> Type. </code> 
     *
     *  @param  assessmentPartRecordType an assessment part record type 
     *  @return the assessment part query inspector record 
     *  @throws org.osid.NullArgumentException <code> assessmentPartRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentPartRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.AssessmentPartQueryInspectorRecord getAssessmentPartQueryInspectorRecord(org.osid.type.Type assessmentPartRecordType)
        throws org.osid.OperationFailedException;
}
