//
// org.osid.assessment.authoring.AssessmentPartQuerySession
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartQuerySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods for searching among <code> AssessmentPart 
 *  </code> objects. The search query is constructed using the <code> 
 *  AssessmentPartQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bank view: searches include assessment parts in bank of 
 *      which this bank is an ancestor in the bank hierarchy </li> 
 *      <li> isolated bank view: searches are restricted to assessment parts 
 *      in this bank </li> 
 *      <li> sequestered assessment part viiew: All assessment part methods 
 *      suppress sequestered assessment parts. </li> 
 *      <li> unsequestered assessment part view: All assessment part methods 
 *      return all assessment parts. </li> 
 *  </ul>
 *  
 *  
 *  <p> Assessment parts may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  AssessmentPartQuery. </code> </p>
 */

public interface AssessmentPartQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AssessmentPart </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchAssessmentParts();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include assessment part in banks which are children of this step in 
     *  the bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  The methods in this session omit sequestered assessment parts. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredAssessmentPartView();


    /**
     *  The methods in this session return all assessment parts, including 
     *  sequestered assessment parts. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredAssessmentPartView();


    /**
     *  Gets an assessment part query. 
     *
     *  @return the assessment part query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartQuery getAssessmentPartQuery();


    /**
     *  Gets a list of <code> AssessmentParts </code> matching the given 
     *  assessment part query. 
     *
     *  @param  assessmentPartQuery the assessment part query 
     *  @return the returned <code> AssessmentPartList </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentPartQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assessmentPartQuery 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentPartsByQuery(org.osid.assessment.authoring.AssessmentPartQuery assessmentPartQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
