//
// org.osid.assessment.authoring.AssessmentPartSearchResults
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartSearchResults.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This interface provides a means to capture results of a search. </p>
 */

public interface AssessmentPartSearchResults
    extends org.osid.OsidSearchResults {


    /**
     *  Gets the <code> AssessmentPartList </code> resulting from a search. 
     *
     *  @return the assessment part list 
     *  @throws org.osid.IllegalStateException list has already been retrieved 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAssessmentParts();


    /**
     *  Gets the inspector for the query to examine the terms used in the 
     *  search. 
     *
     *  @return the assessment part query inspector 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartQueryInspector getAssessmentPartQueryInspector();


    /**
     *  Gets the assessment part search results record corresponding to the 
     *  given assessment part search record <code> Type. </code> This method 
     *  must be used to retrieve an object implementing the requested record. 
     *
     *  @param  assessmentPartSearchRecordType an assessment part search 
     *          record type 
     *  @return the assessment part search results record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentPartSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentPartSearchRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.AssessmentPartSearchResultsRecord getAssessmentPartSearchResultsRecord(org.osid.type.Type assessmentPartSearchRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
