//
// org.osid.assessment.authoring.AssessmentPartSearchSession
//
//     The OSID Java specification for org.osid.assessment.authoring.AssessmentPartSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods for searching among <code> AssessmentPart 
 *  </code> objects. The search query is constructed using the <code> 
 *  AssessmentPartyQuery. </code> </p> 
 *  
 *  <p> <code> getAssessmentPartsByQuery() </code> is the basic search method 
 *  and returns a list of <code> AssessmentParts. </code> A more advanced 
 *  search may be performed with <code> getAssessmentPartsBySearch(). </code> 
 *  It accepts an <code> AssessmentPartSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as workflow. <code> getAssessmentPartsBySearch() </code> 
 *  returns an <code> AssessmentPartSearchResults </code> that can be used to 
 *  access the resulting <code> AssessmentPartList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  AssessmentPartSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bank view: searches include assessment part in bank of 
 *      which this bank matchmaker is an ancestor in the bank hierarchy </li> 
 *      <li> isolated bank view: searches are restricted to assessment part in 
 *      this bank </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> AssessmentParts </code> may have a query record indicated by 
 *  their respective record types. Thequery record is accessed via the <code> 
 *  AssessmentPartQuery. </code> </p>
 */

public interface AssessmentPartSearchSession
    extends org.osid.assessment.authoring.AssessmentPartQuerySession {


    /**
     *  Gets an assessment part search. 
     *
     *  @return the assessment part search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartSearch getAssessmentPartSearch();


    /**
     *  Gets an assessment part search order. The <code> 
     *  AssessmentPartSearchOrder </code> is supplied to an <code> 
     *  AssessmentPartSearch </code> to specify the ordering of results. 
     *
     *  @return the assessment part search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartSearchOrder getAssessmentPartSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  assessmentPartQuery the assessment part query 
     *  @param  assessmentPartSearch the assessment part search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> assessmentPartQuery 
     *          </code> or <code> assessmentPartSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assessmentPartQuery 
     *          </code> or <code> assessmentPartSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartSearchResults getAssessmentPartsBySearch(org.osid.assessment.authoring.AssessmentPartQuery assessmentPartQuery, 
                                                                                                org.osid.assessment.authoring.AssessmentPartSearch assessmentPartSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an assessment part query from an inspector. The inspector is 
     *  available from an <code> AssessmentPartSearchResults. </code> 
     *
     *  @param  assessmentPartQueryInspector an assessment part query 
     *          inspector 
     *  @return the assessment part query 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentPartQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          assessmentPartQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartQuery getAssessmentPartQueryFromInspector(org.osid.assessment.authoring.AssessmentPartQueryInspector assessmentPartQueryInspector);
}
