//
// org.osid.assessment.authoring.SequenceRule
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRule.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>A <code> SequenceRule </code> defines the ordering of <code> 
 *  AssessmentParts. </code> </p>
 */

public interface SequenceRule
    extends org.osid.OsidRule {


    /**
     *  Gets the assessment part <code> Id </code> to which this rule belongs. 
     *
     *  @return <code> Id </code> of an assessment part 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssessmentPartId();


    /**
     *  Gets the assessment part to which this rule belongs. 
     *
     *  @return an assessment part 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPart getAssessmentPart()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the next assessment part <code> Id </code> for success of this 
     *  rule. 
     *
     *  @return <code> Id </code> of an assessment part 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getNextAssessmentPartId();


    /**
     *  Gets the next assessment part for success of this rule. 
     *
     *  @return an assessment part 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPart getNextAssessmentPart()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the minimum score expressed as an integer (0-100) for this rule. 
     *
     *  @return minimum score 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumScore();


    /**
     *  Gets the maximum score expressed as an integer (0-100) for this rule. 
     *
     *  @return maximum score 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaximumScore();


    /**
     *  Tests if the score is applied to all previous assessment parts. 
     *
     *  @return <code> true </code> if the score is applied to all previous 
     *          assessment parts, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isCumulative();


    /**
     *  Qualifies <code> isCumulative() </code> to apply to a specific list of 
     *  assessment parts. If <code> isCumulative() </code> is <code> true, 
     *  </code> this method may return an empty list to mean all previous 
     *  assessment parts. 
     *
     *  @return list of assessment parts 
     *  @throws org.osid.IllegalStateException <code> isCumulative() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAppliedAssessmentPartIds();


    /**
     *  Qualifies <code> isCumulative() </code> to apply to a specific list of 
     *  assessment parts. If <code> isCumulative() </code> is <code> true, 
     *  </code> this method may return an empty list to mean all previous 
     *  assessment parts. 
     *
     *  @return list of assessment parts 
     *  @throws org.osid.IllegalStateException <code> isCumulative() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.AssessmentPartList getAppliedAssessmentParts()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the assessment sequence rule record corresponding to the given 
     *  <code> SequenceRule </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> sequenceRuleRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(sequenceRuleRecordType) </code> is <code> true </code> . 
     *
     *  @param  sequenceRuleRecordType the type of the record to retrieve 
     *  @return the assessment sequence rule record 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(sequenceRuleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.SequenceRuleRecord getSequenceRuleRecord(org.osid.type.Type sequenceRuleRecordType)
        throws org.osid.OperationFailedException;
}
