//
// org.osid.assessment.authoring.SequenceRuleEnablerLookupSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  SequenceRuleEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated bank view: All sequence rule enabler methods in this 
 *      session operate, retrieve and pertain to sequence rule enablers 
 *      defined explicitly in the current bank. Using an isolated view is 
 *      useful for managing <code> SequenceRuleEnablers </code> with the 
 *      <code> SequenceRuleEnablerAdminSession. </code> </li> 
 *      <li> federated bank view: All sequence rule enabler methods in this 
 *      session operate, retrieve and pertain to all sequence rule enablers 
 *      defined in this bank and any other sequence rule enablers implicitly 
 *      available in this bank through bank inheritence. </li> 
 *      <li> active sequence rule enabler view: All sequence rule enabler 
 *      lookup methods return active sequence rule enablers. </li> 
 *      <li> any active sequence rule enabler view: sequence rule enablers of 
 *      any active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedBankView() </code> and <code> 
 *  useIsolatedBankView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface SequenceRuleEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> SequenceRuleEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSequenceRuleEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSequenceRuleEnablerView();


    /**
     *  A complete view of the <code> SequenceRuleEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySequenceRuleEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include sequence rule enablers in banks which are children of this 
     *  bank in the bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Only active sequence rule enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveSequenceRuleEnablerView();


    /**
     *  All active and inactive sequence rule enablers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusSequenceRuleEnablerView();


    /**
     *  Gets the <code> SequenceRuleEnabler </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  SequenceRuleEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> SequenceRuleEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @param  sequenceRuleEnablerId <code> Id </code> of the <code> 
     *          SequenceRuleEnabler </code> 
     *  @return the sequence rule enabler 
     *  @throws org.osid.NotFoundException <code> sequenceRuleEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnabler getSequenceRuleEnabler(org.osid.id.Id sequenceRuleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  sequence rule enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if a 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> SequenceRuleEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @param  sequenceRuleEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> SequenceRuleEnabler </code> list 
     *  @throws org.osid.NotFoundException a <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablersByIds(org.osid.id.IdList sequenceRuleEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleEnablerList </code> corresponding to the 
     *  given sequence rule enabler genus <code> Type </code> which does not 
     *  include sequence rule enablers of genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule enablers or an error results. Otherwise, the returned 
     *  list may contain only those sequence rule enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @param  sequenceRuleEnablerGenusType a sequence rule enabler genus 
     *          type 
     *  @return the returned <code> SequenceRuleEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablersByGenusType(org.osid.type.Type sequenceRuleEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleEnablerList </code> corresponding to the 
     *  given sequence rule enabler genus <code> Type </code> and include any 
     *  additional sequence rule enablers with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule enablers or an error results. Otherwise, the returned 
     *  list may contain only those sequence rule enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @param  sequenceRuleEnablerGenusType a sequence rule enabler genus 
     *          type 
     *  @return the returned <code> SequenceRuleEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablersByParentGenusType(org.osid.type.Type sequenceRuleEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleEnablerList </code> containing the given 
     *  sequence rule enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule enablers or an error results. Otherwise, the returned 
     *  list may contain only those sequence rule enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @param  sequenceRuleEnablerRecordType a sequence rule enabler record 
     *          type 
     *  @return the returned <code> SequenceRuleEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          sequenceRuleEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablersByRecordType(org.osid.type.Type sequenceRuleEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range for any agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule enablers or an error results. Otherwise, the returned 
     *  list may contain only those sequence rule enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> SequenceRuleEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater tha <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range and evaluated against the given agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule enablers or an error results. Otherwise, the returned 
     *  list may contain only those sequence rule enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> SequenceRuleEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater tha <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                        org.osid.calendaring.DateTime from, 
                                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> SequenceRuleEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known sequence rule 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those sequence rule enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rule enablers are returned that are currently 
     *  active. In any status mode, active and inactive sequence rule enablers 
     *  are returned. 
     *
     *  @return the returned <code> SequenceRuleEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleEnablerList getSequenceRuleEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
