//
// org.osid.assessment.authoring.SequenceRuleForm
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This is the form for creating and updating sequence rules. <code> 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  SequenceSession </code> For each data element that may be set, metadata 
 *  may be examined to provide display hints or data constraints. </p>
 */

public interface SequenceRuleForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for the minimum score. 
     *
     *  @return metadata for the minimum score 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumScoreMetadata();


    /**
     *  Sets the minimum score for this rule. 
     *
     *  @param  score minimum score 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumScore(long score);


    /**
     *  Gets the metadata for the maximum score. 
     *
     *  @return metadata for the maximum score 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaximumScoreMetadata();


    /**
     *  Sets the maximum score for this rule. 
     *
     *  @param  score maximum score 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaximumScore(long score);


    /**
     *  Gets the metadata for the cumulative flag. 
     *
     *  @return metadata for the cumulative flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCumulativeMetadata();


    /**
     *  Applies this rule to all previous assessment parts. 
     *
     *  @param  cumulative <code> true </code> to apply to all previous 
     *          assessment parts. <code> false </code> to apply to the 
     *          immediate previous assessment part 
     *  @throws org.osid.InvalidArgumentException <code> cumulative </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCumulative(boolean cumulative);


    /**
     *  Gets the metadata for the applied assessment parts. 
     *
     *  @return metadata for the applied assessment parts 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAppliedAssessmentPartsMetadata();


    /**
     *  Designates assessment parts to which the rule applies. 
     *
     *  @param  assessmentPartIds the parts to which this rule should apply 
     *  @throws org.osid.InvalidArgumentException <code> assessmentPartIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentPartIds 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAssessmentParts(org.osid.id.Id[] assessmentPartIds);


    /**
     *  Gets the <code> SequenceRuleFormRecord </code> corresponding to the 
     *  given sequence rule record <code> Type. </code> 
     *
     *  @param  sequenceRuleRecord a sequence rule record type 
     *  @return the sequence rule record 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(asequenceRuleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.SequenceRuleFormRecord getSequenceRuleFormRecord(org.osid.type.Type sequenceRuleRecord)
        throws org.osid.OperationFailedException;
}
