//
// org.osid.assessment.authoring.SequenceRuleLookupSession
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This session provides methods for retrieving <code> SequenceRules. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated bank view: All sequence rule methods in this session 
 *      operate, retrieve and pertain to sequence rule defined explicitly in 
 *      the current bank. Using an isolated view is useful for managing <code> 
 *      SequenceRules </code> with the <code> SequenceRuleAdminSession. 
 *      </code> </li> 
 *      <li> federated bank view: All sequence rule methods in this session 
 *      operate, retrieve and pertain to all sequence rule defined in this 
 *      bank and any other sequence rule implicitly available in this bank 
 *      through bank inheritence. </li> 
 *      <li> active sequence rule view: All sequence rule lookup methods 
 *      return active sequence rules. </li> 
 *      <li> any status sequence rule view: sequence rules of any active or 
 *      inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedBankView() </code> and <code> 
 *  useIsolatedBankView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface SequenceRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bank </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bank Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBankId();


    /**
     *  Gets the <code> Bank </code> associated with this session. 
     *
     *  @return the bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.Bank getBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> SequenceRules </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSequenceRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSequenceRuleView();


    /**
     *  A complete view of the <code> SequenceRule </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySequenceRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include sequence rule in banks which are children of this bank in the 
     *  bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBankView();


    /**
     *  Only active sequence rules are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveSequenceRuleView();


    /**
     *  All active and inactive sequence rules are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusSequenceRuleView();


    /**
     *  Gets the <code> SequenceRule </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  SequenceRule </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> SequenceRule </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  sequenceRuleId <code> Id </code> of the <code> SequenceRule 
     *          </code> 
     *  @return the sequence rule 
     *  @throws org.osid.NotFoundException <code> sequenceRuleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRule getSequenceRule(org.osid.id.Id sequenceRuleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  sequence rule specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if a <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> SequenceRules </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  sequenceRuleIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NotFoundException a <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesByIds(org.osid.id.IdList sequenceRuleIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> corresponding to the given 
     *  sequence rule genus <code> Type </code> which does not include 
     *  sequence rule of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule or an error results. Otherwise, the returned list may 
     *  contain only those sequence rule that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  sequenceRuleGenusType a sequence rule genus type 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesByGenusType(org.osid.type.Type sequenceRuleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> corresponding to the given 
     *  sequence rule genus <code> Type </code> and include any additional 
     *  sequence rule with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule or an error results. Otherwise, the returned list may 
     *  contain only those sequence rule that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  sequenceRuleGenusType a sequence rule genus type 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesByParentGenusType(org.osid.type.Type sequenceRuleGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> containing the given sequence 
     *  rule record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule or an error results. Otherwise, the returned list may 
     *  contain only those sequence rule that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  sequenceRuleRecordType a sequence rule record type 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesByRecordType(org.osid.type.Type sequenceRuleRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> for the given source assessment 
     *  part. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule or an error results. Otherwise, the returned list may 
     *  contain only those sequence rule that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  assessmentPartId an assessment part <code> Id </code> 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesForAssessmentPart(org.osid.id.Id assessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> for the given target assessment 
     *  part. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule or an error results. Otherwise, the returned list may 
     *  contain only those sequence rule that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  nextAssessmentPartId an assessment part <code> Id </code> 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NullArgumentException <code> nextAssessmentPartId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesForNextAssessmentPart(org.osid.id.Id nextAssessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> for the given source and target 
     *  assessment parts. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule or an error results. Otherwise, the returned list may 
     *  contain only those sequence rule that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  assessmentPartId source assessment part <code> Id </code> 
     *  @param  nextAssessmentPartId target assessment part <code> Id </code> 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          or <code> nextAssessmentPartId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesForAssessmentParts(org.osid.id.Id assessmentPartId, 
                                                                                             org.osid.id.Id nextAssessmentPartId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SequenceRuleList </code> for an entire assessment. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  sequence rule or an error results. Otherwise, the returned list may 
     *  contain only those sequence rule that are accessible through this 
     *  session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRulesForAssessment(org.osid.id.Id assessmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> SequenceRules. </code> 
     *  
     *  In plenary mode, the returned list contains all known sequence rule or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  sequence rule that are accessible through this session. 
     *  
     *  In active mode, sequence rules are returned that are currently active. 
     *  In any status mode, active and inactive sequence rules are returned. 
     *
     *  @return the returned <code> SequenceRule </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.SequenceRuleList getSequenceRules()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
