//
// org.osid.assessment.authoring.SequenceRuleQuery
//
//     The OSID Java specification for org.osid.assessment.authoring.SequenceRuleQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.authoring;


/**
 *  <p>This is the query for searching sequence rules. Each method match 
 *  specifies a <code> AND </code> term while multiple invocations of the same 
 *  method produce a nested <code> OR. </code> </p>
 */

public interface SequenceRuleQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Sets the assessment part <code> Id </code> for this query. 
     *
     *  @param  assessmentPartId an assessment part <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentPartId(org.osid.id.Id assessmentPartId, 
                                      boolean match);


    /**
     *  Clears all assessment part <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentPartIdTerms();


    /**
     *  Tests if an <code> AssessmentPartQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment part query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentPartQuery();


    /**
     *  Gets the query for an assessment part. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment part query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentPartQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentPartQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartQuery getAssessmentPartQuery();


    /**
     *  Clears all assessment part terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentPartTerms();


    /**
     *  Sets the assessment part <code> Id </code> for this query. 
     *
     *  @param  assessmentPartId an assessment part <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNextAssessmentPartId(org.osid.id.Id assessmentPartId, 
                                          boolean match);


    /**
     *  Clears all assessment part <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNextAssessmentPartIdTerms();


    /**
     *  Tests if an <code> AssessmentPartQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment part query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNextAssessmentPartQuery();


    /**
     *  Gets the query for an assessment part. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment part query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNextAssessmentPartQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNextAssessmentPartQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartQuery getNextAssessmentPartQuery();


    /**
     *  Clears all assessment part terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNextAssessmentPartTerms();


    /**
     *  Matches minimum scores that fall in between the given scores 
     *  inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumScore(long low, long high, boolean match);


    /**
     *  Matches assessment parts with any minimum score assigned. 
     *
     *  @param  match <code> true </code> to match assessment parts with any 
     *          minimum score, <code> false </code> to match assessment parts 
     *          with no minimum score 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMinimumScore(boolean match);


    /**
     *  Clears all minimum score terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumScoreTerms();


    /**
     *  Matches maximum scores that fall in between the given scores 
     *  inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMaximumScore(long low, long high, boolean match);


    /**
     *  Matches assessment parts with any maximum score assigned. 
     *
     *  @param  match <code> true </code> to match assessment parts with any 
     *          maximum score, <code> false </code> to match assessment parts 
     *          with no maximum score 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMaximumScore(boolean match);


    /**
     *  Clears all maximum score terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumScoreTerms();


    /**
     *  Matches cumulative rules. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCumulative(boolean match);


    /**
     *  Clears all cumulative terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCumulativeTerms();


    /**
     *  Sets the assessment part <code> Id </code> for this query. 
     *
     *  @param  assessmentPartId an assessment part <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentPartId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAppliedAssessmentPartId(org.osid.id.Id assessmentPartId, 
                                             boolean match);


    /**
     *  Clears all assessment part <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAppliedAssessmentPartIdTerms();


    /**
     *  Tests if an <code> AssessmentPartQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment part query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppliedAssessmentPartQuery();


    /**
     *  Gets the query for an assessment part. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the assessment part query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppliedAssessmentPartQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppliedAssessmentPartQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.assessment.authoring.AssessmentPartQuery getAppliedAssessmentPartQuery();


    /**
     *  Matches assessment parts with any applied assessment part. 
     *
     *  @param  match <code> true </code> to match assessment parts with any 
     *          applied assessment part, <code> false </code> to match 
     *          assessment parts with no applied assessment parts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAppliedAssessmentPart(boolean match);


    /**
     *  Clears all assessment part terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAppliedAssessmentPartTerms();


    /**
     *  Matches constrainers mapped to the bank. 
     *
     *  @param  bankId the bank <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bankId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankId(org.osid.id.Id bankId, boolean match);


    /**
     *  Clears the bank <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankIdTerms();


    /**
     *  Tests if an <code> BankQuery </code> is available. 
     *
     *  @return <code> true </code> if a bank query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankQuery();


    /**
     *  Gets the query for a bank. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bank query 
     *  @throws org.osid.UnimplementedException <code> supportsBankQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBankQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.BankQuery getBankQuery();


    /**
     *  Clears the bank query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankTerms();


    /**
     *  Gets the sequence rule query record corresponding to the given <code> 
     *  SequenceRule </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  sequenceRuleRecordType a sequence rule record type 
     *  @return the sequence rule query record 
     *  @throws org.osid.NullArgumentException <code> sequenceRuleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(sequenceRuleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.authoring.records.SequenceRuleQueryRecord getSequenceRuleQueryRecord(org.osid.type.Type sequenceRuleRecordType)
        throws org.osid.OperationFailedException;
}
