//
// org.osid.assessment.batch.AssessmentBatchProfile
//
//     The OSID Java specification for org.osid.assessment.batch.AssessmentBatchProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.batch;


/**
 *  <p>The <code> AssessmentBatchProfile </code> describes the 
 *  interoperability among batch assessment services. </p>
 */

public interface AssessmentBatchProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if bulk administration of items is available. 
     *
     *  @return <code> true </code> if an item bulk administrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemBatchAdmin();


    /**
     *  Tests if bulk administration of assessments is available. 
     *
     *  @return <code> true </code> if an assessment bulk administrative 
     *          service is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentBatchAdmin();


    /**
     *  Tests if bulk administration of assessments offered is available. 
     *
     *  @return <code> true </code> if an assessment offered bulk 
     *          administrative service is available, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentOfferedBatchAdmin();


    /**
     *  Tests if bulk administration of assessments taken is available. 
     *
     *  @return <code> true </code> if anassessment taken bulk administrative 
     *          service is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentTakenBatchAdmin();


    /**
     *  Tests if bulk administration of banks is available. 
     *
     *  @return <code> true </code> if a bank bulk administrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBankBatchAdmin();
}
