//
// org.osid.assessment.batch.BankBatchAdminSession
//
//     The OSID Java specification for org.osid.assessment.batch.BankBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Banks </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Bank, </code> a <code> BankForm </code> is requested using <code> 
 *  getBankFormsForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. Each of the 
 *  returned <code> BankForms </code> will indicate that it is to be used with 
 *  a create operation and can be used to examine metdata or validate data 
 *  prior to creation. Once a <code> BankForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> BankForm </code> corresponds 
 *  to an attempted transaction. </p> 
 *  
 *  <p> The <code> BankForms </code> returned from <code> 
 *  getBankFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BankForm. </code> In the 
 *  case where there may be duplicates, any <code> BankForm </code> of the 
 *  same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BankForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BankForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createBanks(), 
 *  </code> errors specific to an individual <code> BankForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> BankForm 
 *  </code> through the <code> BankForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BankForms </code> are requested to the <code> Bank 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getBankFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BankForm </code> may be used to link the request. Similarly, 
 *  the <code> BankForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> BankForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> BankForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> BankForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateBanks(), 
 *  </code> errors specific to an individual <code> BankForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> BankForm 
 *  </code> through the <code> BankForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Banks </code> in bulk. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface BankBatchAdminSession
    extends org.osid.assessment.BankAdminSession {


    /**
     *  Gets the bank forms for creating a bunch of new banks. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  bankRecordTypes array of bank record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the bank forms 
     *  @throws org.osid.NullArgumentException <code> bankRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.BankBatchFormList getBankFormsForCreate(long number, 
                                                                             org.osid.type.Type[] bankRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Banks. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  bankForms the bank forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> bankForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBanks(org.osid.assessment.batch.BankBatchFormList bankForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the bank forms for updating an existing set of banks. A new bank 
     *  form should be requested for each update transaction. 
     *
     *  @param  bankIds the <code> Ids </code> of the <code> Bank </code> 
     *  @return the bank form 
     *  @throws org.osid.NotFoundException a <code> bankId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> bankIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.BankBatchFormList getBankFormsForUpdate(org.osid.id.IdList bankIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing banks. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  bankForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> bankForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBanks(org.osid.assessment.batch.BankBatchFormList bankForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Banks. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBanks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes banks for the given <code> Ids. </code> 
     *
     *  @param  bankIds the <code> Ids </code> of the banks to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> bankIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBanks(org.osid.id.IdList bankIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Bank </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Bank </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another bank, it is reassigned to the given bank <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBanks(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
