//
// org.osid.assessment.batch.ItemBatchAdminSession
//
//     The OSID Java specification for org.osid.assessment.batch.ItemBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.assessment.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Items </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Item, </code> an <code> ItemForm </code> is requested using <code> 
 *  getItemFormsForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. Each of the 
 *  returned <code> ItemForms </code> will indicate that it is to be used with 
 *  a create operation and can be used to examine metdata or validate data 
 *  prior to creation. Once an <code> ItemForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ItemForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ItemForms </code> returned from <code> 
 *  getItemFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> ItemForm. </code> In the 
 *  case where there may be duplicates, any <code> ItemForm </code> of the 
 *  same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ItemForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> ItemForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createItems(), 
 *  </code> errors specific to an individual <code> ItemForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> ItemForm 
 *  </code> through the <code> ItemForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ItemForms </code> are requested to the <code> Item 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getItemFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> ItemForm </code> may be used to link the request. Similarly, 
 *  the <code> ItemForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> ItemForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ItemForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> ItemForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateItems(), 
 *  </code> errors specific to an individual <code> ItemForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> ItemForm 
 *  </code> through the <code> ItemForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Items </code> in bulk. To unmap an 
 *  <code> Item </code> from the current <code> Bank, </code> the <code> 
 *  ItemBankAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Item </code> itself thus removing it from all 
 *  known <code> Bank </code> catalogs. Bulk delete operations return the 
 *  results in <code> DeleteResponses. </code> </p>
 */

public interface ItemBatchAdminSession
    extends org.osid.assessment.ItemAdminSession {


    /**
     *  Gets the item forms for creating a bunch of new items. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  itemRecordTypes array of item record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the item forms 
     *  @throws org.osid.NullArgumentException <code> itemRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.ItemBatchFormList getItemFormsForCreate(long number, 
                                                                             org.osid.type.Type[] itemRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Items. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  itemForms the item forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> itemForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createItems(org.osid.assessment.batch.ItemBatchFormList itemForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the item forms for updating an existing set of items. A new item 
     *  form should be requested for each update transaction. 
     *
     *  @param  itemIds the <code> Ids </code> of the <code> Items </code> 
     *  @return the item forms 
     *  @throws org.osid.NotFoundException an <code> itemId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> itemIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.ItemBatchFormList getItemFormsForUpdate(org.osid.id.IdList itemIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing items. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  itemForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> itemForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateItems(org.osid.assessment.batch.ItemBatchFormList itemForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Items </code> in this <code> Bank </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllItems()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes items for the given <code> Ids. </code> 
     *
     *  @param  itemIds the <code> Ids </code> of the items to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> itemIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteItems(org.osid.id.IdList itemIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Item </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Item </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another item, it is reassigned to the given item <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasItems(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the question forms for creating a bunch of new questions. A new 
     *  form is retrieved for each supplied item <code> Id. </code> 
     *
     *  @param  itemIds a list of item <code> Ids </code> 
     *  @param  questionRecordTypes array of question record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the question forms 
     *  @throws org.osid.NotFoundException an <code> itemId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> itemIds </code> or 
     *          <code> questionRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.QuestionBatchFormList getQuestionFormsForCreate(org.osid.id.IdList itemIds, 
                                                                                     org.osid.type.Type[] questionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Questions. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  questionForms the question forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> questionForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createQuestions(org.osid.assessment.batch.QuestionBatchFormList questionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the question forms for updating an existing set of questions. A 
     *  new question form should be requested for each update transaction. 
     *
     *  @param  questionIds the <code> Ids </code> of the <code> Questions 
     *          </code> 
     *  @return the question forms 
     *  @throws org.osid.NotFoundException a <code> questionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> questionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.QuestionBatchFormList getQuestionFormsForUpdate(org.osid.id.IdList questionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing questions. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  questionForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> questionForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateQuestions(org.osid.assessment.batch.QuestionBatchFormList questionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Questions </code> in this <code> Bank </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllQuestions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes questions for the given <code> Ids. </code> 
     *
     *  @param  questionIds the <code> Ids </code> of the questions to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> questionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteQuestions(org.osid.id.IdList questionIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the answer forms for creating a bunch of new answers. A new form 
     *  is retrieved for each supplied item <code> Id. </code> 
     *
     *  @param  itemIds a list of item <code> Ids </code> 
     *  @param  answerRecordTypes array of answer record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the answer forms 
     *  @throws org.osid.NotFoundException an <code> itemId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> itemIds </code> or 
     *          <code> answerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.AnswerBatchFormList getAnswerFormsForCreate(org.osid.id.IdList itemIds, 
                                                                                 org.osid.type.Type[] answerRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Answers. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  answersForms the answer forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> answerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAnswers(org.osid.assessment.batch.AnswerBatchFormList answersForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the answers forms for updating an existing set of answers. A new 
     *  answer form should be requested for each update transaction. 
     *
     *  @param  answersIds the <code> Ids </code> of the <code> Answers 
     *          </code> 
     *  @return the answer forms 
     *  @throws org.osid.NotFoundException an <code> answerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> answerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.batch.AnswerBatchFormList getAnswerFormsForUpdate(org.osid.id.IdList answersIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing answers. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  answersForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> answerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAnswers(org.osid.assessment.batch.AnswerBatchFormList answersForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Answers </code> in this <code> Bank </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAnswers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes answers for the given <code> Ids. </code> 
     *
     *  @param  answersIds the <code> Ids </code> of the answers to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> answerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAnswers(org.osid.id.IdList answersIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
