//
// org.osid.authentication.AgencySearchSession
//
//     The OSID Java specification for org.osid.authentication.AgencySearchSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>This session provides methods for searching among <code> Agency </code> 
 *  objects. The search query is constructed using the <code> AgencyQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getAgenciesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Agency </code> objects.A more advanced search may 
 *  be performed with <code> getAgenciesBySearch(). </code> It accepts a 
 *  <code> AgencySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAgenciesBySearch() </code> returns a <code> 
 *  AgencySearchResults </code> that can be used to access the resulting 
 *  <code> AgencyList </code> or be used to perform a search within the result 
 *  set through <code> AgencySearch. </code> </p> 
 *  
 *  <p> Agencies may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> AgencyQuery. </code> 
 *  </p>
 */

public interface AgencySearchSession
    extends org.osid.authentication.AgencyQuerySession {


    /**
     *  Gets an agency search. 
     *
     *  @return an agency search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgencySearch getAgencySearch();


    /**
     *  Gets an agency search order. The <code> AgencySearchOrder </code> is 
     *  supplied to a <code> AgencySearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the agency search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgencySearchOrder getAgencySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  agencyQuery the agency query 
     *  @param  agencySearch the agency search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> agencyQuery </code> or 
     *          <code> agencySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> agencyQuery </code> or 
     *          <code> agencySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgencySearchResults getAgenciesBySearch(org.osid.authentication.AgencyQuery agencyQuery, 
                                                                           org.osid.authentication.AgencySearch agencySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an agency query from an inspector. The inspector is available 
     *  from an <code> AgencySearchResults. </code> 
     *
     *  @param  agencyQueryInspector an agency query inspector 
     *  @return the agency query 
     *  @throws org.osid.NullArgumentException <code> agencyQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> agencyQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgencyQuery getAgencyQueryFromInspector(org.osid.authentication.AgencyQueryInspector agencyQueryInspector);
}
