//
// org.osid.authentication.AgentQuerySession
//
//     The OSID Java specification for org.osid.authentication.AgentQuerySession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>This session provides methods for searching <code> Agents. </code> The 
 *  search query is constructed using the <code> AgentQuery. </code> The agent 
 *  record <code> Type </code> also specifies the record for the agent query. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated agency view: searches include agents in agencies of 
 *      which this agency is a ancestor in the agency hierarchy </li> 
 *      <li> isolated agency view: searches are restricted to agents in this 
 *      agency </li> 
 *  </ul>
 *  
 *  
 *  <p> Agents may have an agent query record indicated by their respective 
 *  agent record types. The agent query record is accessed via the <code> 
 *  AgentQuery. </code> </p>
 */

public interface AgentQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Agency </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Agency Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgencyId();


    /**
     *  Gets the <code> Agency </code> associated with this session. 
     *
     *  @return the <code> Agency </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agency getAgency()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Agent </code> searches. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchAgents();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include agents in agencies which are children of this agency in the 
     *  agency hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAgencyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this agency only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAgencyView();


    /**
     *  Gets an agent query. 
     *
     *  @return the agent query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentQuery getAgentQuery();


    /**
     *  Gets a list of <code> Agents </code> matching the given agent query. 
     *
     *  @param  agentQuery the agent query 
     *  @return the returned <code> AgentList </code> 
     *  @throws org.osid.NullArgumentException <code> agentQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> agentQuery </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentList getAgentsByQuery(org.osid.authentication.AgentQuery agentQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
