//
// org.osid.authentication.AuthenticationManager
//
//     The OSID Java specification for org.osid.authentication.AuthenticationManager.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication;


/**
 *  <p>The authentication manager provides access to authentication sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AgentLookupSession: </code> a session to look up <code> 
 *      Agents </code> </li> 
 *      <li> <code> AgentQuerySession: </code> a session to query <code> 
 *      Agents </code> </li> 
 *      <li> <code> AgentSearchSession: </code> a session to search <code> 
 *      Agents </code> </li> 
 *      <li> <code> AgentAdminSession: </code> a session to create, modify and 
 *      delete <code> Agents </code> </li> 
 *      <li> <code> AgentNotificationSession: a </code> session to receive 
 *      messages pertaining to <code> Agent </code> changes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AgentAgencySession: </code> a session to retrieve <code> 
 *      Agent </code> to <code> Agency </code> mappings </li> 
 *      <li> <code> AgentAgencyAssignmentSession: </code> a session to manage 
 *      <code> Agent </code> to <code> Agency </code> mappings </li> 
 *      <li> <code> AgentSmartAgencySession: </code> a session to create 
 *      dynamic agencies </li> 
 *      <li> <code> AgencyLookupSession: </code> a session to lookup agencies 
 *      </li> 
 *      <li> <code> AgencyQuerySession: </code> a session to query agencies 
 *      </li> 
 *      <li> <code> AgencySearchSession </code> : a session to search agencies 
 *      </li> 
 *      <li> <code> AgencyAdminSession </code> : a session to create, modify 
 *      and delete agencies </li> 
 *      <li> <code> AgencyNotificationSession </code> : a session to receive 
 *      messages pertaining to <code> Agency </code> changes </li> 
 *      <li> <code> AgencyHierarchySession </code> : a session to traverse the 
 *      <code> Agency </code> hierarchy </li> 
 *      <li> <code> AgencyHierarchyDesignSession </code> : a session to manage 
 *      the <code> Agency </code> hierarchy </li> 
 *  </ul>
 *  
 */

public interface AuthenticationManager
    extends org.osid.OsidManager,
            org.osid.authentication.AuthenticationProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the agent lookup 
     *  service. 
     *
     *  @return an <code> AgentLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgentLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentLookup() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentLookupSession getAgentLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent lookup 
     *  service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return <code> an AgentLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAgentLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentLookupSession getAgentLookupSessionForAgency(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent query 
     *  service. 
     *
     *  @return an <code> AgentQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuerySession getAgentQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent query 
     *  service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return <code> an AgentQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuerySession getAgentQuerySessionForAgency(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent search 
     *  service. 
     *
     *  @return an <code> AgentSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgentSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentSearch() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentSearchSession getAgentSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent search 
     *  service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return <code> an AgentSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAgentSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentSearchSession getAgentSearchSessionForAgency(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent 
     *  administration service. 
     *
     *  @return an <code> AgentAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgentAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentAdmin() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentAdminSession getAgentAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent admin 
     *  service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return <code> an AgentAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAgentAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentAdminSession getAgentAdminSessionForAgency(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to service 
     *  changes. 
     *
     *  @param  agentReceiver the agent receiver 
     *  @return an <code> AgentNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> agentReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgentNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentNotificationSession getAgentNotificationSession(org.osid.authentication.AgentReceiver agentReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent 
     *  notification service for the given agency. 
     *
     *  @param  agentReceiver the agent receiver 
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return <code> an AgentNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agentReceiver </code> or 
     *          <code> agencyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgentNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentNotificationSession getAgentNotificationSessionForAgency(org.osid.authentication.AgentReceiver agentReceiver, 
                                                                                                 org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving agent to agency mappings. 
     *
     *  @return an <code> AgentAgencySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgentAgency() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentAgency() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentAgencySession getAgentAgencySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning agent to agency mappings. 
     *
     *  @return a <code> AgentAgencyAsignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgentAgencyAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentAgencyAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentAgencyAssignmentSession getAgentAgencyAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agent smart 
     *  agency service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return an <code> AgentSmartAgencySession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgentSmartAgency() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentSmartAgency() </code> and <code> 
     *              supportsVisibeFederation() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentSmartAgencySession getAgentSmartAgencySession(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agency lookup 
     *  service. 
     *
     *  @return an <code> AgencyLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgencyLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgencyLookup() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgencyLookupSession getAgencyLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agency search 
     *  service. 
     *
     *  @return an <code> AgencySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgencySearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgencySearch() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgencySearchSession getAgencySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agency 
     *  administration service. 
     *
     *  @return an <code> AgencyAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgencyAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgencyAdmin() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgencyAdminSession getAgencyAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to agency 
     *  service changes. 
     *
     *  @param  agencyReceiver the agency receiver 
     *  @return an <code> AgencyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> agencyReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgencyNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgencyNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgencyNotificationSession getAgencyNotificationSession(org.osid.authentication.AgencyReceiver agencyReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing agency hierarchies. 
     *
     *  @return an <code> AgencyHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgencyHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgencyHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgencyHierarchySession getAgencyHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing agency hierarchies. 
     *
     *  @return an <code> AgencyHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgencyHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgencyHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgencyHierarchyDesignSession getAgencyHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AuthenticationBatchManager. </code> 
     *
     *  @return an <code> AuthenticationBatchManager. </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthenticationBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthenticationBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.batch.AuthenticationBatchManager getAuthenticationBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AuthenticationKeysManager. </code> 
     *
     *  @return an <code> AuthenticationKeysManager. </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthenticationKeys() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthenticationKeys() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.keys.AuthenticationKeysManager getAuthenticationKeysManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AuthenticationProcessManager. </code> 
     *
     *  @return an <code> AuthenticationProcessManager. </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthenticationProcess() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthenticationProcess() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.process.AuthenticationProcessManager getAuthenticationProcessManager()
        throws org.osid.OperationFailedException;
}
