//
// org.osid.authentication.keys.AuthenticationKeysProfile
//
//     The OSID Java specification for org.osid.authentication.keys.AuthenticationKeysProfile.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.keys;


/**
 *  <p>The <code> AuthenticationKeysProfile </code> describes the 
 *  interoperability among authentication keys services. </p>
 */

public interface AuthenticationKeysProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a key lookup service is supported. A key lookup service 
     *  defines methods to access keys. 
     *
     *  @return <code> true </code> if key lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyLookup();


    /**
     *  Tests if a key search service is supported. 
     *
     *  @return <code> true </code> if key search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeySearch();


    /**
     *  Tests if a key administrative service is supported. 
     *
     *  @return <code> true </code> if key admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyAdmin();


    /**
     *  Tests if key notification is supported. Messages may be sent when keys 
     *  are created, modified, or deleted. 
     *
     *  @return <code> true </code> if key notification is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyNotification();


    /**
     *  Tests if retrieving mappings of keys and agencies is supported. 
     *
     *  @return <code> true </code> if key agency mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyAgency();


    /**
     *  Tests if managing mappings of keys and agencies is supported. 
     *
     *  @return <code> true </code> if key agency assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyAgencyAssignment();


    /**
     *  Tests if key smart agency is available. 
     *
     *  @return <code> true </code> if key smart agency is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeySmartAgency();


    /**
     *  Gets the supported <code> Key </code> record types. 
     *
     *  @return a list containing the supported <code> Key </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getKeyRecordTypes();


    /**
     *  Tests if the given <code> Key </code> record type is supported. 
     *
     *  @param  keyRecordType a <code> Type </code> indicating a <code> Key 
     *          </code> type 
     *  @return <code> true </code> if the given key record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> keyRecordType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyRecordType(org.osid.type.Type keyRecordType);


    /**
     *  Gets the supported key search record types. 
     *
     *  @return a list containing the supported <code> Key </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getKeySearchRecordTypes();


    /**
     *  Tests if the given key search record type is supported. 
     *
     *  @param  keySearchRecordType a <code> Type </code> indicating a <code> 
     *          Key </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> keySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeySearchRecordType(org.osid.type.Type keySearchRecordType);
}
