//
// org.osid.authentication.keys.KeySmartAgencySession
//
//     The OSID Java specification for org.osid.authentication.keys.KeySmartAgencySession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.keys;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> KeyQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Agency </code> to create a virtual collection of 
 *  <code> Keys. </code> The keys may be sequenced using the <code> 
 *  KeySearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Agency </code> has a default query that matches any key 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using an <code> KeyQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to an <code> KeyQuery. </code> 
 *  </p>
 */

public interface KeySmartAgencySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Agency </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Agency Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgencyId();


    /**
     *  Gets the <code> Agency </code> associated with this session. 
     *
     *  @return the <code> Agency </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agency getAgency()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart agencies. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart agency management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartAgencies();


    /**
     *  Gets an key query. 
     *
     *  @return the key query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeyQuery getKeyQuery();


    /**
     *  Gets an key search order. 
     *
     *  @return the key search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeySearchOrder getKeySearchOrder();


    /**
     *  Applies an key query to this agency. 
     *
     *  @param  keyQuery the key query 
     *  @throws org.osid.NullArgumentException <code> keyQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> keyQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyKeyQuery(org.osid.authentication.keys.KeyQuery keyQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an key query inspector for this agency. 
     *
     *  @return the key query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeyQueryInspector inspectKeyQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an key search order to this agency. 
     *
     *  @param  keySearchOrder the key search order 
     *  @throws org.osid.NullArgumentException <code> keySearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> keySearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyKeySequencing(org.osid.authentication.keys.KeySearchOrder keySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an key query from an inspector. 
     *
     *  @param  keyQueryInspector a query inspector 
     *  @return the key query 
     *  @throws org.osid.NullArgumentException <code> keyQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> keyQueryInspector </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.KeyQuery getKeyQueryFromInspector(org.osid.authentication.keys.KeyQueryInspector keyQueryInspector);
}
