//
// org.osid.authentication.keys.batch.KeyBatchAdminSession
//
//     The OSID Java specification for org.osid.authentication.keys.batch.KeyBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.keys.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Keys </code> in bulk. 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Key, </code> a <code> KeyForm </code> is requested using <code> 
 *  getKeyFormsForCreate() </code> specifying the desired agent and record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> KeyForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> KeyForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> KeyForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> KeyForms </code> returned from <code> 
 *  getKeyFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> KeyForm. </code> In the 
 *  case where there may be duplicates, any <code> KeyForm </code> of the same 
 *  peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> KeyForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> KeyForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire create operation are returned from <code> createKeys(), </code> 
 *  errors specific to an individual <code> KeyForm </code> are indicated in 
 *  the corresponding <code> CreateResponse. </code> <code> CreateResponses 
 *  </code> may be linked to the originating <code> KeyForm </code> through 
 *  the <code> KeyForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> KeyForms </code> are requested to the <code> Key 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getKeyFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> KeyForm </code> may be used to link the request. Similarly, the 
 *  <code> KeyForm </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> KeyForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> KeyForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> KeyForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire update operation are returned from <code> updateKeys(), </code> 
 *  errors specific to an individual <code> KeyForm </code> are indicated in 
 *  the corresponding <code> UpdateResponse. </code> <code> UpdateResponses 
 *  </code> may be linked to the originating <code> KeyForm </code> through 
 *  the <code> KeyForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Keys </code> in bulk. To unmap a 
 *  <code> Key </code> from the current <code> Agency, </code> the <code> 
 *  KeyAgencyAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Key </code> itself thus removing it from all 
 *  known <code> Agency </code> catalogs. Bulk delete operations return the 
 *  results in <code> DeleteResponses. </code> </p>
 */

public interface KeyBatchAdminSession
    extends org.osid.authentication.keys.KeyAdminSession {


    /**
     *  Gets the key forms for creating a bunch of new keys. A key form is 
     *  returned for each supplied agent. 
     *
     *  @param  agentIds a list of agent <code> Ids </code> 
     *  @param  keyRecordTypes array of key record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the key forms 
     *  @throws org.osid.NotFoundException <code> an agentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> agentIds </code> or 
     *          <code> keyRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.batch.KeyBatchFormList getKeyFormsForCreate(org.osid.id.IdList agentIds, 
                                                                                    org.osid.type.Type[] keyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Keys. </code> This method returns an error 
     *  if the entire operation fails. Otherwise, the status of an individual 
     *  create operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  keyForms the key forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> keyForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createKeys(org.osid.authentication.keys.batch.KeyBatchFormList keyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the key forms for updating an existing set of keys. A new key 
     *  form should be requested for each update transaction. 
     *
     *  @param  keyIds the <code> Ids </code> of the <code> Key </code> 
     *  @return the key form 
     *  @throws org.osid.NotFoundException a <code> keyId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> keyIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.keys.batch.KeyBatchFormList getKeyFormsForUpdate(org.osid.id.IdList keyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing keys. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  keyForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> keyForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateKeys(org.osid.authentication.keys.batch.KeyBatchFormList keyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Keys </code> in this <code> Agency </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllKeys()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes keys for the given <code> Ids. </code> 
     *
     *  @param  keyIds the <code> Ids </code> of the keys to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> keyIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteKeys(org.osid.id.IdList keyIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes keys for the given agent <code> Id. </code> 
     *
     *  @param  agentId the <code> Id </code> of an agent 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteKeysForAgent(org.osid.id.Id agentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Key </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Key </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another key, it is reassigned to the given key <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasKeys(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
