/**
 * <p>The Open Service Interface Definitions for the org.osid.authentication
 * service.</p>
 * 
 * <p>The Authentication OSID manages authenticated entities. </p> 
 * <h4> Agent </h4> 
 * 
 * <p> The Authentication OSID defines an <code> Agent </code> to represent 
 * the identity of the authenticated entity. An Agent may map to a specific 
 * authentication principal while some providers may elect to hide multiple 
 * authentication principals behind a single <code> Agent. </code> Because 
 * principal identities tend not to be durable and persistent, consumers 
 * should always persist the <code> Id. </code> </p> 
 * <h4> Resource Mapping </h4> 
 * 
 * <p> An <code> Agent </code> may be mapped to a <code> Resource </code> in 
 * the Resource OSID. A <code> Resource </code> may map to multiple <code> 
 * Agents </code> but an <code> Agent </code> may only map to a single 
 * Resource. In the case of a person, a person may be utilize a number of 
 * authentication technologies each with a different authentication identity. 
 * Decoupling the authentication identity from that of ther person is to 
 * provide a means of integrating multiple services where different 
 * authentication identities exist for a person that impact the handling of 
 * authorization. </p> 
 * <h4> Authorization </h4> 
 * 
 * <p> Authorization is a separate service. The Authorization OSID manages 
 * what functions the <code> Agent </code> is authorized to perform and 
 * references the <code> Agent </code> <code> Id. </code> The Authentication 
 * OSID is only responsible for identity management of the <code> Agent. 
 * </code> </p> 
 * 
 * <p> Each <code> Agent </code> of a <code> Resource </code> may be used to 
 * define distinct security levels of assurance (although the paranoid may opt 
 * for defining a pseudo-resource for each <code> Agent </code> ). These 
 * security levels of assurance can be linked to the <code> Agent </code> 
 * <code> Type </code> and managed in the Authorization OSID. The <code> Agent 
 * </code> <code> Type </code> would be an indicator of the authentication 
 * strength and although it may correlate to a specific authentication 
 * technology, coupling it too tightly to a particular technology may limit 
 * flexibility. </p> 
 * 
 * <p> Certain consumers may wish to be notified of changes within the 
 * service. Authentication supports notifications via an <code> 
 * AgentNotificationSession. </code> </p> 
 * 
 * <pre>
 *      
 *      
 *      if (manager.supportsAgentNotification()) {
 *          AgentNotificationSession ans = manager.getAgentNotificationSession(receiver);
 *          ans.registerForNewAgents();
 *          hangAround();
 *      }
 *      
 *      AgentReceiver receiver {
 *          newAgent(Id agentId) { print("new agent"); }
 *          changedAgent(Id agentId) { print("updated agent"); }
 *          deletedAgent(Id agentId) { print("deleted agent"); }
 *      }
 *      
 *              
 *      
 * </pre>
 * 
 * <h4> Agency Cataloging </h4> 
 * 
 * <p> <code> Agents </code> are organized into federateable <code> Agency 
 * </code> <code> OsidCatalogs. </code> </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Authentication OSID includes an Authentication Key OSID for 
 * managing private keys associated with an <code> Agent </code> and an 
 * Authentication Process OSID for acquiring and validating authentication 
 * credentials. It slaos includes an Authentication Batch OSID for managing 
 * <code> Agents </code> and <code> Agencies </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004, 2007 Massachusetts Institute of Technology. 
 * </p> 
 * 
 * <p> Copyright &copy; 2009 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.authentication;
