//
// org.osid.authentication.process.AuthenticationProcessManager
//
//     The OSID Java specification for org.osid.authentication.process.AuthenticationProcessManager.
//
// Copyright (C) 2002-2004, 2007-2009 Massachusetts Institute of Technology. 
// All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.process;


/**
 *  <p>The authentication process manager provides access to authentication 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AuthenticationAcquisitionSession: </code> a session to 
 *      acquire credentials from a user and serialize them for transport to a 
 *      remote peer for authentication </li> 
 *      <li> <code> AuthenticationValidationSession: a </code> session to 
 *      receive and validate authentication credentials from a remote peer 
 *      wishing to authenticate </li> 
 *      <li> <code> TrustLookupSession: </code> a session to look up 
 *      authentication circles of trust </li> 
 *      <li> <code> CircleOfTrustSession: </code> a session to examine agent 
 *      circles of trust </li> 
 *  </ul>
 *  
 */

public interface AuthenticationProcessManager
    extends org.osid.OsidManager,
            org.osid.authentication.process.AuthenticationProcessProfile {


    /**
     *  Gets an <code> AuthenticationAcquisitionSession </code> which is 
     *  responsible for acquiring authentication credentials on behalf of a 
     *  service client. 
     *
     *  @return an acquisition session for this service 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthenticationAcquisition() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcquisition() </code> is <code> true. </code> 
     */

    public org.osid.authentication.process.AuthenticationAcquisitionSession getAuthenticationAcquisitionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the <code> 
     *  AuthenticationValidation </code> service. 
     *
     *  @return an <code> AuthenticationValidationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthenticationValidation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValidation() </code> is <code> true. </code> 
     */

    public org.osid.authentication.process.AuthenticationValidationSession getAuthenticationValidationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trust lookup 
     *  service. 
     *
     *  @return a <code> TrustLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTrustLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTrustLookup() </code> is <code> true. </code> 
     */

    public org.osid.authentication.process.TrustLookupSession getTrustLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trust lookup 
     *  service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return a <code> TrustLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsTrustLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTrustLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authentication.process.TrustLookupSession getTrustLookupSessionForAgency(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trust circle 
     *  service. 
     *
     *  @return a <code> CircleOfTrustSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCircleOfTrust() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCircleOfTrust() </code> is <code> true. </code> 
     */

    public org.osid.authentication.process.CircleOfTrustSession getCircleOfTrustSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trust circle 
     *  service for the given agency. 
     *
     *  @param  agencyId the <code> Id </code> of the agency 
     *  @return a <code> CircleOfTrustSession </code> 
     *  @throws org.osid.NotFoundException <code> agencyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> agencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsCiirleOfTrust() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCircleOfTrust() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authentication.process.CircleOfTrustSession getCircleOfTrustSessionForAgency(org.osid.id.Id agencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
