//
// org.osid.authentication.process.AuthenticationProcessProfile
//
//     The OSID Java specification for org.osid.authentication.process.AuthenticationProcessProfile.
//
// Copyright (C) 2002-2004, 2007-2009 Massachusetts Institute of Technology. 
// All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.process;


/**
 *  <p>The <code> AuthenticationProcessProfile </code> describes the 
 *  interoperability among authentication process services. </p>
 */

public interface AuthenticationProcessProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if authentication acquisition is supported. Authentication 
     *  acquisition is responsible for acquiring client side authentication 
     *  credentials. 
     *
     *  @return <code> true </code> if authentication acquisiiton is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationAcquisition();


    /**
     *  Tests if authentication validation is supported. Authentication 
     *  validation verifies given authentication credentials and maps to an 
     *  agent identity. 
     *
     *  @return <code> true </code> if authentication validation is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationValidation();


    /**
     *  Tests if a trust look up session is supported. 
     *
     *  @return <code> true </code> if trust lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTrustLookup();


    /**
     *  Tests if a session to examine agent and trust relationships is 
     *  supported. 
     *
     *  @return <code> true </code> if a circle of trust is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCircleOfTrust();


    /**
     *  Tests if this authentication service supports a challenge-response 
     *  mechanism where credential validation service must implement a means 
     *  to generate challenge data. 
     *
     *  @return <code> true </code> if this is a challenge-response system, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChallenge();


    /**
     *  Gets the supported authentication record types. 
     *
     *  @return a list containing the supported authentication record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuthenticationRecordTypes();


    /**
     *  Tests if the given authentication record type is supported. 
     *
     *  @param  authenticationRecordType a <code> Type </code> indicating an 
     *          authentication record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> authenticationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationRecordType(org.osid.type.Type authenticationRecordType);


    /**
     *  Gets the supported authentication input record types. 
     *
     *  @return a list containing the supported authentication input record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuthenticationInputRecordTypes();


    /**
     *  Tests if the given authentication input record type is supported. 
     *
     *  @param  authenticationInputRecordType a <code> Type </code> indicating 
     *          an authentication input record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          authenticationInputRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationInputRecordType(org.osid.type.Type authenticationInputRecordType);


    /**
     *  Gets the supported challenge types. 
     *
     *  @return a list containing the supported challenge types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getChallengeRecordTypes();


    /**
     *  Tests if the given challenge data type is supported. 
     *
     *  @param  challengeRecordType a <code> Type </code> indicating a 
     *          challenge record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> challengeRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChallengeRecordType(org.osid.type.Type challengeRecordType);


    /**
     *  Tests if <code> Authentication </code> objects can export serialzied 
     *  credentials for transport. 
     *
     *  @return <code> true </code> if the given credentials export is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialExport();


    /**
     *  Gets the supported credential types. 
     *
     *  @return a list containing the supported credential types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCredentialTypes();


    /**
     *  Tests if the given credential type is supported. 
     *
     *  @param  credentialType a <code> Type </code> indicating a credential 
     *          type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> credentialType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialType(org.osid.type.Type credentialType);


    /**
     *  Gets the supported trust types. 
     *
     *  @return a list containing the supported trust types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTrustTypes();


    /**
     *  Tests if the given trust type is supported. 
     *
     *  @param  trustType a <code> Type </code> indicating a trust type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> trustType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTrustType(org.osid.type.Type trustType);
}
