//
// org.osid.authentication.process.Trust
//
//     The OSID Java specification for org.osid.authentication.process.Trust.
//
// Copyright (C) 2002-2004, 2007-2009 Massachusetts Institute of Technology. 
// All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authentication.process;


/**
 *  <p><code> Trust </code> represents the level of confidence in an 
 *  authentication. An Authentication OSID Provider may issue different <code> 
 *  Agents </code> based on the authentication mechanism. <code> Trust </code> 
 *  is a grouping of <code> Agent </code> "types" that can be inferred as 
 *  equivalent from an authorization point of view. </p> 
 *  
 *  <p> The relationship among <code> Agents </code> and <code> Trust </code> 
 *  is not explicity managed but understood by an Authentication OSID Provider 
 *  when orchestration to an Authorization OSID Provider is desired. </p>
 */

public interface Trust
    extends org.osid.OsidObject {


    /**
     *  Gets the trust record corresponding to the given trust record <code> 
     *  Type. </code> This method is used to retrieve an object implementing 
     *  the requested. The <code> trustRecordType </code> may be the <code> 
     *  Type </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(trustRecordType) </code> is <code> true </code> . 
     *
     *  @param  trustRecordType the type of trust record to retrieve 
     *  @return the trust record 
     *  @throws org.osid.NullArgumentException <code> trustRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(trustRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.process.records.TrustRecord getTrustRecord(org.osid.type.Type trustRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
