//
// org.osid.authorization.Authorization
//
//     The OSID Java specification for org.osid.authorization.Authorization.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>An Authorization is a mapping among an actor, a <code> Function </code> 
 *  and a <code> Qualifier. </code> This interface is not required for 
 *  performing authorization checks but is used for examining and managing 
 *  authorizations. </p> 
 *  
 *  <p> The actor of an authorization may be specified in a variety of forms. 
 *  </p> 
 *  
 *  <ul>
 *      <li> <code> Agent </code> </li> 
 *      <li> <code> Resource: </code> the authorization provider uses all the 
 *      <code> Agents </code> associated with a <code> Resource </code> for 
 *      matching authorizations </li> 
 *      <li> <code> Resource </code> and <code> Trust: </code> the 
 *      authorization provider uses the associated <code> Agents </code> 
 *      within a cicle of <code> Trust </code> </li> 
 *  </ul>
 *  
 *  
 *  <p> An explicit <code> Authorization </code> represents the mappings as 
 *  they are specified in the authorization provdier. Implicit authorizations 
 *  may be retrieved which are authorizations inferred through the <code> 
 *  Function </code> or <code> Qualifier </code> hierarchies. An implicit 
 *  <code> Authorization </code> is one where <code> isImplicit() </code> is 
 *  true and should not be used for modification as it is only available for 
 *  auditing purposes. </p> 
 *  
 *  <p> An <code> Authorization </code> containing a <code> Resource </code> 
 *  may also provide the associated Agent in a request for implicit 
 *  authorizations or for all the authorizations, both explicit and implicit, 
 *  for a given <code> Agent. </code> </p>
 */

public interface Authorization
    extends org.osid.OsidRelationship {


    /**
     *  Tests if this authorization is implicit. 
     *
     *  @return <code> true </code> if this authorization is implicit, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isImplicit();


    /**
     *  Tests if this authorization has a <code> Resource. </code> 
     *
     *  @return <code> true </code> if this authorization has a <code> 
     *          Resource, </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasResource();


    /**
     *  Gets the <code> resource Id </code> for this authorization. 
     *
     *  @return the <code> Resource Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasResource() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the <code> Resource </code> for this authorization. 
     *
     *  @return the <code> Resource </code> 
     *  @throws org.osid.IllegalStateException <code> hasResource() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this authorization has a <code> Trust. </code> 
     *
     *  @return <code> true </code> if this authorization has a <code> Trust, 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasTrust();


    /**
     *  Gets the <code> Trust </code> <code> Id </code> for this 
     *  authorization. 
     *
     *  @return the trust <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasTrust() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTrustId();


    /**
     *  Gets the <code> Trust </code> for this authorization. 
     *
     *  @return the <code> Trust </code> 
     *  @throws org.osid.IllegalStateException <code> hasTrust() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.process.Trust getTrust()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this authorization has an <code> Agent. </code> An implied 
     *  authorization may have an <code> Agent </code> in addition to a 
     *  specified <code> Resource. </code> 
     *
     *  @return <code> true </code> if this authorization has an <code> Agent, 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAgent();


    /**
     *  Gets the <code> Agent Id </code> for this authorization. 
     *
     *  @return the <code> Agent Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasAgent() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgentId();


    /**
     *  Gets the <code> Agent </code> for this authorization. 
     *
     *  @return the <code> Agent </code> 
     *  @throws org.osid.IllegalStateException <code> hasAgent() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Function Id </code> for this authorization. 
     *
     *  @return the function <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFunctionId();


    /**
     *  Gets the <code> Function </code> for this authorization. 
     *
     *  @return the function 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Function getFunction()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Qualifier Id </code> for this authorization. 
     *
     *  @return the qualifier <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getQualifierId();


    /**
     *  Gets the qualifier for this authorization. 
     *
     *  @return the qualifier 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Qualifier getQualifier()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the authorization record corresponding to the given <code> 
     *  Authorization </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  authorizationRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(authorizationRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  authorizationRecordType the type of the record to retrieve 
     *  @return the authorization record 
     *  @throws org.osid.NullArgumentException <code> authorizationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(authorizationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.records.AuthorizationRecord getAuthorizationRecord(org.osid.type.Type authorizationRecordType)
        throws org.osid.OperationFailedException;
}
