//
// org.osid.authorization.AuthorizationLookupSession
//
//     The OSID Java specification for org.osid.authorization.AuthorizationLookupSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session defines methods to search and retrieve <code> 
 *  Authorization </code> mappings. </p> 
 *  
 *  <p> This lookup session defines two sets of views: </p> 
 *  
 *  <ul>
 *      <li> isolated vault view: All authorization methods in this session 
 *      operate, retrieve and pertain to <code> Authorizations </code> defined 
 *      explicitly in the current <code> Vault. </code> Using an isolated view 
 *      is useful for managing <code> Authorizations </code> with the <code> 
 *      AuthorizationAdminSession. </code> </li> 
 *      <li> federated vault view; All authorization methods in this session 
 *      operate, retrieve and pertain to all authorizations defined in this 
 *      vault and any other authorizations implicitly available in this vault 
 *      through vault inheritence. </li> 
 *      <li> effective authorization view: All authorization lookup methods 
 *      return edges where the current dates falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective authorization edge view: Authorizations of any 
 *      effective date are returned. </li> 
 *      <li> explicit authorization view: All authorization methods in this 
 *      session operate, retrieve and pertain to only those authorizations 
 *      that have been explicitly defined and not derived from <code> Resource 
 *      </code> groups or <code> Qualifier </code> hierarchies. </li> 
 *      <li> implicit authorization view; All authorization methods in this 
 *      session operate, retrieve and pertain to all authorizations including 
 *      those derived from <code> Resource </code> groups or <code> Qualifier 
 *      </code> hierarchies. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useExplicitAuthorizationView() </code> and <code> 
 *  useImplicitAuthorizationView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface AuthorizationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the <code> Vault </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform authorization lookups. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAuthorizations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuthorizationView();


    /**
     *  A complete view of the <code> Authorization </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuthorizationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include authorizations in vaults which are children of this vault in 
     *  the vault hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedVaultView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this vault only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedVaultView();


    /**
     *  Only authorizations whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveAuthorizationView();


    /**
     *  All authorizations of any effective dates are returned by all methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveAuthorizationView();


    /**
     *  Sets the view for methods in this session to implicit authorizations. 
     *  An implicit view will include authorizations derived from other 
     *  authorizations as a result of the <code> Qualifier, </code> <code> 
     *  Function </code> or <code> Resource </code> hierarchies. This method 
     *  is the opposite of <code> explicitAuthorizationView(). </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useImplicitAuthorizationView();


    /**
     *  Sets the view for methods in this session to explicit authorizations. 
     *  An explicit view includes only those authorizations that were 
     *  explicitly defined and not implied. This method is the opposite of 
     *  <code> implicitAuthorizationView(). </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useExplicitAuthorizationView();


    /**
     *  Gets the <code> Authorization </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Authorization </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Authorization </code> and retained for 
     *  compatibility. 
     *
     *  @param  authorizationId the <code> Id </code> of the <code> 
     *          Authorization </code> to retrieve 
     *  @return the returned <code> Authorization </code> 
     *  @throws org.osid.NotFoundException no <code> Authorization </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Authorization getAuthorization(org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the authorizations specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> Authorizations </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  authorizationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Authorization list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsByIds(org.osid.id.IdList authorizationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> corresponding to the given 
     *  authorization genus <code> Type </code> which does not include 
     *  authorizations of genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  authorizations or an error results. Otherwise, the returned list may 
     *  contain only those authorizations that are accessible through this 
     *  session. 
     *
     *  @param  authorizationGenusType an authorization genus type 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.NullArgumentException <code> authorizationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsByGenusType(org.osid.type.Type authorizationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> corresponding to the given 
     *  authorization genus <code> Type </code> and include authorizations of 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known authorizations or an error 
     *  results. Otherwise, the returned list may contain only those 
     *  authorizations that are accessible through this session. 
     *
     *  @param  authorizationGenusType an authorization genus type 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.NullArgumentException <code> authorizationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsByParentGenusType(org.osid.type.Type authorizationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> containing the given 
     *  authorization record <code> Type. </code> In plenary mode, the 
     *  returned list contains all known authorizations or an error results. 
     *  Otherwise, the returned list may contain only those authorizations 
     *  that are accessible through this session. 
     *
     *  @param  authorizationRecordType an authorization record type 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.NullArgumentException <code> authorizationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsByRecordType(org.osid.type.Type authorizationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  authorizations or an error results. Otherwise, the returned list may 
     *  contain only those authorizations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, authorizations are returned that are currently 
     *  effective. In any effective mode, active authorizations and those 
     *  currently expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsOnDate(org.osid.calendaring.DateTime from, 
                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Authorizations </code> associated with a given 
     *  resource. Authorizations related to the given resource, including 
     *  those related through an <code> Agent, </code> are returned. In 
     *  plenary mode, the returned list contains all known authorizations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  authorizations that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Authorization list </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  Authorizations related to the given resource, including those related 
     *  through an <code> Agent, </code> are returned. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, authorizations are returned that are currently 
     *  effective. In any effective mode, active authorizations and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Authorizations </code> associated with a given 
     *  agent. In plenary mode, the returned list contains all known 
     *  authorizations or an error results. Otherwise, the returned list may 
     *  contain only those authorizations that are accessible through this 
     *  session. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @return the returned <code> Authorization list </code> 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForAgent(org.osid.id.Id agentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> for the given agent and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, authorizations are returned that are currently 
     *  effective. In any effective mode, active authorizations and those 
     *  currently expired are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForAgentOnDate(org.osid.id.Id agentId, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Authorizations </code> associated with a given 
     *  function. In plenary mode, the returned list contains all known 
     *  authorizations or an error results. Otherwise, the returned list may 
     *  contain only those authorizations that are accessible through this 
     *  session. 
     *
     *  @param  functionId a function <code> Id </code> 
     *  @return the returned <code> Authorization list </code> 
     *  @throws org.osid.NullArgumentException <code> functionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForFunction(org.osid.id.Id functionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> for the given function and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, authorizations are returned that are currently 
     *  effective. In any effective mode, active authorizations and those 
     *  currently expired are returned. 
     *
     *  @param  functionId a function <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> functionId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForFunctionOnDate(org.osid.id.Id functionId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Authorizations </code> associated with a given 
     *  resource. Authorizations related to the given resource, including 
     *  those related through an <code> Agent, </code> are returned. In 
     *  plenary mode, the returned list contains all known authorizations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  authorizations that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  functionId a function <code> Id </code> 
     *  @return the returned <code> Authorization list </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> functionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForResourceAndFunction(org.osid.id.Id resourceId, 
                                                                                            org.osid.id.Id functionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  Authorizations related to the given resource, including those related 
     *  through an <code> Agent, </code> are returned. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, authorizations are returned that are currently 
     *  effective. In any effective mode, active authorizations and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  functionId a function <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, functionId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForResourceAndFunctionOnDate(org.osid.id.Id resourceId, 
                                                                                                  org.osid.id.Id functionId, 
                                                                                                  org.osid.calendaring.DateTime from, 
                                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Authorizations </code> associated with a given 
     *  agent. Authorizations related to the given resource, including those 
     *  related through an <code> Agent, </code> are returned. In plenary 
     *  mode, the returned list contains all known authorizations or an error 
     *  results. Otherwise, the returned list may contain only those 
     *  authorizations that are accessible through this session. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  functionId a function <code> Id </code> 
     *  @return the returned <code> Authorization list </code> 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> functionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForAgentAndFunction(org.osid.id.Id agentId, 
                                                                                         org.osid.id.Id functionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuthorizationList </code> for the given agent and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known authorizations 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those authorizations that are accessible through this session. 
     *  
     *  In effective mode, authorizations are returned that are currently 
     *  effective. In any effective mode, active authorizations and those 
     *  currently expired are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  functionId a function <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Authorization </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, functionId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsForAgentAndFunctionOnDate(org.osid.id.Id agentId, 
                                                                                               org.osid.id.Id functionId, 
                                                                                               org.osid.calendaring.DateTime from, 
                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of <code> Authorizations </code> associated with a given 
     *  qualifier. In plenary mode, the returned list contains all known 
     *  authorizations or an error results. Otherwise, the returned list may 
     *  contain only those authorizations that are accessible through this 
     *  session. 
     *
     *  @param  qualifierId a qualifier <code> Id </code> 
     *  @return the returned <code> Authorization list </code> 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizationsByQualifier(org.osid.id.Id qualifierId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the explicit <code> Authorization </code> that generated the 
     *  given implicit authorization. If the given <code> Authorization 
     *  </code> is explicit, then the same <code> Authorization </code> is 
     *  returned. 
     *
     *  @param  authorizationId an authorization 
     *  @return the explicit <code> Authorization </code> 
     *  @throws org.osid.NotFoundException <code> authorizationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Authorization getExplicitAuthorization(org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Geta all <code> Authorizations. </code> In plenary mode, the returned 
     *  list contains all known authorizations or an error results. Otherwise, 
     *  the returned list may contain only those authorizations that are 
     *  accessible through this session. 
     *
     *  @return a list of <code> Authorizations </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationList getAuthorizations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
