//
// org.osid.authorization.AuthorizationManager
//
//     The OSID Java specification for org.osid.authorization.AuthorizationManager.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>The authorization manager provides access to authorization sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AuthorizationSession: </code> a session to performs 
 *      authorization checks </li> 
 *      <li> <code> AuthorizationLookupSession: </code> a session to look up 
 *      <code> Authorizations </code> </li> 
 *      <li> <code> AuthorizationQuerySession: </code> a session to query 
 *      <code> Authorizations </code> </li> 
 *      <li> <code> AuthorizationSearchSession: </code> a session to search 
 *      <code> Authorizations </code> </li> 
 *      <li> <code> AuthorizationAdminSession: </code> a session to create, 
 *      modify and delete <code> Authorizations </code> </li> 
 *      <li> <code> AuthorizationNotificationSession: a </code> session to 
 *      receive messages pertaining to <code> Authorization </code> changes 
 *      </li> 
 *      <li> <code> AuthorizationVaultSession: </code> a session to look up 
 *      authorization to vault mappings </li> 
 *      <li> <code> AuthorizationVaultAssignmentSession: </code> a session to 
 *      manage authorization to vault mappings </li> 
 *      <li> <code> AuthorizationSmartVaultSession: </code> a session to 
 *      manage smart authorization vaults </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> FunctionLookupSession: </code> a session to look up <code> 
 *      Functions </code> </li> 
 *      <li> <code> FunctionQuerySession: </code> a session to query <code> 
 *      Functions </code> </li> 
 *      <li> <code> FunctionSearchSession: </code> a session to search <code> 
 *      Functions </code> </li> 
 *      <li> <code> FunctionAdminSession: </code> a session to create, modify 
 *      and delete <code> Functions </code> </li> 
 *      <li> <code> FunctionNotificationSession: a </code> session to receive 
 *      messages pertaining to <code> Function </code> changes </li> 
 *      <li> <code> FunctionVaultSession: </code> a session for looking up 
 *      function and vault mappings </li> 
 *      <li> <code> FunctionVaultAssignmentSession: </code> a session for 
 *      managing function and vault mappings </li> 
 *      <li> <code> FunctionSmartVaultSession: </code> a session to manage 
 *      dynamic function vaults </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> QualifierLookupSession: </code> a session to look up 
 *      <code> Qualifiers </code> </li> 
 *      <li> <code> QualifierQuerySession: </code> a session to query <code> 
 *      Qualifiers </code> </li> 
 *      <li> <code> QualifierSearchSession: </code> a session to search <code> 
 *      Qualifiers </code> </li> 
 *      <li> <code> QualifierAdminSession: </code> a session to create, modify 
 *      and delete <code> Qualifiers </code> </li> 
 *      <li> <code> QualifierNotificationSession: a </code> session to receive 
 *      messages pertaining to <code> Qualifier </code> changes </li> 
 *      <li> <code> QualifierHierarchySession: </code> a session for 
 *      traversing qualifier hierarchies </li> 
 *      <li> <code> QualifierHierarchyDesignSession: </code> a session for 
 *      managing qualifier hierarchies </li> 
 *      <li> <code> QualifierVaultSession: </code> a session for looking up 
 *      qualifier and vault mappings </li> 
 *      <li> <code> QualifierVaultAssignmentSession: </code> a session for 
 *      managing qualifier and vault mappings </li> 
 *      <li> <code> QualifierSmartVaultSession: </code> a session to manage 
 *      dynamic qualifier vaults </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> VaultLookupSession: </code> a session to lookup vaults 
 *      </li> 
 *      <li> <code> VaultQuerySession: </code> a session to query Vaults </li> 
 *      <li> <code> VaultSearchSession </code> : a session to search vaults 
 *      </li> 
 *      <li> <code> VaultAdminSession </code> : a session to create, modify 
 *      and delete vaults </li> 
 *      <li> <code> VaultNotificationSession </code> : a session to receive 
 *      messages pertaining to <code> Vault </code> changes </li> 
 *      <li> <code> VaultHierarchySession </code> : a session to traverse the 
 *      <code> Vault </code> hierarchy </li> 
 *      <li> <code> VaultHierarchyDesignSession </code> : a session to manage 
 *      the <code> Vault </code> hierarchy </li> 
 *  </ul>
 *  
 */

public interface AuthorizationManager
    extends org.osid.OsidManager,
            org.osid.authorization.AuthorizationProfile {


    /**
     *  Gets an <code> AuthorizationSession </code> which is responsible for 
     *  performing authorization checks. 
     *
     *  @return an authorization session for this service 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAuthorization() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorization() </code> is <code> true. </code> 
     */

    public org.osid.authorization.AuthorizationSession getAuthorizationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AuthorizationSession </code> which is responsible for 
     *  performing authorization checks for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> an AuthorizationSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAuthorization() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorization() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationSession getAuthorizationSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  lookup service. 
     *
     *  @return an <code> AuthorizationLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationLookupSession getAuthorizationLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  lookup service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> an AuthorizationLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationLookupSession getAuthorizationLookupSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  query service. 
     *
     *  @return an <code> AuthorizationQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationQuerySession getAuthorizationQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  query service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> an AuthorizationQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationQuerySession getAuthorizationQuerySessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  search service. 
     *
     *  @return an <code> AuthorizationSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationSearchSession getAuthorizationSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  search service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> an AuthorizationSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationSearchSession getAuthorizationSearchSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  administration service. 
     *
     *  @return an <code> AuthorizationAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationAdminSession getAuthorizationAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  admin service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> an AuthorizationAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationAdminSession getAuthorizationAdminSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  authorization changes. 
     *
     *  @param  authorizationReceiver the authorization receiver 
     *  @return an <code> AuthorizationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.AuthorizationNotificationSession getAuthorizationNotificationSession(org.osid.authorization.AuthorizationReceiver authorizationReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  notification service for the given vault. 
     *
     *  @param  authorizationReceiver the authorization receiver 
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> an AuthorizationNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationReceiver 
     *          </code> or <code> vaultId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationNotificationSession getAuthorizationNotificationSessionForVault(org.osid.authorization.AuthorizationReceiver authorizationReceiver, 
                                                                                                               org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving authorization to vault mappings. 
     *
     *  @return an <code> AuthorizationVaultSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationVault() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationVault() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationVaultSession getAuthorizationVaultSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning authorizations to vault mappings. 
     *
     *  @return a <code> AuthorizationVaultAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationVaultAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationVaultAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.AuthorizationVaultAssignmentSession getAuthorizationVaultAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic authorization vaults. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> AuthorizationSmartVaultSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationSmartVault() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationSmartVault() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationSmartVaultSession getAuthorizationSmartVaultSession(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function 
     *  lookup service. 
     *
     *  @return a <code> FunctionLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionLookup() </code> is <code> true. </code> 
     */

    public org.osid.authorization.FunctionLookupSession getFunctionLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function 
     *  lookup service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> a FunctionLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionLookupSession getFunctionLookupSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function query 
     *  service. 
     *
     *  @return a <code> FunctionQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFunctionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.FunctionQuerySession getFunctionQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function query 
     *  service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> FunctionQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsFunctionQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionQuerySession getFunctionQuerySessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function 
     *  search service. 
     *
     *  @return a <code> FunctionSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionSearch() </code> is <code> true. </code> 
     */

    public org.osid.authorization.FunctionSearchSession getFunctionSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function 
     *  search service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> FunctionSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionSearchSession getFunctionSearchSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function 
     *  administration service. 
     *
     *  @return a <code> FunctionAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFunctionAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionAdmin() </code> is <code> true. </code> 
     */

    public org.osid.authorization.FunctionAdminSession getFunctionAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function admin 
     *  service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> a FunctionAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsFunctionAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionAdminSession getFunctionAdminSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to function 
     *  changes. 
     *
     *  @param  functionReceiver the function receiver 
     *  @return a <code> FunctionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> functionReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionNotificationSession getFunctionNotificationSession(org.osid.authorization.FunctionReceiver functionReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the function 
     *  notification service for the given vault. 
     *
     *  @param  functionReceiver the function receiver 
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return <code> a FunctionNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> functionReceiver </code> 
     *          or <code> vaultId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionNotificationSession getFunctionNotificationSessionForVault(org.osid.authorization.FunctionReceiver functionReceiver, 
                                                                                                     org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving function to vault mappings. 
     *
     *  @return a <code> FunctionVaultSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFunctionVault() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionVault() </code> is <code> true. </code> 
     */

    public org.osid.authorization.FunctionVaultSession getFunctionVaultSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning function to vault mappings. 
     *
     *  @return a <code> FunctionVaultAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionVaultAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionVaultAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionVaultAssignmentSession getFunctionVaultAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the function smart vault for the 
     *  given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> FunctionSmartVaultSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFunctionSmartVault() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionSmartVault() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.FunctionSmartVaultSession getFunctionSmartVaultSession(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  lookup service. 
     *
     *  @return a <code> QualifierLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierLookup() </code> is <code> true. </code> 
     */

    public org.osid.authorization.QualifierLookupSession getQualifierLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  lookup service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> QualifierLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierLookupSession getQualifierLookupSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  query service. 
     *
     *  @return a <code> QualifierQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.QualifierQuerySession getQualifierQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  query service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> QualifierQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierQuerySession getQualifierQuerySessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  search service. 
     *
     *  @return a <code> QualifierSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierSearch() </code> is <code> true. </code> 
     */

    public org.osid.authorization.QualifierSearchSession getQualifierSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  search service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> QualifierSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierSearchSession getQualifierSearchSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  administration service. 
     *
     *  @return a <code> QualifierAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierAdmin() </code> is <code> true. </code> 
     */

    public org.osid.authorization.QualifierAdminSession getQualifierAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  admin service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> QualifierAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierAdminSession getQualifierAdminSessionForVault(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  qualifier changes. 
     *
     *  @param  qualifierReceiver the qualifier receiver 
     *  @return a <code> QualifierNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> qualifierReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierNotificationSession getQualifierNotificationSession(org.osid.authorization.QualifierReceiver qualifierReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  notification service for the given vault. 
     *
     *  @param  qualifierReceiver the qualifier receiver 
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> QualifierNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> qualifierReceiver 
     *          </code> or <code> vaultId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierNotificationSession getQualifierNotificationSessionForVault(org.osid.authorization.QualifierReceiver qualifierReceiver, 
                                                                                                       org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  hierarchy traversal service. The authorization service uses distinct 
     *  hierarchies that can be managed through a Hierarchy OSID. 
     *
     *  @param  qualifierHierarchyId the <code> Id </code> of a qualifier 
     *          hierarchy 
     *  @return a <code> QualifierHierarchySession </code> 
     *  @throws org.osid.NotFoundException <code> qualifierHierarchyId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> qualifierHierarchyId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierHierarchySession getQualifierHierarchySession(org.osid.id.Id qualifierHierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the qualifier 
     *  hierarchy design service. 
     *
     *  @param  qualifierHierarchyId the <code> Id </code> of a qualifier 
     *          hierarchy 
     *  @return a <code> QualifierHierarchyDesignSession </code> 
     *  @throws org.osid.NotFoundException <code> qualifierHierarchyId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> qualifierHierarchyId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierHierarchyDesignSession getQualifierHierarchyDesignSession(org.osid.id.Id qualifierHierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving qualifier to vault mappings. 
     *
     *  @return a <code> QualifierVaultSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierVault() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierVault() </code> is <code> true. </code> 
     */

    public org.osid.authorization.QualifierVaultSession getQualifierVaultSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning qualifier to vault mappings. 
     *
     *  @return a <code> QualifierVaultAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierVaultAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierVaultAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierVaultSession getQualifierVaultAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the qualifier smart vault for the 
     *  given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the vault 
     *  @return a <code> QualifierSmartVaultSession </code> 
     *  @throws org.osid.NotFoundException <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierSmartVault() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierSmartVault() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.QualifierSmartVaultSession getQualifierSmartVaultSession(org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the vault lookup service. 
     *
     *  @return a <code> VaultLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVaultLookup() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultLookup() </code> is true. 
     */

    public org.osid.authorization.VaultLookupSession getVaultLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the vault query service. 
     *
     *  @return a <code> VaultQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVaultQuery() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultQuery() </code> is true. 
     */

    public org.osid.authorization.VaultQuerySession getVaultQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the vault search service. 
     *
     *  @return a <code> VaultSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVaultSearch() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultSearch() </code> is true. 
     */

    public org.osid.authorization.VaultSearchSession getVaultSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the vault administration service. 
     *
     *  @return a <code> VaultAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVaultAdmin() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultAdmin() </code> is true. 
     */

    public org.osid.authorization.VaultAdminSession getVaultAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to vault 
     *  service changes. 
     *
     *  @param  vaultreceiver the vault receiver 
     *  @return a <code> VaultNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> vaultReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVaultNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultNotification() </code> is true. 
     */

    public org.osid.authorization.VaultNotificationSession getVaultNotificationSession(org.osid.authorization.VaultReceiver vaultreceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing vault hierarchies. 
     *
     *  @return a <code> VaultHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVaultHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultHierarchy() </code> is true. 
     */

    public org.osid.authorization.VaultHierarchySession getVaultHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing vault hierarchies. 
     *
     *  @return a <code> VaultHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVaultHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultHierarchyDesign() </code> is true. 
     */

    public org.osid.authorization.VaultHierarchyDesignSession getVaultHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AuthorizationBatchManager. </code> 
     *
     *  @return an <code> AuthorizationBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationBatch() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationBatch() </code> is true. 
     */

    public org.osid.authorization.batch.AuthorizationBatchManager getAuthorizationBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> AuthorizationRulesManager. </code> 
     *
     *  @return an <code> AuthorizationRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationRules() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationRules() </code> is true. 
     */

    public org.osid.authorization.rules.AuthorizationRulesManager getAuthorizationRulesManager()
        throws org.osid.OperationFailedException;
}
