//
// org.osid.authorization.AuthorizationQuery
//
//     The OSID Java specification for org.osid.authorization.AuthorizationQuery.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>The query for authorizations. </p>
 */

public interface AuthorizationQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Matches explciit authorizations. 
     *
     *  @param  match <code> true </code> to match explicit authorizations, 
     *          <code> false </code> to match implciit authorizations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExplicitAuthorizations(boolean match);


    /**
     *  Clears the explicit authorization query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExplicitAuthorizationsTerms();


    /**
     *  Adds an <code> Id </code> to match explicit or implicitly related 
     *  authorizations depending on <code> matchExplicitAuthorizations(). 
     *  </code> Multiple <code> Ids </code> can be added to perform a boolean 
     *  <code> OR </code> among them. 
     *
     *  @param  id <code> Id </code> to match 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelatedAuthorizationId(org.osid.id.Id id, boolean match);


    /**
     *  Clears the related authorization <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelatedAuthorizationIdTerms();


    /**
     *  Tests if an <code> AuthorizationQuery </code> is available. 
     *
     *  @return <code> true </code> if an authorization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelatedAuthorizationQuery();


    /**
     *  Gets the authorization query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> AuthorizationQuery </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelatedAuthorizationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelatedAuthorizationQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.AuthorizationQuery getRelatedAuthorizationQuery(boolean match);


    /**
     *  Clears the related authorization query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelatedAuthorizationTerms();


    /**
     *  Matches the resource identified by the given <code> Id. </code> 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the resource query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> ResourceQuery </code> 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery(boolean match);


    /**
     *  Matches authorizations that have any resource. 
     *
     *  @param  match <code> true </code> to match authorizations with any 
     *          resource, <code> false </code> to match authorizations with no 
     *          resource 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResource(boolean match);


    /**
     *  Clears the resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Matches the trust identified by the given <code> Id. </code> 
     *
     *  @param  trustId the <code> Id </code> of the <code> Trust </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> trustId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTrustId(org.osid.id.Id trustId, boolean match);


    /**
     *  Matches authorizations that have any trust defined. 
     *
     *  @param  match <code> true </code> to match authorizations with any 
     *          trust, <code> false </code> to match authorizations with no 
     *          trusts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTrustId(boolean match);


    /**
     *  Clears the trust <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTrustIdTerms();


    /**
     *  Matches the agent identified by the given <code> Id. </code> 
     *
     *  @param  agentId the Id of the <code> Agent </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the agent <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgentQuery();


    /**
     *  Gets the agent query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> AgentQuery </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuery getAgentQuery(boolean match);


    /**
     *  Matches authorizations that have any agent. 
     *
     *  @param  match <code> true </code> to match authorizations with any 
     *          agent, <code> false </code> to match authorizations with no 
     *          agent 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAgent(boolean match);


    /**
     *  Clears the agent query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgentTerms();


    /**
     *  Matches the function identified by the given <code> Id. </code> 
     *
     *  @param  functionId the Id of the <code> Function </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> functionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFunctionId(org.osid.id.Id functionId, boolean match);


    /**
     *  Clears the function <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFunctionIdTerms();


    /**
     *  Tests if a <code> FunctionQuery </code> is available. 
     *
     *  @return <code> true </code> if a function query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionQuery();


    /**
     *  Gets the function query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> FunctinQuery </code> 
     *  @throws org.osid.UnimplementedException <code> supportsFunctionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.FunctionQuery getFunctionQuery(boolean match);


    /**
     *  Clears the function query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFunctionTerms();


    /**
     *  Matches the qualifier identified by the given <code> Id. </code> 
     *
     *  @param  qualifierId the Id of the <code> Qualifier </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQualifierId(org.osid.id.Id qualifierId, boolean match);


    /**
     *  Clears the qualifier <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualifierIdTerms();


    /**
     *  Tests if a <code> QualifierQuery </code> is available. 
     *
     *  @return <code> true </code> if a qualifier query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierQuery();


    /**
     *  Gets the qualiier query. 
     *
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @return the <code> QualifierQuery </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.QualifierQuery getQualifierQuery(boolean match);


    /**
     *  Clears the qualifier query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualifierTerms();


    /**
     *  Sets the vault <code> Id </code> for this query. 
     *
     *  @param  vaultId a vault <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVaultId(org.osid.id.Id vaultId, boolean match);


    /**
     *  Clears the vault <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVaultIdTerms();


    /**
     *  Tests if a <code> VaultQuery </code> is available. 
     *
     *  @return <code> true </code> if a vault query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultQuery();


    /**
     *  Gets the query for a vault. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the vault query 
     *  @throws org.osid.UnimplementedException <code> supportsVaultQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.VaultQuery getVaultQuery();


    /**
     *  Clears the vault query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVaultTerms();


    /**
     *  Gets the authorization query record corresponding to the given <code> 
     *  Authorization </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  authorizationRecordType an authorization record type 
     *  @return the authorization query record 
     *  @throws org.osid.NullArgumentException <code> authorizationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(authorizationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.records.AuthorizationQueryRecord getAuthorizationQueryRecord(org.osid.type.Type authorizationRecordType)
        throws org.osid.OperationFailedException;
}
