//
// org.osid.authorization.AuthorizationSmartVaultSession
//
//     The OSID Java specification for org.osid.authorization.AuthorizationSmartVaultSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> AuthorizationQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Vault </code> to create a virtual 
 *  collection of <code> Authorizations. </code> The authorizations may be 
 *  sequenced using the <code> AuthorizationSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> Vault </code> has a default query that matches any 
 *  authorization and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> AuthorizationQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> AuthorizationQuery. </code> </p>
 */

public interface AuthorizationSmartVaultSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the <code> Vault </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart vault. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart vault management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartVault();


    /**
     *  Gets a authorization query. 
     *
     *  @return the authorization query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationQuery getAuthorizationQuery();


    /**
     *  Gets a authorization search order. 
     *
     *  @return the authorization search order. 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationSearchOrder getAuthorizationSearchOrder();


    /**
     *  Applies a authorization query to this vault. 
     *
     *  @param  authorizationQuery the authorization query 
     *  @throws org.osid.NullArgumentException <code> authorizationQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> authorizationQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAuthorizationQuery(org.osid.authorization.AuthorizationQuery authorizationQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a authorization query inspector for this vault. 
     *
     *  @return the authorization query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationQueryInspector inspectAuthorizationQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a authorization search order to this vault. 
     *
     *  @param  authorizationSearchOrder the authorization search order 
     *  @throws org.osid.NullArgumentException <code> authorizationSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> authorizationSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAuthorizationSequencing(org.osid.authorization.AuthorizationSearchOrder authorizationSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a authorization query from an inspector. 
     *
     *  @param  authorizationQueryInspector a resorce relationship query 
     *          inspector 
     *  @return the authorization query 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          authorizationQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.AuthorizationQuery getAuthorizationQueryFromInspector(org.osid.authorization.AuthorizationQueryInspector authorizationQueryInspector);
}
