//
// org.osid.authorization.FunctionQuery
//
//     The OSID Java specification for org.osid.authorization.FunctionQuery.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This is the query for searching functions. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface FunctionQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Sets the qualifier hierarchy <code> Id </code> for this query. 
     *
     *  @param  qualifierHierarchyId a hierarchy <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> qualifierHierarchyId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQualifierHierarchyId(org.osid.id.Id qualifierHierarchyId, 
                                          boolean match);


    /**
     *  Clears the qualifier hierarchy <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualifierHierarchyIdTerms();


    /**
     *  Tests if a <code> HierarchyQuery </code> is available. 
     *
     *  @return <code> true </code> if a qualifier hierarchy query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierHierarchyQuery();


    /**
     *  Gets the query for a qualifier hierarchy. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the qualifier hierarchy query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierHierarchyQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierHierarchyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchyQuery getQualifierHierarchyQuery();


    /**
     *  Matches functions that have any qualifier hierarchy. 
     *
     *  @param  match <code> true </code> to match functions with any 
     *          qualifier hierarchy, <code> false </code> to match functions 
     *          with no qualifier hierarchy 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQualifierHierarchy(boolean match);


    /**
     *  Clears the qualifier hierarchy query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualifierHierarchyTerms();


    /**
     *  Sets the authorization <code> Id </code> for this query. 
     *
     *  @param  authorizationId an authorization <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAuthorizationId(org.osid.id.Id authorizationId, 
                                     boolean match);


    /**
     *  Clears the authorization <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuthorizationIdTerms();


    /**
     *  Tests if an <code> AuthorizationQuery </code> is available. 
     *
     *  @return <code> true </code> if an authorization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationQuery();


    /**
     *  Gets the query for an authorization. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the authorization query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationQuery getAuthorizationQuery();


    /**
     *  Matches functions that have any authorization mapping. 
     *
     *  @param  match <code> true </code> to match functions with any 
     *          authorization mapping, <code> false </code> to match functions 
     *          with no authorization mapping 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAuthorization(boolean match);


    /**
     *  Clears the authorization query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuthorizationTerms();


    /**
     *  Sets the vault <code> Id </code> for this query. 
     *
     *  @param  vaultId a vault <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVaultId(org.osid.id.Id vaultId, boolean match);


    /**
     *  Clears the vault <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVaultIdTerms();


    /**
     *  Tests if a <code> VaultQuery </code> is available. 
     *
     *  @return <code> true </code> if a vault query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVaultQuery();


    /**
     *  Gets the query for a vault. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the vault query 
     *  @throws org.osid.UnimplementedException <code> supportsVaultQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVaultQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.VaultQuery getVaultQuery();


    /**
     *  Clears the vault query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVaultTerms();


    /**
     *  Gets the function query record corresponding to the given <code> 
     *  Function </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  functionRecordType a function record type 
     *  @return the function query record 
     *  @throws org.osid.NullArgumentException <code> functionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(functionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.records.FunctionQueryRecord getFunctionQueryRecord(org.osid.type.Type functionRecordType)
        throws org.osid.OperationFailedException;
}
