//
// org.osid.authorization.QualifierLookupSession
//
//     The OSID Java specification for org.osid.authorization.QualifierLookupSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session defines methods for retrieving qualifiers. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated vault view: All qualifier methods in this session 
 *      operate, retrieve and pertain to qualifiers defined explicitly in the 
 *      current vault. Using an isolated view is useful for managing <code> 
 *      Qualifiers </code> with the <code> QualifierAdminSession. </code> 
 *      </li> 
 *      <li> federated vault view: All qualifier methods in this session 
 *      operate, retrieve and pertain to all qualifiers defined in this vault 
 *      and any other qualifiers implicitly available in this vault through 
 *      vault inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedVaultView() </code> and <code> 
 *  useIsolatedVaultView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface QualifierLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the <code> Vault </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Qualifier </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupQualifiers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeQualifierView();


    /**
     *  A complete view of the <code> Qualifier </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryQualifierView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include qualifiers in vaults which are children of this vault in the 
     *  vault hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedVaultView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this vault only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedVaultView();


    /**
     *  Gets the <code> Qualifier </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Qualifier 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Qualifier </code> and retained for compatibility. 
     *
     *  @param  qualifierId <code> Id </code> of the <code> Qualifier </code> 
     *  @return the qualifier 
     *  @throws org.osid.NotFoundException <code> qualifierId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.authorization.Qualifier getQualifier(org.osid.id.Id qualifierId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QualifierList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  qualifiers specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Qualifiers </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  qualifierIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Qualifier </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> qualifierIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierList getQualifiersByIds(org.osid.id.IdList qualifierIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QualifierList </code> corresponding to the given 
     *  qualifier genus <code> Type </code> which does not include qualifiers 
     *  of types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known qualifiers or an error 
     *  results. Otherwise, the returned list may contain only those 
     *  qualifiers that are accessible through this session. In both cases, 
     *  the order of the set is not specified. 
     *
     *  @param  qualifierGenusType a qualifier genus type 
     *  @return the returned <code> Qualifier </code> list 
     *  @throws org.osid.NullArgumentException <code> qualifierGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierList getQualifiersByGenusType(org.osid.type.Type qualifierGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QualifierList </code> corresponding to the given 
     *  qualifier genus <code> Type </code> and include any additional 
     *  qualifiers with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  qualifiers or an error results. Otherwise, the returned list may 
     *  contain only those qualifiers that are accessible through this 
     *  session. 
     *
     *  @param  qualifierGenusType a qualifier genus type 
     *  @return the returned <code> Qualifier </code> list 
     *  @throws org.osid.NullArgumentException <code> qualifierGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierList getQualifiersByParentGenusType(org.osid.type.Type qualifierGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QualifierList </code> corresponding to the given 
     *  qualifier record <code> Type. </code> The set of qualifiers 
     *  implementing the given record type is returned. In plenary mode, the 
     *  returned list contains all known qualifiers or an error results. 
     *  Otherwise, the returned list may contain only those qualifiers that 
     *  are accessible through this session. 
     *
     *  @param  qualifierRecordType a qualifier record type 
     *  @return the returned <code> Qualifier </code> list 
     *  @throws org.osid.NullArgumentException <code> qualifierRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierList getQualifiersByRecordType(org.osid.type.Type qualifierRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Qualifiers. </code> In plenary mode, the returned list 
     *  contains all known qualifiers or an error results. Otherwise, the 
     *  returned list may contain only those qualifiers that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Qualifiers </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierList getQualifiers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
