//
// org.osid.authorization.QualifierSearchSession
//
//     The OSID Java specification for org.osid.authorization.QualifierSearchSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session provides methods for searching among <code> Qualifier 
 *  </code> objects. The search query is constructed using the <code> 
 *  QualifierQuery. </code> If more than one search element is specified 
 *  within a single <code> QualifierQuery, </code> these elements form a 
 *  boolean AND. </p> 
 *  
 *  <p> <code> getQualifiersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Qualifiers. </code> A more advanced search may be 
 *  performed with <code> getQualifiersBySearch(). </code> It accepts a <code> 
 *  QualifierSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getQualifiersBySearch() </code> returns a <code> 
 *  QualifierSearchResults </code> that can be used to access the resulting 
 *  <code> QualifierList </code> or be used to perform a search within the 
 *  result set through <code> QualifierSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated vault view: searches include qualifiers in vaults of 
 *      which this vault is an ancestor in the vault hierarchy </li> 
 *      <li> isolated vault view: searches are restricted to qualifiers in 
 *      this vault </li> 
 *  </ul>
 *  
 *  
 *  <p> Qualifiers may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> QualifierQuery. 
 *  </code> </p>
 */

public interface QualifierSearchSession
    extends org.osid.authorization.QualifierQuerySession {


    /**
     *  Gets a qualifier search. 
     *
     *  @return the qualifier search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierSearch getQualifierSearch();


    /**
     *  Gets a qualifier search order. The <code> QualifierSearchOrder </code> 
     *  is supplied to a <code> QualifierSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the qualifier search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierSearchOrder getQualifierSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  qualifierQuery the qualifier query 
     *  @param  qualifierSearch the qualifier search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> qualifierQueriy </code> 
     *          or <code> qualifierSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> qualifierQuery </code> or 
     *          <code> qualifierSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierSearchResults getQualifiersBySearch(org.osid.authorization.QualifierQuery qualifierQuery, 
                                                                               org.osid.authorization.QualifierSearch qualifierSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a qualifier query from an inspector. The inspector is available 
     *  from a <code> QualifierSearchResults. </code> 
     *
     *  @param  qualifierQueryInspector a qualifier query inspector 
     *  @return the qualifier query 
     *  @throws org.osid.NullArgumentException <code> qualifierQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> qualifierQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.QualifierQuery getQualifierQueryFromInspector(org.osid.authorization.QualifierQueryInspector qualifierQueryInspector);
}
