//
// org.osid.authorization.QualifierVaultAssignmentSession
//
//     The OSID Java specification for org.osid.authorization.QualifierVaultAssignmentSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This session provides methods to re-assign <code> Qualifiers </code> to 
 *  <code> Vaults. </code> A <code> Qualifier </code> may map to multiple 
 *  <code> Vaults </code> and removing the last reference to a <code> 
 *  Qualifier </code> is the equivalent of deleting it. Each <code> Vault 
 *  </code> may have its own authorizations governing who is allowed to 
 *  operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Qualifier </code> to another <code> 
 *  Vault </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface QualifierVaultAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter qualifier/vault mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignQualifiers();


    /**
     *  Tests if this user can alter qualifier/vault mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignQualifiersToVault(org.osid.id.Id vaultId);


    /**
     *  Gets a list of vault including and under the given vault node in which 
     *  any qualifier can be assigned. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @return list of assignable vault <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableVaultIds(org.osid.id.Id vaultId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of vault including and under the given vault node in which 
     *  a specific qualifier can be assigned. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  qualifierId the <code> Id </code> of the <code> Qualifier 
     *          </code> 
     *  @return list of assignable vault <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> or 
     *          <code> qualifierId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableVaultIdsForQualifier(org.osid.id.Id vaultId, 
                                                                org.osid.id.Id qualifierId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Qualifier </code> to a <code> Vault. </code> 
     *
     *  @param  qualifierId the <code> Id </code> of the <code> Qualifier 
     *          </code> 
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @throws org.osid.AlreadyExistsException <code> qualifierId </code> is 
     *          already assigned to <code> vaultId </code> 
     *  @throws org.osid.NotFoundException <code> qualifierId </code> or 
     *          <code> vaultId </code> not found 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> or 
     *          <code> vaultId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignQualifierToVault(org.osid.id.Id qualifierId, 
                                       org.osid.id.Id vaultId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Qualifier </code> from a <code> Vault. </code> 
     *
     *  @param  qualifierId the <code> Id </code> of the <code> Qualifier 
     *          </code> 
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @throws org.osid.NotFoundException <code> qualifierId </code> or 
     *          <code> vaultId </code> not found or <code> qualifierId </code> 
     *          not assigned to <code> vaultId </code> 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> or 
     *          <code> vaultId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignQualifierFromVault(org.osid.id.Id qualifierId, 
                                           org.osid.id.Id vaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Qualifier </code> from one <code> Vault </code> to 
     *  another. Mappings to other <code> Vaults </code> are unaffected. 
     *
     *  @param  qualifierId the <code> Id </code> of the <code> Qualifier 
     *          </code> 
     *  @param  fromVaultId the <code> Id </code> of the current <code> Vault 
     *          </code> 
     *  @param  toVaultId the <code> Id </code> of the destination <code> 
     *          Vault </code> 
     *  @throws org.osid.NotFoundException <code> qualfiierId, fromVaultId, 
     *          </code> or <code> toVaultId </code> not found or <code> 
     *          qualfiierId, </code> not mapped to <code> fromVaultId </code> 
     *  @throws org.osid.NullArgumentException <code> qualfiierId,, 
     *          fromVaultId, </code> or <code> toVaultId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignQualifierToVault(org.osid.id.Id qualifierId, 
                                         org.osid.id.Id fromVaultId, 
                                         org.osid.id.Id toVaultId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
