//
// org.osid.authorization.VaultQuery
//
//     The OSID Java specification for org.osid.authorization.VaultQuery.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization;


/**
 *  <p>This is the query for searching vaults. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface VaultQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the function <code> Id </code> for this query. 
     *
     *  @param  functionId a function <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> functionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFunctionId(org.osid.id.Id functionId, boolean match);


    /**
     *  Clears the function <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFunctionIdTerms();


    /**
     *  Tests if a <code> FunctionQuery </code> is available. 
     *
     *  @return <code> true </code> if a function query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFunctionQuery();


    /**
     *  Gets the query for a function. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the function query 
     *  @throws org.osid.UnimplementedException <code> supportsFunctionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFunctionQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.FunctionQuery getFunctionQuery();


    /**
     *  Matches vaults that have any function. 
     *
     *  @param  match <code> true </code> to match vaults with any function 
     *          mapping, <code> false </code> to match vaults with no function 
     *          mapping 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFunction(boolean match);


    /**
     *  Clears the function query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFunctionTerms();


    /**
     *  Sets the qualifier <code> Id </code> for this query. 
     *
     *  @param  qualifierId a qualifier <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> qualifierId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQualifierId(org.osid.id.Id qualifierId, boolean match);


    /**
     *  Clears the qualifier <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualifierIdTerms();


    /**
     *  Tests if a <code> QualifierQuery </code> is available. 
     *
     *  @return <code> true </code> if a qualifier query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQualifierQuery();


    /**
     *  Gets the query for a qualifier. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the qualifier query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsQualifierQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQualifierQuery() </code> is <code> true. </code> 
     */

    public org.osid.authorization.QualifierQuery getQualifierQuery();


    /**
     *  Matches vaults that have any qualifier. 
     *
     *  @param  match <code> true </code> to match vaults with any qualifier 
     *          mapping, <code> false </code> to match vaults with no 
     *          qualifier mapping 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQualifier(boolean match);


    /**
     *  Clears the qualifier query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualifierTerms();


    /**
     *  Sets the authorization <code> Id </code> for this query. 
     *
     *  @param  authorizationId an authorization <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> authorizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAuthorizationId(org.osid.id.Id authorizationId, 
                                     boolean match);


    /**
     *  Clears the authorization <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuthorizationIdTerms();


    /**
     *  Tests if an <code> AuthorizationQuery </code> is available. 
     *
     *  @return <code> true </code> if an authorization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationQuery();


    /**
     *  Gets the query for an authorization. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the authorization query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.AuthorizationQuery getAuthorizationQuery();


    /**
     *  Matches vaults that have any authorization. 
     *
     *  @param  match <code> true </code> to match vaults with any 
     *          authorization mapping, <code> false </code> to match vaults 
     *          with no authorization mapping 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAuthorization(boolean match);


    /**
     *  Clears the authorization query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuthorizationTerms();


    /**
     *  Sets the vault <code> Id </code> for this query to match vaults that 
     *  have the specified vault as an ancestor. 
     *
     *  @param  vaultId a vault <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorVaultId(org.osid.id.Id vaultId, boolean match);


    /**
     *  Clears the ancestor vault <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorVaultIdTerms();


    /**
     *  Tests if a <code> VaultQuery </code> is available. 
     *
     *  @return <code> true </code> if a vault query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorVaultQuery();


    /**
     *  Gets the query for a vault. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the vault query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorVaultQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorVaultQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.VaultQuery getAncestorVaultQuery();


    /**
     *  Matches vaults that have any ancestor. 
     *
     *  @param  match <code> true </code> to match vaults with any ancestor, 
     *          <code> false </code> to match root vaults 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorVault(boolean match);


    /**
     *  Clears the ancestor vault query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorVaultTerms();


    /**
     *  Sets the vault <code> Id </code> for this query to match vaults that 
     *  have the specified vault as a descendant. 
     *
     *  @param  vaultId a vault <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantVaultId(org.osid.id.Id vaultId, boolean match);


    /**
     *  Clears the descendant vault <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantVaultIdTerms();


    /**
     *  Tests if a <code> VaultQuery </code> is available. 
     *
     *  @return <code> true </code> if a vault query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantVaultQuery();


    /**
     *  Gets the query for a vault. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the vault query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantVaultQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantVaultQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authorization.VaultQuery getDescendantVaultQuery();


    /**
     *  Matches vaults that have any descendant. 
     *
     *  @param  match <code> true </code> to match vaults with any Ddscendant, 
     *          <code> false </code> to match leaf vaults 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantVault(boolean match);


    /**
     *  Clears the descendant vault query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantVaultTerms();


    /**
     *  Gets the vault query record corresponding to the given <code> Vault 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  vaultRecordType a vault record type 
     *  @return the vault query record 
     *  @throws org.osid.NullArgumentException <code> vaultRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(vaultRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.records.VaultQueryRecord getVaultQueryRecord(org.osid.type.Type vaultRecordType)
        throws org.osid.OperationFailedException;
}
