//
// org.osid.authorization.batch.AuthorizationBatchForm
//
//     The OSID Java specification for org.osid.authorization.batch.AuthorizationBatchForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.batch;


/**
 *  <p>This is the form for creating and updating authorizations in bulk. 
 *  <code> </code> Like all <code> OsidForm </code> objects, various data 
 *  elements may be set here for use in the create and update methods in the 
 *  <code> AuthorizationBatchAdminSession. </code> For each data element that 
 *  may be set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface AuthorizationBatchForm
    extends org.osid.authorization.AuthorizationForm {


    /**
     *  Tests if this batch form was requested by specifying an agent if this 
     *  is a create transaction. 
     *
     *  @return <code> true </code> if an agent exists, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAgent();


    /**
     *  Gets the <code> Agent </code> <code> Id </code> of the authorization 
     *  if this is a create transaction. 
     *
     *  @return the agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> or <code> hasAgent() </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgentId();


    /**
     *  Tests if this batch form was requested by specifying a resource if 
     *  this is a create transaction. 
     *
     *  @return <code> true </code> if a resource exists, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasResource();


    /**
     *  Gets the <code> Resource </code> <code> Id </code> of the 
     *  authorization if this is a create transaction. 
     *
     *  @return the resource <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> or <code> hasResource() </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Tests if this batch form was requested by specifying a trust if this 
     *  is a create transaction. 
     *
     *  @return <code> true </code> if a trust exists, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasTrust();


    /**
     *  Gets the <code> Trust </code> <code> Id </code> of the authorization 
     *  if this is a create transaction. 
     *
     *  @return the trust <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> or <code> hasTrust() </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTrustId();


    /**
     *  Gets the qualifier <code> Id </code> of the authorization if this is a 
     *  create transaction. 
     *
     *  @return the qualifier <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getQualifierId();


    /**
     *  Gets the <code> Id </code> of the authorization to be updated if this 
     *  is an update transaction. 
     *
     *  @return the authorization <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isForUpdate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuthorizationId();
}
