//
// org.osid.authorization.rules.AuthorizationEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>This session provides methods to apply <code> AuthorizationEnablers 
 *  </code> to <code> Authorizations. </code> An <code> Authorization </code> 
 *  with multiple <code> AuthorizationEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> 
 *  Authorization. </code> </p>
 */

public interface AuthorizationEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Vault </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Vault Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getVaultId();


    /**
     *  Gets the <code> Vault </code> associated with this session. 
     *
     *  @return the vault 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authorization.Vault getVault()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter authorization enabler/authorization 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuthorizationEnablers();


    /**
     *  Adds an existing <code> AuthorizationEnabler </code> to an <code> 
     *  Authorization. </code> 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @param  authorizationId the <code> Id </code> of the <code> 
     *          Authorization </code> 
     *  @throws org.osid.AlreadyExistsException <code> authorizationEnablerId 
     *          </code> already assigned to <code> authorizationId </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> or <code> authorizationId </code> not found 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> or <code> authorizationId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuthorizationEnablerToAuthorization(org.osid.id.Id authorizationEnablerId, 
                                                          org.osid.id.Id authorizationId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AuthorizationEnabler </code> from an <code> 
     *  Authorization. </code> 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of the <code> 
     *          AuthorizationEnabler </code> 
     *  @param  authorizationId the <code> Id </code> of the <code> 
     *          Authorization </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId 
     *          </code> or <code> authorizationId </code> not found or not 
     *          mapped 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId 
     *          </code> or <code> authorizationId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuthorizationEnablerFromAuthorization(org.osid.id.Id authorizationEnablerId, 
                                                              org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> AuthorizationEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuthorizationEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceAuthorizationEnablers();


    /**
     *  Reorders authorization enablers for an authorization by moving the 
     *  specified authorization enabler in front of a reference authorization 
     *  enabler. 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of an <code> 
     *          AuthorizationEnabler </code> 
     *  @param  authorizationId the <code> Id </code> of an <code> 
     *          Authorization </code> 
     *  @param  referenceId the reference authorization enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnablerId, 
     *          authorizationId, </code> or <code> referenceId </code> not 
     *          found or, <code> authorizationEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> authorizationId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId, 
     *          authorizationId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuthorizationEnablerAhead(org.osid.id.Id authorizationEnablerId, 
                                              org.osid.id.Id authorizationId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders authorization enablers for an authorization by moving the 
     *  specified authorization enabler behind a reference authorization 
     *  enabler. 
     *
     *  @param  authorizationEnablerId the <code> Id </code> of an <code> 
     *          AuthorizationEnabler </code> 
     *  @param  authorizationId the <code> Id </code> of an <code> 
     *          Authorization </code> 
     *  @param  referenceId the reference authorization enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> authorizationEnabelrId, 
     *          authorizationId, </code> or <code> referenceId </code> not 
     *          found or, <code> authorizationEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> authorizationId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerId, 
     *          authorizationId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuthorizationEnablerBehind(org.osid.id.Id authorizationEnablerId, 
                                               org.osid.id.Id authorizationId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of authorization enablers for an authorization. 
     *
     *  @param  authorizationEnablerIds the <code> Ids </code> for a set of 
     *          <code> AuthorizationEnablers </code> 
     *  @param  authorizationId the <code> Id </code> of an <code> 
     *          Authorization </code> 
     *  @throws org.osid.NotFoundException <code> authorizationId </code> not 
     *          found or, an <code> authorizationEnablerId </code> not related 
     *          to <code> authorizationId </code> 
     *  @throws org.osid.NullArgumentException <code> authorizationEnablerIds 
     *          </code> or <code> authorizationId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAuthorizationEnablers(org.osid.id.Id[] authorizationEnablerIds, 
                                           org.osid.id.Id authorizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
