//
// org.osid.authorization.rules.AuthorizationRulesProxyManager
//
//     The OSID Java specification for org.osid.authorization.rules.AuthorizationRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.authorization.rules;


/**
 *  <p>The authorization rules proxy manager provides access to authorization 
 *  rules sessions and provides interoperability tests for various aspects of 
 *  this service. Methods in this manager pass a <code> Proxy </code> for 
 *  passing information from server environments. The sessions included in 
 *  this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AuthorizationEnablerLookupSession: </code> a session to 
 *      retrieve authorization enablers </li> 
 *      <li> <code> AuthorizationEnablerQuerySession: </code> a session to 
 *      query for authorization enablers </li> 
 *      <li> <code> AuthorizationEnablerSearchSession: </code> a session to 
 *      search for authorization enablers </li> 
 *      <li> <code> AuthorizationEnablerAdminSession: </code> a session to 
 *      create and delete authorization enablers </li> 
 *      <li> <code> AuthorizationEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to authorization enabler changes 
 *      </li> 
 *      <li> <code> AuthorizationEnablerVaultSession: </code> a session to 
 *      look up authorization enabler vault mappings </li> 
 *      <li> <code> AuthorizationEnablerVaultAssignmentSession: </code> a 
 *      session to manage authorization enabler to vault mappings </li> 
 *      <li> <code> AuthorizationEnablerSmartVaultSession: </code> a session 
 *      to manage dynamic vaults of authorization enablers </li> 
 *      <li> <code> AuthorizationEnablerRuleLookupSession: </code> a session 
 *      to look up authorization enabler to authorization mappings </li> 
 *      <li> <code> AuthorizationEnablerRuleApplicationSession: </code> a 
 *      session to assign authorization enablers to authorizations </li> 
 *  </ul>
 *  
 */

public interface AuthorizationRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.authorization.rules.AuthorizationRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerLookupSession getAuthorizationEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler lookup service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Vault </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerLookupSession getAuthorizationEnablerLookupSessionForVault(org.osid.id.Id vaultId, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerQuerySession getAuthorizationEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler query service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Vault </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerQuerySession getAuthorizationEnablerQuerySessionForVault(org.osid.id.Id vaultId, 
                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerSearchSession getAuthorizationEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enablers earch service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Vault </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerSearchSession getAuthorizationEnablerSearchSessionForVault(org.osid.id.Id vaultId, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerAdminSession getAuthorizationEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler administration service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Vault </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerAdminSession getAuthorizationEnablerAdminSessionForVault(org.osid.id.Id vaultId, 
                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler notification service. 
     *
     *  @param  authorizationEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerNotificationSession getAuthorizationEnablerNotificationSession(org.osid.authorization.rules.AuthorizationEnablerReceiver authorizationEnablerReceiver, 
                                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler notification service for the given vault. 
     *
     *  @param  authorizationEnablerReceiver the notification callback 
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no vault found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          authorizationEnablerReceiver, vaultId </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerNotificationSession getAuthorizationEnablerNotificationSessionForVault(org.osid.authorization.rules.AuthorizationEnablerReceiver authorizationEnablerReceiver, 
                                                                                                                                   org.osid.id.Id vaultId, 
                                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup authorization 
     *  enabler/vault mappings for authorization enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerVaultSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerVault() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerVault() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerVaultSession getAuthorizationEnablerVaultSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  authorization enablers to vaults for authorization. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerVaultAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerVaultAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerVaultAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerVaultAssignmentSession getAuthorizationEnablerVaultAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage authorization enabler 
     *  smart vaults. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerSmartVaultSession </code> 
     *  @throws org.osid.NotFoundException no <code> Vault </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerSmartVault() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerSmartVault() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerSmartVaultSession getAuthorizationEnablerSmartVaultSession(org.osid.id.Id vaultId, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler mapping lookup service for looking up the rules applied to the 
     *  vault. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerAuthorizationRuleLookup() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerRuleLookupSession getAuthorizationEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler authorization mapping lookup service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Vault </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerRuleLookupSession getAuthorizationEnablerRuleLookupSessionForVault(org.osid.id.Id vaultId, 
                                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler authorization assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablernRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerRuleApplicationSession getAuthorizationEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the authorization 
     *  enabler authorization assignment service for the given vault. 
     *
     *  @param  vaultId the <code> Id </code> of the <code> Vault </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuthorizationEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Vault </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> vaultId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuthorizationEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuthorizationEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.authorization.rules.AuthorizationEnablerRuleApplicationSession getAuthorizationEnablerRuleApplicationSessionForVault(org.osid.id.Id vaultId, 
                                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
