//
// org.osid.bidding.Auction
//
//     The OSID Java specification for org.osid.bidding.Auction.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>An <code> Auction </code> governs how <code> Bids </code> may be 
 *  performed. <code> Auctions </code> are temporal where bidding is open if 
 *  <code> isEffective() </code> is true. </p>
 */

public interface Auction
    extends org.osid.OsidGovernator,
            org.osid.Temporal {


    /**
     *  Gets the currency type used in this auction. 
     *
     *  @return currency type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCurrencyType();


    /**
     *  Gets the minimum number of bidders required for this auction to 
     *  complete. 
     *
     *  @return the minimum number of bidders 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumBidders();


    /**
     *  Tests if bids in this auction are visible. 
     *
     *  @return <code> true </code> if this auction is sealed, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSealed();


    /**
     *  Gets the seller <code> Id. </code> 
     *
     *  @return a resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSellerId();


    /**
     *  Gets the seller. 
     *
     *  @return a resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getSeller()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the item <code> Id. </code> 
     *
     *  @return a resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getItemId();


    /**
     *  Gets the item. 
     *
     *  @return a resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getItem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the number of items up for bid. 
     *
     *  @return the initial number of items 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getLotSize();


    /**
     *  Gets the number of items remaining. 
     *
     *  @return the number of items remaining 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getRemainingItems();


    /**
     *  Tests if this auction has a maxmimum number of items that can be 
     *  bought. 
     *
     *  @return <code> true </code> if the auction has an item limit, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean limitsItems();


    /**
     *  Gets the limit on the number of items that can be bought. 
     *
     *  @return the item limit 
     *  @throws org.osid.IllegalStateException <code> limitsItems() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getItemLimit();


    /**
     *  Gets the starting price per item. 
     *
     *  @return the starting price 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getStartingPrice();


    /**
     *  Gets the minimum increment amount for successive bids. 
     *
     *  @return the increment 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getPriceIncrement();


    /**
     *  Tests if a buyout price is available. 
     *
     *  @return <code> true </code> if the auction has a reserve price, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasReservePrice();


    /**
     *  Gets the reserve price. 
     *
     *  @return the reserve price 
     *  @throws org.osid.IllegalStateException <code> hasReservePrice() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getReservePrice();


    /**
     *  Tests if a buyout price is available. 
     *
     *  @return <code> true </code> if the item can be bought out, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasBuyoutPrice();


    /**
     *  Gets the buyout price. 
     *
     *  @return the buyout price 
     *  @throws org.osid.IllegalStateException <code> hasBuyoutPrice() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getBuyoutPrice();


    /**
     *  Gets the auction record corresponding to the given <code> Auction 
     *  </code> record <code> Type. </code> This method ie used to retrieve an 
     *  object implementing the requested record. The <code> auctionRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(auctionRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  auctionRecordType the type of auction record to retrieve 
     *  @return the auction record 
     *  @throws org.osid.NullArgumentException <code> auctionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(auctionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.AuctionRecord getAuctionRecord(org.osid.type.Type auctionRecordType)
        throws org.osid.OperationFailedException;
}
