//
// org.osid.bidding.AuctionHouseQuery
//
//     The OSID Java specification for org.osid.bidding.AuctionHouseQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This is the query for searching auction houses. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface AuctionHouseQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the auction <code> Id </code> for this query. 
     *
     *  @param  auctionId the auction <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAuctionId(org.osid.id.Id auctionId, boolean match);


    /**
     *  Clears the auction <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuctionIdTerms();


    /**
     *  Tests if an <code> AuctionQuery </code> is available. 
     *
     *  @return <code> true </code> if an auction query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionQuery();


    /**
     *  Gets the query for an auction. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the auction query 
     *  @throws org.osid.UnimplementedException <code> supportsAuctionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionQuery() </code> is <code> true. </code> 
     */

    public org.osid.bidding.AuctionQuery getAuctionQuery();


    /**
     *  Matches auction houses with any auction. 
     *
     *  @param  match <code> true </code> to match auction houses with any 
     *          auction, <code> false </code> to match auction houses with no 
     *          auction 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAuction(boolean match);


    /**
     *  Clears the auction query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuctionTerms();


    /**
     *  Sets the bid <code> Id </code> for this query. 
     *
     *  @param  bidId the bid <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bidId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBidId(org.osid.id.Id bidId, boolean match);


    /**
     *  Clears the bid <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBidIdTerms();


    /**
     *  Tests if a <code> BidQuery </code> is available. 
     *
     *  @return <code> true </code> if a bid query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidQuery();


    /**
     *  Gets the query for a bid. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bid query 
     *  @throws org.osid.UnimplementedException <code> supportsBidQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidQuery() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidQuery getBidQuery();


    /**
     *  Matches auction houses that have any bid. 
     *
     *  @param  match <code> true </code> to match auction houses with any 
     *          bid, <code> false </code> to match auction houses with no bid 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBid(boolean match);


    /**
     *  Clears the bid query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBidTerms();


    /**
     *  Sets the auction house <code> Id </code> for this query to match 
     *  auction houses that have the specified auction house as an ancestor. 
     *
     *  @param  auctionHouseId an auction house <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorAuctionHouseId(org.osid.id.Id auctionHouseId, 
                                            boolean match);


    /**
     *  Clears the ancestor auction house <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAuctionHouseIdTerms();


    /**
     *  Tests if an <code> AuctionHouseQuery </code> is available. 
     *
     *  @return <code> true </code> if an auction house query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorAuctionHouseQuery();


    /**
     *  Gets the query for an <code> AuctionHouse. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the auction house query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorAuctionHouseQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorAuctionHouseQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.AuctionHouseQuery getAncestorAuctionHouseQuery();


    /**
     *  Matches auction houses with any ancestor. 
     *
     *  @param  match <code> true </code> to match auction houses with any 
     *          ancestor, <code> false </code> to match root auction houses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorAuctionHouse(boolean match);


    /**
     *  Clears the ancestor auction house query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAuctionHouseTerms();


    /**
     *  Sets the auction house <code> Id </code> for this query to match 
     *  auction houses that have the specified auction house as a descendant. 
     *
     *  @param  auctionHouseId an auction house <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantAuctionHouseId(org.osid.id.Id auctionHouseId, 
                                              boolean match);


    /**
     *  Clears the descendant auction house <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAuctionHouseIdTerms();


    /**
     *  Tests if an <code> AuctionHouseQuery </code> is available. 
     *
     *  @return <code> true </code> if an auction house query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantAuctionHouseQuery();


    /**
     *  Gets the query for an auction house. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the auction house query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantAuctionHouseQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantAuctionHouseQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.AuctionHouseQuery getDescendantAuctionHouseQuery();


    /**
     *  Matches auction houses with any descendant. 
     *
     *  @param  match <code> true </code> to match auction houses with any 
     *          descendant, <code> false </code> to match leaf auction houses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantAuctionHouse(boolean match);


    /**
     *  Clears the descendant auction house query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAuctionHouseTerms();


    /**
     *  Gets the auction house query record corresponding to the given <code> 
     *  AuctionHouse </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  auctionHouseRecordType an auction house record type 
     *  @return the auction house query record 
     *  @throws org.osid.NullArgumentException <code> auctionHouseRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(auctionHouseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.AuctionHouseQueryRecord getAuctionHouseQueryRecord(org.osid.type.Type auctionHouseRecordType)
        throws org.osid.OperationFailedException;
}
