//
// org.osid.bidding.AuctionHouseSearchSession
//
//     The OSID Java specification for org.osid.bidding.AuctionHouseSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session provides methods for searching among <code> AuctionHouse 
 *  </code> objects. The search query is constructed using the <code> 
 *  AuctionHouseQuery. </code> </p> 
 *  
 *  <p> <code> getAuctionHousesByQuery() </code> is the basic search method 
 *  and returns a list of <code> Auction Houses. </code> A more advanced 
 *  search may be performed with <code> getAuctionHousesBySearch(). </code> It 
 *  accepts an <code> AuctionHouseSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getAuctionHousesBySearch() </code> returns an 
 *  <code> AuctionHouseSearchResults </code> that can be used to access the 
 *  resulting <code> AuctionHouseList </code> or be used to perform a search 
 *  within the result set through <code> AuctionHouseSearch. </code> </p> 
 *  
 *  <p> AuctionHouses may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  AuctionHouseQuery. </code> </p>
 */

public interface AuctionHouseSearchSession
    extends org.osid.bidding.AuctionHouseQuerySession {


    /**
     *  Gets an auction house search. 
     *
     *  @return the auction house search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseSearch getAuctionHouseSearch();


    /**
     *  Gets an auction house search order. The <code> AuctionHouseSearchOrder 
     *  </code> is supplied to an <code> AuctionHouseSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the auction house search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseSearchOrder getAuctionHouseSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  auctionHouseQuery the auction house query 
     *  @param  auctionHouseSearch the auction house search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> auctionHouseQuery 
     *          </code> or <code> auctionHouseSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auctionHouseQuery </code> 
     *          or <code> auctionHouseSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseSearchResults getAuctionHousesBySearch(org.osid.bidding.AuctionHouseQuery auctionHouseQuery, 
                                                                               org.osid.bidding.AuctionHouseSearch auctionHouseSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an auction house query from an inspector. The inspector is 
     *  available from an <code> AuctionHouseSearchResults. </code> 
     *
     *  @param  auctionHouseQueryInspector an auction house query inspector 
     *  @return the auction house query 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionHouseQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionHouseQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseQuery getAuctionHouseQueryFromInspector(org.osid.bidding.AuctionHouseQueryInspector auctionHouseQueryInspector);
}
