//
// org.osid.bidding.AuctionQuery
//
//     The OSID Java specification for org.osid.bidding.AuctionQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This is the query for searching auctions. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface AuctionQuery
    extends org.osid.OsidGovernatorQuery,
            org.osid.OsidTemporalQuery {


    /**
     *  Matches the currency type. 
     *
     *  @param  currencyType a currency type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> currencyType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCurrencyType(org.osid.type.Type currencyType, 
                                  boolean match);


    /**
     *  Matches auctions with any currency type set. 
     *
     *  @param  match <code> true </code> to match auctions with any currency 
     *          type, <code> false </code> to match auctions with no currency 
     *          type 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCurrencyType(boolean match);


    /**
     *  Clears the currency type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCurrencyTypeTerms();


    /**
     *  Matches the minimum bidders between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumBidders(long start, long end, boolean match);


    /**
     *  Matches auctions with any minimum bidders set. 
     *
     *  @param  match <code> true </code> to match auctions with any minimum 
     *          bidders, <code> false </code> to match auctions with no 
     *          minimum bidders 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMinimumBidders(boolean match);


    /**
     *  Clears the minimum bidders terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumBiddersTerms();


    /**
     *  Matches sealed auctions. 
     *
     *  @param  match <code> true </code> to match sealed auctions, <code> 
     *          false </code> to match visible bid auctions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSealed(boolean match);


    /**
     *  Clears the sealed terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSealedTerms();


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSellerId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSellerIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSellerQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsSellerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSellerQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSellerQuery();


    /**
     *  Matches auctions with any seller set. 
     *
     *  @param  match <code> true </code> to match auctions with any seller, 
     *          <code> false </code> to match auctions with no seller 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySeller(boolean match);


    /**
     *  Clears the seller query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSellerTerms();


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getItemQuery();


    /**
     *  Matches auctions with any item set. 
     *
     *  @param  match <code> true </code> to match auctions with any item, 
     *          <code> false </code> to match auctions with no item 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears the seller query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Matches the lot size between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLotSize(long start, long end, boolean match);


    /**
     *  Matches auctions with any lot size set. 
     *
     *  @param  match <code> true </code> to match auctions with any lot size, 
     *          <code> false </code> to match auctions with no lot size set 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLotSize(boolean match);


    /**
     *  Clears the lot size terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLotSizeTerms();


    /**
     *  Matches the remaining items between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRemainingItems(long start, long end, boolean match);


    /**
     *  Clears the remaining items terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRemainingItemsTerms();


    /**
     *  Matches the item limit between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemLimit(long start, long end, boolean match);


    /**
     *  Matches auctions with any item limit. 
     *
     *  @param  match <code> true </code> to match auctions with any item 
     *          limit, <code> false </code> to match auctions with no item 
     *          limit 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItemLimit(boolean match);


    /**
     *  Clears the item limit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemLimitTerms();


    /**
     *  Matches the starting price between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> or <code> 
     *          start.getCurencyType() </code> != <code> end.getCurrencyType() 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartingPrice(org.osid.financials.Currency start, 
                                   org.osid.financials.Currency end, 
                                   boolean match);


    /**
     *  Matches auctions with any starting price. 
     *
     *  @param  match <code> true </code> to match auctions with any starting 
     *          price, <code> false </code> to match auctions with no starting 
     *          price 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStartingPrice(boolean match);


    /**
     *  Clears the starting price terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingPriceTerms();


    /**
     *  Matches the price increment between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> or <code> 
     *          start.getCurencyType() </code> != <code> end.getCurrencyType() 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPriceIncrement(org.osid.financials.Currency start, 
                                    org.osid.financials.Currency end, 
                                    boolean match);


    /**
     *  Matches auctions with any price increment. 
     *
     *  @param  match <code> true </code> to match auctions with any price 
     *          increment, <code> false </code> to match auctions with no 
     *          price increment 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPriceIncrement(boolean match);


    /**
     *  Clears the price increment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceIncrementTerms();


    /**
     *  Matches the reserve price between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> or <code> 
     *          start.getCurencyType() </code> != <code> end.getCurrencyType() 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReservePrice(org.osid.financials.Currency start, 
                                  org.osid.financials.Currency end, 
                                  boolean match);


    /**
     *  Matches auctions with any reserve price. 
     *
     *  @param  match <code> true </code> to match auctions with any reserve 
     *          price, <code> false </code> to match auctions with no reserve 
     *          price 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyReservePrice(boolean match);


    /**
     *  Clears the reserve price terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReservePriceTerms();


    /**
     *  Matches the buyout price between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> or <code> 
     *          start.getCurencyType() </code> != <code> end.getCurrencyType() 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBuyoutPrice(org.osid.financials.Currency start, 
                                 org.osid.financials.Currency end, 
                                 boolean match);


    /**
     *  Matches auctions with any buyout price. 
     *
     *  @param  match <code> true </code> to match auctions with any buyout 
     *          price, <code> false </code> to match auctions with no buyout 
     *          price 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBuyoutPrice(boolean match);


    /**
     *  Clears the buyout price terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBuyoutPriceTerms();


    /**
     *  Sets the bid <code> Id </code> for this query. 
     *
     *  @param  bidId the bid <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> bidId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBidId(org.osid.id.Id bidId, boolean match);


    /**
     *  Clears the bid <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBidIdTerms();


    /**
     *  Tests if a <code> BidQuery </code> is available. 
     *
     *  @return <code> true </code> if a bid query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidQuery();


    /**
     *  Gets the query for a bid. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bid query 
     *  @throws org.osid.UnimplementedException <code> supportsBidQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBidQuery() </code> is <code> true. </code> 
     */

    public org.osid.bidding.BidQuery getBidQuery();


    /**
     *  Clears the bid query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBidTerms();


    /**
     *  Sets the auction house <code> Id </code> for this query to match 
     *  auctions assigned to auction houses. 
     *
     *  @param  auctionHouseId the auction house <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAuctionHouseId(org.osid.id.Id auctionHouseId, 
                                    boolean match);


    /**
     *  Clears the auction house <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuctionHouseIdTerms();


    /**
     *  Tests if an <code> AuctionHouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a auction house query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseQuery();


    /**
     *  Gets the query for a auction house. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the auction house query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseQuery getAuctionHouseQuery();


    /**
     *  Clears the auction house query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuctionHouseTerms();


    /**
     *  Gets the auction query record corresponding to the given <code> 
     *  Auction </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  auctionRecordType an auction record type 
     *  @return the auction query record 
     *  @throws org.osid.NullArgumentException <code> auctionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(auctionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.AuctionQueryRecord getAuctionQueryRecord(org.osid.type.Type auctionRecordType)
        throws org.osid.OperationFailedException;
}
