//
// org.osid.bidding.AuctionSearchOrder
//
//     The OSID Java specification for org.osid.bidding.AuctionSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface AuctionSearchOrder
    extends org.osid.OsidGovernatorSearchOrder,
            org.osid.OsidTemporalSearchOrder {


    /**
     *  Orders the results by the currency type. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCurrencyType(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the minimum bidders. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMinimumBidders(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the sealed flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySealed(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by seller. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySeller(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a resource search order is available. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSellerSearchOrder();


    /**
     *  Gets the resource search order. 
     *
     *  @return the resource search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsSellerSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getSellerSearchOrder();


    /**
     *  Orders the results by item. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByItem(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a resource search order is available. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemSearchOrder();


    /**
     *  Gets the resource search order. 
     *
     *  @return the resource search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsItemSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getItemSearchOrder();


    /**
     *  Orders the results by lot size. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLotSize(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by remaining items. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRemainingItems(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the auction item limit. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByItemLimit(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the starting price. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByStartingPrice(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the price increment 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPriceIncrement(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the reserve price. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByReservePrice(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the buyout price. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBuyoutPrice(org.osid.SearchOrderStyle style);


    /**
     *  Gets the auction search order record corresponding to the given 
     *  auction record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  auctionRecordType an auction record type 
     *  @return the auction search order record 
     *  @throws org.osid.NullArgumentException <code> auctionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(auctionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.AuctionSearchOrderRecord getAuctionSearchOrderRecord(org.osid.type.Type auctionRecordType)
        throws org.osid.OperationFailedException;
}
