//
// org.osid.bidding.BidNotificationSession
//
//     The OSID Java specification for org.osid.bidding.BidNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Bid </code> objects in this <code> AuctionHouse. </code> This 
 *  also includes existing bids that may appear or disappear due to changes in 
 *  the <code> AuctionHouse </code> hierarchy, This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> BidLookupSession. </code> </p>
 */

public interface BidNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Bid </code> notifications. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer notification 
     *  operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForBidNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include bids in auction houses which are children of this auction 
     *  house in the auction house hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAuctionHouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this auction house only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAuctionHouseView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeBidNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableBidNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableBidNotifications();


    /**
     *  Acknowledge a bid notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeBidNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new bids. <code> BidReceiver.newBids() 
     *  </code> is invoked when a new <code> Bid </code> appears in this 
     *  auction house. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new bids for the given auction <code> 
     *  Id. </code> <code> BidReceiver.newBids() </code> is invoked when a new 
     *  <code> Bid </code> is created. 
     *
     *  @param  auctionId the <code> Id </code> of the auction to monitor 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBidsForAuction(org.osid.id.Id auctionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new bids for the given resource <code> 
     *  Id. </code> <code> BidReceiver.newBids() </code> is invoked when a new 
     *  <code> Bid </code> is created. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBidsForBidder(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated bids. <code> 
     *  BidReceiver.changedBids() </code> is invoked when a bid in this 
     *  auction house is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated bids for the given auction 
     *  <code> Id. </code> <code> BidReceiver.changedBids() </code> is invoked 
     *  when a <code> Bid </code> in this auction house is changed. 
     *
     *  @param  auctionId the <code> Id </code> of the auction to monitor 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBidsForAuction(org.osid.id.Id auctionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated bids for the given resource 
     *  <code> Id. </code> <code> BidReceiver.changedBids() </code> is invoked 
     *  when a <code> Bid </code> in this auction house is changed. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBidsForBidder(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated bid. <code> 
     *  BidReceiver.changedBids() </code> is invoked when the specified bid in 
     *  this auction house is changed. 
     *
     *  @param  bidId the <code> Id </code> of the <code> Bid </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> bidId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBid(org.osid.id.Id bidId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted bids. <code> 
     *  BidReceiver.deletedBids() </code> is invoked when a bid is deleted or 
     *  removed from this auction house. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBids()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted bids for the given auction 
     *  <code> Id. </code> <code> BidReceiver.deletedBids() </code> is invoked 
     *  when a <code> Bid </code> is deleted or removed from this auction 
     *  house. 
     *
     *  @param  auctionId the <code> Id </code> of the auction to monitor 
     *  @throws org.osid.NullArgumentException <code> auctionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBidsForAuction(org.osid.id.Id auctionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted bids for the given resource 
     *  <code> Id. </code> <code> BidReceiver.deletedBids() </code> is invoked 
     *  when a <code> Bid </code> is deleted or removed from this auction 
     *  house. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBidsForBidder(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted bid. <code> 
     *  BidReceiver.deletedBids() </code> is invoked when the specified bid is 
     *  deleted or removed from this auction house. 
     *
     *  @param  bidId the <code> Id </code> of the <code> Bid </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> bidId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBid(org.osid.id.Id bidId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
