//
// org.osid.bidding.BidSearchOrder
//
//     The OSID Java specification for org.osid.bidding.BidSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface BidSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Orders the results by auction. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAuction(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an auction search order is available. 
     *
     *  @return <code> true </code> if an auction search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionSearchOrder();


    /**
     *  Gets the auction search order. 
     *
     *  @return the auction search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsAuctionSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionSearchOrder getAuctionSearchOrder();


    /**
     *  Orders the results by bidder. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBidder(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a bidder search order is available. 
     *
     *  @return <code> true </code> if a bidder search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidderSearchOrder();


    /**
     *  Gets the bidder search order. 
     *
     *  @return the resource search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsBidderSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getBidderSearchOrder();


    /**
     *  Orders the results by bidding agent. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByBiddingAgent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a bidding agent search order is available. 
     *
     *  @return <code> true </code> if a bidding agent search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBiddingAgentSearchOrder();


    /**
     *  Gets the bidding agent search order. 
     *
     *  @return the agent search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsBiddingAgentSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentSearchOrder getBiddingAgentSearchOrder();


    /**
     *  Orders the results by the quantity. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByQuantity(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the current bid. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCurrentBid(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the maximum bid. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMaximumBid(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by winning bids. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByWinner(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the settlement amount. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySettlementAmount(org.osid.SearchOrderStyle style);


    /**
     *  Gets the bid order record corresponding to the given bid record <code> 
     *  Type. </code> Multiple retrievals return the same underlying object. 
     *
     *  @param  bidRecordType a bid record type 
     *  @return the bid search order record 
     *  @throws org.osid.NullArgumentException <code> bidRecordType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(bidRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.records.BidSearchOrderRecord getBidSearchOrderRecord(org.osid.type.Type bidRecordType)
        throws org.osid.OperationFailedException;
}
