//
// org.osid.bidding.BidSearchSession
//
//     The OSID Java specification for org.osid.bidding.BidSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>This session provides methods for searching among <code> Bid </code> 
 *  objects. The search query is constructed using the <code> BidQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getBidsByQuery() </code> is the basic search method and returns 
 *  a list of <code> Bids. </code> A more advanced search may be performed 
 *  with <code> getBidsBySearch(). </code> It accepts a <code> BidSearch 
 *  </code> in addition to the query for the purpose of specifying additional 
 *  options affecting the entire search, such as ordering. <code> 
 *  getBidsBySearch() </code> returns a <code> BidSearchResults </code> that 
 *  can be used to access the resulting <code> BidList </code> or be used to 
 *  perform a search within the result set through <code> BidSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated auction house view: searches include bids in auction 
 *      houses of which this auction house is an ancestor in the auction house 
 *      hierarchy </li> 
 *      <li> isolated auction house view: searches are restricted to bids in 
 *      this auction house </li> 
 *  </ul>
 *  
 *  
 *  <p> Bids may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BidQuery. </code> </p>
 */

public interface BidSearchSession
    extends org.osid.bidding.BidQuerySession {


    /**
     *  Gets a bid search. 
     *
     *  @return the bid search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidSearch getBidSearch();


    /**
     *  Gets a bid search order. The <code> BidSearchOrder </code> is supplied 
     *  to a <code> BidSearch </code> to specify the ordering of results. 
     *
     *  @return the bid search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidSearchOrder getBidSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  bidQuery the bid query 
     *  @param  bidSearch the bid search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> bidQuery </code> or 
     *          <code> bidSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> bidQuery </code> or 
     *          <code> bidSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidSearchResults getBidsBySearch(org.osid.bidding.BidQuery bidQuery, 
                                                             org.osid.bidding.BidSearch bidSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a bid query from an inspector. The inspector is available from a 
     *  <code> BidSearchResults. </code> 
     *
     *  @param  bidQueryInspector a bid query inspector 
     *  @return the bid query 
     *  @throws org.osid.NullArgumentException <code> bidQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> bidQueryInspector </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.BidQuery getBidQueryFromInspector(org.osid.bidding.BidQueryInspector bidQueryInspector);
}
