//
// org.osid.bidding.BiddingProfile
//
//     The OSID Java specification for org.osid.bidding.BiddingProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>The bidding profile describes the interoperability among bidding 
 *  services. </p>
 */

public interface BiddingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any auction house federation is exposed. Federation is 
     *  exposed when a specific auction house may be identified, selected and 
     *  used to create a lookup or admin session. Federation is not exposed 
     *  when a set of auction houses appears as a single auction house. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a my auction service is supported for the current agent. 
     *
     *  @return <code> true </code> if my auction is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyAuction();


    /**
     *  Tests if a my auction notification service is supported for the 
     *  current agent. 
     *
     *  @return <code> true </code> if my auction notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyAuctionNotification();


    /**
     *  Tests if looking up auctions is supported. 
     *
     *  @return <code> true </code> if auction lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionLookup();


    /**
     *  Tests if querying auctions is supported. 
     *
     *  @return <code> true </code> if auction query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionQuery();


    /**
     *  Tests if searching auctions is supported. 
     *
     *  @return <code> true </code> if auction search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionSearch();


    /**
     *  Tests if an auction administrative service is supported. 
     *
     *  @return <code> true </code> if auction administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionAdmin();


    /**
     *  Tests if an auction <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if auction notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionNotification();


    /**
     *  Tests if an auction auction house lookup service is supported. 
     *
     *  @return <code> true </code> if an auction auction house lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionAuctionHouse();


    /**
     *  Tests if an auction auction house assignment service is supported. 
     *
     *  @return <code> true </code> if an auction to auction house assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionAuctionHouseAssignment();


    /**
     *  Tests if an auction smart auction house service is supported. 
     *
     *  @return <code> true </code> if an v smart auction house service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionSmartAuctionHouse();


    /**
     *  Tests if looking up bids is supported. 
     *
     *  @return <code> true </code> if bid lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidLookup();


    /**
     *  Tests if querying bids is supported. 
     *
     *  @return <code> true </code> if bid query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidQuery();


    /**
     *  Tests if searching bids is supported. 
     *
     *  @return <code> true </code> if bid search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidSearch();


    /**
     *  Tests if bid administrative service is supported. 
     *
     *  @return <code> true </code> if bid administration is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidAdmin();


    /**
     *  Tests if a bid notification service is supported. 
     *
     *  @return <code> true </code> if bid notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidNotification();


    /**
     *  Tests if a bid auction house lookup service is supported. 
     *
     *  @return <code> true </code> if a bid auction house lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidAuctionHouse();


    /**
     *  Tests if a bid auction house service is supported. 
     *
     *  @return <code> true </code> if bid to auction house assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidAuctionHouseAssignment();


    /**
     *  Tests if a bid smart auction house lookup service is supported. 
     *
     *  @return <code> true </code> if a bid smart auction house service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidSmartAuctionHouse();


    /**
     *  Tests if looking up auction houses is supported. 
     *
     *  @return <code> true </code> if auction house lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseLookup();


    /**
     *  Tests if querying auction houses is supported. 
     *
     *  @return <code> true </code> if a auction house query service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseQuery();


    /**
     *  Tests if searching auction houses is supported. 
     *
     *  @return <code> true </code> if auction house search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseSearch();


    /**
     *  Tests if auction house administrative service is supported. 
     *
     *  @return <code> true </code> if auction house administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseAdmin();


    /**
     *  Tests if a auction house <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction house notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseNotification();


    /**
     *  Tests for the availability of a auction house hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if auction house hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAuctionHouseHierarchy();


    /**
     *  Tests for the availability of a auction house hierarchy design 
     *  service. 
     *
     *  @return <code> true </code> if auction house hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseHierarchyDesign();


    /**
     *  Tests for the availability of a bidding batch service. 
     *
     *  @return <code> true </code> ifa bidding batch servicen is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBiddingBatch();


    /**
     *  Tests for the availability of a bidding rules service. 
     *
     *  @return <code> true </code> ifa bidding rules servicen is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBiddingRules();


    /**
     *  Gets the supported <code> Auction </code> record types. 
     *
     *  @return a list containing the supported <code> Auction </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionRecordTypes();


    /**
     *  Tests if the given <code> Auction </code> record type is supported. 
     *
     *  @param  auctionRecordType a <code> Type </code> indicating an <code> 
     *          Auction </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auctionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionRecordType(org.osid.type.Type auctionRecordType);


    /**
     *  Gets the supported <code> Auction </code> search types. 
     *
     *  @return a list containing the supported <code> Auction </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionSearchRecordTypes();


    /**
     *  Tests if the given <code> Auction </code> search type is supported. 
     *
     *  @param  auctionSearchRecordType a <code> Type </code> indicating an 
     *          <code> Auction </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auctionSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionSearchRecordType(org.osid.type.Type auctionSearchRecordType);


    /**
     *  Gets the supported <code> Bid </code> record types. 
     *
     *  @return a list containing the supported <code> Bid </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBidRecordTypes();


    /**
     *  Tests if the given <code> Bid </code> record type is supported. 
     *
     *  @param  bidRecordType a <code> Type </code> indicating a <code> Bid 
     *          </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bidRecordType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidRecordType(org.osid.type.Type bidRecordType);


    /**
     *  Gets the supported <code> Bid </code> search record types. 
     *
     *  @return a list containing the supported <code> Bid </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBidSearchRecordTypes();


    /**
     *  Tests if the given <code> Bid </code> search record type is supported. 
     *
     *  @param  bidSearchRecordType a <code> Type </code> indicating a <code> 
     *          Bid </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bidSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBidSearchRecordType(org.osid.type.Type bidSearchRecordType);


    /**
     *  Gets the supported <code> AuctionHouse </code> record types. 
     *
     *  @return a list containing the supported <code> AuctionHouse </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionHouseRecordTypes();


    /**
     *  Tests if the given <code> AuctionHouse </code> record type is 
     *  supported. 
     *
     *  @param  auctionHouseRecordType a <code> Type </code> indicating a 
     *          <code> AuctionHouse </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auctionHouseRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseRecordType(org.osid.type.Type auctionHouseRecordType);


    /**
     *  Gets the supported <code> AuctionHouse </code> search record types. 
     *
     *  @return a list containing the supported <code> AuctionHouse </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionHouseSearchRecordTypes();


    /**
     *  Tests if the given <code> AuctionHouse </code> search record type is 
     *  supported. 
     *
     *  @param  auctionHouseSearchRecordType a <code> Type </code> indicating 
     *          a <code> AuctionHouse </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionHouseSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseSearchRecordType(org.osid.type.Type auctionHouseSearchRecordType);
}
