//
// org.osid.bidding.MyAuctionReceiver
//
//     The OSID Java specification for org.osid.bidding.MyAuctionReceiver.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding;


/**
 *  <p>The auction receiver is the consumer supplied interface for receiving 
 *  notifications for an agent's participation in an auction. </p>
 */

public interface MyAuctionReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications for an auction start. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  auctionIds the <code> Id </code> of the <code> Auctions 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void startAuctions(org.osid.id.Id notificationId, 
                              org.osid.id.IdList auctionIds);


    /**
     *  The callback for notifications for new bids in an auction. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  bidIds the <code> Id </code> of the new <code> Bids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newBids(org.osid.id.Id notificationId, 
                        org.osid.id.IdList bidIds);


    /**
     *  The callback for notifications for when this bidder has been outbid. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  bidIds the <code> Id </code> of the new <code> Bids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void outBids(org.osid.id.Id notificationId, 
                        org.osid.id.IdList bidIds);


    /**
     *  The callback for notifications for when this bidder is required to 
     *  bid. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  auctionId the <code> Id </code> of the <code> Auction </code> 
     *  @param  deadline the bidding deadline 
     *  @compliance mandatory This method must be implemented. 
     */

    public void requireBid(org.osid.id.Id notificationId, 
                           org.osid.id.Id auctionId, 
                           org.osid.calendaring.DateTime deadline);


    /**
     *  The callback for notifications for an auction end. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  auctionIds the <code> Id </code> of the <code> Auctions 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void endAuctions(org.osid.id.Id notificationId, 
                            org.osid.id.IdList auctionIds);
}
