//
// org.osid.bidding.rules.AuctionConstrainerAuctionHouseAssignmentSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerAuctionHouseAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods to re-assign <code> AuctionConstrainer 
 *  </code> to <code> AuctionHouse </code> mappings. An <code> 
 *  AuctionConstrainer </code> may appear in multiple <code> AuctionHouse 
 *  </code> objects and removing the last reference to an <code> 
 *  AuctionConstrainer </code> is the equivalent of deleting it. Each <code> 
 *  AuctionHouse </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> AuctionConstrainer </code> to another 
 *  <code> AuctionHouse </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface AuctionConstrainerAuctionHouseAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter auction constrainer/auction house 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuctionConstrainers();


    /**
     *  Tests if this user can alter auction constrainer/auction house 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuctionConstrainersToAuctionHouse(org.osid.id.Id auctionHouseId);


    /**
     *  Gets a list of auction houses including and under the given auction 
     *  house node in which any auction constrainer can be assigned. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @return list of assignable auction house <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAuctionHouseIds(org.osid.id.Id auctionHouseId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of auction houses including and under the given auction 
     *  house node in which a specific auction constrainer can be assigned. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @return list of assignable auction house <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> auctionConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAuctionHouseIdsForAuctionConstrainer(org.osid.id.Id auctionHouseId, 
                                                                                org.osid.id.Id auctionConstrainerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> AuctionConstrainer </code> to an <code> 
     *  AuctionHouse. </code> 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @throws org.osid.AlreadyExistsException <code> auctionConstrainerId 
     *          </code> already assigned to <code> auctionHouseId </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          or <code> auctionHouseId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> or <code> auctionHouseId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuctionConstrainerToAuctionHouse(org.osid.id.Id auctionConstrainerId, 
                                                       org.osid.id.Id auctionHouseId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AuctionConstrainer </code> from an <code> 
     *  AuctionHouse. </code> 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          or <code> auctionHouseId </code> not found or <code> 
     *          auctionConstrainerId </code> already assigned to <code> 
     *          auctionHouseId </code> 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> or <code> auctionHouseId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuctionConstrainerFromAuctionHouse(org.osid.id.Id auctionConstrainerId, 
                                                           org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> AuctionConstrainer </code> from one <code> 
     *  AuctionHouse </code> to another. Mappings to other <code> 
     *  AuctionHouses </code> are unaffected. 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @param  fromAuctionHouseId the <code> Id </code> of the current <code> 
     *          AuctionHouse </code> 
     *  @param  toAuctionHouseId the <code> Id </code> of the destination 
     *          <code> AuctionHouse </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId, 
     *          fromAuctionHouseId, </code> or <code> toAuctionHouseId </code> 
     *          not found or <code> auctionConstrainerId </code> not mapped to 
     *          <code> fromAuctionHouseId </code> 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId, 
     *          fromAuctionHouseId, </code> or <code> toAuctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignAuctionConstrainerToAuctionHouse(org.osid.id.Id auctionConstrainerId, 
                                                         org.osid.id.Id fromAuctionHouseId, 
                                                         org.osid.id.Id toAuctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
