//
// org.osid.bidding.rules.AuctionConstrainerEnablerAdminSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session creates and removes auction constrainer enablers. The data 
 *  for create and update is provided via the <code> 
 *  AuctionConstrainerEnablerForm. </code> </p>
 */

public interface AuctionConstrainerEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create auction constrainer enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> 
     *  AuctionConstrainerEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainerEnabler 
     *          </code> creation is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionConstrainerEnabler();


    /**
     *  Tests if this user can create a single <code> 
     *  AuctionConstrainerEnabler </code> using the desired record types. 
     *  While <code> 
     *  BiddingRulesManager.getAuctionConstrainerEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  AuctionConstrainerEnabler. </code> Providing an empty array tests if 
     *  an <code> AuctionConstrainerEnabler </code> can be created with no 
     *  records. 
     *
     *  @param  auctionConstrainerEnablerRecordTypes array of auction 
     *          constrainer enabler record types 
     *  @return <code> true </code> if <code> AuctionConstrainerEnabler 
     *          </code> creation using the specified record <code> Types 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionConstrainerEnablerWithRecordTypes(org.osid.type.Type[] auctionConstrainerEnablerRecordTypes);


    /**
     *  Gets the auction constrainer enabler form for creating new auction 
     *  constrainer enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  auctionConstrainerEnablerRecordTypes array of auction 
     *          constrainer enabler record types 
     *  @return the auction constrainer enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerForm getAuctionConstrainerEnablerFormForCreate(org.osid.type.Type[] auctionConstrainerEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AuctionConstrainerEnabler. </code> 
     *
     *  @param  auctionConstrainerEnablerForm the form for this <code> 
     *          AuctionConstrainerEnabler </code> 
     *  @return the new <code> AuctionConstrainerEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          auctionConstrainerEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionConstrainerEnablerForm did not originate from 
     *          getAuctionConstrainerEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnabler createAuctionConstrainerEnabler(org.osid.bidding.rules.AuctionConstrainerEnablerForm auctionConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update auction constrainer enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> 
     *  AuctionConstrainerEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainerEnabler 
     *          </code> modification is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAuctionConstrainerEnablers();


    /**
     *  Gets the auction constrainer enabler form for updating an existing 
     *  auction constrainer enabler. A new auction constrainer enabler form 
     *  should be requested for each update transaction. 
     *
     *  @param  auctionConstrainerEnablerId the <code> Id </code> of the 
     *          <code> AuctionConstrainerEnabler </code> 
     *  @return the auction constrainer enabler form 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerForm getAuctionConstrainerEnablerFormForUpdate(org.osid.id.Id auctionConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing auction constrainer enabler. 
     *
     *  @param  auctionConstrainerEnablerForm the form containing the elements 
     *          to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          auctionConstrainerEnablerForm </code> already used in an 
     *          update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionConstrainerEnablerForm </code> did not originate from 
     *          <code> getAuctionConstrainerEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAuctionConstrainerEnabler(org.osid.bidding.rules.AuctionConstrainerEnablerForm auctionConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete auction constrainer enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> 
     *  AuctionConstrainerEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainerEnabler 
     *          </code> deletion is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAuctionConstrainerEnablers();


    /**
     *  Deletes an <code> AuctionConstrainerEnabler. </code> 
     *
     *  @param  auctionConstrainerEnablerId the <code> Id </code> of the 
     *          <code> AuctionConstrainerEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAuctionConstrainerEnabler(org.osid.id.Id auctionConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for auction 
     *  constrainer enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainerEnabler 
     *          </code> aliasing is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuctionConstrainerEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AuctionConstrainerEnabler 
     *  </code> for the purpose of creating compatibility. The primary <code> 
     *  Id </code> of the <code> AuctionConstrainerEnabler </code> is 
     *  determined by the provider. The new <code> Id </code> performs as an 
     *  alias to the primary <code> Id </code> . If the alias is a pointer to 
     *  another auction constrainer enabler. it is reassigned to the given 
     *  auction constrainer enabler <code> Id. </code> 
     *
     *  @param  auctionConstrainerEnablerId the <code> Id </code> of an <code> 
     *          AuctionConstrainerEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerId </code> or <code> aliasId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAuctionConstrainerEnabler(org.osid.id.Id auctionConstrainerEnablerId, 
                                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
