//
// org.osid.bidding.rules.AuctionConstrainerEnablerQuery
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This is the query for searching auction constrainer enablers. Each 
 *  method match specifies an <code> AND </code> term while multiple 
 *  invocations of the same method produce a nested <code> OR. </code> </p>
 */

public interface AuctionConstrainerEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the auction constrainer. 
     *
     *  @param  auctionConstrainerId the auction constrainer <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledAuctionConstrainerId(org.osid.id.Id auctionConstrainerId, 
                                               boolean match);


    /**
     *  Clears the auction constrainer <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledAuctionConstrainerIdTerms();


    /**
     *  Tests if an <code> AuctionConstrainerQuery </code> is available. 
     *
     *  @return <code> true </code> if an auction constrainer query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledAuctionConstrainerQuery();


    /**
     *  Gets the query for an auction constrainer. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the auction constrainer query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledAuctionConstrainerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledAuctionConstrainerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerQuery getRuledAuctionConstrainerQuery();


    /**
     *  Matches enablers mapped to any auction constrainer. 
     *
     *  @param  match <code> true </code> for enablers mapped to any auction 
     *          constrainer, <code> false </code> to match enablers mapped to 
     *          no auction constrainers 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledAuctionConstrainer(boolean match);


    /**
     *  Clears the auction constrainer query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledAuctionConstrainerTerms();


    /**
     *  Matches enablers mapped to the auction house. 
     *
     *  @param  auctionHouseId the auction house <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAuctionHouseId(org.osid.id.Id auctionHouseId, 
                                    boolean match);


    /**
     *  Clears the auction house <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuctionHouseIdTerms();


    /**
     *  Tests if a <code> AuctionHouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a auction house query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionHouseQuery();


    /**
     *  Gets the query for a auction house. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the auction house query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionHouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionHouseQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.AuctionHouseQuery getAuctionHouseQuery();


    /**
     *  Clears the auction house query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuctionHouseTerms();


    /**
     *  Gets the auction constrainer enabler query record corresponding to the 
     *  given <code> AuctionConstrainerEnabler </code> record <code> Type. 
     *  </code> Multiple record retrievals produce a nested <code> OR </code> 
     *  term. 
     *
     *  @param  auctionConstrainerEnablerRecordType an auction constrainer 
     *          enabler record type 
     *  @return the auction constrainer enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(auctionConstrainerEnablerRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.records.AuctionConstrainerEnablerQueryRecord getAuctionConstrainerEnablerQueryRecord(org.osid.type.Type auctionConstrainerEnablerRecordType)
        throws org.osid.OperationFailedException;
}
