//
// org.osid.bidding.rules.AuctionConstrainerEnablerQuerySession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerEnablerQuerySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AuctionConstrainerEnabler </code> objects. The search query is constructed 
 *  using the <code> AuctionConstrainerEnablerQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated auction house view: searches include auction 
 *      constrainer enablers in auction houses of which this auction house is 
 *      an ancestor in the auction house hierarchy </li> 
 *      <li> isolated auction house view: searches are restricted to auction 
 *      constrainer enablers in this auction house </li> 
 *  </ul>
 *  
 *  
 *  <p> Auction constrainer enablers may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  AuctionConstrainerEnablerQuery. </code> </p>
 */

public interface AuctionConstrainerEnablerQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AuctionConstrainerEnabler 
     *  </code> lookups. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may not 
     *  offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchAuctionConstrainerEnablers();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include auction constrainer enablers in auction houses which are 
     *  children of this broker in the auction house hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAuctionHouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this auction house only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAuctionHouseView();


    /**
     *  Gets an auction constrainer enabler query. 
     *
     *  @return the auction constrainer enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerQuery getAuctionConstrainerEnablerQuery();


    /**
     *  Gets a list of <code> AuctionConstrainerEnablers </code> matching the 
     *  given search. 
     *
     *  @param  auctionConstrainerEnablerQuery the auction constraienr enabler 
     *          query 
     *  @return the returned <code> AuctionConstrainerEnablerList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionConstrainerEnablerQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerList getAuctionConstrainerEnablersByQuery(org.osid.bidding.rules.AuctionConstrainerEnablerQuery auctionConstrainerEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
