//
// org.osid.bidding.rules.AuctionConstrainerRuleApplicationSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionConstrainerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods to apply <code> AuctionConstrainers 
 *  </code> to <code> Auctions. </code> An <code> Auction </code> with 
 *  multiple <code> AuctionConstrainers </code> means any positive rule 
 *  evaluation across the result in an effective <code> Auction. </code> </p>
 */

public interface AuctionConstrainerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter auction constrainer/auction mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuctionConstrainers();


    /**
     *  Adds an existing <code> AuctionConstrainer </code> to an <code> 
     *  Auction. </code> 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @param  auctionId the <code> Id </code> of the <code> Auction </code> 
     *  @throws org.osid.AlreadyExistsException <code> auctionConstrainerId 
     *          </code> already applied to <code> auctionId </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          or <code> auctionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> or <code> auctionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuctionConstrainerToAuction(org.osid.id.Id auctionConstrainerId, 
                                                  org.osid.id.Id auctionId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AuctionConstrainer </code> from an <code> Auction. 
     *  </code> 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of the <code> 
     *          AuctionConstrainer </code> 
     *  @param  auctionId the <code> Id </code> of the <code> Auction </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId </code> 
     *          or <code> auctionId </code> not found or <code> 
     *          auctionConstrainerId </code> already applied to <code> 
     *          auctionId </code> 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId 
     *          </code> or <code> auctionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuctionConstrainerFromAuction(org.osid.id.Id auctionConstrainerId, 
                                                      org.osid.id.Id auctionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> AuctionConstrainers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionConstrainer </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceAuctionConstrainers();


    /**
     *  Reorders auction constrainers for an auction by moving the specified 
     *  auction constrainer in front of a reference auction constrainer. 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of an <code> 
     *          AuctionConstrainer </code> 
     *  @param  auctionId the <code> Id </code> of an <code> Auction </code> 
     *  @param  referenceId the reference auction constrainer <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId, 
     *          auctionId, </code> or <code> referenceId </code> not found or, 
     *          <code> auctionConstrainerId </code> or <code> referenceId 
     *          </code> not related to <code> auctionId </code> 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId, 
     *          auctionId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuctionConstrainerAhead(org.osid.id.Id auctionConstrainerId, 
                                            org.osid.id.Id auctionId, 
                                            org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders auction constrainers for an auction by moving the specified 
     *  auction constrainer behind a reference auction constrainer. 
     *
     *  @param  auctionConstrainerId the <code> Id </code> of an <code> 
     *          AuctionConstrainer </code> 
     *  @param  auctionId the <code> Id </code> of an <code> Auction </code> 
     *  @param  referenceId the reference auction constrainer <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> auctionConstrainerId, 
     *          auctionId, </code> or <code> referenceId </code> not found or, 
     *          <code> auctionConstrainerId </code> or <code> referenceId 
     *          </code> not related to <code> auctionId </code> 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerId, 
     *          auctionId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuctionConstrainerBehind(org.osid.id.Id auctionConstrainerId, 
                                             org.osid.id.Id auctionId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of auction constrainers for an auction. 
     *
     *  @param  auctionConstrainerIds the <code> Ids </code> for a set of 
     *          <code> AuctionConstrainers </code> 
     *  @param  auctionId the <code> Id </code> of an <code> Auction </code> 
     *  @throws org.osid.NotFoundException <code> auctionId </code> not found 
     *          or, an <code> auctionConstrainerId </code> not related to 
     *          <code> auctionId </code> 
     *  @throws org.osid.NullArgumentException <code> auctionConstrainerIds 
     *          </code> or <code> auctionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAuctionConstrainers(org.osid.id.Id[] auctionConstrainerIds, 
                                         org.osid.id.Id auctionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
