//
// org.osid.bidding.rules.AuctionProcessorAuctionHouseSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionProcessorAuctionHouseSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods to retrieve <code> AuctionProcessor 
 *  </code> to <code> AuctionHouse </code> mappings. An <code> 
 *  AuctionProcessor </code> may appear in multiple <code> AuctionHouse 
 *  </code> objects. Each auction house may have its own authorizations 
 *  governing who is allowed to look at it. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface AuctionProcessorAuctionHouseSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of auction processor/auction 
     *  house mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAuctionProcessorAuctionHouseMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuctionProcessorAuctionHouseView();


    /**
     *  A complete view of the <code> AuctionProcessor </code> and <code> 
     *  AuctionHouse </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuctionProcessorAuctionHouseView();


    /**
     *  Gets the list of <code> AuctionProcessorIds </code> associated with an 
     *  <code> AuctionHouse. </code> 
     *
     *  @param  auctionHouseId <code> Id </code> of the <code> AuctionHouse 
     *          </code> 
     *  @return list of related auction processor <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> auctionHouseId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAuctionProcessorIdsByAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of auction processors associated with an <code> 
     *  AuctionHouse. </code> 
     *
     *  @param  auctionHouseId <code> Id </code> of the <code> AuctionHouse 
     *          </code> 
     *  @return list of related auction processors 
     *  @throws org.osid.NotFoundException <code> auctionHouseId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorList getAuctionProcessorsByAuctionHouse(org.osid.id.Id auctionHouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> AuctionProcessor Ids </code> corresponding to 
     *  a list of <code> AuctionHouses. </code> 
     *
     *  @param  auctionHouseIds list of auction house <code> Ids </code> 
     *  @return list of auction processor <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAuctionProcessorIdsByAuctionHouses(org.osid.id.IdList auctionHouseIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of auction processor corresponding to a list of <code> 
     *  AuctionHouses. </code> 
     *
     *  @param  auctionHouseIds list of auction house <code> Ids </code> 
     *  @return list of auction processors 
     *  @throws org.osid.NullArgumentException <code> auctionHouseIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorList getAuctionProcessorsByAuctionHouses(org.osid.id.IdList auctionHouseIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AuctionHouse </code> <code> Ids </code> mapped to an 
     *  <code> AuctionProcessor. </code> 
     *
     *  @param  auctionProcessorId <code> Id </code> of an <code> 
     *          AuctionProcessor </code> 
     *  @return list of auction houses 
     *  @throws org.osid.NotFoundException <code> auctionProcessorId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAuctionHouseIdsByAuctionProcessor(org.osid.id.Id auctionProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AuctionHouses </code> mapped to an <code> 
     *  AuctionProcessor. </code> 
     *
     *  @param  auctionProcessorId <code> Id </code> of an <code> 
     *          AuctionProcessor </code> 
     *  @return list of auction houses 
     *  @throws org.osid.NotFoundException <code> auctionProcessorId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> auctionProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouseList getAuctionHousesByAuctionProcessor(org.osid.id.Id auctionProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
