//
// org.osid.bidding.rules.AuctionProcessorEnablerAdminSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionProcessorEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session creates and removes auction processor enablers. The data 
 *  for create and update is provided via the <code> 
 *  AuctionProcessorEnablerForm. </code> </p>
 */

public interface AuctionProcessorEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create auction processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> AuctionProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessorEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionProcessorEnabler();


    /**
     *  Tests if this user can create a single <code> AuctionProcessorEnabler 
     *  </code> using the desired record types. While <code> 
     *  BiddingRulesManager.getAuctionProcessorEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  AuctionProcessorEnabler. </code> Providing an empty array tests if an 
     *  <code> AuctionProcessorEnabler </code> can be created with no records. 
     *
     *  @param  auctionProcessorEnablerRecordTypes array of auction processor 
     *          enabler record types 
     *  @return <code> true </code> if <code> AuctionProcessorEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAuctionProcessorEnablerWithRecordTypes(org.osid.type.Type[] auctionProcessorEnablerRecordTypes);


    /**
     *  Gets the auction processor enabler form for creating new auction 
     *  processor enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  auctionProcessorEnablerRecordTypes array of auction processor 
     *          enabler record types 
     *  @return the auction processor enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerForm getAuctionProcessorEnablerFormForCreate(org.osid.type.Type[] auctionProcessorEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AuctionProcessorEnabler. </code> 
     *
     *  @param  auctionProcessorEnablerForm the form for this <code> 
     *          AuctionProcessorEnabler </code> 
     *  @return the new <code> AuctionProcessorEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          auctionProcessorEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionProcessorEnablerForm did not originate from 
     *          getAuctionProcessorEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnabler createAuctionProcessorEnabler(org.osid.bidding.rules.AuctionProcessorEnablerForm auctionProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update auction processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> AuctionProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessorEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAuctionProcessorEnablers();


    /**
     *  Gets the auction processor enabler form for updating an existing 
     *  auction processor enabler. A new auction processor enabler form should 
     *  be requested for each update transaction. 
     *
     *  @param  auctionProcessorEnablerId the <code> Id </code> of the <code> 
     *          AuctionProcessorEnabler </code> 
     *  @return the auction processor enabler form 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerForm getAuctionProcessorEnablerFormForUpdate(org.osid.id.Id auctionProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing auction processor enabler. 
     *
     *  @param  auctionProcessorEnablerForm the form containing the elements 
     *          to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          auctionProcessorEnablerForm </code> already used in an update 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          auctionProcessorEnablerForm did not originate from 
     *          getAuctionProcessorEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAuctionProcessorEnabler(org.osid.bidding.rules.AuctionProcessorEnablerForm auctionProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete auction processor enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> AuctionProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessorEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAuctionProcessorEnablers();


    /**
     *  Deletes an <code> AuctionProcessorEnabler. </code> 
     *
     *  @param  auctionProcessorEnablerId the <code> Id </code> of the <code> 
     *          AuctionProcessorEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAuctionProcessorEnabler(org.osid.id.Id auctionProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for auction 
     *  processor enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuctionProcessorEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAuctionProcessorEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AuctionProcessorEnabler </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> AuctionProcessorEnabler </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  auction processor enabler. it is reassigned to the given auction 
     *  processor enabler <code> Id. </code> 
     *
     *  @param  auctionProcessorEnablerId the <code> Id </code> of an <code> 
     *          AuctionProcessorEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId </code> or <code> aliasId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAuctionProcessorEnabler(org.osid.id.Id auctionProcessorEnablerId, 
                                             org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
