//
// org.osid.bidding.rules.AuctionProcessorEnablerLookupSession
//
//     The OSID Java specification for org.osid.bidding.rules.AuctionProcessorEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  AuctionProcessorEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated auction house view: All auction processor enabler 
 *      methods in this session operate, retrieve and pertain to auction 
 *      processor enablers defined explicitly in the current auction house. 
 *      Using an isolated view is useful for managing <code> 
 *      AuctionProcessorEnablers </code> with the <code> 
 *      AuctionProcessorEnablerAdminSession. </code> </li> 
 *      <li> federated auction house view: All auction processor enabler 
 *      methods in this session operate, retrieve and pertain to all auction 
 *      processor enablers defined in this auction house and any other auction 
 *      processor enablers implicitly available in this auction house through 
 *      auction house inheritence. </li> 
 *      <li> active auction processor enabler view: All auction processor 
 *      enabler lookup methods return active auction processor enablers. </li> 
 *      <li> any status auction processor enabler view: Auction processor 
 *      enablers of any active or inactive status are returned from methods. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface AuctionProcessorEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AuctionHouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AuctionHouse Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAuctionHouseId();


    /**
     *  Gets the <code> AuctionHouse </code> associated with this session. 
     *
     *  @return the auction house 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.AuctionHouse getAuctionHouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AuctionProcessorEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAuctionProcessorEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuctionProcessorEnablerView();


    /**
     *  A complete view of the <code> AuctionProcessorEnabler </code> returns 
     *  is desired. Methods will return what is requested or result in an 
     *  error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuctionProcessorEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include auction processor enablers in auction houses which are 
     *  children of this auction house in the auction house hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAuctionHouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this auction house only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAuctionHouseView();


    /**
     *  Only active auction processor enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveAuctionProcessorEnablerView();


    /**
     *  All active and inactive auction processor enablers are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusAuctionProcessorEnablerView();


    /**
     *  Gets the <code> AuctionProcessorEnabler </code> specified by its 
     *  <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  AuctionProcessorEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to an <code> AuctionProcessorEnabler </code> and retained 
     *  for compatibility. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @param  auctionProcessorEnablerId <code> Id </code> of the <code> 
     *          AuctionProcessorEnabler </code> 
     *  @return the auction processor enabler 
     *  @throws org.osid.NotFoundException <code> auctionProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnabler getAuctionProcessorEnabler(org.osid.id.Id auctionProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionProcessorEnablerList </code> corresponding to 
     *  the given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  auction processor enablers specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> AuctionProcessorEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @param  auctionProcessorEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> AuctionProcessorEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerList getAuctionProcessorEnablersByIds(org.osid.id.IdList auctionProcessorEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionProcessorEnablerList </code> corresponding to 
     *  the given auction processor enabler genus <code> Type </code> which 
     *  does not include auction processor enablers of genus types derived 
     *  from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auction processor enablers or an error results. Otherwise, the 
     *  returned list may contain only those auction processor enablers that 
     *  are accessible through this session. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @param  auctionProcessorEnablerGenusType an auction processor enabler 
     *          genus type 
     *  @return the returned <code> AuctionProcessorEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerList getAuctionProcessorEnablersByGenusType(org.osid.type.Type auctionProcessorEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionProcessorEnablerList </code> corresponding to 
     *  the given auction processor enabler genus <code> Type </code> and 
     *  include any additional auction processor enablers with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auction processor enablers or an error results. Otherwise, the 
     *  returned list may contain only those auction processor enablers that 
     *  are accessible through this session. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @param  auctionProcessorEnablerGenusType an auction processor enabler 
     *          genus type 
     *  @return the returned <code> AuctionProcessorEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerList getAuctionProcessorEnablersByParentGenusType(org.osid.type.Type auctionProcessorEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionProcessorEnablerList </code> containing the 
     *  given auction processor enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auction processor enablers or an error results. Otherwise, the 
     *  returned list may contain only those auction processor enablers that 
     *  are accessible through this session. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @param  auctionProcessorEnablerRecordType an auction processor enabler 
     *          record type 
     *  @return the returned <code> AuctionProcessorEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerList getAuctionProcessorEnablersByRecordType(org.osid.type.Type auctionProcessorEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionProcessorEnablerList </code> effective within 
     *  the given date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auction processor enablers or an error results. Otherwise, the 
     *  returned list may contain only those auction processor enablers that 
     *  are accessible through this session. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> AuctionProcessorEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerList getAuctionProcessorEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuctionProcessorEnablerList </code> effective during 
     *  the entire given date range but not confined to the date range and 
     *  evaluated against the given agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  auction processor enablers or an error results. Otherwise, the 
     *  returned list may contain only those auction processor enablers that 
     *  are accessible through this session. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @param  agentId an agent Id 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> AuctionProcessorEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerList getAuctionProcessorEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                         org.osid.calendaring.DateTime from, 
                                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> AuctionProcessorEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known auction 
     *  processor enablers or an error results. Otherwise, the returned list 
     *  may contain only those auction processor enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, auction processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive auction 
     *  processor enablers are returned. 
     *
     *  @return the returned <code> AuctionProcessorEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerList getAuctionProcessorEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
