//
// org.osid.bidding.rules.BiddingRulesProfile
//
//     The OSID Java specification for org.osid.bidding.rules.BiddingRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>The bidding rules profile describes the interoperability among bidding 
 *  rules services. </p>
 */

public interface BiddingRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up auction constrainer is supported. 
     *
     *  @return <code> true </code> if auction constrainer lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerLookup();


    /**
     *  Tests if querying auction constrainer is supported. 
     *
     *  @return <code> true </code> if auction constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerQuery();


    /**
     *  Tests if searching auction constrainer is supported. 
     *
     *  @return <code> true </code> if auction constrainer search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerSearch();


    /**
     *  Tests if an auction constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if auction constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerAdmin();


    /**
     *  Tests if an auction constrainer notification service is supported. 
     *
     *  @return <code> true </code> if auction constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerNotification();


    /**
     *  Tests if an auction constrainer auction house lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an auction constrainer auction house 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerAuctionHouse();


    /**
     *  Tests if an auction constrainer auction house service is supported. 
     *
     *  @return <code> true </code> if auction constrainer auction house 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerAuctionHouseAssignment();


    /**
     *  Tests if an auction constrainer auction house lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an auction constrainer auction house 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerSmartAuctionHouse();


    /**
     *  Tests if an auction constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if an auction constrainer rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerRuleLookup();


    /**
     *  Tests if an auction constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if an auction constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerRuleApplication();


    /**
     *  Tests if looking up auction constrainer enablers is supported. 
     *
     *  @return <code> true </code> if auction constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerLookup();


    /**
     *  Tests if querying auction constrainer enablers is supported. 
     *
     *  @return <code> true </code> if auction constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerQuery();


    /**
     *  Tests if searching auction constrainer enablers is supported. 
     *
     *  @return <code> true </code> if auction constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerSearch();


    /**
     *  Tests if an auction constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction constrainer enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerAdmin();


    /**
     *  Tests if an auction constrainer enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction constrainer enabler 
     *          notification is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerNotification();


    /**
     *  Tests if an auction constrainer enabler auction house lookup service 
     *  is supported. 
     *
     *  @return <code> true </code> if an auction constrainer enabler auction 
     *          house lookup service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerAuctionHouse();


    /**
     *  Tests if an auction constrainer enabler auction house service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction constrainer enabler auction 
     *          house assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerAuctionHouseAssignment();


    /**
     *  Tests if an auction constrainer enabler auction house lookup service 
     *  is supported. 
     *
     *  @return <code> true </code> if an auction constrainer enabler auction 
     *          house service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerSmartAuctionHouse();


    /**
     *  Tests if an auction constrainer enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an auction constrainer enabler rule 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerRuleLookup();


    /**
     *  Tests if an auction constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up auction processor is supported. 
     *
     *  @return <code> true </code> if auction processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorLookup();


    /**
     *  Tests if querying auction processor is supported. 
     *
     *  @return <code> true </code> if auction processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorQuery();


    /**
     *  Tests if searching auction processor is supported. 
     *
     *  @return <code> true </code> if auction processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorSearch();


    /**
     *  Tests if an auction processor administrative service is supported. 
     *
     *  @return <code> true </code> if auction processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorAdmin();


    /**
     *  Tests if an auction processor notification service is supported. 
     *
     *  @return <code> true </code> if auction processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorNotification();


    /**
     *  Tests if an auction processor auction house lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an auction processor auction house 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorAuctionHouse();


    /**
     *  Tests if an auction processor auction house service is supported. 
     *
     *  @return <code> true </code> if auction processor auction house 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorAuctionHouseAssignment();


    /**
     *  Tests if an auction processor auction house lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an auction processor auction house 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorSmartAuctionHouse();


    /**
     *  Tests if an auction processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if an auction processor rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorRuleLookup();


    /**
     *  Tests if an auction processor rule application service is supported. 
     *
     *  @return <code> true </code> if auction processor rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorRuleApplication();


    /**
     *  Tests if looking up auction processor enablers is supported. 
     *
     *  @return <code> true </code> if auction processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerLookup();


    /**
     *  Tests if querying auction processor enablers is supported. 
     *
     *  @return <code> true </code> if auction processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerQuery();


    /**
     *  Tests if searching auction processor enablers is supported. 
     *
     *  @return <code> true </code> if auction processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerSearch();


    /**
     *  Tests if an auction processor enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction processor enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerAdmin();


    /**
     *  Tests if an auction processor enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction processor enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerNotification();


    /**
     *  Tests if an auction processor enabler auction house lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an auction processor enabler auction 
     *          house lookup service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerAuctionHouse();


    /**
     *  Tests if an auction processor enabler auction house service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction processor enabler auction house 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerAuctionHouseAssignment();


    /**
     *  Tests if an auction processor enabler auction house lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an auction processor enabler auction 
     *          house service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerSmartAuctionHouse();


    /**
     *  Tests if an auction processor enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerRuleLookup();


    /**
     *  Tests if an auction processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if auction processor enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerRuleApplication();


    /**
     *  Gets the supported <code> AuctionConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> AuctionConstrainer 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionConstrainerRecordTypes();


    /**
     *  Tests if the given <code> AuctionConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  auctionConstrainerRecordType a <code> Type </code> indicating 
     *          an <code> AuctionConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerRecordType(org.osid.type.Type auctionConstrainerRecordType);


    /**
     *  Gets the supported <code> AuctionConstrainer </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> AuctionConstrainer 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> AuctionConstrainer </code> search record 
     *  type is supported. 
     *
     *  @param  auctionConstrainerSearchRecordType a <code> Type </code> 
     *          indicating an <code> AuctionConstrainer </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerSearchRecordType(org.osid.type.Type auctionConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> AuctionConstrainerEnabler </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> 
     *          AuctionConstrainerEnabler </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> AuctionConstrainerEnabler </code> record 
     *  type is supported. 
     *
     *  @param  auctionConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating an <code> AuctionConstrainerEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerRecordType(org.osid.type.Type auctionConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> AuctionConstrainerEnabler </code> search 
     *  record types. 
     *
     *  @return a list containing the supported <code> 
     *          AuctionConstrainerEnabler </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> AuctionConstrainerEnabler </code> search 
     *  record type is supported. 
     *
     *  @param  auctionConstrainerEnablerSearchRecordType a <code> Type 
     *          </code> indicating an <code> AuctionConstrainerEnabler </code> 
     *          search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerSearchRecordType </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionConstrainerEnablerSearchRecordType(org.osid.type.Type auctionConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> AuctionProcessor </code> record types. 
     *
     *  @return a list containing the supported <code> AuctionProcessor 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionProcessorRecordTypes();


    /**
     *  Tests if the given <code> AuctionProcessor </code> record type is 
     *  supported. 
     *
     *  @param  auctionProcessorRecordType a <code> Type </code> indicating an 
     *          <code> AuctionProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorRecordType(org.osid.type.Type auctionProcessorRecordType);


    /**
     *  Gets the supported <code> AuctionProcessor </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> AuctionProcessor 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> AuctionProcessor </code> search record type 
     *  is supported. 
     *
     *  @param  auctionProcessorSearchRecordType a <code> Type </code> 
     *          indicating an <code> AuctionProcessor </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorSearchRecordType(org.osid.type.Type auctionProcessorSearchRecordType);


    /**
     *  Gets the supported <code> AuctionProcessorEnabler </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> AuctionProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> AuctionProcessorEnabler </code> record type 
     *  is supported. 
     *
     *  @param  auctionProcessorEnablerRecordType a <code> Type </code> 
     *          indicating an <code> AuctionProcessorEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerRecordType(org.osid.type.Type auctionProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> AuctionProcessorEnabler </code> search 
     *  record types. 
     *
     *  @return a list containing the supported <code> AuctionProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuctionProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> AuctionProcessorEnabler </code> search 
     *  record type is supported. 
     *
     *  @param  auctionProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating an <code> AuctionProcessorEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuctionProcessorEnablerSearchRecordType(org.osid.type.Type auctionProcessorEnablerSearchRecordType);
}
