//
// org.osid.bidding.rules.BiddingRulesProxyManager
//
//     The OSID Java specification for org.osid.bidding.rules.BiddingRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.bidding.rules;


/**
 *  <p>The bidding rules proxy manager provides access to bidding rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AuctionConstrainerLookupSession: </code> a session to 
 *      retrieve auction constrainer </li> 
 *      <li> <code> AuctionConstrainerQuerySession: </code> a session to query 
 *      for auction constrainer </li> 
 *      <li> <code> AuctionConstrainerSearchSession: </code> a session to 
 *      search for auction constrainer </li> 
 *      <li> <code> AuctionConstrainerAdminSession: </code> a session to 
 *      create and delete auction constrainer </li> 
 *      <li> <code> AuctionConstrainerNotificationSession: </code> a session 
 *      to receive notifications pertaining to auction constrainer changes 
 *      </li> 
 *      <li> <code> AuctionConstrainerAuctionHouseSession: </code> a session 
 *      to look up auction constrainer auction house mappings </li> 
 *      <li> <code> AuctionConstrainerAuctionHouseAssignmentSession: </code> a 
 *      session to manage auction constrainer to auction house mappings </li> 
 *      <li> <code> AuctionConstrainerSmartAuctionHouseSession: </code> a 
 *      session to manage dynamic auction houses of auction constrainer </li> 
 *      <li> <code> AuctionConstrainerRuleLookupSession: </code> a session to 
 *      look up auction constrainer to auction mappings </li> 
 *      <li> <code> AuctionConstrainerRuleApplicationSession: </code> a 
 *      session to apply auction constrainer to auctions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AuctionConstrainerEnablerLookupSession: </code> a session 
 *      to retrieve auction constrainer enablers </li> 
 *      <li> <code> AuctionConstrainerEnablerQuerySession: </code> a session 
 *      to query for auction constrainer enablers </li> 
 *      <li> <code> AuctionConstrainerEnablerSearchSession: </code> a session 
 *      to search for auction constrainer enablers </li> 
 *      <li> <code> AuctionConstrainerEnablerAdminSession: </code> a session 
 *      to create and delete auction constrainer enablers </li> 
 *      <li> <code> AuctionConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to auction constrainer 
 *      enabler changes </li> 
 *      <li> <code> AuctionConstrainerEnablerAuctionHouseSession: </code> a 
 *      session to look up auction constrainer enabler auction house mappings 
 *      </li> 
 *      <li> <code> AuctionConstrainerEnablerAuctionHouseAssignmentSession: 
 *      </code> a session to manage auction constrainer enabler to auction 
 *      house mappings </li> 
 *      <li> <code> AuctionConstrainerEnablerSmartAuctionHouseSession: </code> 
 *      a session to manage dynamic auction houses of auction constrainer 
 *      enablers </li> 
 *      <li> <code> AuctionConstrainerEnableRuleLookupSession: </code> a 
 *      session to look up auction constrainer enabler mappings </li> 
 *      <li> <code> AuctionConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply auction constrainer enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AuctionProcessorLookupSession: </code> a session to 
 *      retrieve auction processor </li> 
 *      <li> <code> AuctionProcessorQuerySession: </code> a session to query 
 *      for auction processor </li> 
 *      <li> <code> AuctionProcessorSearchSession: </code> a session to search 
 *      for auction processor </li> 
 *      <li> <code> AuctionProcessorAdminSession: </code> a session to create 
 *      and delete auction processor </li> 
 *      <li> <code> AuctionProcessorNotificationSession: </code> a session to 
 *      receive notifications pertaining to auction processor changes </li> 
 *      <li> <code> AuctionProcessorAuctionHouseSession: </code> a session to 
 *      look up auction processor auction house mappings </li> 
 *      <li> <code> AuctionProcessorAuctionHouseAssignmentSession: </code> a 
 *      session to manage auction processor to auction house mappings </li> 
 *      <li> <code> AuctionProcessorSmartAuctionHouseSession: </code> a 
 *      session to manage dynamic auction houses of auction processor </li> 
 *      <li> <code> AuctionProcessorRuleLookupSession: </code> a session to 
 *      look up auction processor to auction mappings </li> 
 *      <li> <code> AuctionProcessorRuleApplicationSession: </code> a session 
 *      to apply auction processor to auctions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AuctionProcessorEnablerLookupSession: </code> a session to 
 *      retrieve auction processor enablers </li> 
 *      <li> <code> AuctionProcessorEnablerQuerySession: </code> a session to 
 *      query for auction processor enablers </li> 
 *      <li> <code> AuctionProcessorEnablerSearchSession: </code> a session to 
 *      search for auction processor enablers </li> 
 *      <li> <code> AuctionProcessorEnablerAdminSession: </code> a session to 
 *      create and delete auction processor enablers </li> 
 *      <li> <code> AuctionProcessorEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to auction processor 
 *      enabler changes </li> 
 *      <li> <code> AuctionProcessorEnablerAuctionHouseSession: </code> a 
 *      session to look up auction processor enabler auction house mappings 
 *      </li> 
 *      <li> <code> AuctionProcessorEnablerAuctionHouseAssignmentSession: 
 *      </code> a session to manage auction processor enabler to auction house 
 *      mappings </li> 
 *      <li> <code> AuctionProcessorEnablerSmartAuctionHouseSession: </code> a 
 *      session to manage dynamic auction houses of auction processor enablers 
 *      </li> 
 *      <li> <code> AuctionProcessorEnablerRuleLookupSession: </code> a 
 *      session to look up auction processor enabler mappings </li> 
 *      <li> <code> AuctionProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply auction processor enablers </li> 
 *  </ul>
 *  
 */

public interface BiddingRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.bidding.rules.BiddingRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerLookupSession getAuctionConstrainerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer lookup service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerLookupSession getAuctionConstrainerLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerQuerySession getAuctionConstrainerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer query service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerQuerySession getAuctionConstrainerQuerySessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerSearchSession getAuctionConstrainerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer earch service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerSearchSession getAuctionConstrainerSearchSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerAdminSession getAuctionConstrainerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer administration service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerAdminSession getAuctionConstrainerAdminSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer notification service. 
     *
     *  @param  auctionConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerNotificationSession getAuctionConstrainerNotificationSession(org.osid.bidding.rules.AuctionConstrainerReceiver auctionConstrainerReceiver, 
                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer notification service for the given auction house. 
     *
     *  @param  auctionConstrainerReceiver the notification callback 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerReceiver, auctionHouseId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerNotificationSession getAuctionConstrainerNotificationSessionForAuctionHouse(org.osid.bidding.rules.AuctionConstrainerReceiver auctionConstrainerReceiver, 
                                                                                                                                org.osid.id.Id auctionHouseId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup auction 
     *  constrainer/auction house mappings for auction constrainers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerAuctionHouseSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerAuctionHouse() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerAuctionHouse() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerAuctionHouseSession getAuctionConstrainerAuctionHouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning auction 
     *  constrainer to auction houses. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerAuctionHouseAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerAuctionHouseAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerAuctionHouseAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerAuctionHouseAssignmentSession getAuctionConstrainerAuctionHouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage auction constrainer 
     *  smart auction houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerSmartAuctionHouseSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerSmartAuctionHouse() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerSmartAuctionHouse() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerSmartAuctionHouseSession getAuctionConstrainerSmartAuctionHouseSession(org.osid.id.Id auctionHouseId, 
                                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  the auction house. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerRuleLookupSession getAuctionConstrainerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer mapping lookup service for the given auction house for 
     *  looking up rules applied to an auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerRuleLookupSession getAuctionConstrainerRuleLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer assignment service to apply to auction houses. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerRuleApplicationSession getAuctionConstrainerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer assignment service for the given auction house to apply to 
     *  auction houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerRuleApplicationSession getAuctionConstrainerRuleApplicationSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerLookupSession getAuctionConstrainerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler lookup service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerLookupSession getAuctionConstrainerEnablerLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerQuery() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerQuerySession getAuctionConstrainerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler query service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerQuery() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerQuerySession getAuctionConstrainerEnablerQuerySessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerSearch() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerSearchSession getAuctionConstrainerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enablers earch service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerSearch() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerSearchSession getAuctionConstrainerEnablerSearchSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerAdmin() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerAdminSession getAuctionConstrainerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler administration service for the given auction 
     *  house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerAdmin() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerAdminSession getAuctionConstrainerEnablerAdminSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler notification service. 
     *
     *  @param  auctionConstrainerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerReceiver </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerNotificationSession getAuctionConstrainerEnablerNotificationSession(org.osid.bidding.rules.AuctionConstrainerEnablerReceiver auctionConstrainerEnablerReceiver, 
                                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler notification service for the given auction house. 
     *
     *  @param  auctionConstrainerEnablerReceiver the notification callback 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionConstrainerEnablerReceiver, auctionHouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerNotification() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerNotificationSession getAuctionConstrainerEnablerNotificationSessionForAuctionHouse(org.osid.bidding.rules.AuctionConstrainerEnablerReceiver auctionConstrainerEnablerReceiver, 
                                                                                                                                              org.osid.id.Id auctionHouseId, 
                                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup auction constrainer 
     *  enabler/auction house mappings for auction constrainer enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerAuctionHouseSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerAuctionHouse() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerAuctionHouse() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerAuctionHouseSession getAuctionConstrainerEnablerAuctionHouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning auction 
     *  constrainer enablers to auction houses. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> 
     *          AuctionConstrainerEnablerAuctionHouseAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerAuctionHouseAssignment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerAuctionHouseAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerAuctionHouseAssignmentSession getAuctionConstrainerEnablerAuctionHouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage auction constrainer 
     *  enabler smart auction houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerSmartAuctionHouseSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerSmartAuctionHouse() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerSmartAuctionHouse() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerSmartAuctionHouseSession getAuctionConstrainerEnablerSmartAuctionHouseSession(org.osid.id.Id auctionHouseId, 
                                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerRuleLookup() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerRuleLookupSession getAuctionConstrainerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler mapping lookup service for the given auction 
     *  house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerRuleLookup() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerRuleLookupSession getAuctionConstrainerEnablerRuleLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerRuleApplication() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerRuleApplicationSession getAuctionConstrainerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  constrainer enabler assignment service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionConstrainerEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionConstrainerEnablerRuleApplicationSession getAuctionConstrainerEnablerRuleApplicationSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorLookupSession getAuctionProcessorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor lookup service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorLookupSession getAuctionProcessorLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorQuerySession getAuctionProcessorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor query service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorQuerySession getAuctionProcessorQuerySessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorSearchSession getAuctionProcessorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor earch service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorSearchSession getAuctionProcessorSearchSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorAdminSession getAuctionProcessorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor administration service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorAdminSession getAuctionProcessorAdminSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor notification service. 
     *
     *  @param  auctionProcessorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> auctionProcessoReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorNotificationSession getAuctionProcessorNotificationSession(org.osid.bidding.rules.AuctionProcessorReceiver auctionProcessorReceiver, 
                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor notification service for the given auction house. 
     *
     *  @param  auctionProcessoReceiver the notification callback 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionProcessoReceiver, 
     *          auctionHouseId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorNotificationSession getAuctionProcessorNotificationSessionForAuctionHouse(org.osid.bidding.rules.AuctionProcessorReceiver auctionProcessoReceiver, 
                                                                                                                            org.osid.id.Id auctionHouseId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup auction 
     *  processor/auction house mappings for auction processors. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorAuctionHouseSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorAuctionHouse() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorAuctionHouse() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorAuctionHouseSession getAuctionProcessorAuctionHouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning auction 
     *  processor to auction houses. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorAuctionHouseAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorAuctionHouseAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorAuctionHouseAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorAuctionHouseAssignmentSession getAuctionProcessorAuctionHouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage auction processor smart 
     *  auction houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorSmartAuctionHouseSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorSmartAuctionHouse() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorSmartAuctionHouse() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorSmartAuctionHouseSession getAuctionProcessorSmartAuctionHouseSession(org.osid.id.Id auctionHouseId, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor mapping lookup service for looking up the rules applied to 
     *  the auction house. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorRuleLookupSession getAuctionProcessorRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor mapping lookup service for the given auction house for 
     *  looking up rules applied to an auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorRuleLookupSession getAuctionProcessorRuleLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor assignment service to apply to auction houses. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorRuleApplicationSession getAuctionProcessorRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor assignment service for the given auction house to apply to 
     *  auction houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorRuleApplicationSession getAuctionProcessorRuleApplicationSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerLookupSession getAuctionProcessorEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler lookup service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerLookupSession getAuctionProcessorEnablerLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerQuerySession getAuctionProcessorEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler query service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerQuerySession getAuctionProcessorEnablerQuerySessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerSearchSession getAuctionProcessorEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enablers earch service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerSearchSession getAuctionProcessorEnablerSearchSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerAdminSession getAuctionProcessorEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler administration service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId or proxy 
     *          is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerAdminSession getAuctionProcessorEnablerAdminSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler notification service. 
     *
     *  @param  auctionProcessoEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessoEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerNotificationSession getAuctionProcessorEnablerNotificationSession(org.osid.bidding.rules.AuctionProcessorEnablerReceiver auctionProcessoEnablerReceiver, 
                                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler notification service for the given auction house. 
     *
     *  @param  auctionProcessoEnablerReceiver the notification callback 
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no auction house found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          auctionProcessoEnablerReceiver, auctionHouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerNotificationSession getAuctionProcessorEnablerNotificationSessionForAuctionHouse(org.osid.bidding.rules.AuctionProcessorEnablerReceiver auctionProcessoEnablerReceiver, 
                                                                                                                                          org.osid.id.Id auctionHouseId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup auction processor 
     *  enabler/auction house mappings for auction processor enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerAuctionHouseSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerAuctionHouse() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerAuctionHouse() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerAuctionHouseSession getAuctionProcessorEnablerAuctionHouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning auction 
     *  processor enablers to auction houses. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerAuctionHouseAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerAuctionHouseAssignment() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerAuctionHouseAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerAuctionHouseAssignmentSession getAuctionProcessorEnablerAuctionHouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage auction processor 
     *  enabler smart auction houses. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerSmartAuctionHouseSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerSmartAuctionHouse() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerSmartAuctionHouse() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerSmartAuctionHouseSession getAuctionProcessorEnablerSmartAuctionHouseSession(org.osid.id.Id auctionHouseId, 
                                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerRuleLookupSession getAuctionProcessorEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler mapping lookup service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerRuleLookupSession getAuctionProcessorEnablerRuleLookupSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerRuleApplication() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerRuleApplicationSession getAuctionProcessorEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the auction 
     *  processor enabler assignment service for the given auction house. 
     *
     *  @param  auctionHouseId the <code> Id </code> of the <code> 
     *          AuctionHouse </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuctionProcessorEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> AuctionHouse </code> 
     *          found by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auctionHouseId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuctionProcessorEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuctionProcessorEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.bidding.rules.AuctionProcessorEnablerRuleApplicationSession getAuctionProcessorEnablerRuleApplicationSessionForAuctionHouse(org.osid.id.Id auctionHouseId, 
                                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
