//
// org.osid.billing.BusinessHierarchySession
//
//     The OSID Java specification for org.osid.billing.BusinessHierarchySession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> 
 *  Business </code> objects. Each node in the hierarchy is a unique <code> 
 *  Business. </code> The hierarchy may be traversed recursively to establish 
 *  the tree structure through <code> getParentBusinesses() </code> and <code> 
 *  getChildBusinesses(). </code> To relate these <code> Ids </code> to 
 *  another OSID, <code> getBusinessNodes() </code> can be used for retrievals 
 *  that can be used for bulk lookups in other OSIDs. Any <code> Business 
 *  </code> available in the Customer OSID is known to this hierarchy but does 
 *  not appear in the hierarchy traversal until added as a root node or a 
 *  child of another node. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentBusinesses() </code> or <code> getChildBusiness() 
 *  </code> in lieu of a <code> PERMISSION_DENIED </code> error that may 
 *  disrupt the traversal through authorized pathways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: business elements may be silently omitted or 
 *      re-ordered </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *  </ul>
 *  
 */

public interface BusinessHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getBusinessHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessBusinessHierarchy();


    /**
     *  The returns from the business methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBusinessView();


    /**
     *  A complete view of the <code> Businesses </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBusinessView();


    /**
     *  Gets the root business <code> Ids </code> in this hierarchy. 
     *
     *  @return the root catalog <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootBusinessIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root businesses in the business hierarchy. A node with no 
     *  parents is an orphan. While all business Ids are known to the 
     *  hierarchy, an orphan does not appear in the hierarchy unless 
     *  explicitly added as a root node or child of another node. 
     *
     *  @return the root businesses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.billing.BusinessList getRootBusinesses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> Business </code> has any parents. 
     *
     *  @param  businessId a catalog <code> Id </code> 
     *  @return <code> true </code> if the catalog has parents, f <code> alse 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> businessId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentBusinesses(org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of business. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  businessId the <code> Id </code> of a catalog 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> businessId, </code> f <code> alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> businessId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          businessId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfBusiness(org.osid.id.Id id, 
                                      org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given business. 
     *
     *  @param  businessId a catalog <code> Id </code> 
     *  @return the parent Ids of the catalog 
     *  @throws org.osid.NotFoundException <code> businessId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentBusinessIds(org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given business. 
     *
     *  @param  businessId the <code> Id </code> to query 
     *  @return the parents of the business 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.BusinessList getParentBusinesses(org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of a business. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  businessId the <code> Id </code> of a catalog 
     *  @return <code> tru </code> e if this <code> id </code> is an ancestor 
     *          of <code> businessId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfBusiness(org.osid.id.Id id, 
                                        org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a business has any children. 
     *
     *  @param  businessId a business <code> Id </code> 
     *  @return <code> true </code> if the <code> businessId </code> has 
     *          children, <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildBusinesses(org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a business is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  businessId the <code> Id </code> of a catalog 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> businessId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          businessId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfBusiness(org.osid.id.Id id, 
                                     org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given business. 
     *
     *  @param  businessId the <code> Id </code> to query 
     *  @return the children of the catalog 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildBusinessIds(org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given business. 
     *
     *  @param  businessId the <code> Id </code> to query 
     *  @return the children of the business 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.BusinessList getChildBusinesses(org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of a business. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  businessId the <code> Id </code> of a catalog 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> businessId, </code> <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          businessId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfBusiness(org.osid.id.Id id, 
                                          org.osid.id.Id businessId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given business. 
     *
     *  @param  businessId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the node. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the node. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given node, <code> false </code> to omit the siblings 
     *  @return a catalog node 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getBusinessNodeIds(org.osid.id.Id businessId, 
                                                      long ancestorLevels, 
                                                      long descendantLevels, 
                                                      boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given business. 
     *
     *  @param  businessId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the node. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the node. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given node, <code> false </code> to omit the siblings 
     *  @return a catalog node 
     *  @throws org.osid.NotFoundException <code> businessId </code> not found 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.BusinessNode getBusinessNodes(org.osid.id.Id businessId, 
                                                          long ancestorLevels, 
                                                          long descendantLevels, 
                                                          boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
