//
// org.osid.billing.BusinessQuery
//
//     The OSID Java specification for org.osid.billing.BusinessQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This is the query for searching businesses. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface BusinessQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the customer <code> Id </code> for this query to match customers 
     *  that have a related customer. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCustomerId(org.osid.id.Id customerId, boolean match);


    /**
     *  Clears the customer <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerIdTerms();


    /**
     *  Tests if a <code> CustomerQuery </code> is available. 
     *
     *  @return <code> true </code> if a customer query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCustomerQuery();


    /**
     *  Gets the query for a customer. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the customer query 
     *  @throws org.osid.UnimplementedException <code> supportsCustomerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCustomerQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.CustomerQuery getCustomerQuery();


    /**
     *  Matches businesses that have any customer. 
     *
     *  @param  match <code> true </code> to match customers with any 
     *          customer, <code> false </code> to match customers with no 
     *          customer 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCustomer(boolean match);


    /**
     *  Clears the customer query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerTerms();


    /**
     *  Sets the item <code> Id </code> for this query. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears the item <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if an <code> ItemQuery </code> is available. 
     *
     *  @return <code> true </code> if an item query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for an item. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the item query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.ItemQuery getItemQuery();


    /**
     *  Matches businesses that have any item. 
     *
     *  @param  match <code> true </code> to match businesses with any item, 
     *          <code> false </code> to match businesses with no items 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears the item query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Sets the catalog <code> Id </code> for this query. 
     *
     *  @param  categoryId a category <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> categoryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCategoryId(org.osid.id.Id categoryId, boolean match);


    /**
     *  Clears the category <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCategoryIdTerms();


    /**
     *  Tests if a <code> CategoryQuery </code> is available. 
     *
     *  @return <code> true </code> if a category query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCategoryQuery();


    /**
     *  Gets the query for a category. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the category query 
     *  @throws org.osid.UnimplementedException <code> supportsCategoryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCategoryQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.CategoryQuery getCategoryQuery();


    /**
     *  Matches businesses that have any category. 
     *
     *  @param  match <code> true </code> to match customers with any 
     *          category, <code> false </code> to match customers with no 
     *          category 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCategory(boolean match);


    /**
     *  Clears the category query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCategoryTerms();


    /**
     *  Sets the entry <code> Id </code> for this query. 
     *
     *  @param  itemId an entry <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> entryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEntryId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears the entry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEntryIdTerms();


    /**
     *  Tests if an <code> EntryQuery </code> is available. 
     *
     *  @return <code> true </code> if an entry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryQuery();


    /**
     *  Gets the query for an entry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the entry query 
     *  @throws org.osid.UnimplementedException <code> supportsEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.EntryQuery getEntryQuery();


    /**
     *  Matches businesses that have any entry. 
     *
     *  @param  match <code> true </code> to match businesses with any entry, 
     *          <code> false </code> to match businesses with no entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEntry(boolean match);


    /**
     *  Clears the entry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEntryTerms();


    /**
     *  Sets the period <code> Id </code> for this query to match catalogs 
     *  containing terms. 
     *
     *  @param  periodId the period <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> periodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPeriodId(org.osid.id.Id periodId, boolean match);


    /**
     *  Clears the period <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPeriodIdTerms();


    /**
     *  Tests if a <code> PeriodQuery </code> is available. 
     *
     *  @return <code> true </code> if a period query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPeriodQuery();


    /**
     *  Gets the query for a period Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the period query 
     *  @throws org.osid.UnimplementedException <code> supportsPeriodQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPeriodQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.PeriodQuery getPeriodQuery();


    /**
     *  Matches businesses that have any period. 
     *
     *  @param  match <code> true </code> to match businesses with any period, 
     *          <code> false </code> to match customers with no period 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPeriod(boolean match);


    /**
     *  Clears the period query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPeriodTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match businesses 
     *  that have the specified business as an ancestor. 
     *
     *  @param  businessId a business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorBusinessId(org.osid.id.Id businessId, 
                                        boolean match);


    /**
     *  Clears the ancestor business <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorBusinessQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorBusinessQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.billing.BusinessQuery getAncestorBusinessQuery();


    /**
     *  Matches businesses with any business ancestor. 
     *
     *  @param  match <code> true </code> to match businesses with any 
     *          ancestor, <code> false </code> to match root businesses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorBusiness(boolean match);


    /**
     *  Clears the ancestor business query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBusinessTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match businesses 
     *  that have the specified business as an descendant. 
     *
     *  @param  businessId a business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantBusinessId(org.osid.id.Id businessId, 
                                          boolean match);


    /**
     *  Clears the descendant business <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantBusinessQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantBusinessQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.billing.BusinessQuery getDescendantBusinessQuery();


    /**
     *  Matches businesses with any descendant business. 
     *
     *  @param  match <code> true </code> to match businesses with any 
     *          descendant, <code> false </code> to match leaf businesses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantBusiness(boolean match);


    /**
     *  Clears the descendant business query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBusinessTerms();


    /**
     *  Gets the business query record corresponding to the given <code> 
     *  Business </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  businessRecordType a business record type 
     *  @return the business query record 
     *  @throws org.osid.NullArgumentException <code> businessRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(businessRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.BusinessQueryRecord getBusinessQueryRecord(org.osid.type.Type businessRecordType)
        throws org.osid.OperationFailedException;
}
