//
// org.osid.billing.Entry
//
//     The OSID Java specification for org.osid.billing.Entry.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>An <code> Entry </code> is a relationship between a customer and item 
 *  in a billing period. </p>
 */

public interface Entry
    extends org.osid.OsidRelationship {


    /**
     *  Gets the customer <code> Id </code> associated with this entry. 
     *
     *  @return the customer <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCustomerId();


    /**
     *  Gets the customer associated with this entry. 
     *
     *  @return the customer 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Customer getCustomer()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the item <code> Id </code> associated with this entry. 
     *
     *  @return the item <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getItemId();


    /**
     *  Gets the item associated with this entry. 
     *
     *  @return the item 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Item getItem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Period </code> of this 
     *  offering. 
     *
     *  @return the <code> Period </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPeriodId();


    /**
     *  Gets the <code> Period </code> of this offering. 
     *
     *  @return the period 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Period getPeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the quantity of the item. 
     *
     *  @return the quantity 
     *  @throws org.osid.IllegalStateException <code> hasProduct() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method is must be implemented. 
     */

    public long getQuantity();


    /**
     *  Gets the amount of this entry. 
     *
     *  @return the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getAmount();


    /**
     *  Tests if the amount is a debit or a credit. 
     *
     *  @return <code> true </code> if this item amount is a debit, <code> 
     *          false </code> if it is a credit 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDebit();


    /**
     *  Gets the entry record corresponding to the given <code> Entry </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> entryRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(entryRecordType) </code> is <code> true </code> . 
     *
     *  @param  entryRecordType the type of entry record to retrieve 
     *  @return the entry record 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(entryRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.EntryRecord getEntryRecord(org.osid.type.Type entryRecordType)
        throws org.osid.OperationFailedException;
}
