//
// org.osid.billing.ItemForm
//
//     The OSID Java specification for org.osid.billing.ItemForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This is the form for creating and updating <code> Items. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> ItemAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface ItemForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the category. 
     *
     *  @return metadata for the category 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCategoryMetadata();


    /**
     *  Sets the category. 
     *
     *  @param  categoryId the new category 
     *  @throws org.osid.InvalidArgumentException <code> categoryId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> categoryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCategory(org.osid.id.Id categoryId);


    /**
     *  Removes the category. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCategory();


    /**
     *  Gets the metadata for the general ledger account. 
     *
     *  @return metadata for the account 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAccountMetadata();


    /**
     *  Sets the general ledger account. 
     *
     *  @param  accountId the new account 
     *  @throws org.osid.InvalidArgumentException <code> accountId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAccount(org.osid.id.Id accountId);


    /**
     *  Removes the account. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAccount();


    /**
     *  Gets the metadata for the product. 
     *
     *  @return metadata for the product 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getProductMetadata();


    /**
     *  Sets the product. 
     *
     *  @param  productId the new product 
     *  @throws org.osid.InvalidArgumentException <code> productId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> productId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setProduct(org.osid.id.Id productId);


    /**
     *  Removes the product. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProduct();


    /**
     *  Gets the metadata for the amount. 
     *
     *  @return metadata for the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAmountMetadata();


    /**
     *  Sets the amount. 
     *
     *  @param  amount the new amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> amount </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAmount(org.osid.financials.Currency amount);


    /**
     *  Removes the amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAmount();


    /**
     *  Gets the metadata for the debit flag. 
     *
     *  @return metadata for the debit 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDebitMetadata();


    /**
     *  Sets the debit flag. 
     *
     *  @param  debit <code> true </code> for a debit, <code> false </code> 
     *          for a credit 
     *  @throws org.osid.InvalidArgumentException <code> debit </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAmount(boolean debit);


    /**
     *  Removes the debit flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDebit();


    /**
     *  Gets the metadata for the recurring interval. 
     *
     *  @return metadata for the recurring interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRecurringIntervalMetadata();


    /**
     *  Sets the recurring interval. 
     *
     *  @param  interval the new interval 
     *  @throws org.osid.InvalidArgumentException <code> interval </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> interval </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRecurringInterval(org.osid.calendaring.Duration interval);


    /**
     *  Removes the recurring interval and sets the item as a one-time charge. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecurringInterval();


    /**
     *  Gets the <code> ItemFormRecord </code> corresponding to the given item 
     *  record <code> Type. </code> 
     *
     *  @param  itemRecordType an item record type 
     *  @return the item form record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.ItemFormRecord getItemFormRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
