//
// org.osid.billing.PeriodForm
//
//     The OSID Java specification for org.osid.billing.PeriodForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This is the form for creating and updating <code> Periods. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> PeriodAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface PeriodForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for a display label title. 
     *
     *  @return metadata for the display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDisplayLabelMetadata();


    /**
     *  Sets the display label. 
     *
     *  @param  displayLabel the new display label 
     *  @throws org.osid.InvalidArgumentException <code> displayLabel </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> displayLabel </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDisplayLabel(String displayLabel);


    /**
     *  Removes the display label. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabel();


    /**
     *  Gets the metadata for an open date. 
     *
     *  @return metadata for the open date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOpenDateMetadata();


    /**
     *  Sets the open date. 
     *
     *  @param  date the new open date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOpenDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the open date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOpenDate();


    /**
     *  Gets the metadata for the close date. 
     *
     *  @return metadata for the close date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCloseDateMetadata();


    /**
     *  Sets the close date. 
     *
     *  @param  date the new close date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCloseDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the close date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloseDate();


    /**
     *  Gets the metadata for the billing date. 
     *
     *  @return metadata for the billing date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBillingDateMetadata();


    /**
     *  Sets the billing date. 
     *
     *  @param  date the new billing date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBillingDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the billing date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBillingDate();


    /**
     *  Gets the metadata for the due date. 
     *
     *  @return metadata for the due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDueDateMetadata();


    /**
     *  Sets the due date. 
     *
     *  @param  date the new due date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDueDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the due date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDate();


    /**
     *  Gets the <code> PeriodFormRecord </code> corresponding to the given 
     *  period record <code> Type. </code> 
     *
     *  @param  periodRecordType a period record type 
     *  @return the period form record 
     *  @throws org.osid.NullArgumentException <code> periodRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(periodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.PeriodFormRecord getPeriodFormRecord(org.osid.type.Type periodRecordType)
        throws org.osid.OperationFailedException;
}
