//
// org.osid.billing.PeriodQuery
//
//     The OSID Java specification for org.osid.billing.PeriodQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This is the query for searching periods. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PeriodQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Adds a display label for this query. 
     *
     *  @param  label label string to match 
     *  @param  stringMatchType the label match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> label </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> label </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDisplayLabel(String label, 
                                  org.osid.type.Type stringMatchType, 
                                  boolean match);


    /**
     *  Matches a display label that has any value. 
     *
     *  @param  match <code> true </code> to match customers with any label, 
     *          <code> false </code> to match assets with no title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDisplayLabel(boolean match);


    /**
     *  Clears the display label query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabelTerms();


    /**
     *  Matches the open date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOpenDate(org.osid.calendaring.DateTime low, 
                              org.osid.calendaring.DateTime high, 
                              boolean match);


    /**
     *  Matches a period that has any open date assigned. 
     *
     *  @param  match <code> true </code> to match periods with any open date, 
     *          <code> false </code> to match events with no open date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOpenDate(boolean match);


    /**
     *  Clears the open date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOpenDateTerms();


    /**
     *  Matches the close date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCloseDate(org.osid.calendaring.DateTime low, 
                               org.osid.calendaring.DateTime high, 
                               boolean match);


    /**
     *  Matches a period that has any close date assigned. 
     *
     *  @param  match <code> true </code> to match periods with any close 
     *          date, <code> false </code> to match events with no close date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCloseDate(boolean match);


    /**
     *  Clears the close date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloseDateTerms();


    /**
     *  Matches the billing date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBillingDate(org.osid.calendaring.DateTime low, 
                                 org.osid.calendaring.DateTime high, 
                                 boolean match);


    /**
     *  Matches a period that has any billing date assigned. 
     *
     *  @param  match <code> true </code> to match periods with any billing 
     *          date, <code> false </code> to match events with no billing 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBillingDate(boolean match);


    /**
     *  Clears the billing date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBillingDateTerms();


    /**
     *  Matches the due date between the given range inclusive. 
     *
     *  @param  low low date range 
     *  @param  high high date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDueDate(org.osid.calendaring.DateTime low, 
                             org.osid.calendaring.DateTime high, boolean match);


    /**
     *  Matches a period that has any due date assigned. 
     *
     *  @param  match <code> true </code> to match periods with any due date, 
     *          <code> false </code> to match events with no due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDueDate(boolean match);


    /**
     *  Clears the due date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDateTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match periods 
     *  assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the period query record corresponding to the given <code> Period 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  periodRecordType a period record type 
     *  @return the period query record 
     *  @throws org.osid.NullArgumentException <code> periodRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(periodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.records.PeriodQueryRecord getPeriodQueryRecord(org.osid.type.Type periodRecordType)
        throws org.osid.OperationFailedException;
}
