//
// org.osid.billing.PeriodSearchSession
//
//     The OSID Java specification for org.osid.billing.PeriodSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing;


/**
 *  <p>This session provides methods for searching among <code> Period </code> 
 *  objects. The search query is constructed using the <code> PeriodQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getPeriodsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Periods. </code> A more advanced search may be 
 *  performed with <code> getPeriodsBySearch(). </code> It accepts a <code> 
 *  PeriodSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getPeriodsBySearch() </code> returns a <code> 
 *  PeriodsSearchResults </code> that can be used to access the resulting 
 *  <code> PeriodList </code> or be used to perform a search within the result 
 *  set through <code> PeriodSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include periods in businesses 
 *      of which this business is an ancestor in the business hierarchy </li> 
 *      <li> isolated business view: searches are restricted to periods in 
 *      this business </li> 
 *  </ul>
 *  
 *  
 *  <p> Periods may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PeriodQuery. </code> 
 *  </p>
 */

public interface PeriodSearchSession
    extends org.osid.billing.PeriodQuerySession {


    /**
     *  Gets a period search. 
     *
     *  @return the period search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.PeriodSearch getPeriodSearch();


    /**
     *  Gets a period search order. The <code> PeriodSearchOrder </code> is 
     *  supplied to a <code> PeriodSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the period search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.PeriodSearchOrder getPeriodSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  periodQuery the period query 
     *  @param  periodSearch the period search 
     *  @return the period search results 
     *  @throws org.osid.NullArgumentException <code> periodQuery </code> or 
     *          <code> periodSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> periodQuery </code> or 
     *          <code> periodSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.PeriodSearchResults getPeriodsBySearch(org.osid.billing.PeriodQuery periodQuery, 
                                                                   org.osid.billing.PeriodSearch periodSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a period query from an inspector. The inspector is available from 
     *  a <code> PeriodSearchResults. </code> 
     *
     *  @param  periodQueryInspector a period query inspector 
     *  @return the period query 
     *  @throws org.osid.NullArgumentException <code> periodQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> periodQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.PeriodQuery getPeriodQueryFromInspector(org.osid.billing.PeriodQueryInspector periodQueryInspector);
}
