//
// org.osid.billing.batch.CustomerBatchAdminSession
//
//     The OSID Java specification for org.osid.billing.batch.CustomerBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO CUSTOMER SHALL THE 
//     AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Customers </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Customer, </code> a <code> CustomerForm </code> is requested using <code> 
 *  getCustomerFormsForCreate() </code> specifying the resource and desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> CustomerForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> CustomerForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> CustomerForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> CustomerForms </code> returned from <code> 
 *  getCustomerFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> CustomerForm. 
 *  </code> In the case where there may be duplicates, any <code> CustomerForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> CustomerForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> CustomerForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createCustomers(), 
 *  </code> errors specific to an individual <code> CustomerForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  CustomerForm </code> through the <code> CustomerForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> CustomerForms </code> are requested to the <code> 
 *  Customer </code> <code> Id </code> that is to be updated using <code> 
 *  getCustomerFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> CustomerForm </code> may be used to link the request. 
 *  Similarly, the <code> CustomerForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> CustomerForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> CustomerForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> CustomerForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateCustomers(), 
 *  </code> errors specific to an individual <code> CustomerForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  CustomerForm </code> through the <code> CustomerForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Customers </code> in bulk. To 
 *  unmap a <code> Customer </code> from the current <code> Business, </code> 
 *  the <code> CustomerBusinessAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Customer </code> itself 
 *  thus removing it from all known <code> Business </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface CustomerBatchAdminSession
    extends org.osid.billing.CustomerAdminSession {


    /**
     *  Gets the customer forms for creating a bunch of new customers. A new 
     *  form is returned for each supplied resource. 
     *
     *  @param  resourceIds a list of resource <code> Ids </code> 
     *  @param  customerRecordTypes array of customer record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the customer forms 
     *  @throws org.osid.NotFoundException a resource is not found 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> or 
     *          <code> customerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.batch.CustomerBatchFormList getCustomerFormsForCreate(org.osid.id.IdList resourceIds, 
                                                                                  org.osid.type.Type[] customerRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Customers. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  customerForms the customer forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> customerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCustomers(org.osid.billing.batch.CustomerBatchFormList customerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the customer forms for updating an existing set of customers. A 
     *  new customer form should be requested for each update transaction. 
     *
     *  @param  customerIds the <code> Ids </code> of the <code> Customer 
     *          </code> 
     *  @return the customer form 
     *  @throws org.osid.NotFoundException a <code> customerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> customerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.batch.CustomerBatchFormList getCustomerFormsForUpdate(org.osid.id.IdList customerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing customers. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  customerForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> customerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCustomers(org.osid.billing.batch.CustomerBatchFormList customerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Customers </code> in this <code> Business </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCustomers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes customers for the given <code> Ids. </code> 
     *
     *  @param  customerIds the <code> Ids </code> of the customers to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> customerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCustomers(org.osid.id.IdList customerIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes customers for the given resource. 
     *
     *  @param  resourceId the <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> customerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCustomersForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes customers expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveCustomersByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Customer </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Customer </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another customer, it is reassigned to the given customer 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCustomers(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
