//
// org.osid.billing.payment.Payer
//
//     The OSID Java specification for org.osid.billing.payment.Payer.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>A <code> Payer </code> represents the payer of the bills. A <code> 
 *  Payer </code> links a payment type to a paying contact <code> Resource. 
 *  </code> </p>
 */

public interface Payer
    extends org.osid.OsidObject,
            org.osid.Temporal {


    /**
     *  Gets the resource <code> Id </code> representing the billing contact. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the resource. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this payer is linked directly to a customer account. 
     *
     *  @return <code> true </code> if this payer is linked to a customer, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCustomer();


    /**
     *  Gets the customer <code> Id. </code> 
     *
     *  @return the customer <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasCustomer() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCustomerId();


    /**
     *  Gets the customer. 
     *
     *  @return the customer 
     *  @throws org.osid.IllegalStateException <code> hasCustomer() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Customer getCustomer()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this payer uses the customer financial activity for payments. 
     *  If <code> usesActivity() </code> is true, then <code> usesCash(), 
     *  </code> <code> hasCreditCard(), </code> and <code> hasBankAccount() 
     *  </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this payer uses the customer activity, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasCustomer() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean usesActivity();


    /**
     *  Tests if this payer uses cash for payments. 
     *
     *  @return <code> true </code> if this payer uses the cash, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean usesCash();


    /**
     *  Tests if this payer pays by credit card. If <code> hasCreditCard() 
     *  </code> is true, then <code> usesActivity(), </code> <code> 
     *  usesCash(), </code> <code> hasCreditCard(), </code> and <code> 
     *  hasBankAccount() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this payer pays by credit card, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCreditCard();


    /**
     *  Gets the credit card number. 
     *
     *  @return the credit card number 
     *  @throws org.osid.IllegalStateException <code> hasCreditCard() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getCreditCardNumber();


    /**
     *  Gets the credit card expiration date. 
     *
     *  @return the expiration date 
     *  @throws org.osid.IllegalStateException <code> hasCreditCard() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCreditCardExpiration();


    /**
     *  Gets the credit card security code. 
     *
     *  @return the credit card security code 
     *  @throws org.osid.IllegalStateException <code> hasCreditCard() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getCreditCardCode();


    /**
     *  Tests if this payer pays by bank account If <code> hasBankAccount() 
     *  </code> is true, then <code> usesActivity(), </code> <code> 
     *  usesCash(), </code> <code> hasCreditCard(), </code> and <code> 
     *  hasCreditCard() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if this payer pays by bank account, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasBankAccount();


    /**
     *  Gets the bank routing number. 
     *
     *  @return the bank routing number number 
     *  @throws org.osid.IllegalStateException <code> hasBankAccount() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getBankRoutingNumber();


    /**
     *  Gets the bank account number. 
     *
     *  @return the bank account number 
     *  @throws org.osid.IllegalStateException <code> hasBankAccount() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getBankAccountNumber();


    /**
     *  Gets the payer record corresponding to the given <code> Payer </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> payerRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(payerRecordType) </code> is <code> true </code> . 
     *
     *  @param  payerRecordType the type of payer record to retrieve 
     *  @return the payer record 
     *  @throws org.osid.NullArgumentException <code> payerRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(payerRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.PayerRecord getPayerRecord(org.osid.type.Type payerRecordType)
        throws org.osid.OperationFailedException;
}
