//
// org.osid.billing.payment.PayerForm
//
//     The OSID Java specification for org.osid.billing.payment.PayerForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This is the form for creating and updating <code> Payers. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> PayerAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface PayerForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidTemporalForm {


    /**
     *  Gets the metadata for an customer. 
     *
     *  @return metadata for the customer 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCustomerMetadata();


    /**
     *  Sets the customer. 
     *
     *  @param  customerId the new customer 
     *  @throws org.osid.InvalidArgumentException <code> customerId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCustomer(org.osid.id.Id customerId);


    /**
     *  Removes the customer. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomer();


    /**
     *  Gets the metadata for a financial activity based payer. 
     *
     *  @return metadata for the activity flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getUsesActivityMetadata();


    /**
     *  Sets the activity flag. 
     *
     *  @param  activity the new activity flag 
     *  @throws org.osid.InvalidArgumentException <code> activity </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setUsesActivity(boolean activity);


    /**
     *  Removes the activity flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearUsesActivity();


    /**
     *  Gets the metadata for a cash payer. 
     *
     *  @return metadata for the cash flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getUsesCashMetadata();


    /**
     *  Sets the cash flag. 
     *
     *  @param  cash the new cash flag 
     *  @throws org.osid.InvalidArgumentException <code> cash </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setUsesCash(boolean cash);


    /**
     *  Removes the cash flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearUsesCash();


    /**
     *  Gets the metadata for the credit card number. 
     *
     *  @return metadata for the credit card number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditCardNumberMetadata();


    /**
     *  Sets the credit card number. 
     *
     *  @param  number the new number 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreditCardNumber(String number);


    /**
     *  Clears the credit card number. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditCardNumber();


    /**
     *  Gets the metadata for the credit card expiration. 
     *
     *  @return metadata for the credit card expiration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditCardExpirationMetadata();


    /**
     *  Sets the credit card expiration. 
     *
     *  @param  date the new expiration date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreditCardExpiration(org.osid.calendaring.DateTime date);


    /**
     *  Clears the credit card expiration. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditCardExpiration();


    /**
     *  Gets the metadata for the credit card code. 
     *
     *  @return metadata for the credit card code 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditCardCodeMetadata();


    /**
     *  Sets the credit card code. 
     *
     *  @param  code the new code 
     *  @throws org.osid.InvalidArgumentException <code> code </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreditCardCode(String code);


    /**
     *  Clears the credit card code. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditCardCode();


    /**
     *  Gets the metadata for the bank routing number. 
     *
     *  @return metadata for the bank routing number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBankRoutingNumberMetadata();


    /**
     *  Sets the bank routing number. 
     *
     *  @param  number the new number 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBankRoutingNumber(String number);


    /**
     *  Clears the bank routing number. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankRoutingNumber();


    /**
     *  Gets the metadata for the bank account number. 
     *
     *  @return metadata for the bank account number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBankAccountNumberMetadata();


    /**
     *  Sets the bank account number. 
     *
     *  @param  number the new number 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBankAccountNumber(String number);


    /**
     *  Clears the bank account number. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankAccountNumber();


    /**
     *  Gets the <code> PayerFormRecord </code> corresponding to the given 
     *  payer record <code> Type. </code> 
     *
     *  @param  payerRecordType a payer record type 
     *  @return the payer form record 
     *  @throws org.osid.NullArgumentException <code> payerRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(payerRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.PayerFormRecord getPayerFormRecord(org.osid.type.Type payerRecordType)
        throws org.osid.OperationFailedException;
}
