//
// org.osid.billing.payment.PayerQuery
//
//     The OSID Java specification for org.osid.billing.payment.PayerQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This is the query for searching payers. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PayerQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidTemporalQuery {


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery();


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Sets the customer <code> Id </code> for this query. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCustomerId(org.osid.id.Id customerId, boolean match);


    /**
     *  Clears the customer <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerIdTerms();


    /**
     *  Tests if a <code> CustomereQuery </code> is available. 
     *
     *  @return <code> true </code> if a customer query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCustomerQuery();


    /**
     *  Gets the query for a customer. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return a customer query 
     *  @throws org.osid.UnimplementedException <code> supportsCustomerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCustomerQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.CustomerQuery getCustomerQuery();


    /**
     *  Matches payers with any related customer. 
     *
     *  @param  match <code> true </code> to match payers with any related 
     *          customer, <code> false </code> to match payers with no 
     *          customer 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCustomer(boolean match);


    /**
     *  Clears the customer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerTerms();


    /**
     *  Matches payers using their activity account. 
     *
     *  @param  match <code> true </code> to match payers using an activity, 
     *          false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchUsesActivity(boolean match);


    /**
     *  Clears the activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearUsesActivityTerms();


    /**
     *  Matches payers using cash. 
     *
     *  @param  match <code> true </code> to match payers using cash, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchUsesCash(boolean match);


    /**
     *  Clears the cash terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearUsesCashTerms();


    /**
     *  Matches credit card numbers. 
     *
     *  @param  number a credit card number 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreditCardNumber(String number, 
                                      org.osid.type.Type stringMatchType, 
                                      boolean match);


    /**
     *  Matches payers with any credit card. 
     *
     *  @param  match <code> true </code> to match payers with any credit 
     *          card, <code> false </code> to match payers with no credit card 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreditCardNumber(boolean match);


    /**
     *  Clears the credit card number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditCardNumberTerms();


    /**
     *  Matches credit card expirations between the given date range 
     *  inclusive. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreditCardExpiration(org.osid.calendaring.DateTime from, 
                                          org.osid.calendaring.DateTime to, 
                                          boolean match);


    /**
     *  Matches payers with any credit card expiration date. 
     *
     *  @param  match <code> true </code> to match payers with any credit card 
     *          expiration, <code> false </code> to match payers with no 
     *          credit card expiration 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreditCardExpiration(boolean match);


    /**
     *  Clears the credit card expiration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditCardExpirationTerms();


    /**
     *  Matches credit card security codes. 
     *
     *  @param  code a credit card code 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> code </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreditCardCode(String code, 
                                    org.osid.type.Type stringMatchType, 
                                    boolean match);


    /**
     *  Matches payers with any credit card security code. 
     *
     *  @param  match <code> true </code> to match payers with any credit card 
     *          security code, <code> false </code> to match payers with no 
     *          credit card security code 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreditCardCode(boolean match);


    /**
     *  Clears the credit card code terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditCardCodeTerms();


    /**
     *  Matches bank routing numbers. 
     *
     *  @param  number a bank routing number 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankRoutingNumber(String number, 
                                       org.osid.type.Type stringMatchType, 
                                       boolean match);


    /**
     *  Matches payers with any bank routing number. 
     *
     *  @param  match <code> true </code> to match payers with any bank 
     *          routing number, <code> false </code> to match payers with no 
     *          bank routing number 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBankRoutingNumber(boolean match);


    /**
     *  Clears the bank routing number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankRoutingNumberTerms();


    /**
     *  Matches bank account numbers. 
     *
     *  @param  number a bank account number 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBankAccountNumber(String number, 
                                       org.osid.type.Type stringMatchType, 
                                       boolean match);


    /**
     *  Matches payers with any bank account number. 
     *
     *  @param  match <code> true </code> to match payers with any bank 
     *          account number, <code> false </code> to match payers with no 
     *          bank account number 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBankAccountNumber(boolean match);


    /**
     *  Clears the bank account number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBankAccountNumberTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match payers 
     *  assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.billing.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the payer query record corresponding to the given <code> Payer 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  payerRecordType a payer record type 
     *  @return the payer query record 
     *  @throws org.osid.NullArgumentException <code> payerRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(payerRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.PayerQueryRecord getPayerQueryRecord(org.osid.type.Type payerRecordType)
        throws org.osid.OperationFailedException;
}
