//
// org.osid.billing.payment.PaymentForm
//
//     The OSID Java specification for org.osid.billing.payment.PaymentForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This is the form for creating and updating <code> Payments. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  PaymentAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface PaymentForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the billing period. 
     *
     *  @return metadata for the billing period 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPeriodMetadata();


    /**
     *  Sets the period. 
     *
     *  @param  periodId the new billing period 
     *  @throws org.osid.InvalidArgumentException <code> periodId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> periodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPeriod(org.osid.id.Id periodId);


    /**
     *  Clears the billing period. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPeriod();


    /**
     *  Gets the metadata for the payment date. 
     *
     *  @return metadata for the payment date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPaymentDateMetadata();


    /**
     *  Sets the payment date. 
     *
     *  @param  date the new payment date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPaymentDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the payment date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPaymentDate();


    /**
     *  Gets the metadata for the process date. 
     *
     *  @return metadata for the procssed date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getProcessDateMetadata();


    /**
     *  Sets the process date. 
     *
     *  @param  date the new process date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setProcessDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the process date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessDate();


    /**
     *  Gets the metadata for the amount. 
     *
     *  @return metadata for the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAmountMetadata();


    /**
     *  Sets the amount. 
     *
     *  @param  amount the new amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> amount </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAmount(org.osid.financials.Currency amount);


    /**
     *  Clears the amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAmount();


    /**
     *  Gets the <code> PaymentFormRecord </code> corresponding to the given 
     *  payment record <code> Type. </code> 
     *
     *  @param  paymentRecordType a payment record type 
     *  @return the payment form record 
     *  @throws org.osid.NullArgumentException <code> paymentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(paymentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.PaymentFormRecord getPaymentFormRecord(org.osid.type.Type paymentRecordType)
        throws org.osid.OperationFailedException;
}
