//
// org.osid.billing.payment.PaymentSearchOrder
//
//     The OSID Java specification for org.osid.billing.payment.PaymentSearchOrder.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface PaymentSearchOrder
    extends org.osid.OsidObjectSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the payer. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPayer(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a payer search order is available. 
     *
     *  @return <code> true </code> if a payer search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPayerSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the payer. 
     *
     *  @return the payer search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPayerSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPayerSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.billing.payment.PayerSearchOrder getPayerSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the customer. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCustomer(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a customer search order is available. 
     *
     *  @return <code> true </code> if a customer search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCustomerSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the customer. 
     *
     *  @return the customer search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCustomerSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCustomerSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.billing.CustomerSearchOrder getCustomerSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the billing 
     *  period. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPeriod(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a billing period search order is available. 
     *
     *  @return <code> true </code> if a period search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPeriodSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the billing 
     *  period. 
     *
     *  @return the period search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPeriodSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPeriodSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.billing.PeriodSearchOrder getPeriodSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the payment 
     *  date. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPaymentDate(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the process 
     *  date. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByProcessDate(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the amount. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAmount(org.osid.SearchOrderStyle style);


    /**
     *  Gets the payment search order record corresponding to the given 
     *  payment record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  paymentRecordType a payment record type 
     *  @return the payment search order record 
     *  @throws org.osid.NullArgumentException <code> paymentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(paymentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.records.PaymentSearchOrderRecord getPaymentSearchOrderRecord(org.osid.type.Type paymentRecordType)
        throws org.osid.OperationFailedException;
}
