//
// org.osid.billing.payment.SummarySession
//
//     The OSID Java specification for org.osid.billing.payment.SummarySession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment;


/**
 *  <p>This session defines methods for retrieving payment summaries. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative summary view: elements may be silently omitted or 
 *      re-ordered </li> 
 *      <li> plenary summary view: provides a complete result set or is an 
 *      error condition </li> 
 *      <li> isolated business view: All summary methods in this session 
 *      operate, retrieve and pertain to summaries defined explicitly in the 
 *      current business. Using an isolated view is useful for managing <code> 
 *      Summaries </code> with the <code> SummaryAdminSession. </code> </li> 
 *      <li> federated business view: All summary lookup methods in this 
 *      session operate, retrieve and pertain to all summaries defined in this 
 *      business and any other summaries implicitly available in this business 
 *      through business inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBusinessView() </code> and <code> 
 *  useIsolatedBusinessView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Summaries may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Summary. </code> </p>
 */

public interface SummarySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Summary </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSummaries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSummaryView();


    /**
     *  A complete view of the <code> Summary </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySummaryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include summaries in catalogs which are children of this catalog in 
     *  the business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Gets the current <code> Summary </code> for the given customer. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @return the returned <code> Summary </code> 
     *  @throws org.osid.NotFoundException <code> customerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.Summary getCurrentSummaryForCustomer(org.osid.id.Id customerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SummaryList </code> for the given customer. In plenary 
     *  mode, the returned list contains all known summaries or an error 
     *  results. Otherwise, the returned list may contain only those summaries 
     *  that are accessible through this session. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @return the returned <code> Summary </code> list 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.SummaryList getSummariesForCustomer(org.osid.id.Id customerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SummaryList </code> for the given period. In plenary 
     *  mode, the returned list contains all known summaries or an error 
     *  results. Otherwise, the returned list may contain only those summaries 
     *  that are accessible through this session. 
     *
     *  @param  periodId a period <code> Id </code> 
     *  @return the returned <code> Summary </code> list 
     *  @throws org.osid.NullArgumentException <code> periodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.SummaryList getSummariesByPeriod(org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SummaryList </code> for the given customer and billing 
     *  period. In plenary mode, the returned list contains all known 
     *  summaries or an error results. Otherwise, the returned list may 
     *  contain only those summaries that are accessible through this session. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @param  periodId a period <code> Id </code> 
     *  @return the returned <code> Summary </code> list 
     *  @throws org.osid.NullArgumentException <code> customerId </code> or 
     *          <code> periodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.SummaryList getSummariesByPeriodForCustomer(org.osid.id.Id customerId, 
                                                                                org.osid.id.Id periodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SummaryList </code> of currently past due payments. In 
     *  plenary mode, the returned list contains all known summaries or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  summaries that are accessible through this session. 
     *
     *  @return the returned <code> Summary </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.SummaryList getPastDueSummaries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Summaries. </code> In plenary mode, the returned list 
     *  contains all known summaries or an error results. Otherwise, the 
     *  returned list may contain only those summaries that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Summary </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.SummaryList getSummaries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
