//
// org.osid.billing.payment.batch.PaymentBatchAdminSession
//
//     The OSID Java specification for org.osid.billing.payment.batch.PaymentBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.billing.payment.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Payments </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Payment, </code> a <code> PaymentForm </code> is requested using <code> 
 *  getPaymentFormsForCreate() </code> specifying the desired payer, customer, 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. Each of the returned <code> PaymentForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> PaymentForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> PaymentForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> PaymentForms </code> returned from <code> 
 *  getPaymentFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> PaymentForm. 
 *  </code> In the case where there may be duplicates, any <code> PaymentForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> PaymentForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> PaymentForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createPayments(), 
 *  </code> errors specific to an individual <code> PaymentForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  PaymentForm </code> through the <code> PaymentForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> PaymentForms </code> are requested to the <code> 
 *  Payment </code> <code> Id </code> that is to be updated using <code> 
 *  getPaymentFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> PaymentForm </code> may be used to link the request. 
 *  Similarly, the <code> PaymentForm </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> PaymentForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> PaymentForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> PaymentForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updatePayments(), 
 *  </code> errors specific to an individual <code> PaymentForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  PaymentForm </code> through the <code> PaymentForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Payments </code> in bulk. To unmap 
 *  a <code> Payment </code> from the current <code> Business, </code> the 
 *  <code> PaymentBusinessAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Payment </code> itself thus 
 *  removing it from all known <code> Business </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface PaymentBatchAdminSession
    extends org.osid.billing.payment.PaymentAdminSession {


    /**
     *  Gets the payment forms for creating a bunch of new payments. A form is 
     *  returned for each set of payment peers. 
     *
     *  @param  peers a list of payment peers 
     *  @param  paymentRecordTypes array of payment record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the payment forms 
     *  @throws org.osid.NotFoundException a node is not found 
     *  @throws org.osid.NullArgumentException a <code> payerId, customerId, 
     *          </code> or <code> paymentRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.batch.PaymentBatchFormList getPaymentFormsForCreate(org.osid.billing.payment.batch.PaymentPeerList peers, 
                                                                                        org.osid.type.Type[] paymentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Payments. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  paymentForms the payment forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> paymentForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createPayments(org.osid.billing.payment.batch.PaymentBatchFormList paymentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the payment forms for updating an existing set of payments. A new 
     *  payment form should be requested for each update transaction. 
     *
     *  @param  paymentIds the <code> Ids </code> of the <code> Payment 
     *          </code> 
     *  @return the payment form 
     *  @throws org.osid.NotFoundException a <code> paymentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> paymentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.billing.payment.batch.PaymentBatchFormList getPaymentFormsForUpdate(org.osid.id.IdList paymentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing payments. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  paymentForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> paymentForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updatePayments(org.osid.billing.payment.batch.PaymentBatchFormList paymentForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Payments </code> in this <code> Business </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllPayments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes payments for the given <code> Ids. </code> 
     *
     *  @param  paymentIds the <code> Ids </code> of the payments to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> paymentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePayments(org.osid.id.IdList paymentIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes payments for the given payer. 
     *
     *  @param  payerId the <code> Id </code> of a payer 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> payerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePaymentsForPayer(org.osid.id.Id payerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes payments for the given customer. 
     *
     *  @param  customerId the <code> Id </code> of a customer 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> customerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deletePaymentsForCustomer(org.osid.id.Id customerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Payment </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Payment </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another payment, it is reassigned to the given payment 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasPayments(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
