//
// Distance
//
//    Supplements the OSID Distance interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Distance interface for Java.
 */

public interface Distance
    extends OsidPrimitive,
	    Comparable<org.osid.mapping.Distance> {


    /**
     *  Tests if this Distance is greater than the given Distance. A
     *  greater Distance is one whose values minus uncertainty is
     *  greater than another plus its uncertainty. An uncertainty of
     *  infinity is undefined and returns false.
     *
     *  @param  distance the distance to compare
     *  @return <code>true</code> if this distance is larger,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>distance</code>
     *          is <code>null</code>
     */

    public boolean isGreater(org.osid.mapping.Distance distance);


    /**
     *  Tests if this Distance is less than the given Distance. A
     *  lesser Distance is one whose values plus uncertainty is less
     *  than another minus its uncertainty. An uncertainty of infinity
     *  is undefined and returns false.
     *
     *  @param  distance the distance to compare
     *  @return <code>true</code> if this distance is less,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>distance</code>
     *          is <code>null</code>
     */

    public boolean isLess(org.osid.mapping.Distance distance);


    /**
     *  Tests if the range of this Distance, as specified by its
     *  uncertainty, includes the given Distance ranged by its
     *  uncertainty.
     *
     *  If either distance has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  distance the distance to compare
     *  @return <code>true</code> if this distance includes the given
     *          distance, <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>distance</code>
     *          is <code>null</code>
     */

    public boolean isInclusive(org.osid.mapping.Distance distance);


    /**
     *  Tests if the range of this Distance, as specified by its
     *  uncertainty, is included within the given two Distances.
     *
     *  If either distance has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  distance1 the start distance to compare
     *  @param  distance2 the end distance to compare
     *  @return <code>true</code> if this distance is included,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>distance1</code>
     *          or <code>distance2</code> is <code>null</code>
     */

    public boolean isContained(org.osid.mapping.Distance distance1, 
			       org.osid.mapping.Distance distance2);


    /**
     *  Tests if the range of this Distance, as specified by its
     *  uncertainty, does not overlap the given Distance.
     *
     *  If either distance has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  distance the distance to compare
     *  @return <code>true</code> if this distance is excluded,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>distance</code>
     *          is <code>null</code>
     */

    public boolean isExclusive(org.osid.mapping.Distance distance);


    /**
     *  Tests if the range of this Distance, as specified by its
     *  uncertainty, does not overlap with the range of the given two
     *  distances.
     *
     *  If either distance has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  distance1 the start distance to compare
     *  @param  distance2 the end distance to compare
     *  @return <code>true</code> if this distance is excluded,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>distance1</code>
     *          or <code>distance2</code> is <code>null</code>
     */

    public boolean isExclusive(org.osid.mapping.Distance distance1, 
			       org.osid.mapping.Distance distance2);


    /**
     *  Gets the lower bound of the distance. The lower bound is the
     *  distance minus the uncertainty.
     *
     *  @return the distance lower bound
     */

    public org.osid.mapping.Distance getLowerBound();


    /**
     *  Gets the upper bound of the distance. The lower bound is the
     *  distance plus the uncertainty.
     *
     *  @return the distance upper bound
     */

    public org.osid.mapping.Distance getUpperBound();


    /**
     *  Compares this distance with the specified <code>Distance</code>
     *  to determine the natural order. Returns a negative integer,
     *  zero, or a positive integer as this distance is less than,
     *  equal to, or greater than the specified Distance.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the type, then by its values. This method is not
     *  useful for numeric comparisons. The ranges implied by their
     *  granularities and uncertainties may overlap in such a way that
     *  two unequal Distances may be neither less than or greater than
     *  the other.
     *
     *  If <code>compareTo</code> a distance is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param distance the distance to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this distance is less than, equal to, or greater than
     *          the specified distance
     *  @throws ClassCastException if the specified distance's type
     *          prevents it from being compared to this distance
     */

    @Override
    public int compareTo(org.osid.mapping.Distance distance);


    /**
     *  Determines if the given <code> Distance </code> is equal to
     *  this one.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>DateTime</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>Distance</code> based
     *  on the types, values, granularity and uncertainties.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
