//
// Heading
//
//    Supplements the OSID Heading interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Heading interface for Java.
 */

public interface Heading
    extends OsidPrimitive,
	    Comparable<org.osid.mapping.Heading> {


    /**
     *	Tests if this <code>Heading</code>, as specified by its
     *	uncertainty, completely includes the given
     *	<code>Heading</code> ranged by its uncertainty.
     *
     *	If either heading has an uncertainty of infinity this
     *	method returns false.
     *
     *  It is possible for <code>isInclusive()</code> and
     *  <code>isExclsuive()</code> to be both <code>false</code> among
     *  two <code>Headings</code> due to uncertainties in the
     *  values.
     *
     *	@param	heading the heading to compare
     *	@return <code>true</code> if this heading includes the given
     *		heading, <code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>heading</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare heading
     */

    public boolean isInclusive(org.osid.mapping.Heading heading);


    /**
     *	Tests if this <code>Heading</code>, as specified by its
     *	uncertainty, does not overlap the given
     *	<code>Heading</code>.
     *
     *	If either heading has an uncertainty of infinity this
     *	method returns false.
     *
     *  It is possible for <code>isInclusive()</code> and
     *  <code>isExclsuive()</code> to be both <code>false</code> among
     *  two <code>Headings</code> due to uncertainties in the
     *  values.
     *     
     *	@param	heading the heading to compare
     *	@return <code>true</code> if this heading is excluded,
     *		<code>false</code> otherwise
     *	@throws org.osid.NullArgumentException <code>heading</code>
     *		is <code>null</code>
     *	@throws org.osid.UnsupportedException cannot compare heading
     */

    public boolean isExclusive(org.osid.mapping.Heading heading);


    /**
     *	Gets the outer bounds of the heading. The outer bounds are the
     *	heading minus and plus the uncertainty. This method returns
     *	the Headings forming the largest radius allowed by its
     *	uncertainty.
     *
     *	@return the heading outer bounds
     */

    public org.osid.mapping.Heading[] getOuterBound();


    /**
     *  Compares this heading with the specified <code>Heading</code>
     *  to determine the natural order. Returns a negative integer,
     *  zero, or a positive integer as this heading is less than,
     *  equal to, or greater than the specified heading.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the heading type, then by its values. This method
     *  is not useful for numeric comparisons. The ranges implied by
     *  their granularities and uncertainties may overlap in such a
     *  way that two unequal Headings may be neither less than or
     *  greater than the other.
     *
     *  If <code>compareTo</code> a heading is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param heading the heading to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this heading is less than, equal to, or greater than
     *          the specified heading
     *  @throws ClassCastException if the specified heading's type
     *          prevents it from being compared to this heading
     */

    @Override
    public int compareTo(org.osid.mapping.Heading heading);


    /**
     *  Determines if the given <code> Heading </code> is equal to
     *  this one. Two <code>Headings</code> are equal if their heading
     *  type and values are equal.
     *
     *  If <code>equals()</code> is <code>true</code>, then
     *  <code>compareTo()</code> must be zero and their hash codes
     *  must also be equal for consistent behavior. For orderings that
     *  may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  If <code>obj</code> is null or if a different interface, this
     *  method returns <code>false</code>.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Heading</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>Heading</code>.
     *  The hash code is determined by the heading type and values.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
