//
// Speed
//
//    Supplements the OSID Speed interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Speed interface for Java.
 */

public interface Speed
    extends OsidPrimitive,
	    Comparable<org.osid.mapping.Speed> {


    /**
     *  Tests if this Speed is greater than the given Speed. A
     *  greater Speed is one whose values minus uncertainty is
     *  greater than another plus its uncertainty. An uncertainty of
     *  infinity is undefined and returns false.
     *
     *  @param  speed the speed to compare
     *  @return <code>true</code> if this speed is larger,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>speed</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare speed
     */

    public boolean isGreater(org.osid.mapping.Speed speed);


    /**
     *  Tests if this Speed is less than the given Speed. A
     *  lesser Speed is one whose values plus uncertainty is less
     *  than another minus its uncertainty. An uncertainty of infinity
     *  is undefined and returns false.
     *
     *  @param  speed the speed to compare
     *  @return <code>true</code> if this speed is less,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>speed</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException cannot compare speed
     */

    public boolean isLess(org.osid.mapping.Speed speed);


    /**
     *  Tests if the range of this Speed, as specified by its
     *  uncertainty, includes the given Speed ranged by its
     *  uncertainty.
     *
     *  If either speed has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  speed the speed to compare
     *  @return <code>true</code> if this speed includes the given
     *          speed, <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>speed</code>
     *          is <code>null</code>
     */

    public boolean isInclusive(org.osid.mapping.Speed speed);


    /**
     *  Tests if the range of this Speed, as specified by its
     *  uncertainty, is included within the given two Speeds.
     *
     *  If either speed has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  speed1 the start speed to compare
     *  @param  speed2 the end speed to compare
     *  @return <code>true</code> if this speed is included,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>speed1</code>
     *          or <code>speed2</code> is <code>null</code>
     */

    public boolean isContained(org.osid.mapping.Speed speed1, 
			       org.osid.mapping.Speed speed2);


    /**
     *  Tests if the range of this Speed, as specified by its
     *  uncertainty, does not overlap the given Speed.
     *
     *  If either speed has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  speed the speed to compare
     *  @return <code>true</code> if this speed is excluded,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>speed</code>
     *          is <code>null</code>
     */

    public boolean isExclusive(org.osid.mapping.Speed speed);


    /**
     *  Tests if the range of this Speed, as specified by its
     *  uncertainty, does not overlap with the range of the given two
     *  speeds.
     *
     *  If either speed has an uncertainty of infinity this method
     *  returns false.
     *
     *  @param  speed1 the start speed to compare
     *  @param  speed2 the end speed to compare
     *  @return <code>true</code> if this speed is excluded,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>speed1</code>
     *          or <code>speed2</code> is <code>null</code>
     */

    public boolean isExclusive(org.osid.mapping.Speed speed1, 
			       org.osid.mapping.Speed speed2);


    /**
     *  Gets the lower bound of the speed. The lower bound is the
     *  speed minus the uncertainty.
     *
     *  @return the speed lower bound
     */

    public org.osid.mapping.Speed getLowerBound();


    /**
     *  Gets the upper bound of the speed. The lower bound is the
     *  speed plus the uncertainty.
     *
     *  @return the speed upper bound
     */

    public org.osid.mapping.Speed getUpperBound();


    /**
     *  Compares this Speed with the specified Speed to determine the
     *  natural order. Returns a negative integer, zero, or a positive
     *  integer as this speed is less than, equal to, or greater than
     *  the specified speed.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the speed scheme, then by its components. This
     *  method is not useful for numeric comparisons. The ranges
     *  implied by the granularities and uncertainties of their
     *  Distances and Durations may overlap in such a way that two
     *  unequal Speeds may be neither less than or greater than the
     *  other.
     *
     *  If <code>compareTo</code> a speed is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param speed the speed to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this speed is less than, equal to, or greater than
     *          the specified speed
     *  @throws ClassCastException if the specified speed's type
     *          prevents it from being compared to this speed
     */

    @Override
    public int compareTo(org.osid.mapping.Speed speed);


    /**
     *  Determines if the given <code> Speeds </code> is equal to
     *  this one.  Two versions are equal if their distance and
     *  time units are equal.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Speed</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);

    /**
     *  Returns a hash code value for this <code>Speed</code> based
     *  on the distance and time units.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
