//
// Version
//
//    Supplements the OSID Version interface for Java.
//
//
// Tom Coppeto
// OnTapSolutions
// 21 October 2010
//
// Copyright (c) 2010 Ingenescus. All Rights Reserved.
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//

package org.osid.binding.java;


/**
 *  Supplements the OSID Version interface for Java.
 */

public interface Version
    extends OsidPrimitive,
	    Comparable<org.osid.installation.Version> {


    /**
     *  Tests if this Version is more recent than the given Version.
     *
     *  @param  version the version to compare
     *  @return <code>true</code> if this version is more recent,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>version</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException version scheme types 
     *          not compatible
     */

    public boolean isNewer(org.osid.installation.Version version);


    /**
     *  Tests if this Version is older than the given Version.
     *
     *  @param  version the version to compare
     *  @return <code>true</code> if this version is older,
     *          <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>version</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException version scheme types 
     *          not compatible
     */

    public boolean isOlder(org.osid.installation.Version version);


    /**
     *  Tests if this Version includes the given version. A version
     *  3.2 may include version 3.2.5 but not include version 3.0.
     *
     *  @param  version the version to compare
     *  @return <code>true</code> if this version includes the given
     *          version, <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>version</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException version scheme types 
     *          not compatible
     */

    public boolean isInclusive(org.osid.installation.Version version);


    /**
     *  Tests if this Version excludes the given version. Two versions
     *  are exclusive if a.isInclusive(b) and b.isInclusive(c) are
     *  both false.
     *
     *  @param  version the version to compare
     *  @return <code>true</code> if this version excludes the given
     *          version, <code>false</code> otherwise
     *  @throws org.osid.NullArgumentException <code>version</code>
     *          is <code>null</code>
     *  @throws org.osid.UnsupportedException version scheme types 
     *          not compatible
     */

    public boolean isExclusive(org.osid.installation.Version version);


    /**
     *  Compares this Version with the specified Version to determine
     *  the natural order. Returns a negative integer, zero, or a
     *  positive integer as this version is less than, equal to, or
     *  greater than the specified version.
     *
     *  The natural ordering is determined first by the natural
     *  ordering of the version scheme, then by its components.
     *
     *  If <code>compareTo</code> an version is zero, then
     *  <code>equals()</code> must be <code>true</code> and their hash
     *  codes must also be equal for consistent behavior. For
     *  orderings that may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  @param version the version to be compared
     *  @return a negative integer, zero, or a positive integer as
     *          this version is less than, equal to, or greater than
     *          the specified version
     *  @throws ClassCastException if the specified version's type
     *          prevents it from being compared to this version
     */

    @Override
    public int compareTo(org.osid.installation.Version version);


    /**
     *  Determines if the given <code> Version </code> is equal to
     *  this one.  Two versions are equal if their schema and
     *  components are equal.
     *
     *  If <code>equals()</code> is <code>true</code>, then
     *  <code>compareTo()</code> must be zero and their hash codes
     *  must also be equal for consistent behavior. For orderings that
     *  may yield inconsistent behavior, an external
     *  <code>Comparator</code> should be used.
     *
     *  If <code>obj</code> is null or if a different interface, this
     *  method returns <code>false</code>.
     *
     *  @param  obj an object to compare
     *  @return <code> true </code> if the given object is equal to
     *          this <code>Version</code>, <code> false </code>
     *          otherwise
     */

    @Override
    public boolean equals(Object obj);


    /**
     *  Returns a hash code value for this <code>Version</code> based
     *  on the schema and components.
     *
     *  @return a hash code value for this object
     */

    @Override
    public int hashCode();
}
