//
// org.osid.blogging.BlogQuery
//
//     The OSID Java specification for org.osid.blogging.BlogQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>This is the query for searching blogs. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface BlogQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the entry <code> Id </code> for this query. 
     *
     *  @param  entryId an entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> entryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEntryId(org.osid.id.Id entryId, boolean match);


    /**
     *  Clears the entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEntryIdTerms();


    /**
     *  Tests if a <code> EntryQuery </code> is available. 
     *
     *  @return <code> true </code> if an entry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryQuery();


    /**
     *  Gets the query for an entry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the entry query 
     *  @throws org.osid.UnimplementedException <code> supportsEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.blogging.EntryQuery getEntryQuery();


    /**
     *  Matches blogs with any entries. 
     *
     *  @param  match <code> true </code> to match blogs with any entries, 
     *          <code> false </code> to match blogs with no entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEntry(boolean match);


    /**
     *  Clears the entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEntryTerms();


    /**
     *  Sets the blog <code> Id </code> for this query to match blogs that 
     *  have the specified blog as an ancestor. 
     *
     *  @param  blogId a blog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> blogId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorBlogId(org.osid.id.Id blogId, boolean match);


    /**
     *  Clears the ancestor blog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBlogIdTerms();


    /**
     *  Tests if a <code> BlogQuery </code> is available. 
     *
     *  @return <code> true </code> if a blog query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorBlogQuery();


    /**
     *  Gets the query for a blog. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the blog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorBlogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorBlogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.blogging.BlogQuery getAncestorBlogQuery();


    /**
     *  Matches blogs with any ancestor. 
     *
     *  @param  match <code> true </code> to match blogs with any ancestor, 
     *          <code> false </code> to match root blogs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorBlog(boolean match);


    /**
     *  Clears the ancestor blog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorBlogTerms();


    /**
     *  Sets the blog <code> Id </code> for this query to match blogs that 
     *  have the specified blog as a descendant. 
     *
     *  @param  blogId a blog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> blogId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantBlogId(org.osid.id.Id blogId, boolean match);


    /**
     *  Clears the descendant blog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBlogIdTerms();


    /**
     *  Tests if a <code> BlogQuery </code> is available. 
     *
     *  @return <code> true </code> if a blog query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantBlogQuery();


    /**
     *  Gets the query for a blog. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the blog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantBlogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantBlogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.blogging.BlogQuery getDescendantBlogQuery();


    /**
     *  Matches blogs with any descendant. 
     *
     *  @param  match <code> true </code> to match blogs with any descendant, 
     *          <code> false </code> to match leaf blogs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantBlog(boolean match);


    /**
     *  Clears the descendant blog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantBlogTerms();


    /**
     *  Gets the blog query record corresponding to the given <code> Blog 
     *  </code> record <code> Type. </code> Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @param  blogRecordType a blog record type 
     *  @return the blog query record 
     *  @throws org.osid.NullArgumentException <code> blogRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(blogRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.records.BlogQueryRecord getBlogQueryRecord(org.osid.type.Type blogRecordType)
        throws org.osid.OperationFailedException;
}
