//
// org.osid.blogging.BlogQuerySession
//
//     The OSID Java specification for org.osid.blogging.BlogQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>This session provides methods for searching among <code> Blog </code> 
 *  objects. The search query is constructed using the <code> BlogQuery. 
 *  </code> </p> 
 *  
 *  <p> Blogs may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BlogQuery. </code> </p>
 */

public interface BlogQuerySession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform <code> Blog </code> searches. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchBlogs();


    /**
     *  Gets a blog query. The returned query will not have an extension 
     *  query. 
     *
     *  @return the blog query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogQuery getBlogQuery();


    /**
     *  Gets a list of <code> Blogs </code> matching the given search. 
     *
     *  @param  blogQuery the blog query 
     *  @return the returned <code> BlogList </code> 
     *  @throws org.osid.NullArgumentException <code> blogQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException a <code> blogQuery </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogList getBlogsByQuery(org.osid.blogging.BlogQuery blogQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
