//
// org.osid.blogging.BlogSearchSession
//
//     The OSID Java specification for org.osid.blogging.BlogSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>This session provides methods for searching among <code> Blog </code> 
 *  objects. The search query is constructed using the <code> BlogQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getBlogsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Blog </code> objects.A more advanced search may 
 *  be performed with <code> getBlogsBySearch(). </code> It accepts a <code> 
 *  BlogSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getBlogsBySearch() </code> returns a <code> BlogSearchResults </code> that 
 *  can be used to access the resulting <code> BlogList </code> or be used to 
 *  perform a search within the result set through <code> BlogSearch. </code> 
 *  </p> 
 *  
 *  <p> Blogs may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> BlogQuery. </code> </p>
 */

public interface BlogSearchSession
    extends org.osid.blogging.BlogQuerySession {


    /**
     *  Gets a blog search. 
     *
     *  @return the blog search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogSearch getBlogSearch();


    /**
     *  Gets a blog search order. The <code> BlogSearchOrder </code> is 
     *  supplied to a <code> BlogSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the blog search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogSearchOrder getBlogSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  blogQuery the blog query 
     *  @param  blogSearch the blog search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> blogQuery </code> or 
     *          <code> blogSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> blogQuery </code> or 
     *          <code> blogSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogSearchResults getBlogsBySearch(org.osid.blogging.BlogQuery blogQuery, 
                                                                org.osid.blogging.BlogSearch blogSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a blog query from an inspector. The inspector is available from 
     *  an <code> BlogSearchResults. </code> 
     *
     *  @param  blogQueryInspector a query inspector 
     *  @return the blog query 
     *  @throws org.osid.NullArgumentException <code> blogQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> blogQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.BlogQuery getBlogQueryFromInspector(org.osid.blogging.BlogQueryInspector blogQueryInspector);
}
