//
// org.osid.blogging.BloggingProxyManager
//
//     The OSID Java specification for org.osid.blogging.BloggingProxyManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>The blogging manager provides access to entry lookup and creation 
 *  session and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager support the passing of a <code> Proxy 
 *  </code> object for the purposes of passing information from a server 
 *  environment. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> EntryLookupSession: </code> a session to retrieve entries 
 *      </li> 
 *      <li> <code> EntryQuerySession: </code> a session for querying entries 
 *      </li> 
 *      <li> <code> EntrySearchSession: </code> a session to search for 
 *      entries </li> 
 *      <li> <code> EntryAdminSession: </code> a session to create and delete 
 *      entries </li> 
 *      <li> <code> EntryNotificationSession: </code> a session to receive 
 *      notifications pertaining to entry changes </li> 
 *      <li> <code> EntryBlogSession: </code> a session to look up entry to 
 *      blog mappings </li> 
 *      <li> <code> EntryBlogAssignmentSession: </code> a session to manage 
 *      entry to blog mappings </li> 
 *      <li> <code> EntrySmartBlogSession: </code> a session for managing 
 *      dynamic blogs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BlogLookupSession: a </code> session to retrieve blogs 
 *      </li> 
 *      <li> <code> BlogQuerySession: </code> a session for querying blogs 
 *      </li> 
 *      <li> <code> BlogSearchSession: </code> a session to search for blogs 
 *      </li> 
 *      <li> <code> BlogAdminSession: </code> a session to create, update and 
 *      delete blogs </li> 
 *      <li> <code> BlogNotificationSession: </code> a session to receive 
 *      notifications pertaining to changes in blogs </li> 
 *      <li> <code> BlogHierarchySession: </code> a session to traverse blog 
 *      hierarchies </li> 
 *      <li> <code> BlogHierarchyDesignSession: </code> a session to manage 
 *      blog hierarchies </li> 
 *  </ul>
 *  
 */

public interface BloggingProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.blogging.BloggingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the entry lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return <code> an EntryLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryLookup() </code> is <code> true. </code> 
     */

    public org.osid.blogging.EntryLookupSession getEntryLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the entry lookup 
     *  service for the given blog. 
     *
     *  @param  blogId the <code> Id </code> of the blog 
     *  @param  proxy a proxy 
     *  @return <code> an EntryLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> blogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> blogId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEntryLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.blogging.EntryLookupSession getEntryLookupSessionForBlog(org.osid.id.Id blogId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an entry query session. 
     *
     *  @param  proxy a proxy 
     *  @return <code> an EntryQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.blogging.EntryQuerySession getEntryQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an entry query session for the given blog. 
     *
     *  @param  blogId the <code> Id </code> of the blog 
     *  @param  proxy a proxy 
     *  @return <code> an EntryQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> blogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> blogId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEntryQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.blogging.EntryQuerySession getEntryQuerySessionForBlog(org.osid.id.Id blogId, 
                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an entry search session. 
     *
     *  @param  proxy a proxy 
     *  @return <code> an EntrySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntrySearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntrySearch() </code> is <code> true. </code> 
     */

    public org.osid.blogging.EntrySearchSession getEntrySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an entry search session for the given blog. 
     *
     *  @param  blogId the <code> Id </code> of the blog 
     *  @param  proxy a proxy 
     *  @return <code> an EntrySearchSession </code> 
     *  @throws org.osid.NotFoundException <code> blogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> blogId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEntrySearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntrySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.blogging.EntrySearchSession getEntrySearchSessionForBlog(org.osid.id.Id blogId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an entry administration session for creating, updating and 
     *  deleting entries. 
     *
     *  @param  proxy a proxy 
     *  @return <code> an EntryAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.blogging.EntryAdminSession getEntryAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an entry administration session for the given blog. 
     *
     *  @param  blogId the <code> Id </code> of the blog 
     *  @param  proxy a proxy 
     *  @return <code> an EntryAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> blogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> blogId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.blogging.EntryAdminSession getEntryAdminSessionForBlog(org.osid.id.Id blogId, 
                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the entry notification session for the given blog. 
     *
     *  @param  entryReceiver notification callback 
     *  @param  proxy a proxy 
     *  @return <code> an EntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> entryReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.blogging.EntryNotificationSession getEntryNotificationSession(org.osid.blogging.EntryReceiver entryReceiver, 
                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the entry notification session for the given blog. 
     *
     *  @param  entryReceiver notification callback 
     *  @param  blogId the <code> Id </code> of the blog 
     *  @param  proxy a proxy 
     *  @return <code> an EntryNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> blogId </code> not found 
     *  @throws org.osid.NullArgumentException <code> entryReceiver, blogId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.blogging.EntryNotificationSession getEntryNotificationSessionForBlog(org.osid.blogging.EntryReceiver entryReceiver, 
                                                                                         org.osid.id.Id blogId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving entry to blog mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EntryBlogSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryBlog() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryBlog() </code> is <code> true. </code> 
     */

    public org.osid.blogging.EntryBlogSession getEntryBlogSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning entry to blog mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> EntryBlogAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryBlogAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryBlogAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.blogging.EntryBlogAssignmentSession getEntryBlogAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session managing smart blogs. 
     *
     *  @param  blogId the <code> Id </code> of the blog 
     *  @param  proxy a proxy 
     *  @return a <code> EntrySmartBlogSession </code> 
     *  @throws org.osid.NotFoundException <code> blogId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> blogId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntrySmartBlog() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntrySmartBlog() </code> is <code> true. </code> 
     */

    public org.osid.blogging.EntrySmartBlogSession getEntrySmartBlogSession(org.osid.id.Id blogId, 
                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the blog lookup session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BlogLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBlogLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlogLookup() </code> is <code> true. </code> 
     */

    public org.osid.blogging.BlogLookupSession getBlogLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the blog query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BlogQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBlogQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlogQuery() </code> is <code> true. </code> 
     */

    public org.osid.blogging.BlogQuerySession getBlogQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the blog search session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BlogSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBlogSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlogSearch() </code> is <code> true. </code> 
     */

    public org.osid.blogging.BlogSearchSession getBlogSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the blog administrative session for creating, updating and 
     *  deleteing blogs. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BlogAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBlogAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlogAdmin() </code> is <code> true. </code> 
     */

    public org.osid.blogging.BlogAdminSession getBlogAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscriblogg to changes to a blog. 
     *
     *  @param  blogReceiver notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BlogNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> blogReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBlogNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlogNotification() </code> is <code> true. </code> 
     */

    public org.osid.blogging.BlogNotificationSession getBlogNotificationSession(org.osid.blogging.BlogReceiver blogReceiver, 
                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the blog hierarchy traversal session. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a BlogHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBlogHierarchy() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlogHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.blogging.BlogHierarchySession getBlogHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the blog hierarchy design session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BlogHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBlogHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBlogHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.blogging.BlogHierarchyDesignSession getBlogHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> BloggingBatchProxyManager. </code> 
     *
     *  @return a <code> BloggingBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBloggingBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBloggingBatch() </code> is <code> true. </code> 
     */

    public org.osid.blogging.batch.BloggingBatchProxyManager getBloggingBatchProxyManager()
        throws org.osid.OperationFailedException;
}
