//
// org.osid.blogging.EntryLookupSession
//
//     The OSID Java specification for org.osid.blogging.EntryLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.blogging;


/**
 *  <p>This session defines methods for retrieving entries. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated blog view: All entry methods in this session operate, 
 *      retrieve and pertain to entries defined explicitly in the current 
 *      blog. Using an isolated view is useful for managing <code> Entries 
 *      </code> with the <code> EntryAdminSession. </code> </li> 
 *      <li> federated blog view: All entry methods in this session operate, 
 *      retrieve and pertain to all entries defined in this blog and any other 
 *      entries implicitly available in this blog through blog inheritence. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBlogView() </code> and <code> 
 *  useIsolatedBlogView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Entries may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Entry. </code> </p>
 */

public interface EntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Blog </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Blog Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBlogId();


    /**
     *  Gets the <code> Blog </code> associated with this session. 
     *
     *  @return the <code> Blog </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.Blog getBlog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Entry </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupEntries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeEntryView();


    /**
     *  A complete view of the <code> Entry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in blogs which are children of this blog in the blog 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBlogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this blog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBlogView();


    /**
     *  Gets the <code> Entry </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Entry 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Entry </code> and retained for compatibility. 
     *
     *  @param  entryId the <code> Id </code> of the <code> Entry </code> to 
     *          retrieve 
     *  @return the returned <code> Entry </code> 
     *  @throws org.osid.NotFoundException no <code> Entry </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> entryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.Entry getEntry(org.osid.id.Id entryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  entries specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Entries </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  entryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Entry list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> entryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByIds(org.osid.id.IdList entryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> corresponding to the given entry 
     *  genus <code> Type </code> which does not include entries of types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known entries or an error results. 
     *  Otherwise, the returned list may contain only those entries that are 
     *  accessible through this session. 
     *
     *  @param  entryGenusType an entry genus type 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> corresponding to the given entry 
     *  genus <code> Type </code> and include any additional entries with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session. 
     *
     *  @param  entryGenusType an entry genus type 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByParentGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> containing the given entry record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known entries or an error results. Otherwise, the returned list may 
     *  contain only those entries that are accessible through this session. 
     *
     *  @param  entryRecordType an entry record type 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByRecordType(org.osid.type.Type entryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> posted within the specified range 
     *  inclusive. In plenary mode, the returned list contains all known 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByDate(org.osid.calendaring.DateTime from, 
                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> for the given poster resource <code> 
     *  Id. </code> In plenary mode, the returned list contains all known 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. 
     *
     *  @param  resourceId a poster <code> Id </code> 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesForPoster(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> for a poster resource <code> Id 
     *  </code> posted within the specified range inclusive. In plenary mode, 
     *  the returned list contains all known entries or an error results. 
     *  Otherwise, the returned list may contain only those entries that are 
     *  accessible through this session. 
     *
     *  @param  resourceId a poster <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByDateForPoster(org.osid.id.Id resourceId, 
                                                                 org.osid.calendaring.DateTime from, 
                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EntryList </code> for the given provider. In plenary 
     *  mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Entry </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntriesByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Entries. </code> In plenary mode, the returned list 
     *  contains all known entries or an error results. Otherwise, the 
     *  returned list may contain only those entries that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Entries </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.blogging.EntryList getEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
