//
// org.osid.calendaring.CalendarQuery
//
//     The OSID Java specification for org.osid.calendaring.CalendarQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query for searching calendars. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CalendarQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the event <code> Id </code> for this query. 
     *
     *  @param  eventId an event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEventId(org.osid.id.Id eventId, boolean match);


    /**
     *  Clears the event <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventIdTerms();


    /**
     *  Tests if an <code> EventQuery </code> is available. 
     *
     *  @return <code> true </code> if an event query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventQuery();


    /**
     *  Gets the query for an event. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventQuery getEventQuery();


    /**
     *  Matches a calendar that has any event assigned. 
     *
     *  @param  match <code> true </code> to match calendars with any event, 
     *          <code> false </code> to match calendars with no events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEvent(boolean match);


    /**
     *  Clears the event terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEventTerms();


    /**
     *  Sets the time period <code> Id </code> for this query. 
     *
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimePeriodId(org.osid.id.Id timePeriodId, boolean match);


    /**
     *  Clears the time period <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodIdTerms();


    /**
     *  Tests if a <code> TimePeriodQuery </code> is available. 
     *
     *  @return <code> true </code> if a time period query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodQuery();


    /**
     *  Gets the query for a time period. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the tiem period query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodQuery getTimePeriodQuery();


    /**
     *  Matches a calendar that has any time period assigned. 
     *
     *  @param  match <code> true </code> to match calendars with any time 
     *          period, <code> false </code> to match calendars with no time 
     *          periods 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimePeriod(boolean match);


    /**
     *  Clears the time period terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodTerms();


    /**
     *  Sets the commitment <code> Id </code> for this query. 
     *
     *  @param  commitmentId a commitment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> commitmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCommitmentId(org.osid.id.Id commitmentId, boolean match);


    /**
     *  Clears the commitment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommitmentIdTerms();


    /**
     *  Tests if a <code> CommitmentQuery </code> is available. 
     *
     *  @return <code> true </code> if a commitment query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentQuery();


    /**
     *  Gets the query for a commitment. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the commitment query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CommitmentQuery getCommitmentQuery();


    /**
     *  Matches a calendar that has any event commitment. 
     *
     *  @param  match <code> true </code> to match calendars with any 
     *          commitment, <code> false </code> to match calendars with no 
     *          commitments 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCommitment(boolean match);


    /**
     *  Clears the commitment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommitmentTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query to match calendars 
     *  that have the specified calendar as an ancestor. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorCalendarId(org.osid.id.Id calendarId, 
                                        boolean match);


    /**
     *  Clears the ancestor calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorCalendarQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorCalndarQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CalendarQuery getAncestorCalendarQuery();


    /**
     *  Matches a calendar that has any ancestor. 
     *
     *  @param  match <code> true </code> to match calendars with any 
     *          ancestor, <code> false </code> to match root calendars 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorCalendar(boolean match);


    /**
     *  Clears the ancestor calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCalendarTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query to match calendars 
     *  that have the specified calendar as a descendant. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantCalendarId(org.osid.id.Id calendarId, 
                                          boolean match);


    /**
     *  Clears the descendant calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery. </code> 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantCalendarQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantCalndarQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CalendarQuery getDescendantCalendarQuery();


    /**
     *  Matches a calendar that has any descendant. 
     *
     *  @param  match <code> true </code> to match calendars with any 
     *          descendant, <code> false </code> to match leaf calendars 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantCalendar(boolean match);


    /**
     *  Clears the descendant calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCalendarTerms();


    /**
     *  Gets the calendar query record corresponding to the given <code> 
     *  Calendar </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  calendarRecordType a calendar record type 
     *  @return the calendar query record 
     *  @throws org.osid.NullArgumentException <code> calendarRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(calendarRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.CalendarQueryRecord getCalendarQueryRecord(org.osid.type.Type calendarRecordType)
        throws org.osid.OperationFailedException;
}
