//
// org.osid.calendaring.CalendaringManager
//
//     The OSID Java specification for org.osid.calendaring.CalendaringManager.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>The calendaring manager provides access to calendaring sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> EventLookupSession: </code> a session to look up events 
 *      </li> 
 *      <li> <code> EventQuerySession: </code> a session to query events 
 *      <code> </code> </li> 
 *      <li> <code> EventSearchSession: </code> a session to search events 
 *      </li> 
 *      <li> <code> EventAdminSession: </code> a session to manage events 
 *      <code> </code> </li> 
 *      <li> <code> EventNotificationSession: a </code> session to receive 
 *      messages pertaining to event <code> </code> changes </li> 
 *      <li> <code> EventCalendarSession: </code> a session for retriieving 
 *      event and calendar mappings </li> 
 *      <li> <code> EventCalendarAssignmentSession: </code> a session for 
 *      managing event and calendar mappings </li> 
 *      <li> <code> EventSmartCalendarSession: </code> a session to manage 
 *      dynamic event catalogs </li> 
 *      <li> <code> RecurringEventLookupSession: </code> a session to look up 
 *      recurring events </li> 
 *      <li> <code> RecurringEventQuerySession: </code> a session to query 
 *      recurring events </li> 
 *      <li> <code> RecurringEventSearchSession: </code> a session to search 
 *      recurring events </li> 
 *      <li> <code> RecurringEventAdminSession: </code> a session to create, 
 *      modify and delete recurring event </li> 
 *      <li> <code> RecurringEventNotificationSession: </code> a session to 
 *      receive messages pertaining to recurring event changes </li> 
 *      <li> <code> RecurringEventCalendarSession: </code> a session for 
 *      retriieving recurring event and calendar mappings </li> 
 *      <li> <code> RecurringEventCalendarAssignmentSession: </code> a session 
 *      for managing recurring event and calendar mappings </li> 
 *      <li> <code> RecurringEventSmartCalendarSession: </code> a session to 
 *      manage dynamic recurring event catalogs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SupersedingEventLookupSession: </code> a session to look 
 *      up superseding events </li> 
 *      <li> <code> SupersedingEventQuerySession: </code> a session to query 
 *      superseding events <code> </code> </li> 
 *      <li> <code> SupersedingEventSearchSession: </code> a session to search 
 *      superseding events </li> 
 *      <li> <code> SupersedingEventAdminSession: </code> a session to create, 
 *      modify and delete superseding events <code> </code> </li> 
 *      <li> <code> SupersedingEventNotificationSession: a </code> session to 
 *      receive messages pertaining to superseding event <code> </code> 
 *      changes </li> 
 *      <li> <code> SupersedingEventCalendarSession: </code> a session for 
 *      retriieving superseding event and calendar mappings </li> 
 *      <li> <code> SupersedingEventCalendarAssignmentSession: </code> a 
 *      session for managing superseding event and calendar mappings </li> 
 *      <li> <code> SupersedingEventSmartCalendarSession: </code> a session to 
 *      manage dynamic superseding event catalogs </li> 
 *      <li> <code> OffsetEventLookupSession: </code> a session to look up 
 *      offset events </li> 
 *      <li> <code> OffsetEventQuerySession: </code> a session to query offset 
 *      events </li> 
 *      <li> <code> OffsetEventSearchSession: </code> a session to search 
 *      offset events </li> 
 *      <li> <code> OffsetEventAdminSession: </code> a session to create, 
 *      modify and delete offset events </li> 
 *      <li> <code> OffsetEventNotificationSession: </code> a session to 
 *      receive messages pertaining to offset event changes </li> 
 *      <li> <code> OffsetEventCalendarSession: </code> a session for 
 *      retriieving offset event and calendar mappings </li> 
 *      <li> <code> OffsetEventCalendarAssignmentSession: </code> a session 
 *      for managing offset event and calendar mappings </li> 
 *      <li> <code> OffsetEventSmartCalendarSession: </code> a session to 
 *      manage dynamic offset event catalogs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ScheduleLookupSession: </code> a session to look up 
 *      schedules </li> 
 *      <li> <code> ScheduleQuerySession: </code> a session to query schedules 
 *      <code> </code> </li> 
 *      <li> <code> ScheduleSearchSession: </code> a session to search 
 *      schedules </li> 
 *      <li> <code> ScheduleAdminSession: </code> a session to create, modify 
 *      and delete schedules <code> </code> </li> 
 *      <li> <code> ScheduleNotificationSession: a </code> session to receive 
 *      messages pertaining to schedule <code> </code> changes </li> 
 *      <li> <code> ScheduleCalendarSession: </code> a session for retriieving 
 *      schedule and calendar mappings </li> 
 *      <li> <code> ScheduleCalendarAssignmentSession: </code> a session for 
 *      managing schedule and calendar mappings </li> 
 *      <li> <code> ScheduleSmartCalendarSession: </code> a session to manage 
 *      dynamic schedule catalogs </li> 
 *      <li> <code> ScheduleSlotLookupSession: </code> a session to look up 
 *      schedule slots </li> 
 *      <li> <code> ScheduleSlotQuerySession: </code> a session to query 
 *      schedule slots </li> 
 *      <li> <code> ScheduleSlotSearchSession: </code> a session to search 
 *      scheduls slots </li> 
 *      <li> <code> ScheduleSlotAdminSession: </code> a session to create, 
 *      modify and delete schedule slots </li> 
 *      <li> <code> ScheduleSlotNotificationSession: </code> a session to 
 *      receive messages pertaining to schedule slot changes </li> 
 *      <li> <code> ScheduleSlotCalendarSession: </code> a session for 
 *      retriieving schedule slot and calendar mappings </li> 
 *      <li> <code> ScheduleSlotCalendarAssignmentSession: </code> a session 
 *      for managing schedule slot and calendar mappings </li> 
 *      <li> <code> ScheduleSlotSmartCalendarSession: </code> a session to 
 *      manage dynamic schedule slot catalogs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CommitmentLookupSession: </code> a session to look up 
 *      commitments </li> 
 *      <li> <code> CommitmentQuerySession: </code> a session to query 
 *      commitments <code> </code> </li> 
 *      <li> <code> CommitmentSearchSession: </code> a session to search 
 *      commitments </li> 
 *      <li> <code> CommitmentAdminSession: </code> a session to create, 
 *      modify and delete commitments <code> </code> </li> 
 *      <li> <code> CommitmentNotificationSession: a </code> session to 
 *      receive messages pertaining to commitment changes </li> 
 *      <li> <code> CommitmentCalendarSession: </code> a session for 
 *      retriieving commitment and calendar mappings </li> 
 *      <li> <code> CommitmentCalendarAssignmentSession: </code> a session for 
 *      managing commitment and calendar mappings </li> 
 *      <li> <code> CommitmentSmartCalendarSession: </code> a session to 
 *      manage dynamic commitment catalogs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> TimePeriodLookupSession: </code> a session to look up time 
 *      periods </li> 
 *      <li> <code> TimePeriodQuerySession: </code> a session to query time 
 *      periods <code> </code> </li> 
 *      <li> <code> TimePeriodSearchSession: </code> a session to search time 
 *      periods </li> 
 *      <li> <code> TimePeriodAdminSession: </code> a session to create, 
 *      modify and delete time periods <code> </code> </li> 
 *      <li> <code> TimePeriodNotificationSession: a </code> session to 
 *      receive messages pertaining to time period <code> </code> changes 
 *      </li> 
 *      <li> <code> TimePeriodCalendarSession: </code> a session for 
 *      retriieving time period and calendar mappings </li> 
 *      <li> <code> TimePeriodCalendarAssignmentSession: </code> a session for 
 *      managing time period and calendar mappings </li> 
 *      <li> <code> TimePeriodSmartCalendarSession: </code> a session to 
 *      manage dynamic time period catalogs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CalendarLookupSession: </code> a session to lookup 
 *      calendars </li> 
 *      <li> <code> CalendarSearchSession </code> : a session to search 
 *      calendars </li> 
 *      <li> <code> CalendarAdminSession </code> : a session to create, modify 
 *      and delete calendars </li> 
 *      <li> <code> CalendarNotificationSession </code> : a session to receive 
 *      messages pertaining to calendar changes </li> 
 *      <li> <code> CalendarHierarchySession: </code> a session to traverse 
 *      the calendar hierarchy </li> 
 *      <li> <code> CalendarHierarchyDesignSession: </code> a session to 
 *      manage the calendar hierarchy </li> 
 *  </ul>
 *  
 */

public interface CalendaringManager
    extends org.osid.OsidManager,
            org.osid.calendaring.CalendaringProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the event lookup 
     *  service. 
     *
     *  @return an <code> EventLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventLookup() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventLookupSession getEventLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event lookup 
     *  service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventLookupSession getEventLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event query 
     *  service. 
     *
     *  @return an <code> EventQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventQuerySession getEventQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event query 
     *  service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventQuerySession getEventQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event search 
     *  service. 
     *
     *  @return an <code> EventSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventSearch() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventSearchSession getEventSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event search 
     *  service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventSearchSession getEventSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event 
     *  administration service. 
     *
     *  @return an <code> EventAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventAdmin() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventAdminSession getEventAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event admin 
     *  service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsEventAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventAdminSession getEventAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to event 
     *  changes. 
     *
     *  @param  eventReceiver the event receiver 
     *  @return an <code> EventNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> eventReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventNotificationSession getEventNotificationSession(org.osid.calendaring.EventReceiver eventReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event 
     *  notification service for the given calendar. 
     *
     *  @param  eventReceiver the event receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> eventReceiver </code> or 
     *          <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventNotificationSession getEventNotificationSessionForCalendar(org.osid.calendaring.EventReceiver eventReceiver, 
                                                                                                org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving event to calendar mappings. 
     *
     *  @return an <code> EventCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventCalendar() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCalendar() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.EventCalendarSession getEventCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning event to calendar mappings. 
     *
     *  @return an <code> EventCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCalendarAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCalendarAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventCalendarAssignmentSession getEventCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the event smart calendar for the 
     *  given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventSmartCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventSmartCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventSmartCalendarSession getEventSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event lookup service. 
     *
     *  @return a <code> RecurringEventLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventLookupSession getRecurringEventLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> RecurringEventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventLookupSession getRecurringEventLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event query service. 
     *
     *  @return a <code> RecurringEventQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventQuerySession getRecurringEventQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> RecurringEventQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventQuerySession getRecurringEventQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event search service. 
     *
     *  @return a <code> RecurringEventSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventSearchSession getRecurringEventSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> RecurringEventSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventSearchSession getRecurringEventSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event administration service. 
     *
     *  @return a <code> RecurringEventAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventAdminSession getRecurringEventAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> RecurringEventAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventAdminSession getRecurringEventAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  recurring event changes. 
     *
     *  @param  recurringEventReceiver the recurring event receiver 
     *  @return a <code> RecurringEventNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> recurringEventReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.RecurringEventNotificationSession getRecurringEventNotificationSession(org.osid.calendaring.RecurringEventReceiver recurringEventReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event notification service for the given calendar. 
     *
     *  @param  recurringEventReceiver the recurring event receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> RecurringEventNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventNotificationSession getRecurringEventNotificationSessionForCalendar(org.osid.calendaring.RecurringEventReceiver recurringEventReceiver, 
                                                                                                                  org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving recurring event to calendar mappings. 
     *
     *  @return A <code> RecurringEventCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.RecurringEventCalendarSession getRecurringEventCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning recurring event to calendar mappings. 
     *
     *  @return a <code> RecurringEventCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventCalendarAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventCalendarAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.RecurringEventCalendarAssignmentSession getRecurringEventCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the recurring event smart calendar 
     *  for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> RecurringEventSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventSmartCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventSmartCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.RecurringEventSmartCalendarSession getRecurringEventSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event lookup service. 
     *
     *  @return a <code> SupersedingEventLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventLookupSession getSupersedingEventLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> SupersedingEventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventLookupSession getSupersedingEventLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event query service. 
     *
     *  @return a <code> SupersedingEventQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventQuerySession getSupersedingEventQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> SupersedingEventQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventQuerySession getSupersedingEventQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event search service. 
     *
     *  @return a <code> SupersedingEventSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventSearch() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.SupersedingEventSearchSession getSupersedingEventSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> SupersedingEventSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventSearchSession getSupersedingEventSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event administration service. 
     *
     *  @return a <code> SupersedingEventAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEventAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventAdminSession getSupersedingEventAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> SupersedingEventAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventAdminSession getSupersedingEventAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  superseding event changes. 
     *
     *  @param  supersedingEventReceiver the superseding event receiver 
     *  @return a <code> SupersedingEventNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> supersedingEventReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.SupersedingEventNotificationSession getSupersedingEventNotificationSession(org.osid.calendaring.SupersedingEventReceiver supersedingEventReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event notification service for the given calendar. 
     *
     *  @param  supersedingEventReceiver the superseding event receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> SupersedingEventNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> supersedingEventReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventNotificationSession getSupersedingEventNotificationSessionForCalendar(org.osid.calendaring.SupersedingEventReceiver supersedingEventReceiver, 
                                                                                                                      org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving superseding event to calendar 
     *  mappings. 
     *
     *  @return a <code> SupersedingEventCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.SupersedingEventCalendarSession getSupersedingEventCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning superseding event to calendar mappings. 
     *
     *  @return a <code> SupersedingEventCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventCalendarAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventCalendarAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.SupersedingEventCalendarAssignmentSession getSupersedingEventCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the superseding event smart calendar 
     *  for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> SupersedingEventSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventSmartCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventSmartCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.SupersedingEventSmartCalendarSession getSupersedingEventSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  lookup service. 
     *
     *  @return an <code> OffsetEventLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventLookupSession getOffsetEventLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> OffsetEventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventLookupSession getOffsetEventLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  query service. 
     *
     *  @return an <code> OffsetEventQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.OffsetEventQuerySession getOffsetEventQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> OffsetEventQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventQuerySession getOffsetEventQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  search service. 
     *
     *  @return an <code> OffsetEventSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventSearchSession getOffsetEventSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> OffsetEventSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventSearchSession getOffsetEventSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  administration service. 
     *
     *  @return an <code> OffsetEventAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventAdmin() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.OffsetEventAdminSession getOffsetEventAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> OffsetEventAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventAdminSession getOffsetEventAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to offset 
     *  event changes. 
     *
     *  @param  offsetEventReceiver the offset event receiver 
     *  @return an <code> OffsetEventNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> offsetEventReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventNotificationSession getOffsetEventNotificationSession(org.osid.calendaring.OffsetEventReceiver offsetEventReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  notification service for the given calendar. 
     *
     *  @param  offsetEventReceiver the offset event receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> OffsetEventNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> offsetEventReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventNotificationSession getOffsetEventNotificationSessionForCalendar(org.osid.calendaring.OffsetEventReceiver offsetEventReceiver, 
                                                                                                            org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving offset event to calendar mappings. 
     *
     *  @return an <code> OffsetEventCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventCalendarSession getOffsetEventCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning offset event to calendar mappings. 
     *
     *  @return an <code> OffsetEventCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventCalendarAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventCalendarAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.OffsetEventCalendarAssignmentSession getOffsetEventCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the offset event smart calendar for 
     *  the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> OffsetEventSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventSmartCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventSmartCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventSmartCalendarSession getOffsetEventSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule 
     *  lookup service. 
     *
     *  @return a <code> ScheduleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleLookup() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleLookupSession getScheduleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule 
     *  lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleLookupSession getScheduleLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule query 
     *  service. 
     *
     *  @return a <code> ScheduleQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsScheduleQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleQuerySession getScheduleQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule query 
     *  service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsScheduleQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleQuerySession getScheduleQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule 
     *  search service. 
     *
     *  @return a <code> ScheduleSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSearch() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleSearchSession getScheduleSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule 
     *  search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSearchSession getScheduleSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule 
     *  administration service. 
     *
     *  @return a <code> ScheduleAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsScheduleAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleAdmin() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleAdminSession getScheduleAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule admin 
     *  service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsScheduleAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleAdminSession getScheduleAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to schedule 
     *  changes. 
     *
     *  @param  scheduleReceiver the schedule receiver 
     *  @return a <code> ScheduleNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> scheduleReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleNotificationSession getScheduleNotificationSession(org.osid.calendaring.ScheduleReceiver scheduleReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule 
     *  notification service for the given calendar. 
     *
     *  @param  scheduleReceiver the schedule receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> scheduleReceiver </code> 
     *          or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleNotificationSession getScheduleNotificationSessionForCalendar(org.osid.calendaring.ScheduleReceiver scheduleReceiver, 
                                                                                                      org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving schedule to calendar mappings. 
     *
     *  @return a <code> ScheduleCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleCalendar() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.ScheduleCalendarSession getScheduleCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning schedule to calendar mappings. 
     *
     *  @return a <code> ScheduleCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleCalendarAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleCalendarAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.ScheduleCalendarAssignmentSession getScheduleCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the schedule smart calendar for the 
     *  given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSmartCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSmartCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSmartCalendarSession getScheduleSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  lookup service. 
     *
     *  @return a <code> ScheduleSlotLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotLookupSession getScheduleSlotLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSlotLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotLookupSession getScheduleSlotLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  query service. 
     *
     *  @return a <code> ScheduleSlotQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotQuerySession getScheduleSlotQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSlotQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotQuerySession getScheduleSlotQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  search service. 
     *
     *  @return a <code> ScheduleSlotSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotSearchSession getScheduleSlotSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSlotSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotSearchSession getScheduleSlotSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  administration service. 
     *
     *  @return a <code> ScheduleSlotAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotAdminSession getScheduleSlotAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSlotAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotAdminSession getScheduleSlotAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to schedule 
     *  slot changes. 
     *
     *  @param  scheduleSlotReceiver the schedule slot receiver 
     *  @return a <code> ScheduleSlotNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotNotificationSession getScheduleSlotNotificationSession(org.osid.calendaring.ScheduleSlotReceiver scheduleSlotReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the schedule slot 
     *  notification service for the given calendar. 
     *
     *  @param  scheduleSlotReceiver the schedule slot receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSlotNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotNotificationSession getScheduleSlotNotificationSessionForCalendar(org.osid.calendaring.ScheduleSlotReceiver scheduleSlotReceiver, 
                                                                                                              org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving schedule slot to calendar mappings. 
     *
     *  @return a <code> ScheduleSlotCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotCalendarSession getScheduleSlotCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning schedule slot to calendar mappings. 
     *
     *  @return a <code> ScheduleSlotCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotCalendarAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotCalendarAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.ScheduleSlotCalendarAssignmentSession getScheduleSlotCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the schedule slot smart calendar for 
     *  the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> ScheduleSlotSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotSmartCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotSmartCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.ScheduleSlotSmartCalendarSession getScheduleSlotSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  lookup service. 
     *
     *  @return a <code> CommitmentLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentLookup() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CommitmentLookupSession getCommitmentLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CommitmentLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentLookupSession getCommitmentLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  query service. 
     *
     *  @return a <code> CommitmentQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentLookup() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CommitmentQuerySession getCommitmentQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CommitmentQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentQuerySession getCommitmentQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  search service. 
     *
     *  @return a <code> CommitmentSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentSearch() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CommitmentSearchSession getCommitmentSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CommitmentSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentSearchSession getCommitmentSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  administration service. 
     *
     *  @return a <code> CommitmentAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentAdmin() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CommitmentAdminSession getCommitmentAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CommitmenttAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentAdminSession getCommitmentAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  commitment changes. 
     *
     *  @param  commitmentReceiver the commitment receiver 
     *  @return a <code> CommitmentNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> commitmentReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentNotificationSession getCommitmentNotificationSession(org.osid.calendaring.CommitmentReceiver commitmentReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  notification service for the given calendar. 
     *
     *  @param  commitmentReceiver the commitment receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CommitmentNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> commitmentReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentNotificationSession getCommitmentNotificationSessionForCalendar(org.osid.calendaring.CommitmentReceiver commitmentReceiver, 
                                                                                                          org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving commitment to calendar mappings. 
     *
     *  @return a <code> CommitmentCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentCalendarSession getCommitmentCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning commitment to calendar mappings. 
     *
     *  @return a <code> CommitmentCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentCalendarAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentCalendarAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.CommitmentCalendarAssignmentSession getCommitmentCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the commitment smart calendar for the 
     *  given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CommitmentSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentSmartCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentSmartCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.CommitmentSmartCalendarSession getCommitmentSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  lookup service. 
     *
     *  @return a <code> TimePeriodLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodLookup() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodLookupSession getTimePeriodLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> TimePeriodLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodLookupSession getTimePeriodLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  query service. 
     *
     *  @return a <code> TimePeriodQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodQuerySession getTimePeriodQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> TimePeriodQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodQuerySession getTimePeriodQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  search service. 
     *
     *  @return a <code> TimePeriodSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodSearch() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodSearchSession getTimePeriodSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> TimePeriodSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodSearchSession getTimePeriodSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  administration service. 
     *
     *  @return a <code> TimePeriodAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodAdmin() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodAdminSession getTimePeriodAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> TimePeriodAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodAdminSession getTimePeriodAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to time 
     *  period changes. 
     *
     *  @param  timePeriodReceiver the time period receiver 
     *  @return a <code> TimePeriodNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodNotificationSession getTimePeriodNotificationSession(org.osid.calendaring.TimePeriodReceiver timePeriodReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  notification service for the given calendar. 
     *
     *  @param  timePeriodReceiver the time period receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return <code> a TimePeriodNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> timePeriodReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodNotificationSession getTimePeriodNotificationSessionForCalendar(org.osid.calendaring.TimePeriodReceiver timePeriodReceiver, 
                                                                                                          org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving time period to calendar mappings. 
     *
     *  @return a <code> TimePeriodCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodCalendarSession getTimePeriodCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning time period to calendar mappings. 
     *
     *  @return a <code> TimePeriodCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCalendarAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCalendarAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.TimePeriodCalendarAssignmentSession getTimePeriodCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the time period smart calendar for 
     *  the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> TimePeriodSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodSmartCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodSmartCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodSmartCalendarSession getTimePeriodSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the calendar lookup service. 
     *
     *  @return a <code> CalendarLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarLookup() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarLookup() </code> is true. 
     */

    public org.osid.calendaring.CalendarLookupSession getCalendarLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the calendar search service. 
     *
     *  @return a <code> CalendarSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarSearch() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarSearch() </code> is true. 
     */

    public org.osid.calendaring.CalendarSearchSession getCalendarSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the calendar administration 
     *  service. 
     *
     *  @return a <code> CalendarAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarAdmin() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarAdmin() </code> is true. 
     */

    public org.osid.calendaring.CalendarAdminSession getCalendarAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to calendar 
     *  service changes. 
     *
     *  @param  calendarReceiver the calendar receiver 
     *  @return a <code> CalendarNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> calendarReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarNotification() </code> is true. 
     */

    public org.osid.calendaring.CalendarNotificationSession getCalendarNotificationSession(org.osid.calendaring.CalendarReceiver calendarReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing calendar hierarchies. 
     *
     *  @return a <code> CalendarHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarHierarchy() </code> is true. 
     */

    public org.osid.calendaring.CalendarHierarchySession getCalendarHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing calendar hierarchies. 
     *
     *  @return a <code> CalendarHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarHierarchyDesign() </code> is true. 
     */

    public org.osid.calendaring.CalendarHierarchyDesignSession getCalendarHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the calendaring batch manager. 
     *
     *  @return a <code> CalendaringBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendaringBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendaringBatch() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.batch.CalendaringBatchManager getCalandaringBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the calendaring cycle manager. 
     *
     *  @return a <code> CalendaringCycleManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendaringCycle() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendaringCycle() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CalendaringCycleManager getCalandaringCycleManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the calendaring rules manager. 
     *
     *  @return a <code> CalendaringRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendaringRules() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendaringRules() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.rules.CalendaringRulesManager getCalandaringRulesManager()
        throws org.osid.OperationFailedException;
}
