//
// org.osid.calendaring.CalendaringProfile
//
//     The OSID Java specification for org.osid.calendaring.CalendaringProfile.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>The <code> CalendaringProfile </code> describes the interoperability 
 *  among calendaring services. </p>
 */

public interface CalendaringProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if an event lookup service is supported. An event lookup service 
     *  defines methods to access events. 
     *
     *  @return true if event lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventLookup();


    /**
     *  Tests if an event query service is supported. 
     *
     *  @return <code> true </code> if event query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventQuery();


    /**
     *  Tests if an event search service is supported. 
     *
     *  @return <code> true </code> if event search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventSearch();


    /**
     *  Tests if an event administrative service is supported. 
     *
     *  @return <code> true </code> if event admin is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventAdmin();


    /**
     *  Tests if event notification is supported. Messages may be sent when 
     *  events are created, modified, or deleted. 
     *
     *  @return <code> true </code> if event notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventNotification();


    /**
     *  Tests if an event to calendar lookup session is available. 
     *
     *  @return <code> true </code> if event calendar lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventCalendar();


    /**
     *  Tests if an event to calendar assignment session is available. 
     *
     *  @return <code> true </code> if event calendar assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventCalendarAssignment();


    /**
     *  Tests if event smart calendaring is available. 
     *
     *  @return <code> true </code> if event smart calendaring is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventSmartCalendar();


    /**
     *  Tests if a recurring event lookup service is supported. 
     *
     *  @return true if recurring event lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventLookup();


    /**
     *  Tests if a recurring event unravelling service is supported. 
     *
     *  @return true if recurring event unravelling is supported, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventUnravelling();


    /**
     *  Tests if a recurring event query service is supported. 
     *
     *  @return <code> true </code> if recurring event query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventQuery();


    /**
     *  Tests if a recurring event search service is supported. 
     *
     *  @return <code> true </code> if recurring event search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventSearch();


    /**
     *  Tests if a recurring event administrative service is supported. 
     *
     *  @return <code> true </code> if recurring event admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventAdmin();


    /**
     *  Tests if recurring event notification is supported. Messages may be 
     *  sent when recurring events are created, modified, or deleted. 
     *
     *  @return <code> true </code> if recurring event notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventNotification();


    /**
     *  Tests if a recurring event to calendar lookup session is available. 
     *
     *  @return <code> true </code> if recurring event calendar lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventCalendar();


    /**
     *  Tests if a recurring event to calendar assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if recurring event calendar assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventCalendarAssignment();


    /**
     *  Tests if recurring event smart calendaring is available. 
     *
     *  @return <code> true </code> if recurring event smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventSmartCalendar();


    /**
     *  Tests if a superseding event lookup service is supported. A 
     *  superseding event lookup service defines methods to access superseding 
     *  events. 
     *
     *  @return true if superseding event lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventLookup();


    /**
     *  Tests if a superseding event query service is supported. 
     *
     *  @return <code> true </code> if superseding event query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventQuery();


    /**
     *  Tests if a superseding event search service is supported. 
     *
     *  @return <code> true </code> if superseding event search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventSearch();


    /**
     *  Tests if a superseding event administrative service is supported. 
     *
     *  @return <code> true </code> if superseding event admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventAdmin();


    /**
     *  Tests if superseding event notification is supported. Messages may be 
     *  sent when supsreding events are created, modified, or deleted. 
     *
     *  @return <code> true </code> if superseding event notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventNotification();


    /**
     *  Tests if superseding event to calendar lookup session is available. 
     *
     *  @return <code> true </code> if superseding event calendar lookup 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventCalendar();


    /**
     *  Tests if a superseding event to calendar assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if superseding event calendar assignment 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventCalendarAssignment();


    /**
     *  Tests if supsreding event smart calendaring is available. 
     *
     *  @return <code> true </code> if superseding smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventSmartCalendar();


    /**
     *  Tests if an offset event lookup service is supported. An offset event 
     *  lookup service defines methods to access events. 
     *
     *  @return true if offset event lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventLookup();


    /**
     *  Tests if an offset event query service is supported. 
     *
     *  @return <code> true </code> if offset event query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventQuery();


    /**
     *  Tests if an offset event search service is supported. 
     *
     *  @return <code> true </code> if offset event search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventSearch();


    /**
     *  Tests if an offset event administrative service is supported. 
     *
     *  @return <code> true </code> if offset event admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventAdmin();


    /**
     *  Tests if offset event notification is supported. Messages may be sent 
     *  when events are created, modified, or deleted. 
     *
     *  @return <code> true </code> if offset event notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventNotification();


    /**
     *  Tests if an offset event to calendar lookup session is available. 
     *
     *  @return <code> true </code> if event calendar lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventCalendar();


    /**
     *  Tests if an offset event to calendar assignment session is available. 
     *
     *  @return <code> true </code> if offset event calendar assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventCalendarAssignment();


    /**
     *  Tests if offset event smart calendaring is available. 
     *
     *  @return <code> true </code> if offset event smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventSmartCalendar();


    /**
     *  Tests if a schedule lookup service is supported. A schedule lookup 
     *  service defines methods to access schedules. 
     *
     *  @return true if schedule lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleLookup();


    /**
     *  Tests if a schedule query service is supported. 
     *
     *  @return <code> true </code> if schedule query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleQuery();


    /**
     *  Tests if a schedule search service is supported. 
     *
     *  @return <code> true </code> if schedule search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSearch();


    /**
     *  Tests if a schedule administrative service is supported. 
     *
     *  @return <code> true </code> if schedule admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleAdmin();


    /**
     *  Tests if schedule notification is supported. Messages may be sent when 
     *  schedules are created, modified, or deleted. 
     *
     *  @return <code> true </code> if schedule notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleNotification();


    /**
     *  Tests if a schedule to calendar lookup session is available. 
     *
     *  @return <code> true </code> if schedule calendar lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleCalendar();


    /**
     *  Tests if a schedule to calendar assignment session is available. 
     *
     *  @return <code> true </code> if schedule calendar assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleCalendarAssignment();


    /**
     *  Tests if schedule smart calendaring is available. 
     *
     *  @return <code> true </code> if schedule smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSmartCalendar();


    /**
     *  Tests if a schedule slot lookup service is supported. A schedule sot 
     *  lookup service defines methods to access schedule slots. 
     *
     *  @return true if schedule slot lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotLookup();


    /**
     *  Tests if a schedule slot query service is supported. 
     *
     *  @return <code> true </code> if schedule slot query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotQuery();


    /**
     *  Tests if a schedule slot search service is supported. 
     *
     *  @return <code> true </code> if schedule slots search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotSearch();


    /**
     *  Tests if a schedule slot administrative service is supported. 
     *
     *  @return <code> true </code> if schedule slot admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotAdmin();


    /**
     *  Tests if schedule slot notification is supported. Messages may be sent 
     *  when schedule slots are created, modified, or deleted. 
     *
     *  @return <code> true </code> if schedule slot notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotNotification();


    /**
     *  Tests if a schedule slot to calendar lookup session is available. 
     *
     *  @return <code> true </code> if schedule slot calendar lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotCalendar();


    /**
     *  Tests if a schedule slot to calendar assignment session is available. 
     *
     *  @return <code> true </code> if schedule slot calendar assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotCalendarAssignment();


    /**
     *  Tests if schedule slot smart calendaring is available. 
     *
     *  @return <code> true </code> if schedule slot smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotSmartCalendar();


    /**
     *  Tests if an event commitment lookup service is supported. 
     *
     *  @return <code> true </code> if commitment lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentLookup();


    /**
     *  Tests if a commitment query service is supported. 
     *
     *  @return <code> true </code> if commitment query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentQuery();


    /**
     *  Tests if a commitment search service is supported. 
     *
     *  @return <code> true </code> if commitment search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentSearch();


    /**
     *  Tests if a commitment administrative service is supported. 
     *
     *  @return <code> true </code> if commitment admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentAdmin();


    /**
     *  Tests if commitment notification is supported. Messages may be sent 
     *  when commitments are created, modified, or deleted. 
     *
     *  @return <code> true </code> if commitment notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentNotification();


    /**
     *  Tests if a commitment to calendar lookup session is available. 
     *
     *  @return <code> true </code> if commitment calendar lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentCalendar();


    /**
     *  Tests if a commitment to calendar assignment session is available. 
     *
     *  @return <code> true </code> if commitment calendar assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentCalendarAssignment();


    /**
     *  Tests if commitment smart calendaring is available. 
     *
     *  @return <code> true </code> if commitment smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentSmartCalendar();


    /**
     *  Tests if a time period lookup service is supported. 
     *
     *  @return <code> true </code> if time period lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodLookup();


    /**
     *  Tests if a time period search service is supported. 
     *
     *  @return <code> true </code> if time period search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodSearch();


    /**
     *  Tests if a time period administrative service is supported. 
     *
     *  @return <code> true </code> if time period admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodAdmin();


    /**
     *  Tests if time period notification is supported. Messages may be sent 
     *  when time periods are created, modified, or deleted. 
     *
     *  @return <code> true </code> if time period notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodNotification();


    /**
     *  Tests if a time period to calendar lookup session is available. 
     *
     *  @return <code> true </code> if time period calendar lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodCalendar();


    /**
     *  Tests if a time period to calendar assignment session is available. 
     *
     *  @return <code> true </code> if time period calendar assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodCalendarAssignment();


    /**
     *  Tests if time period smart calendaring is available. 
     *
     *  @return <code> true </code> if time period smart calendaring is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodSmartCalendar();


    /**
     *  Tests if a calendar lookup service is supported. 
     *
     *  @return <code> true </code> if calendar lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarLookup();


    /**
     *  Tests if a calendar search service is supported. 
     *
     *  @return <code> true </code> if calendar search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarSearch();


    /**
     *  Tests if a calendar administrative service is supported. 
     *
     *  @return <code> true </code> if calendar admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarAdmin();


    /**
     *  Tests if calendar notification is supported. Messages may be sent when 
     *  calendars are created, modified, or deleted. 
     *
     *  @return <code> true </code> if calendar notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarNotification();


    /**
     *  Tests if a calendar hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a calendar hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarHierarchy();


    /**
     *  Tests if calendar hierarchy design is supported. 
     *
     *  @return <code> true </code> if a calendar hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarHierarchyDesign();


    /**
     *  Tests if a calendaring batch subpackage is supported. 
     *
     *  @return <code> true </code> if a calendar batch package is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendaringBatch();


    /**
     *  Tests if a calendaring cycle subpackage is supported. 
     *
     *  @return <code> true </code> if a calendar cycle package is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendaringCycle();


    /**
     *  Tests if a calendaring rules subpackage is supported. 
     *
     *  @return <code> true </code> if a calendar rules package is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendaringRules();


    /**
     *  Gets the supported <code> Event </code> record types. 
     *
     *  @return a list containing the supported <code> Event </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEventRecordTypes();


    /**
     *  Tests if the given <code> Event </code> record type is supported. 
     *
     *  @param  eventRecordType a <code> Type </code> indicating an <code> 
     *          Event </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> eventRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventRecordType(org.osid.type.Type eventRecordType);


    /**
     *  Gets the supported <code> Event </code> search record types. 
     *
     *  @return a list containing the supported <code> Event </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEventSearchRecordTypes();


    /**
     *  Tests if the given <code> Event </code> search record type is 
     *  supported. 
     *
     *  @param  eventSearchRecordType a <code> Type </code> indicating an 
     *          <code> Event </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> eventSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventSearchRecordType(org.osid.type.Type eventSearchRecordType);


    /**
     *  Gets the supported <code> RecurringEvent </code> record types. 
     *
     *  @return a list containing the supported <code> RecurringEvent </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRecurringEventRecordTypes();


    /**
     *  Tests if the given <code> RecurringEvent </code> record type is 
     *  supported. 
     *
     *  @param  recurringEventRecordType a <code> Type </code> indicating a 
     *          <code> RecurringEvent </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> recurringEventRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventRecordType(org.osid.type.Type recurringEventRecordType);


    /**
     *  Gets the supported <code> RecurringEvent </code> search record types. 
     *
     *  @return a list containing the supported <code> RecurringEvent </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRecurringEventSearchRecordTypes();


    /**
     *  Tests if the given <code> RecurringEvent </code> search record type is 
     *  supported. 
     *
     *  @param  recurringEventSearchRecordType a <code> Type </code> 
     *          indicating a <code> RecurringEvent </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventSearchRecordType(org.osid.type.Type recurringEventSearchRecordType);


    /**
     *  Gets the supported <code> Superseding </code> record types. 
     *
     *  @return a list containing the supported <code> SupersedingEvent 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSupersedingEventRecordTypes();


    /**
     *  Tests if the given <code> SupersedingEvent </code> record type is 
     *  supported. 
     *
     *  @param  supersedingEventRecordType a <code> Type </code> indicating a 
     *          <code> SupersedingEvent </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventRecordType(org.osid.type.Type supersedingEventRecordType);


    /**
     *  Gets the supported <code> SupersedingEvent </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> SupersedingEvent 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSupersedingEventSearchRecordTypes();


    /**
     *  Tests if the given <code> SupersedingEvent </code> search record type 
     *  is supported. 
     *
     *  @param  supersedingEventSearchRecordType a <code> Type </code> 
     *          indicating a <code> SupersedingEvent </code> search record 
     *          type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventSearchRecordType(org.osid.type.Type supersedingEventSearchRecordType);


    /**
     *  Gets the supported <code> OffsetEvent </code> record types. 
     *
     *  @return a list containing the supported <code> OffsetEvent </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOffsetEventRecordTypes();


    /**
     *  Tests if the given <code> OffsetEvent </code> record type is 
     *  supported. 
     *
     *  @param  offsetEventRecordType a <code> Type </code> indicating a 
     *          <code> OffsetEvent </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> offsetEventRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventRecordType(org.osid.type.Type offsetEventRecordType);


    /**
     *  Gets the supported <code> OffsetEvent </code> search record types. 
     *
     *  @return a list containing the supported <code> OffsetEvent </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOffsetEventSearchRecordTypes();


    /**
     *  Tests if the given <code> OffsetEvent </code> search record type is 
     *  supported. 
     *
     *  @param  offsetEventSearchRecordType a <code> Type </code> indicating a 
     *          <code> OffsetEvent </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventSearchRecordType(org.osid.type.Type offsetEventSearchRecordType);


    /**
     *  Gets the supported <code> Schedule </code> record types. 
     *
     *  @return a list containing the supported <code> Schedule </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getScheduleRecordTypes();


    /**
     *  Tests if the given <code> Schedule </code> record type is supported. 
     *
     *  @param  scheduleRecordType a <code> Type </code> indicating a <code> 
     *          Schedule </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> scheduleRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleRecordType(org.osid.type.Type scheduleRecordType);


    /**
     *  Gets the supported <code> Schedule </code> search record types. 
     *
     *  @return a list containing the supported <code> Schedule </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getScheduleSearchRecordTypes();


    /**
     *  Tests if the given <code> Schedule </code> search record type is 
     *  supported. 
     *
     *  @param  scheduleSearchRecordType a <code> Type </code> indicating a 
     *          <code> Schedule </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> scheduleSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSearchRecordType(org.osid.type.Type scheduleSearchRecordType);


    /**
     *  Gets the supported <code> ScheduleSlot </code> record types. 
     *
     *  @return a list containing the supported <code> ScheduleSlot </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getScheduleSlotRecordTypes();


    /**
     *  Tests if the given <code> ScheduleSlot </code> record type is 
     *  supported. 
     *
     *  @param  scheduleSlotRecordType a <code> Type </code> indicating a 
     *          <code> ScheduleSlot </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotRecordType(org.osid.type.Type scheduleSlotRecordType);


    /**
     *  Gets the supported <code> ScheduleSlot </code> search record types. 
     *
     *  @return a list containing the supported <code> ScheduleSlot </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getScheduleSlotSearchRecordTypes();


    /**
     *  Tests if the given <code> ScheduleSlot </code> search record type is 
     *  supported. 
     *
     *  @param  scheduleSlotSearchRecordType a <code> Type </code> indicating 
     *          a <code> ScheduleSlot </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          scheduleSlotSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotSearchRecordType(org.osid.type.Type scheduleSlotSearchRecordType);


    /**
     *  Gets the supported <code> TimePeriod </code> record types. 
     *
     *  @return a list containing the supported <code> TimePeriod </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTimePeriodRecordTypes();


    /**
     *  Tests if the given <code> TimePeriod </code> record type is supported. 
     *
     *  @param  timePeriodRecordType a <code> Type </code> indicating a <code> 
     *          TimePeriod </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> timePeriodRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodRecordType(org.osid.type.Type timePeriodRecordType);


    /**
     *  Gets the supported <code> TimePeriod </code> search record types. 
     *
     *  @return a list containing the supported <code> TimePeriod </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTimePeriodSearchRecordTypes();


    /**
     *  Tests if the given <code> TimePeriod </code> search record type is 
     *  supported. 
     *
     *  @param  timePeriodSearchRecordType a <code> Type </code> indicating a 
     *          <code> TimePeriod </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          timePeriodSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodSearchRecordType(org.osid.type.Type timePeriodSearchRecordType);


    /**
     *  Gets the supported <code> Commitment </code> record types. 
     *
     *  @return a list containing the supported <code> Commitment </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommitmentRecordTypes();


    /**
     *  Tests if the given <code> Commitment </code> record type is supported. 
     *
     *  @param  commitmentRecordType a <code> Type </code> indicating a <code> 
     *          Commitment </code> type 
     *  @return <code> true </code> if the given commitment record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> commitmentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentRecordType(org.osid.type.Type commitmentRecordType);


    /**
     *  Gets the supported commitment search record types. 
     *
     *  @return a list containing the supported <code> Commitment </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommitmentSearchRecordTypes();


    /**
     *  Tests if the given commitment search record type is supported. 
     *
     *  @param  commitmentSearchRecordType a <code> Type </code> indicating a 
     *          <code> Commitment </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentSearchRecordType(org.osid.type.Type commitmentSearchRecordType);


    /**
     *  Gets the supported <code> Calendar </code> record types. 
     *
     *  @return a list containing the supported <code> Calendar </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCalendarRecordTypes();


    /**
     *  Tests if the given <code> Calendar </code> record type is supported. 
     *
     *  @param  calendarRecordType a <code> Type </code> indicating a <code> 
     *          Calendar </code> type 
     *  @return <code> true </code> if the given calendar record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> calendarRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarRecordType(org.osid.type.Type calendarRecordType);


    /**
     *  Gets the supported calendar search record types. 
     *
     *  @return a list containing the supported <code> Calendar </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCalendarSearchRecordTypes();


    /**
     *  Tests if the given calendar search record type is supported. 
     *
     *  @param  calendarSearchRecordType a <code> Type </code> indicating a 
     *          <code> Calendar </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> calendarSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarSearchRecordType(org.osid.type.Type calendarSearchRecordType);


    /**
     *  Gets all the spatial unit record types supported. 
     *
     *  @return the list of supported spatial unit record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpatialUnitRecordTypes();


    /**
     *  Tests if a given spatial unit record type is supported. 
     *
     *  @param  spatialUnitRecordType the spatial unit record type 
     *  @return <code> true </code> if the spatial unit record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> spatialUnitRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpatialUnitRecordType(org.osid.type.Type spatialUnitRecordType);


    /**
     *  Gets all the coordinate record types supported. 
     *
     *  @return the list of supported coordinate record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCoordinateRecordTypes();


    /**
     *  Tests if a given coordinate record type is supported. 
     *
     *  @param  coordinateRecordType the coordinate domain type 
     *  @return <code> true </code> if the coordinate record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> coordinateRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoordinateRecordType(org.osid.type.Type coordinateRecordType);
}
