//
// org.osid.calendaring.Duration
//
//     The OSID Java specification for org.osid.calendaring.Duration.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>The <code> Duration </code> a length of time. </p> 
 *  
 *  <p> While a <code> DateTime </code> represents a point on a calendar and a 
 *  tick on a clock, a <code> Duration </code> represents a measurement. Each 
 *  of these methods returns the total absolute measurement in the specified 
 *  units. </p>
 */

public interface Duration
    extends org.osid.OsidPrimitive,
            org.osid.binding.java.Duration {


    /**
     *  Gets the calendar type. 
     *
     *  @return the calendar type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCalendarType();


    /**
     *  Gets the time type. 
     *
     *  @return the time type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTimeType();


    /**
     *  Gets the number of aeons. An aeon is 1B years. 
     *
     *  @return the number of aeons 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getAeons();


    /**
     *  Gets the number of epochs. An epoch is 1M years. 
     *
     *  @return the number of epochs 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getEpochs();


    /**
     *  Gets the number of millennia. A millennium is 1,000 years. 
     *
     *  @return the number of millennia 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMillennia();


    /**
     *  Gets the number of centuries. 
     *
     *  @return the number of centuries 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getCenturies();


    /**
     *  Gets the number of scores. 
     *
     *  @return the number of scores 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getScores();


    /**
     *  Gets the number of blue moons. 
     *
     *  @return the number of blue moons 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getBluemoons();


    /**
     *  Gets the number of years. 
     *
     *  @return the number of years 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getYears();


    /**
     *  Gets the number of months. 
     *
     *  @return the number of months 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMonths();


    /**
     *  Gets the number of weeks. 
     *
     *  @return the number of weeks 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getWeeks();


    /**
     *  Gets the number of days. 
     *
     *  @return the number of days 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getDays();


    /**
     *  Gets the number of hours. 
     *
     *  @return the number of hours 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getHours();


    /**
     *  Gets the number of minutes. 
     *
     *  @return the number of minutes 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMinutes();


    /**
     *  Gets the number of seconds. 
     *
     *  @return the number of seconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getSeconds();


    /**
     *  Gets the number of milliseconds. A millisecond is one thousandth of a 
     *  second. 
     *
     *  @return the number of milliseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMilliseconds();


    /**
     *  Gets the number of microseconds. A microsecond is one millionth of a 
     *  second. 
     *
     *  @return the number of micrseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMicroseconds();


    /**
     *  Gets the number of nanoseconds. A nanosecond is one billionth of a 
     *  second. 
     *
     *  @return the number of nanoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getNanoseconds();


    /**
     *  Gets the number of picoseconds. A picosecond is one trillionth of a 
     *  second. 
     *
     *  @return the number of picoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getPicoseconds();


    /**
     *  Gets the number of femtoseconds. A femtosecond is one quadrillionth of 
     *  a second. 
     *
     *  @return the number of femtoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getFemtoseconds();


    /**
     *  Gets the number of attoseconds. An attosecond is one quintillionth of 
     *  a second. 
     *
     *  @return the number of attoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getAttoseconds();


    /**
     *  Gets the number of zeptoseconds. A zeptosecond is one sextillionth of 
     *  a second. 
     *
     *  @return the number of zeptoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getZeptoseconds();


    /**
     *  Gets the number of yoctoseconds. A yoctosecond is one septillionth of 
     *  a second. This is getting quite small. 
     *
     *  @return the number of yoctoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getYoctoseconds();


    /**
     *  Gets the number of xoxxoseconds. A xoxxosecond is one octillionth of a 
     *  second. We're going with Rudy Rucker here. 
     *
     *  @return the number of xoxxoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getXoxxoseconds();


    /**
     *  Gets the number of weebleseconds. A weeblesecond is one nonillionth of 
     *  a second. 
     *
     *  @return the number of weebleseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getWeebleseconds();


    /**
     *  Gets the number of vatoseconds. A vatosecond is one decillionth of a 
     *  second. 
     *
     *  @return the number of vatoseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getVatoseconds();


    /**
     *  Gets the number of undaseconds. An undasecond is one unadecillionth of 
     *  a second. 
     *
     *  @return the number of undaseconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getUndaseconds();


    /**
     *  Gets the number of Planck sseconds. A Planck is 10 
     *  quattuordecillionths of a second. 
     *
     *  @return the number of planck seconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getPlanckSeconds();


    /**
     *  Gets the granularity of this duration. The granularity indicates the 
     *  resolution of the clock. More precision than what is specified in this 
     *  method cannot be inferred from the available data. 
     *
     *  @return the time units 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTimeResolution getGranularity();


    /**
     *  If the granularity of the time equals <code> getGranularity(), </code> 
     *  then the multiplier is 1. This method may return a different number 
     *  when the granularity differs from one of the defined resolutions. 
     *
     *  @return granularity multiplier 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getGranularityMultiplier();


    /**
     *  Tests if uncertainty is defined for this time. 
     *
     *  @return <code> true </code> if uncertainty is defined, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean definesUncertainty();


    /**
     *  Gets the units of the uncertainty. 
     *
     *  @return units of the uncertainty 
     *  @throws org.osid.IllegalStateException <code> definesUncertainty() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTimeResolution getUncertaintyUnits();


    /**
     *  Gets the uncertainty of this time in the negative direction. 
     *
     *  @return the uncertainty under this value 
     *  @throws org.osid.IllegalStateException <code> definesUncertainty() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getUncertaintyMinus();


    /**
     *  Gets the uncertainty of this time in the positive direction. 
     *
     *  @return the uncertainty over this value 
     *  @throws org.osid.IllegalStateException <code> definesUncertainty() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getUncertaintyPlus();
}
