//
// org.osid.calendaring.Event
//
//     The OSID Java specification for org.osid.calendaring.Event.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>An <code> Event </code> represents a span of time and an optional 
 *  location. </p>
 */

public interface Event
    extends org.osid.OsidObject,
            org.osid.Temporal,
            org.osid.Containable {


    /**
     *  Tests if this event is implicit. An implicit event is one that is 
     *  generated from an offset or recurring series. 
     *
     *  @return <code> true </code> if this event is implicit, <code> false 
     *          </code> if explicitly defined 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isImplicit();


    /**
     *  Tests if this event is an implclit event part of a recurring event. If 
     *  true, <code> isImplicit() </code> must also be true. 
     *
     *  @return <code> true </code> if this event is part of a recurring 
     *          series, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isInRecurringSeries();


    /**
     *  Tests if this event is a superseding event. If true, <code> 
     *  isImplicit() </code> must also be true. 
     *
     *  @return <code> true </code> if this event is superseding event, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSupersedingEvent();


    /**
     *  Tests if this event is an event calculated from an offset. If true, 
     *  <code> isImplicit() </code> must also be true. 
     *
     *  @return <code> true </code> if this event is an offset event, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOffsetEvent();


    /**
     *  Gets the duration of the event. 
     *
     *  @param  units the units of the duration 
     *  @return the duration 
     *  @throws org.osid.NullArgumentException <code> units </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getDuration(org.osid.calendaring.DateTimeResolution units);


    /**
     *  Gets a descriptive location. 
     *
     *  @return the location 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getLocationDescription();


    /**
     *  Tests if a location is associated with this event. 
     *
     *  @return <code> true </code> if there is an associated location, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLocation();


    /**
     *  Gets the location <code> Id </code> . 
     *
     *  @return a location <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLocationId();


    /**
     *  Gets the <code> Location. </code> 
     *
     *  @return a location 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Location getLocation()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a sponsor is associated with this event. 
     *
     *  @return <code> true </code> if there is an associated sponsor. <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSponsors();


    /**
     *  Gets the <code> Id </code> of the event sponsors. 
     *
     *  @return the sponsor <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSponsorIds();


    /**
     *  Gets the <code> Sponsors. </code> 
     *
     *  @return the sponsors 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getSponsors()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the event record corresponding to the given <code> Event </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> eventRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(eventRecordType) </code> is <code> true </code> . 
     *
     *  @param  eventRecordType the type of the record to retrieve 
     *  @return the event record 
     *  @throws org.osid.NullArgumentException <code> eventRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(eventRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.EventRecord getEventRecord(org.osid.type.Type eventRecordType)
        throws org.osid.OperationFailedException;
}
