//
// org.osid.calendaring.EventForm
//
//     The OSID Java specification for org.osid.calendaring.EventForm.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the form for creating and updating <code> Events. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> EventAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface EventForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidTemporalForm,
            org.osid.OsidContainableForm {


    /**
     *  Gets the metadata for a location description. 
     *
     *  @return metadata for the location description 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLocationDescriptionMetadata();


    /**
     *  Sets the location description. 
     *
     *  @param  location the new location description 
     *  @throws org.osid.InvalidArgumentException <code> location </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> location </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> location </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocationDescription(String location);


    /**
     *  Clears the location description. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationDescription();


    /**
     *  Gets the metadata for a location. 
     *
     *  @return metadata for the location 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLocationMetadata();


    /**
     *  Sets the location. 
     *
     *  @param  locationId the new location 
     *  @throws org.osid.InvalidArgumentException <code> locationId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> locationId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocation(org.osid.id.Id locationId);


    /**
     *  Clears the location. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocation();


    /**
     *  Gets the metadata for a sponsor. 
     *
     *  @return metadata for the sponsor 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSponsorMetadata();


    /**
     *  Sets the sponsors. 
     *
     *  @param  sponsorIds the new sponsor 
     *  @throws org.osid.InvalidArgumentException <code> sponsorIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> sponsorIds </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> sponsorIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSponsors(org.osid.id.Id[] sponsorIds);


    /**
     *  Clears the sponsors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsors();


    /**
     *  Gets the <code> EventFormRecord </code> corresponding to the given 
     *  event record <code> Type. </code> 
     *
     *  @param  eventRecordType the event record type 
     *  @return the event form record 
     *  @throws org.osid.NullArgumentException <code> eventRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(eventRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.EventFormRecord getEventFormRecord(org.osid.type.Type eventRecordType)
        throws org.osid.OperationFailedException;
}
