//
// org.osid.calendaring.EventLookupSession
//
//     The OSID Java specification for org.osid.calendaring.EventLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for retrieving <code> Event </code> s. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All event methods in this session 
 *      operate, retrieve and pertain to events defined explicitly in the 
 *      current calendar. Using an isolated view is useful for managing events 
 *      with the <code> EventAdminSession. </code> </li> 
 *      <li> federated calendar view: All event methods in this session 
 *      operate, retrieve and pertain to all events defined in this calendar 
 *      and any other calendars implicitly available in this calendar through 
 *      calendar inheritence. </li> 
 *      <li> effective event view: All events lookup methods return events 
 *      where the current date falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective event view: Events of any effective date are 
 *      returned from methods. </li> 
 *      <li> denormalized event view: recurring events are expanded into a 
 *      series of non-recurring events </li> 
 *      <li> normalized event view: recurring events are represented by a 
 *      single event </li> 
 *      <li> sequestered event viiew: All event methods suppress sequestered 
 *      events. </li> 
 *      <li> unsequestered event view: All event methods return all events. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Events may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Event. </code> </p>
 */

public interface EventLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Event </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupEvents();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeEventView();


    /**
     *  A complete view of the <code> Event </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryEventView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include events in calendars which are children of this calendar in the 
     *  calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Only events whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveEventView();


    /**
     *  All events of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveEventView();


    /**
     *  A normalized view uses a single <code> Event </code> to represent a 
     *  set of recurring events. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useNormalizedEventView();


    /**
     *  A denormalized view expands recurring events into a series of <code> 
     *  Events. </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useDenormalizedEventView();


    /**
     *  The returns from the lookup methods omit sequestered events. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredEventView();


    /**
     *  All events are returned including sequestered events. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredEventView();


    /**
     *  Gets the <code> Event </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Event </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to 
     *  an <code> Event </code> and retained for compatibility. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  eventId <code> Id </code> of the <code> Event </code> 
     *  @return the event 
     *  @throws org.osid.NotFoundException <code> eventId </code> not found 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.Event getEvent(org.osid.id.Id eventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  events specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Events </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  eventIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> eventIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsByIds(org.osid.id.IdList eventIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> corresponding to the given event 
     *  genus <code> Type </code> which does not include events of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  eventGenusType an event genus type 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.NullArgumentException <code> eventGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsByGenusType(org.osid.type.Type eventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> corresponding to the given event 
     *  genus <code> Type </code> and include any additional event with genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  eventGenusType an event genus type 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.NullArgumentException <code> eventGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsByParentGenusType(org.osid.type.Type eventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> containing the given event record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *
     *  @param  eventRecordType an event record type 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.NullArgumentException <code> eventRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsByRecordType(org.osid.type.Type eventRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of events where the given date range falls within an event 
     *  inclusive. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsOnDate(org.osid.calendaring.DateTime from, 
                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> that fall within the given range 
     *  inclusive <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsInDateRange(org.osid.calendaring.DateTime from, 
                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the next upcoming events on this calendar. 
     *  
     *  In plenary mode, the returned list contains all known events or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  number the number of events 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getUpcomingEvents(long number)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of events with the given location. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  locationId a location 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsByLocation(org.osid.id.Id locationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> at the given location where the given 
     *  date range falls within the event dates inclusive. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  locationId a location 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> locationId, from </code> 
     *          , or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsByLocationOnDate(org.osid.id.Id locationId, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> that fall within the given range 
     *  inclusive at the given location <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  locationId a location 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> locationId, from </code> 
     *          , or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsByLocationInDateRange(org.osid.id.Id locationId, 
                                                                         org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of events with the given sponsor. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  resourceId a sponsor 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsBySponsor(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> with the given sponsor where the 
     *  given date range falls within the event dates inclusive. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  resourceId a sponsor 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsBySponsorOnDate(org.osid.id.Id resourceId, 
                                                                   org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EventList </code> that fall within the given range 
     *  inclusive at the given location <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @param  resourceId a sponsor 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Event </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEventsBySponsorInDateRange(org.osid.id.Id resourceId, 
                                                                        org.osid.calendaring.DateTime from, 
                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Events. </code> 
     *  
     *  In plenary mode, the returned list contains all known events or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  events that are accessible through this session. 
     *  
     *  In normalized mode, recurring events appear as a single event. In 
     *  denormalized mode, each element in the recurring series appears as a 
     *  separate event. 
     *  
     *  In effective mode, events are returned that are currently effective. 
     *  In any effective mode, effective events and those currently expired 
     *  are returned. 
     *  
     *  In sequestered mode, no sequestered events are returned. In 
     *  unsequestered mode, all events are returned. 
     *
     *  @return an <code> EventList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEvents()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
