//
// org.osid.calendaring.EventQueryInspector
//
//     The OSID Java specification for org.osid.calendaring.EventQueryInspector.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query inspector for examining event queries. </p>
 */

public interface EventQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidTemporalQueryInspector,
            org.osid.OsidContainableQueryInspector {


    /**
     *  Gets the implicit terms. 
     *
     *  @return the implicit terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getImplicitTerms();


    /**
     *  Gets the duration terms. 
     *
     *  @return the duration terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationTerm[] getDurationTerms();


    /**
     *  Gets the recurring event <code> Id </code> terms. 
     *
     *  @return the recurring event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRecurringEventIdTerms();


    /**
     *  Gets the recurring event terms. 
     *
     *  @return the recurring event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventQueryInspector[] getRecurringEventTerms();


    /**
     *  Gets the superseding event <code> Id </code> terms. 
     *
     *  @return the superseding event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSupersedingEventIdTerms();


    /**
     *  Gets the superseding event terms. 
     *
     *  @return the superseding event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventQueryInspector[] getSupersedingEventTerms();


    /**
     *  Gets the offset event <code> Id </code> terms. 
     *
     *  @return the offset event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getOffsetEventIdTerms();


    /**
     *  Gets the offset event terms. 
     *
     *  @return the offset event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventQueryInspector[] getOffsetEventTerms();


    /**
     *  Gets the location description terms. 
     *
     *  @return the location description terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getLocationDescriptionTerms();


    /**
     *  Gets the location <code> Id </code> terms. 
     *
     *  @return the location <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLocationIdTerms();


    /**
     *  Gets the location terms. 
     *
     *  @return the location terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationQueryInspector[] getLocationTerms();


    /**
     *  Gets the sponsor <code> Id </code> terms. 
     *
     *  @return the sponsor <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSponsorIdTerms();


    /**
     *  Gets the sponsor terms. 
     *
     *  @return the sponsor terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getSponsorTerms();


    /**
     *  Gets the coordinate terms. 
     *
     *  @return the coordinate terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CoordinateTerm[] getCoordinateTerms();


    /**
     *  Gets the spatial unit terms. 
     *
     *  @return the spatial unit terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.SpatialUnitTerm[] getSpatialUnitTerms();


    /**
     *  Gets the commitment <code> Id </code> terms. 
     *
     *  @return the commitment <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCommitmentIdTerms();


    /**
     *  Gets the commitment terms. 
     *
     *  @return the commitment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CommitmentQueryInspector[] getCommitmentTerms();


    /**
     *  Gets the containing event <code> Id </code> terms. 
     *
     *  @return the event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getContainingEventIdTerms();


    /**
     *  Gets the containing event terms. 
     *
     *  @return the event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getContainingEventTerms();


    /**
     *  Gets the calendar <code> Id </code> terms. 
     *
     *  @return the calendar <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCalendarIdTerms();


    /**
     *  Gets the calendar terms. 
     *
     *  @return the calendar terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CalendarQueryInspector[] getCalendarTerms();


    /**
     *  Gets the event query inspector record corresponding to the given 
     *  <code> Event </code> record <code> Type. </code> 
     *
     *  @param  eventRecordType an event query record type 
     *  @return the event query inspector record 
     *  @throws org.osid.NullArgumentException <code> eventRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(eventRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.EventQueryInspectorRecord getEventQueryInspectorRecord(org.osid.type.Type eventRecordType)
        throws org.osid.OperationFailedException;
}
