//
// org.osid.calendaring.EventSearchOrder
//
//     The OSID Java specification for org.osid.calendaring.EventSearchOrder.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface EventSearchOrder
    extends org.osid.OsidObjectSearchOrder,
            org.osid.OsidTemporalSearchOrder,
            org.osid.OsidContainableSearchOrder {


    /**
     *  Specified a preference for ordering results by the duration. For 
     *  recurring events, the duration is the duration of a single event. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDuration(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the recurring event. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRecurringEvent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> RecurringEventSearchOrder </code> is available for 
     *  recurring events. 
     *
     *  @return <code> true </code> if a recurring event search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventSearchOrder();


    /**
     *  Gets the search order for a recurring event. 
     *
     *  @return the recurring event search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.RecurringEventSearchOrder getRecurringEventSearchOrder();


    /**
     *  Specified a preference for ordering results by the superseding event. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySupersedingEvent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> SupersedingEventSearchOrder </code> is available for 
     *  offset events. 
     *
     *  @return <code> true </code> if a superseding event search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventSearchOrder();


    /**
     *  Gets the search order for a superseding event. 
     *
     *  @return the superseding event search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.SupersedingEventSearchOrder getSupersedingEventSearchOrder();


    /**
     *  Specified a preference for ordering results by the offset event. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByOffsetEvent(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> OffsetEventSearchOrder </code> is available for 
     *  offset events. 
     *
     *  @return <code> true </code> if an offset event search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventSearchOrder();


    /**
     *  Gets the search order for an offset event. 
     *
     *  @return the offset event search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.OffsetEventSearchOrder getOffsetEventSearchOrder();


    /**
     *  Specified a preference for ordering results by the location 
     *  description. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLocationDescription(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the location. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLocation(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> LocationSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a location search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationSearchOrder();


    /**
     *  Gets the search order for a location. 
     *
     *  @return the location search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLocationSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationSearchOrder getLocationSearchOrder();


    /**
     *  Gets the event search order record corresponding to the given event 
     *  record <code> Type. </code> Multiple retrievals return the same 
     *  underlying object. 
     *
     *  @param  eventRecordType an event record type 
     *  @return the event search order record 
     *  @throws org.osid.NullArgumentException <code> eventRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(eventRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.EventSearchOrderRecord getEventSearchOrderRecord(org.osid.type.Type eventRecordType)
        throws org.osid.OperationFailedException;
}
