//
// org.osid.calendaring.OffsetEventForm
//
//     The OSID Java specification for org.osid.calendaring.OffsetEventForm.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the form for creating and updating <code> OffsetEvents. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  OffsetEventAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface OffsetEventForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for the fixed start time. 
     *
     *  @return metadata for the fixed start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFixedStartTimeMetadata();


    /**
     *  Sets the fixed start time. 
     *
     *  @param  date the fixed start time 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFixedStartTime(org.osid.calendaring.DateTime date);


    /**
     *  Clears the fixed start time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedStartTime();


    /**
     *  Gets the metadata for the starting reference event. 
     *
     *  @return metadata for the starting reference event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStartReferenceEventMetadata();


    /**
     *  Sets the fixed start time. 
     *
     *  @param  eventId the start reference event <code> Id </code> 
     *  @throws org.osid.InvalidArgumentException <code> eventId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> eventId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStartReferenceEvent(org.osid.id.Id eventId);


    /**
     *  Clears the start reference event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartReferenceEvent();


    /**
     *  Gets the metadata for the fixed start offset. 
     *
     *  @return metadata for the fixed start offset 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFixedStartOffsetMetadata();


    /**
     *  Sets the fixed start offset. 
     *
     *  @param  offset the fixed offset 
     *  @throws org.osid.InvalidArgumentException <code> offset </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> offset </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> offset </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFixedStartOffset(org.osid.calendaring.Duration offset);


    /**
     *  Clears the fixed start offset. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedStartOffset();


    /**
     *  Gets the metadata for the relative weekday offset. 
     *
     *  @return metadata for the relative weekday offset 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRelativeWeekdayStartOffsetMetadata();


    /**
     *  Sets the relative weekday offset as the nth weekday from the relative 
     *  event. 
     *
     *  @param  offset the week offset 
     *  @throws org.osid.InvalidArgumentException <code> offset </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> offset </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRelativeWeekdayStartOffset(long offset);


    /**
     *  Clears the relative weekday offset. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeWeekdayStartOffset();


    /**
     *  Gets the metadata for the relative weekday. 
     *
     *  @return metadata for the relative weekday 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRelativeStartWeekdayMetadata();


    /**
     *  Sets the relative weekday. 
     *
     *  @param  weekday the weekday 
     *  @throws org.osid.InvalidArgumentException <code> weekday </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> weekday </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRelativeStartWeekday(long weekday);


    /**
     *  Clears the relative start weekday. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeStartWeekday();


    /**
     *  Gets the metadata for the fixed duration. 
     *
     *  @return metadata for the fixed duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFixedDurationMetadata();


    /**
     *  Sets the fixed duration. 
     *
     *  @param  duration the fixed duration 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> duration </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFixedDuration(org.osid.calendaring.Duration duration);


    /**
     *  Clears the fixed duration. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedDuration();


    /**
     *  Gets the metadata for the ending reference event. 
     *
     *  @return metadata for the ending reference event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEndReferenceEventMetadata();


    /**
     *  Sets the fixed end time. 
     *
     *  @param  eventId the end reference event <code> Id </code> 
     *  @throws org.osid.InvalidArgumentException <code> eventId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> eventId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEndReferenceEvent(org.osid.id.Id eventId);


    /**
     *  Clears the ending reference event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndReferenceEvent();


    /**
     *  Gets the metadata for the fixed end offset. 
     *
     *  @return metadata for the fixed end offset 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFixedEndOffsetMetadata();


    /**
     *  Sets the fixed end offset. 
     *
     *  @param  offset the fixed offset 
     *  @throws org.osid.InvalidArgumentException <code> offset </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> offset </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> offset </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFixedEndOffset(org.osid.calendaring.Duration offset);


    /**
     *  Clears the fixed end offset. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedEndOffset();


    /**
     *  Gets the metadata for the relative weekday offset. 
     *
     *  @return metadata for the relative weekday offset 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRelativeWeekdayEndOffsetMetadata();


    /**
     *  Sets the relative weekday offset as the nth weekday from the relative 
     *  event. 
     *
     *  @param  offset the week offset 
     *  @throws org.osid.InvalidArgumentException <code> offset </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> offset </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRelativeWeekdayEndOffset(long offset);


    /**
     *  Clears the relative weekday offset. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeWeekdayEndOffset();


    /**
     *  Gets the metadata for the relative weekday. 
     *
     *  @return metadata for the relative weekday 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRelativeEndWeekdayMetadata();


    /**
     *  Sets the relative weekday. 
     *
     *  @param  weekday the weekday 
     *  @throws org.osid.InvalidArgumentException <code> weekday </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> weekday </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRelativeEndWeekday(long weekday);


    /**
     *  Clears the relative end weekday. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelativeEndWeekday();


    /**
     *  Gets the metadata for a location description. 
     *
     *  @return metadata for the location description 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLocationDescriptionMetadata();


    /**
     *  Sets the location description. 
     *
     *  @param  location the new location description 
     *  @throws org.osid.InvalidArgumentException <code> location </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> location </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> location </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocationDescription(String location);


    /**
     *  Clears the location description. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationDescription();


    /**
     *  Gets the metadata for a location. 
     *
     *  @return metadata for the location 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLocationMetadata();


    /**
     *  Sets the location. 
     *
     *  @param  locationId the new location 
     *  @throws org.osid.InvalidArgumentException <code> locationId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> locationId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocation(org.osid.id.Id locationId);


    /**
     *  Clears the location. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocation();


    /**
     *  Gets the metadata for a sponsor. 
     *
     *  @return metadata for the sponsor 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSponsorMetadata();


    /**
     *  Sets the sponsors. 
     *
     *  @param  sponsorIds the new sponsor 
     *  @throws org.osid.InvalidArgumentException <code> sponsorIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> sponsorIds </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> sponsorIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSponsors(org.osid.id.Id[] sponsorIds);


    /**
     *  Clears the sponsors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsors();


    /**
     *  Gets the <code> OffsetEventFormRecord </code> corresponding to the 
     *  given schedule record <code> Type. </code> 
     *
     *  @param  offsetEventRecordType the offset event record type 
     *  @return the offset event form record 
     *  @throws org.osid.NullArgumentException <code> offsetEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offsetEventRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.OffsetEventFormRecord getOffsetEventFormRecord(org.osid.type.Type offsetEventRecordType)
        throws org.osid.OperationFailedException;
}
