//
// org.osid.calendaring.OffsetEventQueryInspector
//
//     The OSID Java specification for org.osid.calendaring.OffsetEventQueryInspector.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query inspector for examining offset event queries. </p>
 */

public interface OffsetEventQueryInspector
    extends org.osid.OsidRuleQueryInspector {


    /**
     *  Gets the fixed start time terms. 
     *
     *  @return the fixed start time terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getFixedStartTimeTerms();


    /**
     *  Gets the event <code> Id </code> terms. 
     *
     *  @return the event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getStartReferenceEventIdTerms();


    /**
     *  Gets the event terms. 
     *
     *  @return the event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getStartReferenceEventTerms();


    /**
     *  Gets the fixed offset terms. 
     *
     *  @return the fixed offset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IntegerRangeTerm[] getFixedStartOffsetTerms();


    /**
     *  Gets the relative weekday offset terms. 
     *
     *  @return the relative weekday offset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IntegerRangeTerm[] getRelativeWeekdayStartOffsetTerms();


    /**
     *  Gets the relative weekday terms. 
     *
     *  @return the relative weekday terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalTerm[] getRelativeStartWeekdayTerms();


    /**
     *  Gets the fixed duration terms. 
     *
     *  @return the fixed duration terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getFixedDurationTerms();


    /**
     *  Gets the event <code> Id </code> terms. 
     *
     *  @return the event <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getEndReferenceEventIdTerms();


    /**
     *  Gets the event terms. 
     *
     *  @return the event terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getEndReferenceEventTerms();


    /**
     *  Gets the fixed offset terms. 
     *
     *  @return the fixed offset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IntegerRangeTerm[] getFixedEndOffsetTerms();


    /**
     *  Gets the relative weekday offset terms. 
     *
     *  @return the relative weekday offset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IntegerRangeTerm[] getRelativeWeekdayEndOffsetTerms();


    /**
     *  Gets the relative weekday terms. 
     *
     *  @return the relative weekday terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalTerm[] getRelativeEndWeekdayTerms();


    /**
     *  Gets the location description terms. 
     *
     *  @return the location description terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getLocationDescriptionTerms();


    /**
     *  Gets the location <code> Id </code> terms. 
     *
     *  @return the location <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLocationIdTerms();


    /**
     *  Gets the location terms. 
     *
     *  @return the location terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationQueryInspector[] getLocationTerms();


    /**
     *  Gets the sponsor <code> Id </code> terms. 
     *
     *  @return the sponsor <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSponsorIdTerms();


    /**
     *  Gets the sponsor terms. 
     *
     *  @return the sponsor terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getSponsorTerms();


    /**
     *  Gets the calendar <code> Id </code> terms. 
     *
     *  @return the calendar <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCalendarIdTerms();


    /**
     *  Gets the calendar terms. 
     *
     *  @return the calendar terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.CalendarQueryInspector[] getCalendarTerms();


    /**
     *  Gets the offset event query inspector record corresponding to the 
     *  given <code> OffsetEvent </code> record <code> Type. </code> 
     *
     *  @param  offsetEventRecordType an offset event query record type 
     *  @return the offset event query inspector record 
     *  @throws org.osid.NullArgumentException <code> offsetEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offsetEventRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.OffsetEventQueryInspectorRecord getOffsetEventQueryInspectorRecord(org.osid.type.Type offsetEventRecordType)
        throws org.osid.OperationFailedException;
}
