//
// org.osid.calendaring.OffsetEventSearchSession
//
//     The OSID Java specification for org.osid.calendaring.OffsetEventSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> OffsetEvent </code> 
 *  objects. The search query is constructed using the <code> 
 *  OffsetEventQuery. </code> The offset event record <code> Type </code> also 
 *  specifies the record for the offset event query. </p> 
 *  
 *  <p> <code> getOffsetEventsByQuery() </code> is the basic search method and 
 *  returns a list of <code> OffsetEvents. </code> A more advanced search may 
 *  be performed with <code> getOffsetEventsBySearch(). </code> It accepts an 
 *  <code> OffsetEventSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getOffsetEventsBySearch() </code> returns an <code> 
 *  OffsetEventSearchResults </code> that can be used to access the resulting 
 *  <code> OffsetEventList </code> or be used to perform a search within the 
 *  result set through <code> OffsetEventSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include offset events in 
 *      calendars of which this calendar is a ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to offset events 
 *      in this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> Offset events may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  OffsetEventQuery. </code> </p>
 */

public interface OffsetEventSearchSession
    extends org.osid.calendaring.OffsetEventQuerySession {


    /**
     *  Gets an offset event search. 
     *
     *  @return the offset event search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventSearch getOffsetEventSearch();


    /**
     *  Gets an offset event search order. The <code> OffsetEventSearchOrder 
     *  </code> is supplied to an <code> OffsetEventSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the offset event search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventSearchOrder getOffsetEventSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  offsetEventQuery the offset event search query 
     *  @param  offsetEventSearch the offset event search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> offsetEventQuery </code> 
     *          or <code> offsetEventSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> offsetEventQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventSearchResults getOffsetEventsBySearch(org.osid.calendaring.OffsetEventQuery offsetEventQuery, 
                                                                                 org.osid.calendaring.OffsetEventSearch offsetEventSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offset event query from an inspector. The inspector is 
     *  available from an <code> OffsetEventSearchResults. </code> 
     *
     *  @param  offsetEventQueryInspector an offset event query inspector 
     *  @return the offset event query 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> offsetEventQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.OffsetEventQuery getOffsetEventQueryFromInspector(org.osid.calendaring.OffsetEventQueryInspector offsetEventQueryInspector);
}
