//
// org.osid.calendaring.RecurringEvent
//
//     The OSID Java specification for org.osid.calendaring.RecurringEvent.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>A <code> RecurringEvent </code> an event that repeats over a set of 
 *  <code> Schedules, </code> other events, or custom rule. The active status 
 *  of the rule informs the appearance of recurring events as events. </p>
 */

public interface RecurringEvent
    extends org.osid.OsidRule,
            org.osid.Containable {


    /**
     *  Gets the <code> Schedule Id </code> of this composite event. 
     *
     *  @return the recurring schedule <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getScheduleIds();


    /**
     *  Gets the recurring schedule in this composite event. 
     *
     *  @return the recurring schedules 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleList getSchedules()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the superseding event <code> Ids. </code> A superseding event is 
     *  one that replaces another in a series. 
     *
     *  @return list of superseding event <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSupersedingEventIds();


    /**
     *  Gets the superseding events. A superseding event is one that replaces 
     *  another in a series. 
     *
     *  @return list of superseding events 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.SupersedingEventList getSupersedingEvents()
        throws org.osid.OperationFailedException;


    /**
     *  Gets specific dates for this event outside of the schedules. Specific 
     *  dates are excluded from blackouts. 
     *
     *  @return speciifc list of dates 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.MeetingTimeList getSpecificMeetingTimes();


    /**
     *  Gets the composed event <code> Ids. </code> 
     *
     *  @return list of event <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getEventIds();


    /**
     *  Gets the composed events. 
     *
     *  @return list of events 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getEvents()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the blackout dates for this recurring event. Recurring events 
     *  overlapping with the time intervals do not appear in their series. 
     *
     *  @return recurring event exceptions 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTimeIntervalList getBlackouts();


    /**
     *  Tests if a sponsor is associated with the overall recurring event. 
     *
     *  @return <code> true </code> if there is an associated sponsor. <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSponsors();


    /**
     *  Gets the <code> Id </code> of the recurring event sponsors. 
     *
     *  @return the sponsor <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSponsorIds();


    /**
     *  Gets the <code> Sponsors. </code> 
     *
     *  @return the sponsors 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getSponsors()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the recurring event record corresponding to the given <code> 
     *  RecurringEvent </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  recurringEventRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(recurringEventRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  recurringEventRecordType the type of the record to retrieve 
     *  @return the recurring event record 
     *  @throws org.osid.NullArgumentException <code> recurringEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(recurringEventRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.RecurringEventRecord getRecurringEventRecord(org.osid.type.Type recurringEventRecordType)
        throws org.osid.OperationFailedException;
}
