//
// org.osid.calendaring.RecurringEventAdminSession
//
//     The OSID Java specification for org.osid.calendaring.RecurringEventAdminSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session creates, updates, and deletes <code> RecurringEvents. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  RecurringEvent, </code> a <code> RecurringEventForm </code> is requested 
 *  using <code> getRecurringEventFormForCreate() </code> specifying the 
 *  desired relationship peers and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. The returned <code> 
 *  RecurringEventForm </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once the <code> RecurringEventForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> RecurringEventForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> RecurringEventForms </code> are requested to the 
 *  <code> RecurringEvent </code> <code> Id </code> that is to be updated 
 *  using <code> getRecurringEventFormForUpdate(). </code> Similarly, the 
 *  <code> RecurringEventForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> RecurringEventForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Recurring Events. </code> To unmap 
 *  a <code> RecurringEvent </code> from the current <code> Calendar, </code> 
 *  the <code> RecurringEventCalendarAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Event </code> itself 
 *  thus removing it from all known <code> Calendar </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RecurringEventAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> RecurringEvents. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> RecurringEvent </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RecurringEvent </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRecurringEvents();


    /**
     *  Tests if this user can create a single <code> RecurringEvent </code> 
     *  using the desired record types. While <code> 
     *  CalendaringManager.getRecurringEventRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> RecurringEvent. 
     *  </code> Providing an empty array tests if a <code> RecurringEvent 
     *  </code> can be created with no records. 
     *
     *  @param  recurringEventRecordTypes array of recurring event types 
     *  @return <code> true </code> if <code> RecurringEvent </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRecurringEventWithRecordTypes(org.osid.type.Type[] recurringEventRecordTypes);


    /**
     *  Gets the recurring event form for creating new recurring events. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  recurringEventRecordTypes array of recurring event types 
     *  @return the recurring event form 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventForm getRecurringEventFormForCreate(org.osid.type.Type[] recurringEventRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> RecurringEvent. </code> 
     *
     *  @param  recurringEventForm the form for this <code> RecurringEvent 
     *          </code> 
     *  @return the new <code> RecurringEvent </code> 
     *  @throws org.osid.IllegalStateException <code> recurringEventForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> recurringEventForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> recurringEventForm 
     *          </code> did not originate in a create transaction 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEvent createRecurringEvent(org.osid.calendaring.RecurringEventForm recurringEventForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> RecurringEvents. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> RecurringEvent </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if recurring event modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRecurringEvents();


    /**
     *  Gets the recurring event form for updating an existing recurring 
     *  event. A new recurring event form should be requested for each update 
     *  transaction. 
     *
     *  @param  recurringEventId the <code> Id </code> of the <code> 
     *          RecurringEvent </code> 
     *  @return the recurring event form 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventForm getRecurringEventFormForUpdate(org.osid.id.Id recurringEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing recurring event. 
     *
     *  @param  recurringEventForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> recurringEventForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> recurringEventForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> recurringEventForm 
     *          </code> did not originate in an update transaction 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRecurringEvent(org.osid.calendaring.RecurringEventForm recurringEventForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> RecurringEvents. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> RecurringEvent </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RecurringEvent </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRecurringEvents();


    /**
     *  Deletes the <code> RecurringEvent </code> identified by the given 
     *  <code> Id. </code> 
     *
     *  @param  recurringEventId the <code> Id </code> of the <code> 
     *          RecurringEvent </code> to delete 
     *  @throws org.osid.NotFoundException a <code> RecurringEvent </code> was 
     *          not found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRecurringEvent(org.osid.id.Id recurringEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  RecurringEvents. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> RecurringEvent </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRecurringEventAliases();


    /**
     *  Adds an <code> Id </code> to a <code> RecurringEvent </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> RecurringEvent </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another recurring event, it is 
     *  reassigned to the given recurring event <code> Id. </code> 
     *
     *  @param  recurringEventId the <code> Id </code> of a <code> 
     *          RecurringEvent </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRecurringEvent(org.osid.id.Id recurringEventId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can schedule recurring events. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known recurring event methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if recurring event scheduling is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canScheduleRecurringEvents();


    /**
     *  Adds a schedule to the given recurring event. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  scheduleId a schedule <code> Id </code> 
     *  @return the <code> Id </code> of the schedule 
     *  @throws org.osid.AlreadyExistsException schedule is already part of 
     *          recurring event 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> or 
     *          <code> scheduleId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          or <code> scheduleId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id addSchedule(org.osid.id.Id recurringEventId, 
                                      org.osid.id.Id scheduleId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a schedule from a given recurring event. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  scheduleId the schedule <code> Id </code> 
     *  @throws org.osid.NotFoundException schedule not part of recurring 
     *          event 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          or <code> scheduleId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeSchedule(org.osid.id.Id recurringEventId, 
                               org.osid.id.Id scheduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a specific date to the given recurring event. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  date a date 
     *  @param  locationDescription location description 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId, date 
     *          </code> , or <code> locationDescription </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addSpecificDate(org.osid.id.Id recurringEventId, 
                                org.osid.calendaring.DateTime date, 
                                org.osid.locale.DisplayText locationDescription)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a specific date to the given recurring event. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  date a date 
     *  @param  locationId a location 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> or 
     *          <code> locationId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId, date 
     *          </code> , or <code> locationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addSpecificDateWithLocation(org.osid.id.Id recurringEventId, 
                                            org.osid.calendaring.DateTime date, 
                                            org.osid.id.Id locationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Clears any specific dates between the given dates inclusive. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  from start date inclusive 
     *  @param  to end date inclusive 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpecificDates(org.osid.id.Id recurringEventId, 
                                   org.osid.calendaring.DateTime from, 
                                   org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds another event as part of this recurring event. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  eventId an event <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> or 
     *          <code> eventId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          or <code> eventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addEvent(org.osid.id.Id recurringEventId, 
                         org.osid.id.Id eventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an event as part of this recurring event. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  eventId an event <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> or 
     *          <code> eventId </code> is not found or <code> eventId </code> 
     *          not part of <code> recurringEventId </code> 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          or <code> eventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeEvent(org.osid.id.Id recurringEventId, 
                            org.osid.id.Id eventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a blackout to the given recurring event that blocks events in the 
     *  series. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  from start date inclusive 
     *  @param  to end date inclusive 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addBlackout(org.osid.id.Id recurringEventId, 
                            org.osid.calendaring.DateTime from, 
                            org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Clears any blackouts between the given dates inclusive. 
     *
     *  @param  recurringEventId a recurring event <code> Id </code> 
     *  @param  from start date inclusive 
     *  @param  to end date inclusive 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlackout(org.osid.id.Id recurringEventId, 
                              org.osid.calendaring.DateTime from, 
                              org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
