//
// org.osid.calendaring.RecurringEventLookupSession
//
//     The OSID Java specification for org.osid.calendaring.RecurringEventLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for retrieving <code> RecurringEvent 
 *  </code> s. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All recurring event methods in this 
 *      session operate, retrieve and pertain to events defined explicitly in 
 *      the current calendar. Using an isolated view is useful for managing 
 *      recurring events with the <code> RecurringEventAdminSession. </code> 
 *      </li> 
 *      <li> federated calendar view: All recurring event methods in this 
 *      session operate, retrieve and pertain to all recurring events defined 
 *      in this calendar and any other calendars implicitly available in this 
 *      calendar through calendar inheritence. </li> 
 *      <li> active recurring event view: All recurring event lookup methods 
 *      return active recurring events. </li> 
 *      <li> any status recurring event view: Recurring events of any active 
 *      or inactive status are returned from methods. </li> 
 *      <li> sequestered recurring event viiew: All event methods suppress 
 *      sequestered recurring events. </li> 
 *      <li> unsequestered recurring event view: All event methods return all 
 *      recurring events. </li> 
 *  </ul>
 *  
 *  
 *  <p> Events may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Event. </code> </p>
 */

public interface RecurringEventLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> RecurringEvent </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRecurringEvents();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRecurringEventView();


    /**
     *  A complete view of the <code> Event </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRecurringEventView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include recurring events in calendars which are children of this 
     *  calendar in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Only active recurring events are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveRecurringEventView();


    /**
     *  All active and inactive recurring events are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusRecurringEventView();


    /**
     *  The returns from the lookup methods omit sequestered recurring events. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredRecurringEventView();


    /**
     *  All recurring events are returned including sequestered recurring 
     *  events. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredRecurringEventView();


    /**
     *  Gets the <code> RecurringEvent </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  RecurringEvent </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Event </code> and retained for compatibility. 
     *  
     *  In active mode, recurring events are returned that are currently 
     *  active. In any status mode, active and inactive recurring events are 
     *  returned. 
     *
     *  @param  recurringEventId <code> Id </code> of the <code> 
     *          RecurringEvent </code> 
     *  @return the recurring event 
     *  @throws org.osid.NotFoundException <code> recurringEventId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.RecurringEvent getRecurringEvent(org.osid.id.Id recurringEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecurringEventList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  recurring events specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> RecurringEvents </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, recurring events are returned that are currently 
     *  active. In any status mode, active and inactive recurring events are 
     *  returned. 
     *
     *  @param  recurringEventIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsByIds(org.osid.id.IdList recurringEventIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecurringEventList </code> corresponding to the given 
     *  recurring event genus <code> Type </code> which does not include 
     *  recurring events of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  recurring events or an error results. Otherwise, the returned list may 
     *  contain only those recurring events that are accessible through this 
     *  session. 
     *  
     *  In active mode, recurring events are returned that are currently 
     *  active. In any status mode, active and inactive recurring events are 
     *  returned. 
     *
     *  @param  recurringEventGenusType a recurring event genus type 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> recurringEventGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsByGenusType(org.osid.type.Type recurringEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecurringEventList </code> corresponding to the given 
     *  recurring event genus <code> Type </code> and include any additional 
     *  recurring event with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  recurring events or an error results. Otherwise, the returned list may 
     *  contain only those recurring events that are accessible through this 
     *  session. 
     *  
     *  In active mode, recurring events are returned that are currently 
     *  active. In any status mode, active and inactive recurring events are 
     *  returned. 
     *
     *  @param  recurringEventGenusType a recurring event genus type 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> recurringEventGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsByParentGenusType(org.osid.type.Type recurringEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecurringEventList </code> containing the given 
     *  recurring event record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  recurring events or an error results. Otherwise, the returned list may 
     *  contain only those recurring events that are accessible through this 
     *  session. 
     *  
     *  In active mode, recurring events are returned that are currently 
     *  active. In any status mode, active and inactive recurring events are 
     *  returned. 
     *
     *  @param  recurringEventRecordType a recurring event record type 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> recurringEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsByRecordType(org.osid.type.Type recurringEventRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> RecurringEvents </code> containing the given schedule 
     *  slot. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all 
     *  matching recurring events or an error results. Otherwise, the returned 
     *  list may contain only those recurring events that are accessible 
     *  through this session. 
     *  
     *  In active mode, recurring events are returned that are currently 
     *  active. In any status mode, active and inactive recurring events are 
     *  returned. 
     *
     *  @param  scheduleSlotId a schedule slot <code> Id </code> 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsByScheduleSlot(org.osid.id.Id scheduleSlotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> RecurringEvents. </code> 
     *  
     *  In plenary mode, the returned list contains all known recurring events 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those recurring events that are accessible through this session. 
     *  
     *  In active mode, recurring events are returned that are currently 
     *  active. In any status mode, active and inactive recurring events are 
     *  returned. 
     *
     *  @return a <code> RecurringEventList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEvents()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
