//
// org.osid.calendaring.RecurringEventUnravellingSession
//
//     The OSID Java specification for org.osid.calendaring.RecurringEventUnravellingSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for retrieving and expanding <code> 
 *  RecurringEvent </code> s. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All recurring event methods in this 
 *      session operate, retrieve and pertain to recurring events defined 
 *      explicitly in the current calendar. Using an isolated view is useful 
 *      for managing recurring events with the <code> 
 *      RecurringEventAdminSession. </code> </li> 
 *      <li> federated calendar view: All recurring event methods in this 
 *      session operate, retrieve and pertain to all recurring events defined 
 *      in this calendar and any other calendars implicitly available in this 
 *      calendar through calendar inheritence. </li> 
 *  </ul>
 *  
 */

public interface RecurringEventUnravellingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> RecurringEvent </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUnravelRecurringEvents();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRecurringEventView();


    /**
     *  A complete view of the <code> Event </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRecurringEventView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include events in calendars which are children of this calendar in the 
     *  calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Gets the recurring event where the given event <code> Id </code> was 
     *  issued as part of the recurring series. 
     *
     *  @param  eventId <code> an event Id </code> 
     *  @return the returned <code> RecurringEvent </code> 
     *  @throws org.osid.NotFoundException <code> eventId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEvent getRecurringEventByEvent(org.osid.id.Id eventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecurringEventList </code> corresponding to the given 
     *  event <code> IdList </code> where the events were implcitly created 
     *  from the recurring series. In plenary mode, the returned list contains 
     *  all of the recurring events corresponding to the events in the <code> 
     *  Id </code> list, in the order of the list, including duplicates, or an 
     *  error results if an <code> Id </code> in the supplied list is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Events </code> 
     *  may be omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *
     *  @param  eventIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> eventIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsByEvents(org.osid.id.IdList eventIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given recurring event into a series of non-recurring 
     *  events. In plenary mode, the returned list contains all of the events 
     *  in the series, including duplicates, or an error results. In 
     *  comparative mode, events may be omitted from the list and may present 
     *  the elements in any order, including providing a unique set. 
     *
     *  @param  recurringEventId <code> Id </code> of the recurring <code> 
     *          Event </code> 
     *  @return the returned <code> Event list </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId was </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.EventList expandRecurringEvent(org.osid.id.Id recurringEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given recurring event into a series of non-recurring 
     *  events that fall within the given date range inclusive. In plenary 
     *  mode, the returned list contains all of the events in the series, 
     *  including duplicates, or an error results. In comparative mode, events 
     *  may be omitted from the list and may present the elements in any 
     *  order, including providing a unique set. 
     *
     *  @param  recurringEventId <code> Id </code> of the recurring <code> 
     *          Event </code> 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Event list </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId was </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.EventList expandRecurringEventInDateRange(org.osid.id.Id recurringEventId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given recurring events into a series of non-recurring 
     *  events. In plenary mode, the returned list contains all of the events 
     *  in the series, including duplicates, or an error results. In 
     *  comparative mode, events may be omitted from the list and may present 
     *  the elements in any order, including providing a unique set. 
     *
     *  @param  recurringEventIds the list of <code> Ids </code> to expand 
     *  @return the returned <code> Event list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList expandRecurringEvents(org.osid.id.IdList recurringEventIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given recurring events into a series of non-recurring 
     *  events that fall within the given date range inclusive. In plenary 
     *  mode, the returned list contains all of the events in the series, 
     *  including duplicates, or an error results. In comparative mode, events 
     *  may be omitted from the list and may present the elements in any 
     *  order, including providing a unique set. 
     *
     *  @param  recurringEventIds the list of <code> Ids </code> to expand 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Event list </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.EventList expandRecurringEventsInDateRange(org.osid.id.Id recurringEventIds, 
                                                                           org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of recurring events where the given date falls within the 
     *  span of a recurring event. <code> </code> In plenary mode, the 
     *  returned list contains all known events or an error results. 
     *  Otherwise, the returned list may contain only those events that are 
     *  accessible through this session. In both cases, the order of the set 
     *  is not specified. 
     *
     *  @param  datetime a date 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> datetime </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsByDate(org.osid.calendaring.DateTime datetime)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RecurringEventList </code> whose series falls entirely 
     *  within the given range inclusive <code> . </code> In plenary mode, the 
     *  returned list contains all known recurring events or an error results. 
     *  Otherwise, the returned list may contain only those recurring events 
     *  that are accessible through this session. In both cases, the order of 
     *  the set is not specified. 
     *
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> RecurringEvent </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.RecurringEventList getRecurringEventsInDateRange(org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the number of events in the recurring series. 
     *
     *  @param  recurringEventId <code> Id </code> of the recurring <code> 
     *          Event </code> 
     *  @return the number of meeting times 
     *  @throws org.osid.NotFoundException <code> recurringEventId was </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public long getNumberOfEvents(org.osid.id.Id recurringEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the number of events in the recurring series between the given 
     *  dates inclusive. 
     *
     *  @param  recurringEventId <code> Id </code> of the recurring <code> 
     *          Event </code> 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the number of meeting times 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventId was </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public long getNumberOfEventsInDateRange(org.osid.id.Id recurringEventId, 
                                             org.osid.calendaring.DateTime from, 
                                             org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
