//
// org.osid.calendaring.ScheduleQuery
//
//     The OSID Java specification for org.osid.calendaring.ScheduleQuery.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This is the query for searching schedules. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface ScheduleQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the schedule <code> Id </code> for this query for matching nested 
     *  schedule slots. 
     *
     *  @param  scheduleSlotId a schedule slot <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleSlotId(org.osid.id.Id scheduleSlotId, 
                                    boolean match);


    /**
     *  Clears the schedule slot <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleSlotIdTerms();


    /**
     *  Tests if a <code> ScheduleSlotQuery </code> is available for querying 
     *  sechedule slots. 
     *
     *  @return <code> true </code> if a schedule slot query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotQuery();


    /**
     *  Gets the query for a schedul slot. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the schedule slot query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotQuery getScheduleSlotQuery();


    /**
     *  Matches a schedule that has any schedule slot assigned. 
     *
     *  @param  match <code> true </code> to match schedule with any schedule 
     *          slots, <code> false </code> to match schedules with no 
     *          schedule slots 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScheduleSlot(boolean match);


    /**
     *  Clears the schedule slot terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleSlotTerms();


    /**
     *  Sets the time period <code> Id </code> for this query. 
     *
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimePeriodId(org.osid.id.Id timePeriodId, boolean match);


    /**
     *  Clears the time period <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodIdTerms();


    /**
     *  Tests if a <code> TimePeriodQuery </code> is available. 
     *
     *  @return <code> true </code> if a time period query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodQuery();


    /**
     *  Gets the query for a time period. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the time period query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodQuery getTimePeriodQuery();


    /**
     *  Matches a schedule that has any time period assigned. 
     *
     *  @param  match <code> true </code> to match schedules with any time 
     *          periods, <code> false </code> to match schedules with no time 
     *          periods 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimePeriod(boolean match);


    /**
     *  Clears the time period terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodTerms();


    /**
     *  Matches the schedule start time between the given range inclusive. 
     *
     *  @param  low low time range 
     *  @param  high high time range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> high </code> or <code> 
     *          low </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleStart(org.osid.calendaring.DateTime low, 
                                   org.osid.calendaring.DateTime high, 
                                   boolean match);


    /**
     *  Matches a schedule that has any start time assigned. 
     *
     *  @param  match <code> true </code> to match schedules with any start 
     *          time, <code> false </code> to match schedules with no start 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScheduleStart(boolean match);


    /**
     *  Clears the schedule start terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleStartTerms();


    /**
     *  Matches the schedule end time between the given range inclusive. 
     *
     *  @param  low low time range 
     *  @param  high high time range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> high </code> or <code> 
     *          low </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleEnd(org.osid.calendaring.DateTime low, 
                                 org.osid.calendaring.DateTime high, 
                                 boolean match);


    /**
     *  Matches a schedule that has any end time assigned. 
     *
     *  @param  match <code> true </code> to match schedules with any end 
     *          time, <code> false </code> to match schedules with no start 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScheduleEnd(boolean match);


    /**
     *  Clears the schedule end terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleEndTerms();


    /**
     *  Matches schedules with start and end times between the given range 
     *  inclusive. 
     *
     *  @param  date a date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleTime(org.osid.calendaring.DateTime date, 
                                  boolean match);


    /**
     *  Matches schedules that has any time assigned. 
     *
     *  @param  match <code> true </code> to match schedules with any time, 
     *          <code> false </code> to match schedules with no time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScheduleTime(boolean match);


    /**
     *  Clears the schedule time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleTimeTerms();


    /**
     *  Matches schedules with start and end times between the given range 
     *  inclusive. 
     *
     *  @param  start start date 
     *  @param  end end date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> end </code> or <code> 
     *          start </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScheduleTimeInclusive(org.osid.calendaring.DateTime start, 
                                           org.osid.calendaring.DateTime end, 
                                           boolean match);


    /**
     *  Clears the schedule time inclusive terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScheduleTimeInclusiveTerms();


    /**
     *  Matches schedules that have the given limit in the given range 
     *  inclusive. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLimit(long from, long to, boolean match);


    /**
     *  Matches schedules with any occurrence limit. 
     *
     *  @param  match <code> true </code> to match schedules with any limit, 
     *          to match schedules with no limit 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLimit(boolean match);


    /**
     *  Clears the limit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLimitTerms();


    /**
     *  Matches the location description string. 
     *
     *  @param  location location string 
     *  @param  stringMatchType string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> location </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> location </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationDescription(String location, 
                                         org.osid.type.Type stringMatchType, 
                                         boolean match);


    /**
     *  Matches a schedule that has any location description assigned. 
     *
     *  @param  match <code> true </code> to match schedules with any location 
     *          description, <code> false </code> to match schedules with no 
     *          location description 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocationDescription(boolean match);


    /**
     *  Clears the location description terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationDescriptionTerms();


    /**
     *  Sets the location <code> Id </code> for this query. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the location <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available for querying 
     *  locations. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Gets the query for a location. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> supportsLocationQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.LocationQuery getLocationQuery();


    /**
     *  Matches a schedule that has any location assigned. 
     *
     *  @param  match <code> true </code> to match schedules with any 
     *          location, <code> false </code> to match schedules with no 
     *          location 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocation(boolean match);


    /**
     *  Clears the location terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationTerms();


    /**
     *  Matches the total duration between the given range inclusive. 
     *
     *  @param  low low duration range 
     *  @param  high high duration range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> high </code> is less 
     *          than <code> low </code> 
     *  @throws org.osid.NullArgumentException <code> high </code> or <code> 
     *          low </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalDuration(org.osid.calendaring.Duration low, 
                                   org.osid.calendaring.Duration high, 
                                   boolean match);


    /**
     *  Clears the total duration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalDurationTerms();


    /**
     *  Sets the calendar <code> Id </code> for this query. 
     *
     *  @param  calendarId a calendar <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCalendarId(org.osid.id.Id calendarId, boolean match);


    /**
     *  Clears the calendar <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarIdTerms();


    /**
     *  Tests if a <code> CalendarQuery </code> is available for querying 
     *  calendars. 
     *
     *  @return <code> true </code> if a calendar query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarQuery();


    /**
     *  Gets the query for a calendar. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the calendar query 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.CalendarQuery getCalendarQuery();


    /**
     *  Clears the calendar terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCalendarTerms();


    /**
     *  Gets the schedule query record corresponding to the given <code> 
     *  Schedule </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  scheduleRecordType a schedule query record type 
     *  @return the schedule query record 
     *  @throws org.osid.NullArgumentException <code> scheduleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleQueryRecord getScheduleQueryRecord(org.osid.type.Type scheduleRecordType)
        throws org.osid.OperationFailedException;
}
