//
// org.osid.calendaring.ScheduleSearchOrder
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSearchOrder.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface ScheduleSearchOrder
    extends org.osid.OsidObjectSearchOrder {


    /**
     *  Specified a preference for ordering results by the schedule slot. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByScheduleSlot(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> ScheduleSlotSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a schedule slot search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotSearchOrder();


    /**
     *  Gets the search order for the schedule slot. 
     *
     *  @return the schdeule slot search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsScheduleSlotSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsScheduleSlotSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.ScheduleSlotSearchOrder getScheduleSlotSearchOrder();


    /**
     *  Specified a preference for ordering results by the time period. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTimePeriod(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> TimePeriodSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a time period search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodSearchOrder();


    /**
     *  Gets the search order for the time period. 
     *
     *  @return the time period search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.TimePeriodSearchOrder getTimePeriodSearchOrder();


    /**
     *  Specified a preference for ordering results by the schedule start. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByScheduleStart(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the schedule end. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByScheduleEnd(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the schedule duration. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTotalDuration(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the occurrence limit. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLimit(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the location 
     *  description. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLocationDescription(org.osid.SearchOrderStyle style);


    /**
     *  Specified a preference for ordering results by the location. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByLocation(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a <code> LocationSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if a location search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationSearchOrder();


    /**
     *  Gets the search order for a location. 
     *
     *  @return the location search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLocationSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationSearchOrder getLocationSearchOrder();


    /**
     *  Gets the schedule search order record corresponding to the given 
     *  schedule record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  scheduleRecordType a schedule record type 
     *  @return the schedule search order record 
     *  @throws org.osid.NullArgumentException <code> scheduleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleSearchOrderRecord getScheduleSearchOrderRecord(org.osid.type.Type scheduleRecordType)
        throws org.osid.OperationFailedException;
}
