//
// org.osid.calendaring.ScheduleSlot
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSlot.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>A <code> ScheduleSlot </code> describes a repeating time slot. The time 
 *  slot can be defined as a fixed time interval or be defined on a weekly 
 *  interval specifying the days of the week. </p>
 */

public interface ScheduleSlot
    extends org.osid.OsidObject,
            org.osid.Containable {


    /**
     *  Gets the <code> Ids </code> of the schedule slots included inside this 
     *  one. 
     *
     *  @return the schedules slot <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getScheduleSlotIds();


    /**
     *  Gets the schedule slots included inside this one. 
     *
     *  @return the schedule slots 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotList getScheduleSlots()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this schedule has a weekly interval. If <code> true, </code> 
     *  <code> hasFixedInterval() </code> must be <code> false. </code> 
     *
     *  @return <code> true </code> if there is a weekly interval, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasWeeklyInterval();


    /**
     *  Gets the weekdays of the schedule. On a Gregorian calendar, Sunday is 
     *  zero. 
     *
     *  @return the weekdays 
     *  @throws org.osid.IllegalStateException <code> hasWeeklyInterval() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long[] getWeekdays();


    /**
     *  Tests if this schedule has a weekly interval based on the week of the 
     *  month. This method must be <code> false </code> if <code> 
     *  hasWeeklyInterval() </code> is <code> false. </code> 
     *
     *  @return <code> true </code> if there is a week of month specified, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasWeekOfMonthInterval();


    /**
     *  Gets the number of weeks of the interval. 1 is every week. 2 is every 
     *  other week. -1 is every week back in time. 
     *
     *  @return <code> the week interval </code> 
     *  @throws org.osid.IllegalStateException <code> hasWeekdlyInterval() 
     *          </code> is <code> false </code> or <code> 
     *          hasWeekofMonthInterval() </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getWeeklyInterval();


    /**
     *  Gets the week of the month for the interval. 1 is the first week of 
     *  the month. -1 is the last week of the month. 0 is invalid. 
     *
     *  @return <code> the week interval </code> 
     *  @throws org.osid.IllegalStateException <code> hasWeeklyInterval() 
     *          </code> is <code> false </code> or <code> 
     *          hasWeekofMonthInterval() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getWeekOfMonth();


    /**
     *  Gets the time of this recurring schedule. 
     *
     *  @return the time 
     *  @throws org.osid.IllegalStateException <code> hasWeeklyInterval() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Time getWeekdayTime();


    /**
     *  Tests if this schedule has a fixed time interval. 
     *
     *  @return <code> true </code> if there is a fixed time interval, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasFixedInterval();


    /**
     *  Gets the repeating interval. 
     *
     *  @return the interval 
     *  @throws org.osid.IllegalStateException <code> hasFixedInterval() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getFixedInterval();


    /**
     *  Gets the duration of the schedule slot. 
     *
     *  @return the duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getDuration();


    /**
     *  Gets the schedule slot record corresponding to the given <code> 
     *  ScheduleSlot </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  scheduleSlotRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(scheduleSlotRecordType) </code> is <code> true </code> . 
     *
     *  @param  scheduleSlotRecordType the type of the record to retrieve 
     *  @return the schedule slot record 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(scheduleSlotRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.ScheduleSlotRecord getScheduleSlotRecord(org.osid.type.Type scheduleSlotRecordType)
        throws org.osid.OperationFailedException;
}
