//
// org.osid.calendaring.ScheduleSlotAdminSession
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSlotAdminSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session creates, updates, and deletes <code> Schedule Slots. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ScheduleSlot, </code> a <code> ScheduleSlotForm </code> is requested using 
 *  <code> getScheduleSlotFormForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> ScheduleSlotForm </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once the <code> ScheduleSlotForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ScheduleSlotForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> ScheduleSlotForms </code> are requested to the 
 *  <code> ScheduleSlot </code> <code> Id </code> that is to be updated using 
 *  <code> getScheduleSlotFormForUpdate(). </code> Similarly, the <code> 
 *  ScheduleSlotForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ScheduleSlotForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Schedule Slots. </code> To unmap a 
 *  <code> ScheduleSlot </code> from the current <code> Calendar, </code> the 
 *  <code> ScheduleSlotCalendarAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> ScheduleSlot </code> itself 
 *  thus removing it from all known <code> Calendar </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ScheduleSlotAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ScheduleSlots. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> ScheduleSlot </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ScheduleSlot </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateScheduleSlots();


    /**
     *  Tests if this user can create a single <code> ScheduleSlot </code> 
     *  using the desired record types. While <code> 
     *  CalendaringManager.getScheduleSlotRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> ScheduleSlot. </code> 
     *  Providing an empty array tests if a <code> ScheduleSlot </code> can be 
     *  created with no records. 
     *
     *  @param  scheduleSlotRecordTypes array of schedule slot record types 
     *  @return <code> true </code> if <code> ScheduleSlot </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateScheduleSlotWithRecordTypes(org.osid.type.Type[] scheduleSlotRecordTypes);


    /**
     *  Gets the schedule slot form for creating new schedule slots. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  scheduleSlotRecordTypes array of schedule slot record types 
     *  @return the schedule slot form 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotForm getScheduleSlotFormForCreate(org.osid.type.Type[] scheduleSlotRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ScheduleSlot. </code> 
     *
     *  @param  scheduleSlotForm the form for this <code> ScheduleSlot </code> 
     *  @return the new <code> ScheduleSlot </code> 
     *  @throws org.osid.IllegalStateException <code> scheduleSlotForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> scheduleSlotForm </code> 
     *          did not originate from <code> getScheduleSlotFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlot createScheduleSlot(org.osid.calendaring.ScheduleSlotForm scheduleSlotForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ScheduleSlots. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> ScheduleSlot </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if schedule slot modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateScheduleSlots();


    /**
     *  Gets the schedule slot form for updating an existing schedule slot. A 
     *  new schedule slot form should be requested for each update 
     *  transaction. 
     *
     *  @param  scheduleSlotId the <code> Id </code> of the <code> 
     *          ScheduleSlot </code> 
     *  @return the schedule slot form 
     *  @throws org.osid.NotFoundException <code> scheduleSlotId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotForm getScheduleSlotFormForUpdate(org.osid.id.Id scheduleSlotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing schedule slot. 
     *
     *  @param  scheduleSlotForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> scheduleSlotForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> scheduleSlotForm </code> 
     *          did not originate from <code> getScheduleSlotFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateScheduleSlot(org.osid.calendaring.ScheduleSlotForm scheduleSlotForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ScheduleSlots. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> ScheduleSlot </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ScheduleSlot </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteScheduleSlots();


    /**
     *  Deletes the <code> ScheduleSlot </code> identified by the given <code> 
     *  Id. </code> 
     *
     *  @param  scheduleSlotId the <code> Id </code> of the <code> 
     *          ScheduleSlot </code> to delete 
     *  @throws org.osid.NotFoundException a <code> ScheduleSlot </code> was 
     *          not found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteScheduleSlot(org.osid.id.Id scheduleSlotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ScheduleSlots. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ScheduleSlot </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageScheduleSlotAliases();


    /**
     *  Adds an <code> Id </code> to a <code> ScheduleSlot </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ScheduleSlot </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another schedule slot, it is 
     *  reassigned to the given schedule slot <code> Id. </code> 
     *
     *  @param  scheduleSlotId the <code> Id </code> of a <code> ScheduleSlot 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> scheduleSlotId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasScheduleSlot(org.osid.id.Id scheduleSlotId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
