//
// org.osid.calendaring.ScheduleSlotQuerySession
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSlotQuerySession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> ScheduleSlot </code> 
 *  objects. The search query is constructed using the <code> 
 *  ScheduleSlotQuery. </code> The schedule slot record <code> Type </code> 
 *  also specifies the record for the schedule slot query. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include schedule slots in 
 *      calendars of which this calendar is an ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to schedule slots 
 *      in this calendar </li> 
 *      <li> sequestered schedule slot viiew: All schedule slot methods 
 *      suppress sequestered schedule slots. </li> 
 *      <li> unsequestered schedule slot view: All schedule slot methods 
 *      return all schedule slots. </li> 
 *  </ul>
 *  
 *  
 *  <p> Schedule slots may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ScheduleSlotQuery. </code> </p>
 */

public interface ScheduleSlotQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ScheduleSlots </code> searches. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchScheduleSlots();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include schedules in calendars which are children of this calendar in 
     *  the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  The returns from the search methods omit sequestered schedule slots. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredScheduleSlotView();


    /**
     *  All schedule slots are returned including sequestered schedule slots. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredScheduleSlotView();


    /**
     *  Gets a schedule slot query. 
     *
     *  @return the schedule slot query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotQuery getScheduleSlotQuery();


    /**
     *  Gets a list of <code> ScheduleSlots </code> matching the given 
     *  schedule slot query. 
     *
     *  @param  scheduleSlotQuery the schedule slot query 
     *  @return the returned <code> ScheduleSlotList </code> 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> scheduleSlotQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotList getScheduleSlotsByQuery(org.osid.calendaring.ScheduleSlotQuery scheduleSlotQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
