//
// org.osid.calendaring.ScheduleSlotSearchSession
//
//     The OSID Java specification for org.osid.calendaring.ScheduleSlotSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> ScheduleSlot </code> 
 *  objects. The search query is constructed using the <code> 
 *  ScheduleSlotQuery. </code> The schedule slot record <code> Type </code> 
 *  also specifies the record for the schedule slot query. </p> 
 *  
 *  <p> <code> getScheduleSlotsByQuery() </code> is the basic search method 
 *  and returns a list of <code> ScheduleSlots. </code> A more advanced search 
 *  may be performed with <code> getScheduleSlotsBySearch(). </code> It 
 *  accepts a <code> ScheduleSlotSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getScheduleSlotsBySearch() </code> returns a 
 *  <code> ScheduleSlotSearchResults </code> that can be used to access the 
 *  resulting <code> ScheduleSlotsList </code> or be used to perform a search 
 *  within the result set through <code> ScheduleSlotSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include schedule slots in 
 *      calendars of which this calendar is a ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to schedule slots 
 *      in this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> Schedule slots may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ScheduleSlotQuery. </code> </p>
 */

public interface ScheduleSlotSearchSession
    extends org.osid.calendaring.ScheduleSlotQuerySession {


    /**
     *  Gets a schedule slot search. 
     *
     *  @return the schedule slot search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotSearch getScheduleSlotSearch();


    /**
     *  Gets a schedule slot search order. The <code> ScheduleSlotSearchOrder 
     *  </code> is supplied to a <code> ScheduleSlotSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the schedule slot search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotSearchOrder getScheduleSlotSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  scheduleSlotQuery the schedule slot query 
     *  @param  scheduleSlotSearch the schedule slot search 
     *  @return the schedule slot search results 
     *  @throws org.osid.NullArgumentException <code> scheduleSlotQuery 
     *          </code> or <code> scheduleSlotSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> scheduleSlotSearch 
     *          </code> or <code> scheduleSlotQuery </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSearchResults getScheduleSlotsBySearch(org.osid.calendaring.ScheduleSlotQuery scheduleSlotQuery, 
                                                                               org.osid.calendaring.ScheduleSlotSearch scheduleSlotSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a schedule slot query from an inspector. The inspector is 
     *  available from an <code> ScheduleSlotSearchResults. </code> 
     *
     *  @param  scheduleSlotQueryInspector a schedule slot query inspector 
     *  @return the schedule query 
     *  @throws org.osid.NullArgumentException <code> 
     *          scheduleSlotQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          scheduleSlotQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleSlotQuery getScheduleSlotQueryFromInspector(org.osid.calendaring.ScheduleSlotQueryInspector scheduleSlotQueryInspector);
}
