//
// org.osid.calendaring.TimePeriod
//
//     The OSID Java specification for org.osid.calendaring.TimePeriod.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>A <code> TimePeriod </code> represents a span of time in which 
 *  recurring events are expanded. </p>
 */

public interface TimePeriod
    extends org.osid.OsidObject {


    /**
     *  Gets the start time of the time period. 
     *
     *  @return the start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getStart();


    /**
     *  Gets the end time of the time period. 
     *
     *  @return the end time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getEnd();


    /**
     *  Gets the exception <code> Ids </code> to this time period. Recurring 
     *  events overlapping with these events do not appear in any recurring 
     *  event for this time period. 
     *
     *  @return list of exception event <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getExceptionIds();


    /**
     *  Gets the exceptions to this time period. Recurring events overlapping 
     *  with these events do not appear in any recurring event for this time 
     *  period. 
     *
     *  @return event exceptions 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventList getExceptions()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the time period record corresponding to the given <code> 
     *  TimePeriod </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  timePeriodRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(timePeriodRecordType) </code> is <code> true </code> . 
     *
     *  @param  timePeriodRecordType the type of the record to retrieve 
     *  @return the time period record 
     *  @throws org.osid.NullArgumentException <code> timePeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(timePeriodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.records.TimePeriodRecord getTimePeriodRecord(org.osid.type.Type timePeriodRecordType)
        throws org.osid.OperationFailedException;
}
