//
// org.osid.calendaring.TimePeriodAdminSession
//
//     The OSID Java specification for org.osid.calendaring.TimePeriodAdminSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session creates, updates, and deletes <code> Time Periods. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  TimePeriod, </code> a <code> TimePeriodForm </code> is requested using 
 *  <code> getTimePeriodFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> TimePeriodForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> TimePeriodForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  TimePeriodForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> TimePeriodForms </code> are requested to the 
 *  <code> TimePeriod </code> <code> Id </code> that is to be updated using 
 *  <code> getTimePeriodFormForUpdate(). </code> Similarly, the <code> 
 *  TimePeriodForm </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> 
 *  TimePeriodForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Time Periods. </code> To unmap a 
 *  <code> TimePeriod </code> from the current <code> Calendar, </code> the 
 *  <code> TimePeriodCalendarAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> TimePeriod </code> itself 
 *  thus removing it from all known <code> Calendar </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface TimePeriodAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> TimePeriods. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a TimePeriod will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> TimePeriod </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTimePeriods();


    /**
     *  Tests if this user can create a single <code> TimePeriod </code> using 
     *  the desired record types. While <code> 
     *  CalendaringManager.getTimePeriodRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> TimePeriod. </code> 
     *  Providing an empty array tests if a <code> TimePeriod </code> can be 
     *  created with no records. 
     *
     *  @param  timePeriodRecordTypes array of time period record types 
     *  @return <code> true </code> if <code> TimePeriod </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> timePeriodRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTimePeriodWithRecordTypes(org.osid.type.Type[] timePeriodRecordTypes);


    /**
     *  Gets the time period form for creating new time periods. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  timePeriodRecordTypes array of time period record types 
     *  @return the time period form 
     *  @throws org.osid.NullArgumentException <code> timePeriodRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodForm getTimePeriodFormForCreate(org.osid.type.Type[] timePeriodRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> TimePeriod. </code> 
     *
     *  @param  timePeriodForm the forms for this <code> TimePeriod </code> 
     *  @return the new <code> TimePeriod </code> 
     *  @throws org.osid.IllegalStateException <code> timePeriodForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> timePeriodForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> timePeriodForm </code> 
     *          did not originate from <code> getTimePeriodForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriod createTimePeriod(org.osid.calendaring.TimePeriodForm timePeriodForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> TimePeriods. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> TimePeriod </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if time period modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateTimePeriods();


    /**
     *  Gets the time period form for updating an existing time period. A new 
     *  time period form should be requested for each update transaction. 
     *
     *  @param  timePeriodId the <code> Id </code> of the <code> TimePeriod 
     *          </code> 
     *  @return the time period form 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> timePeriodid </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodForm getTimePeriodFormForUpdate(org.osid.id.Id timePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing tiem period. 
     *
     *  @param  timePeriodForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> timePeriodForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> timePeriodForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> timePeriodForm </code> 
     *          did not originate from <code> getTimePeriodForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateTimePeriod(org.osid.calendaring.TimePeriodForm timePeriodForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> TimePeriods. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> TimePeriod </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> TimePeriod </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteTimePeriods();


    /**
     *  Deletes the <code> TimePeriod </code> identified by the given <code> 
     *  Id. </code> 
     *
     *  @param  timePeriodId the <code> Id </code> of the <code> TimePeriod 
     *          </code> to delete 
     *  @throws org.osid.NotFoundException a <code> TimePeriod </code> was not 
     *          found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteTimePeriod(org.osid.id.Id timePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  TimePeriods. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> TimePeriod </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageTimePeriodAliases();


    /**
     *  Adds an <code> Id </code> to a <code> TimePeriod </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> TimePeriod </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another time period, it is 
     *  reassigned to the given time period <code> Id. </code> 
     *
     *  @param  timePeriodId the <code> Id </code> of a <code> TimePeriod 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasTimePeriod(org.osid.id.Id timePeriodId, 
                                org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an exception event to a time period. Time period exception events 
     *  govern exceptions to recurring events mapped to a time period. 
     *
     *  @param  timePeriodId the <code> Id </code> of a <code> TimePeriod 
     *          </code> 
     *  @param  eventId an exception event <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException event is already part of the 
     *          time period 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> or 
     *          <code> eventId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> or 
     *          <code> eventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addExceptionEvent(org.osid.id.Id timePeriodId, 
                                  org.osid.id.Id eventId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an exception event from a time period. 
     *
     *  @param  timePeriodId the <code> Id </code> of a <code> TimePeriod 
     *          </code> 
     *  @param  eventId an exception event <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> eventId </code> not an 
     *          exception in <code> timePeriodId </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> or 
     *          <code> eventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeExceptionEvent(org.osid.id.Id timePeriodId, 
                                     org.osid.id.Id eventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
