//
// org.osid.calendaring.TimePeriodLookupSession
//
//     The OSID Java specification for org.osid.calendaring.TimePeriodLookupSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for retrieving <code> TimePeriod </code> 
 *  objects. The <code> TimePeriod </code> represents a period of time in 
 *  which to manage recurring events. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated calendar view: All time period methods in this session 
 *      operate, retrieve and pertain to time periods defined explicitly in 
 *      the current calendar. Using an isolated view is useful for managing 
 *      time periods with the <code> TimePeriodAdminSession. </code> </li> 
 *      <li> federated calendar view: All time period methods in this session 
 *      operate, retrieve and pertain to all time periods defined in this 
 *      calendar and any other calendars implicitly available in this calendar 
 *      through calendar inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Time periods may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> TimePeriod. </code> </p>
 */

public interface TimePeriodLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> TimePeriod </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupTimePeriods();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeTimePeriodView();


    /**
     *  A complete view of the <code> TimePeriod </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryTimePeriodView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include time periods in calendars which are children of this calendar 
     *  in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Gets the <code> TimePeriod </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> TimePeriod 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  TimePeriod </code> and retained for compatibility. 
     *
     *  @param  timePeriodId <code> Id </code> of the <code> TimePeriod 
     *          </code> 
     *  @return the time period 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.TimePeriod getTimePeriod(org.osid.id.Id timePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TimePeriodList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  time periods specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> TimePeriods </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  timePeriodIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> TimePeriod </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> rimePeriodIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsByIds(org.osid.id.IdList timePeriodIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TimePeriodList </code> corresponding to the given time 
     *  period genus <code> Type </code> which does not include time periods 
     *  of genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known time periods or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  time periods that are accessible through this session. 
     *
     *  @param  timePeriodGenusType a time period genus type 
     *  @return the returned <code> TimePeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> timePeriodGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsByGenusType(org.osid.type.Type timePeriodGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TimePeriodList </code> corresponding to the given time 
     *  period genus <code> Type </code> and include any additional time 
     *  periods with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known time 
     *  periods or an error results. Otherwise, the returned list may contain 
     *  only those time periods that are accessible through this session. 
     *
     *  @param  timePeriodGenusType a time period genus type 
     *  @return the returned <code> TimePeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> timePeriodGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsByParentGenusType(org.osid.type.Type timePeriodGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TimePeriodList </code> containing the given time period 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known time periods or an error results. Otherwise, the 
     *  returned list may contain only those time periods that are accessible 
     *  through this session. 
     *
     *  @param  timePeriodRecordType a time period record type 
     *  @return the returned <code> TimePeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> timePeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsByRecordType(org.osid.type.Type timePeriodRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TimePeriodList </code> containing the given <code> 
     *  DateTime. </code> Time periods containing the given date are matched. 
     *  In plenary mode, the returned list contains all of the time periods 
     *  specified in the <code> Id </code> list, in the order of the list, 
     *  including duplicates, or an error results if an <code> Id </code> in 
     *  the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> TimePeriods </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  datetime a date 
     *  @return the returned <code> TimePeriod </code> list 
     *  @throws org.osid.NullArgumentException <code> datetime </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsByDate(org.osid.calendaring.DateTime datetime)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TimePeriodList </code> corresponding to the given <code> 
     *  DateTime. </code> Time periods whose start end end times are included 
     *  in the given date range are matched.In plenary mode, the returned list 
     *  contains all of the time periods specified in the <code> Id </code> 
     *  list, in the order of the list, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible <code> TimePeriods </code> may 
     *  be omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *
     *  @param  start start of daterange 
     *  @param  end end of date range 
     *  @return the returned <code> TimePeriod </code> list 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsInDateRange(org.osid.calendaring.DateTime start, 
                                                                         org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> TimePeriods. </code> In plenary mode, the returned 
     *  list contains all known time periods or an error results. Otherwise, 
     *  the returned list may contain only those time periods that are 
     *  accessible through this session. 
     *
     *  @return a <code> TimePeriodList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriods()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
