//
// org.osid.calendaring.TimePeriodSearchSession
//
//     The OSID Java specification for org.osid.calendaring.TimePeriodSearchSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session provides methods for searching <code> TimePeriod </code> 
 *  objects. The search query is constructed using the <code> TimePeriodQuery. 
 *  </code> The time period record <code> Type </code> also specifies the 
 *  record for the time period query. </p> 
 *  
 *  <p> <code> getTimePeriodsByQuery() </code> is the basic search method and 
 *  returns a list of <code> TimePeriods. </code> A more advanced search may 
 *  be performed with <code> getTimePeriodsBySearch(). </code> It accepts a 
 *  <code> TimePeriodSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getTimePeriodsBySearch() </code> returns a <code> 
 *  TimePeriodSearchResults </code> that can be used to access the resulting 
 *  <code> TimePeriodList </code> or be used to perform a search within the 
 *  result set through <code> TimePeriodSearch. </code> </p> 
 *  
 *  <p> Time periods may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> TimePeriodQuery. 
 *  </code> </p>
 */

public interface TimePeriodSearchSession
    extends org.osid.calendaring.TimePeriodQuerySession {


    /**
     *  Gets a time period search. 
     *
     *  @return the time period search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodSearch getTimePeriodSearch();


    /**
     *  Gets a time period search order. The <code> TimePeriodSearchOrder 
     *  </code> is supplied to a <code> TimePeriodSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the time period search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodSearchOrder getTimePeriodSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  timePeriodQuery the time period query 
     *  @param  timePeriodSearch the time period search 
     *  @return the time period search results 
     *  @throws org.osid.NullArgumentException <code> timePeriodQuery </code> 
     *          or <code> timePeriodSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> timePeriodSearch </code> 
     *          or t <code> imePeriodQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodSearchResults getTimePeriodsBySearch(org.osid.calendaring.TimePeriodQuery timePeriodQuery, 
                                                                               org.osid.calendaring.TimePeriodSearch timePeriodSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a time period query from an inspector. The inspector is available 
     *  from a <code> TimePeriodSearchResults. </code> 
     *
     *  @param  timePeriodQueryInspector a time period query inspector 
     *  @return the time period query 
     *  @throws org.osid.NullArgumentException <code> timePeriodQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> timePeriodQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodQuery getTimePeriodQueryFromInspector(org.osid.calendaring.TimePeriodQueryInspector timePeriodQueryInspector);
}
