//
// org.osid.calendaring.TimePeriodSmartCalendarSession
//
//     The OSID Java specification for org.osid.calendaring.TimePeriodSmartCalendarSession.
//
// Copyright (C) 2002-2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2008-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> TimePeriodQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Calendar </code> to create a virtual 
 *  collection of <code> TomePeriods. </code> The entries may be sequenced 
 *  using the <code> TimePeriodSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Calendar </code> has a default query that matches any time 
 *  period and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> TimePeriodQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  TimePeriodQuery. </code> </p>
 */

public interface TimePeriodSmartCalendarSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart calendars. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart calendar methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCalendars();


    /**
     *  Gets a time period query. 
     *
     *  @return the time period query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodQuery getTimePeriodQuery();


    /**
     *  Gets a time period search order. 
     *
     *  @return the time period search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodSearchOrder getTimePeriodSearchOrder();


    /**
     *  Applies a time period query to this calendar. 
     *
     *  @param  timePeriodQuery the time period query 
     *  @throws org.osid.NullArgumentException <code> timePeriodQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> timePeriodQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyTimePeriodQuery(org.osid.calendaring.TimePeriodQuery timePeriodQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a time period query inspector for this calendar. 
     *
     *  @return the time period query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodQueryInspector inspectTimePeriodQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a time period search order to this calendar. 
     *
     *  @param  timePeriodSearchOrder the time period search order 
     *  @throws org.osid.NullArgumentException <code> timePeriodSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> timePeriodSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyTimePeriodSequencing(org.osid.calendaring.TimePeriodSearchOrder timePeriodSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a time period query from an inspector. 
     *
     *  @param  timePeriodQueryInspector a time period query inspector 
     *  @return the time period query interface 
     *  @throws org.osid.NullArgumentException <code> timePeriodQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> timePeriodQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodQuery getTimePeriodQueryFromInspector(org.osid.calendaring.TimePeriodQueryInspector timePeriodQueryInspector);
}
