//
// org.osid.calendaring.batch.CalendarBatchAdminSession
//
//     The OSID Java specification for org.osid.calendaring.batch.CalendarBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Calendars </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Calendar, </code> a <code> CalendarForm </code> is requested using <code> 
 *  getCalendarFormsForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> CalendarForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> CalendarForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  CalendarForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> CalendarForms </code> returned from <code> 
 *  getCalendarFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> CalendarForm. 
 *  </code> In the case where there may be duplicates, any <code> CalendarForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> CalendarForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> CalendarForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createCalendars(), 
 *  </code> errors specific to an individual <code> CalendarForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  CalendarForm </code> through the <code> CalendarForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> CalendarForms </code> are requested to the <code> 
 *  Calendar </code> <code> Id </code> that is to be updated using <code> 
 *  getCalendarFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> CalendarForm </code> may be used to link the request. 
 *  Similarly, the <code> CalendarForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> CalendarForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> CalendarForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> CalendarForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateCalendars(), 
 *  </code> errors specific to an individual <code> CalendarForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  CalendarForm </code> through the <code> CalendarForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Calendars </code> in bulk. To 
 *  unmap a <code> Calendar </code> from the current <code> Calendar, </code> 
 *  the <code> CalendarCalendarAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Calendar </code> itself 
 *  thus removing it from all known <code> Calendar </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface CalendarBatchAdminSession
    extends org.osid.calendaring.CalendarAdminSession {


    /**
     *  Gets the calendar forms for creating a bunch of new calendars. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  calendarRecordTypes array of calendar record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the calendar forms 
     *  @throws org.osid.NullArgumentException <code> calendarRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.batch.CalendarBatchFormList getCalendarFormsForCreate(long number, 
                                                                                      org.osid.type.Type[] calendarRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Calendars. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  calendarForms the calendar forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> calendarForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCalendars(org.osid.calendaring.batch.CalendarBatchFormList calendarForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the calendar forms for updating an existing set of calendars. A 
     *  new calendar form should be requested for each update transaction. 
     *
     *  @param  calendarIds the <code> Ids </code> of the <code> Calendar 
     *          </code> 
     *  @return the calendar form 
     *  @throws org.osid.NotFoundException a <code> calendarId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> calendarIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.batch.CalendarBatchFormList getCalendarFormsForUpdate(org.osid.id.IdList calendarIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing calendars. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  calendarForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> calendarForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCalendars(org.osid.calendaring.batch.CalendarBatchFormList calendarForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Calendars </code> in this <code> Calendar </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCalendars()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes calendars for the given <code> Ids. </code> 
     *
     *  @param  calendarIds the <code> Ids </code> of the calendars to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> calendarIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCalendars(org.osid.id.IdList calendarIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Calendar </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Calendar </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another calendar, it is reassigned to the given calendar 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCalendars(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
