//
// org.osid.calendaring.batch.CalendaringBatchProfile
//
//     The OSID Java specification for org.osid.calendaring.batch.CalendaringBatchProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.batch;


/**
 *  <p>The <code> CalendaringBatchProfile </code> describes the 
 *  interoperability among batch calendaring services. </p>
 */

public interface CalendaringBatchProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if bulk administration of events is available. 
     *
     *  @return <code> true </code> if an event bulk administrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEventBatchAdmin();


    /**
     *  Tests if bulk administration of recurring events is available. 
     *
     *  @return <code> true </code> if a recurring event bulk administrative 
     *          service is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventBatchAdmin();


    /**
     *  Tests if bulk administration of offset events is available. 
     *
     *  @return <code> true </code> if an offset event bulk administrative 
     *          service is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventBatchAdmin();


    /**
     *  Tests if bulk administration of schedules is available. 
     *
     *  @return <code> true </code> if a schedule bulk administrative service 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleBatchAdmin();


    /**
     *  Tests if bulk administration of schedule slots is available. 
     *
     *  @return <code> true </code> if an schedule slot bulk administrative 
     *          service is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsScheduleSlotBatchAdmin();


    /**
     *  Tests if bulk administration of commitments is available. 
     *
     *  @return <code> true </code> if a commitment bulk administrative 
     *          service is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentBatchAdmin();


    /**
     *  Tests if bulk administration of time periods is available. 
     *
     *  @return <code> true </code> if a time period bulk administrative 
     *          service is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodBatchAdmin();


    /**
     *  Tests if bulk administration of calendars is available. 
     *
     *  @return <code> true </code> if a calendar bulk administrative service 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendarBatchAdmin();
}
