//
// org.osid.calendaring.cycle.CalendaringCycleManager
//
//     The OSID Java specification for org.osid.calendaring.cycle.CalendaringCycleManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>The calendaring cycle manager provides access to calendaring cycle 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CyclicEventLookupSession: </code> a session to look up 
 *      cyclic events </li> 
 *      <li> <code> CyclicEventQuerySession: </code> a session to query cyclic 
 *      events <code> </code> </li> 
 *      <li> <code> CyclicEventSearchSession: </code> a session to search 
 *      cyclic events </li> 
 *      <li> <code> CyclicEventAdminSession: </code> a session to create, 
 *      modify and delete cyclic events <code> </code> </li> 
 *      <li> <code> CyclicEventNotificationSession: a </code> session to 
 *      receive messages pertaining to cyclic event <code> </code> changes 
 *      </li> 
 *      <li> <code> CyclicEventCalendarSession: </code> a session for 
 *      retriieving cyclic event and calendar mappings </li> 
 *      <li> <code> CyclicEventCalendarAssignmentSession: </code> a session 
 *      for managing cyclic event and calendar mappings </li> 
 *      <li> <code> CyclicEventSmartCalendarSession: </code> a session to 
 *      manage dynamic cyclic event catalogs </li> 
 *      <li> <code> EventCyclicEventLookupSession: </code> a session to look 
 *      up the associations between events and cyclic events </li> 
 *      <li> <code> EventCyclicEventAssignmentSession: </code> a session to 
 *      manually map events to cyclic events </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CyclicTimePeriodLookupSession: </code> a session to look 
 *      up cyclic time periods </li> 
 *      <li> <code> CyclicTimePeriodQuerySession: </code> a session to query 
 *      cyclic time periods <code> </code> </li> 
 *      <li> <code> CyclicTimePeriodSearchSession: </code> a session to search 
 *      cyclic time periods </li> 
 *      <li> <code> CyclicTimePeriodAdminSession: </code> a session to create, 
 *      modify and delete cyclic time periods <code> </code> </li> 
 *      <li> <code> CyclicTimePeriodNotificationSession: a </code> session to 
 *      receive messages pertaining to cyclic time period <code> </code> 
 *      changes </li> 
 *      <li> <code> CyclicTimePeriodCalendarSession: </code> a session for 
 *      retriieving cyclic time period and calendar mappings </li> 
 *      <li> <code> CyclicTimePeriodCalendarAssignmentSession: </code> a 
 *      session for managing cyclic time period and calendar mappings </li> 
 *      <li> <code> CyclicTimePeriodSmartCalendarSession: </code> a session to 
 *      manage dynamic cyclic time period catalogs </li> 
 *      <li> <code> TimePeriodCyclicTimePeriodLookupSession: </code> a session 
 *      to look up the associations between time periods and cyclic time 
 *      periods </li> 
 *      <li> <code> TimePeriodCyclicTimePeriodAssignmentSession: </code> a 
 *      session to manually map time periods to cyclic time periods </li> 
 *  </ul>
 *  
 */

public interface CalendaringCycleManager
    extends org.osid.OsidManager,
            org.osid.calendaring.cycle.CalendaringCycleProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  lookup service. 
     *
     *  @return a <code> CyclicEventLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventLookupSession getCyclicEventLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicEventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventLookupSession getCyclicEventLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  query service. 
     *
     *  @return a <code> CyclicEventQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventQuerySession getCyclicEventQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicEventQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventQuerySession getCyclicEventQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  search service. 
     *
     *  @return a <code> CyclicEventSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventSearchSession getCyclicEventSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicEventSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventSearchSession getCyclicEventSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  administration service. 
     *
     *  @return a <code> CyclicEventAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventAdmin() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventAdminSession getCyclicEventAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicEventAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventAdminSession getCyclicEventAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to cyclic 
     *  event changes. 
     *
     *  @param  cyclicEventReceiver the cyclic event receiver 
     *  @return a <code> CyclicEventNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicEventReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventNotificationSession getCyclicEventNotificationSession(org.osid.calendaring.cycle.CyclicEventReceiver cyclicEventReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic event 
     *  notification service for the given calendar. 
     *
     *  @param  cyclicEventReceiver the cyclic event receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicEventNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> cyclicEventReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventNotificationSession getCyclicEventNotificationSessionForCalendar(org.osid.calendaring.cycle.CyclicEventReceiver cyclicEventReceiver, 
                                                                                                                  org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving cyclic event to calendar mappings. 
     *
     *  @return a <code> CyclicEventCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventCalendar() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventCalendarSession getCyclicEventCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning event to calendar mappings. 
     *
     *  @return a <code> CyclicEventCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventCalendarAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventCalendarAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventCalendarAssignmentSession getCyclicEventCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the cyclic event smart calendar for 
     *  the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicEventSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicEventSmartCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicEventSmartCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventSmartCalendarSession getCyclicEventSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving event to cyclic event associations. 
     *
     *  @return an <code> EventCyclicEventLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventLookupSession getEventCyclicEventLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event cyclic 
     *  event lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventCyclicEventLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventLookupSession getEventCyclicEventLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for manually making event to cyclic event 
     *  associations. 
     *
     *  @return an <code> EventCyclicEventAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventAssignmentSession getEventCyclicEventAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the event cyclic 
     *  event assignment service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return an <code> EventCyclicEventAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEventCyclicEventAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEventCyclicEventAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.EventCyclicEventAssignmentSession getEventCyclicEventAssignmentSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period lookup service. 
     *
     *  @return a <code> CyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodLookupSession getCyclicTimePeriodLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodLookupSession getCyclicTimePeriodLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period query service. 
     *
     *  @return a <code> CyclicTimePeriodQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodQuerySession getCyclicTimePeriodQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicTimePeriodQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodQuerySession getCyclicTimePeriodQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period search service. 
     *
     *  @return a <code> CyclicTimePeriodSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSearchSession getCyclicTimePeriodSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period search service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicTimePeriodSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSearchSession getCyclicTimePeriodSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period administration service. 
     *
     *  @return a <code> CyclicTimePeriodAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodAdminSession getCyclicTimePeriodAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period admin service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicTimePeriodAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodAdminSession getCyclicTimePeriodAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to cyclic 
     *  time period changes. 
     *
     *  @param  cyclicTimePeriodReceiver the cyclic time period receiver 
     *  @return a <code> CyclicTimePeriodNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodNotificationSession getCyclicTimePeriodNotificationSession(org.osid.calendaring.cycle.CyclicTimePeriodReceiver cyclicTimePeriodReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the cyclic time 
     *  period notification service for the given calendar. 
     *
     *  @param  cyclicTimePeriodReceiver the cyclic time period receiver 
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return <code> a CyclicTimePeriodNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodReceiver 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodNotificationSession getCyclicTimePeriodNotificationSessionForCalendar(org.osid.calendaring.cycle.CyclicTimePeriodReceiver cyclicTimePeriodReceiver, 
                                                                                                                            org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving cyclic time period to calendar 
     *  mappings. 
     *
     *  @return a <code> CyclicTimePeriodCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodCalendar() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodCalendarSession getCyclicTimePeriodCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning cyclic time period to calendar 
     *  mappings. 
     *
     *  @return a <code> CyclicTimePeriodCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodCalendarAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodCalendarAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodCalendarAssignmentSession getCyclicTimePeriodCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the cyclic time period smart calendar 
     *  for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> CyclicTimePeriodSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCyclicTimePeriodSmartCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCyclicTimePeriodSmartCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSmartCalendarSession getCyclicTimePeriodSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving time period to cyclic time period 
     *  associations. 
     *
     *  @return a <code> TimePeriodCyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodLookupSession getTimePeriodCyclicTimePeriodLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  cyclic time period lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> TimePeriodCyclicTimePeriodLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodLookupSession getTimePeriodCyclicTimePeriodLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for manually making time period to cyclic time period 
     *  associations. 
     *
     *  @return a <code> TimePeriodCyclicTimePeriodAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodAssignmentSession getTimePeriodCyclicTimePeriodAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the time period 
     *  cyclic time period assignment service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the calendar 
     *  @return a <code> TimePeriodCyclicTimePeriodAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodCyclicTimePeriodAssignment() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodCyclicTimePeriodAssignment() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodAssignmentSession getTimePeriodCyclicTimePeriodAssignmentSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a <code> CalendaringCycleBatchManager. </code> 
     *
     *  @return a <code> CalendaringCycleBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendaringCycleBatch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendaringCycleBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.cycle.batch.CalendaringCycleBatchManager getCalendaringCycleBatchManager()
        throws org.osid.OperationFailedException;
}
