//
// org.osid.calendaring.cycle.CyclicEventAdminSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicEventAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session creates, updates, and deletes <code> Cyclic Events. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CyclicEvent, </code> a <code> CyclicEventForm </code> is requested using 
 *  <code> getCyclicEventFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> CycllicEventForm </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> CyclicEventForm </code> 
 *  is submiited to a create operation, it cannot be reused with another 
 *  create operation unless the first operation was unsuccessful. Each <code> 
 *  CyclicEventForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CycliccEventForms </code> are requested to the 
 *  <code> CyclicEvent </code> <code> Id </code> that is to be updated using 
 *  <code> getCyclicEventFormForUpdate(). </code> Similarly, the <code> 
 *  CyclicEventForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  CyclicEventForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Cyclic Events. </code> To unmap a 
 *  <code> CyclicEvent </code> from the current <code> Calendar, </code> the 
 *  <code> CyclicEventCalendarAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> CyclicEvent </code> itself 
 *  thus removing it from all known <code> Calendar </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CyclicEventAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> CyclicEvents. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> CyclicEvent </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CyclicEvent </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCyclicEvents();


    /**
     *  Tests if this user can create a single <code> CyclicEvent </code> 
     *  using the desired record types. While <code> 
     *  CalendaringCycleManager.getCyclicEventRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> CyclicEvent. 
     *  </code> Providing an empty array tests if a <code> CyclicEvent </code> 
     *  can be created with no records. 
     *
     *  @param  cyclicEventRecordTypes array of cyclic event record types 
     *  @return <code> true </code> if <code> CyclicEvent </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> cyclicEventRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCyclicEventWithRecordTypes(org.osid.type.Type[] cyclicEventRecordTypes);


    /**
     *  Gets the cyclic event form for creating new cyclic events. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  cyclicEventRecordTypes array of cyclic event record types 
     *  @return the cyclic event form 
     *  @throws org.osid.NullArgumentException <code> cyclicEventRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEventForm getCyclicEventFormForCreate(org.osid.type.Type[] cyclicEventRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CyclicEvent. </code> 
     *
     *  @param  cyclicEventForm the form for this <code> CyclicEvent </code> 
     *  @return the new <code> CyclicEvent </code> 
     *  @throws org.osid.IllegalStateException <code> cyclicEventForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> cyclicEventForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> cyclicEventForm </code> 
     *          did not originate from <code> getCyclicEventFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEvent createCyclicEvent(org.osid.calendaring.cycle.CyclicEventForm cyclicEventForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> CyclicEvents. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> CyclicEvent </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if cyclic event modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCyclicEvents();


    /**
     *  Gets the cyclic event form for updating an existing cyclic event. A 
     *  new event form should be requested for each update transaction. 
     *
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> 
     *  @return the cyclic event form 
     *  @throws org.osid.NotFoundException <code> cyclicEventId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEventForm getCyclicEventFormForUpdate(org.osid.id.Id cyclicEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing cyclic event. 
     *
     *  @param  cyclicEventForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> cyclicEventForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> cyclicEventForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> cyclicEventForm </code> 
     *          did not originate from <code> getCyclicEventFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCyclicEvent(org.osid.calendaring.cycle.CyclicEventForm cyclicEventForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> CyclicEvents. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> CyclicEvent </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CyclicEvent </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCyclicEvents();


    /**
     *  Deletes the <code> CyclicEvent </code> identified by the given <code> 
     *  Id. </code> 
     *
     *  @param  cyclicEventId the <code> Id </code> of the <code> CyclicEvent 
     *          </code> to delete 
     *  @throws org.osid.NotFoundException a <code> CyclicEvent </code> was 
     *          not found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCyclicEvent(org.osid.id.Id cyclicEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  CyclicEvents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CyclicEvent </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCyclicEventAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CyclicEvent </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CyclicEvent </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another cyclic event, it is 
     *  reassigned to the given cyclic event <code> Id. </code> 
     *
     *  @param  cyclicEventId the <code> Id </code> of a <code> CyclicEvent 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> cyclicEventId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCyclicEvent(org.osid.id.Id cyclicEventId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
