//
// org.osid.calendaring.cycle.CyclicTimePeriodSearchSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.CyclicTimePeriodSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods for searching <code> CyclicTimePeriod 
 *  </code> objects. The search query is constructed using the <code> 
 *  CyclicTimePeriodQuery. </code> The cyclic time period record <code> Type 
 *  </code> also specifies the record for the cyclic time period query. </p> 
 *  
 *  <p> <code> getCyclicTimePeriodsByQuery() </code> is the basic search 
 *  method and returns a list of <code> CyclicTimePeriods. </code> A more 
 *  advanced search may be performed with <code> 
 *  getCyclicTimePeriodsBySearch(). </code> It accepts a <code> 
 *  CyclicTimePeriodSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCyclicTimePeriodsBySearch() </code> returns a <code> 
 *  CyclicTimePeriodSearchResults </code> that can be used to access the 
 *  resulting <code> CyclicTimePeriodList </code> or be used to perform a 
 *  search within the result set through <code> CyclicTimePeriodSearch. 
 *  </code> </p> 
 *  
 *  <p> Cyclic time periods may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  CyclicTimePeriodQuery. </code> </p>
 */

public interface CyclicTimePeriodSearchSession
    extends org.osid.calendaring.cycle.CyclicTimePeriodQuerySession {


    /**
     *  Gets a cyclic time period search. 
     *
     *  @return the cyclic time period search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSearch getCyclicTimePeriodSearch();


    /**
     *  Gets a cyclic time period search order. The <code> 
     *  CyclicTimePeriodSearchOrder </code> is supplied to a <code> 
     *  CyclicTimePeriodSearch </code> to specify the ordering of results. 
     *
     *  @return the cyclic time period search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSearchOrder getCyclicTimePeriodSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  cyclicTimePeriodQuery the cyclic time period query 
     *  @param  cyclicTimePeriodSearch the cyclic time period search 
     *  @return the cyclic time period search results 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodQuery 
     *          </code> or <code> cyclicTimePeriodSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> cyclicTimePeriodSearch 
     *          </code> or t <code> imePeriodQuery </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodSearchResults getCyclicTimePeriodsBySearch(org.osid.calendaring.cycle.CyclicTimePeriodQuery cyclicTimePeriodQuery, 
                                                                                                 org.osid.calendaring.cycle.CyclicTimePeriodSearch cyclicTimePeriodSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a cyclic time period query from an inspector. The inspector is 
     *  available from a <code> CyclicTimePeriodSearchResults. </code> 
     *
     *  @param  cyclicTimePeriodQueryInspector a cyclic time period query 
     *          inspector 
     *  @return the cyclic time period query 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          cyclicTimePeriodQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodQuery getCyclicTimePeriodQueryFromInspector(org.osid.calendaring.cycle.CyclicTimePeriodQueryInspector cyclicTimePeriodQueryInspector);
}
