//
// org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodLookupSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.TimePeriodCyclicTimePeriodLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle;


/**
 *  <p>This session provides methods to retrieve <code> CyclicTimePeriod 
 *  </code> to <code> TimePeriod </code> mappings. A <code> TimePeriod </code> 
 *  may be mapped to multiple <code> CyclicTimePeriods </code> explicitly or 
 *  through a rule-based generation. </p> 
 *  
 *  <p> This lookup session defines two views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated calendar view: All cyclic time period methods in this 
 *      session operate, retrieve and pertain to cyclic time periods defined 
 *      explicitly in the current calendar. </li> 
 *      <li> federated calendar view: All cyclic time period methods in this 
 *      session operate, retrieve and pertain to all cyclic time periods 
 *      defined in this calendar and any other calendars implicitly available 
 *      in this calendar through calendar inheritence. </li> 
 *  </ul>
 *  
 */

public interface TimePeriodCyclicTimePeriodLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the <code> Calendar </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of tiem period/cyclic time 
     *  period mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupTimePeriodCyclicTimePeriodMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCalendarView();


    /**
     *  A complete view of the <code> CyclicTimePeriod </code> and <code> 
     *  TmePeriod </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCalendarView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include cyclic time periods in calendars which are children of this 
     *  calendar in the calendar hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCalendarView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this calendar only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCalendarView();


    /**
     *  Gets the list of <code> TimePeriod </code> <code> Ids </code> 
     *  associated with a <code> CyclicTimePeriod. </code> 
     *
     *  @param  cyclicTimePeriodId <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @return list of related time period <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getTimePeriodIdsByCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> TimePeriods </code> associated with a <code> 
     *  CyclicTimePeriod. </code> 
     *
     *  @param  cyclicTimePeriodId <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @return list of related time periods 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsByCyclicTimePeriod(org.osid.id.Id cyclicTimePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> TimePeriod </code> <code> Ids </code> between 
     *  the given date range included associated with a <code> 
     *  CyclicTimePeriod. </code> 
     *
     *  @param  cyclicTimePeriodId <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of related time period <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getTimePeriodIdsByCyclicTimePeriodAndDate(org.osid.id.Id cyclicTimePeriodId, 
                                                                        org.osid.calendaring.DateTime from, 
                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> TimePeriods </code> between the given date 
     *  range included associated with a <code> CyclicTimePeriod. </code> 
     *
     *  @param  cyclicTimePeriodId <code> Id </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return list of related cyclic time periods 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriodList getTimePeriodsByCyclicTimePeriodAndDate(org.osid.id.Id cyclicTimePeriodId, 
                                                                                       org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> CyclicTimePeriod Ids </code> mapped to a 
     *  <code> TimePeriod. </code> 
     *
     *  @param  timePeriodId <code> Id </code> of a <code> TimePeriod </code> 
     *  @return list of cyclic time period <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCyclicTimePeriodIdsByTimePeriod(org.osid.id.Id timePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> CyclicTimePeriods </code> mapped to a <code> 
     *  TimePeriod. </code> 
     *
     *  @param  timePeriodId <code> Id </code> of a <code> TimePeriod </code> 
     *  @return list of cyclic time periods 
     *  @throws org.osid.NotFoundException <code> timePeriodId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicTimePeriodList getCyclicTimePeriodsByTimePeriod(org.osid.id.Id timePeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
