//
// org.osid.calendaring.cycle.batch.CyclicTimePeriodBatchAdminSession
//
//     The OSID Java specification for org.osid.calendaring.cycle.batch.CyclicTimePeriodBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.cycle.batch;


/**
 *  <p>This session creates, updates, and deletes <code> CyclicTimePeriods 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CyclicTimePeriod, </code> a <code> CyclicTimePeriodForm </code> is 
 *  requested using <code> getCyclicTimePeriodFormsForCreate() </code> 
 *  specifying the desired record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  CyclicTimePeriodForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> CyclicTimePeriodForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> CyclicTimePeriodForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> CyclicTimePeriodForms </code> returned from <code> 
 *  getCyclicTimePeriodFormsForCreate() </code> may be linked to the 
 *  originating request through the peer <code> Ids </code> of the <code> 
 *  CyclicTimePeriodForm. </code> In the case where there may be duplicates, 
 *  any <code> CyclicTimePeriodForm </code> of the same peer <code> Ids 
 *  </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> CyclicTimePeriodForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  CyclicTimePeriodForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createCyclicTimePeriods(), </code> errors specific to an individual 
 *  <code> CyclicTimePeriodForm </code> are indicated in the corresponding 
 *  <code> CreateResponse. </code> <code> CreateResponses </code> may be 
 *  linked to the originating <code> CyclicTimePeriodForm </code> through the 
 *  <code> CyclicTimePeriodForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> CyclicTimePeriodForms </code> are requested to the 
 *  <code> CyclicTimePeriod </code> <code> Id </code> that is to be updated 
 *  using <code> getCyclicTimePeriodFormsForUpdate() </code> where the 
 *  reference <code> Id </code> in the <code> CyclicTimePeriodForm </code> may 
 *  be used to link the request. Similarly, the <code> CyclicTimePeriodForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> CyclicTimePeriodForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> CyclicTimePeriodForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  CyclicTimePeriodForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateCyclicTimePeriods(), </code> errors specific to an individual 
 *  <code> CyclicTimePeriodForm </code> are indicated in the corresponding 
 *  <code> UpdateResponse. </code> <code> UpdateResponses </code> may be 
 *  linked to the originating <code> CyclicTimePeriodForm </code> through the 
 *  <code> CyclicTimePeriodForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> CyclicTimePeriods </code> in bulk. 
 *  To unmap a <code> CyclicTimePeriod </code> from the current <code> 
 *  Calendar, </code> the <code> CyclicTimePeriodCalendarAssignmentSession 
 *  </code> should be used. These delete operations attempt to remove the 
 *  <code> CyclicTimePeriod </code> itself thus removing it from all known 
 *  <code> Calendar </code> catalogs. Bulk delete operations return the 
 *  results in <code> DeleteResponses. </code> </p>
 */

public interface CyclicTimePeriodBatchAdminSession
    extends org.osid.calendaring.cycle.CyclicTimePeriodAdminSession {


    /**
     *  Gets the cyclic time period forms for creating a bunch of new cyclic 
     *  time periods. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  cyclicTimePeriodRecordTypes array of cyclic time period record 
     *          types to be included in each create operation or an empty list 
     *          if none 
     *  @return the cyclic time period forms 
     *  @throws org.osid.NullArgumentException <code> 
     *          cyclicTimePeriodRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.batch.CyclicTimePeriodBatchFormList getCyclicTimePeriodFormsForCreate(long number, 
                                                                                                            org.osid.type.Type[] cyclicTimePeriodRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> CyclicTimePeriods. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  cyclicTimePeriodForms the cyclic time period forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCyclicTimePeriods(org.osid.calendaring.cycle.batch.CyclicTimePeriodBatchFormList cyclicTimePeriodForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the cyclic time period forms for updating an existing set of 
     *  cyclic time periods. A new cyclic time period form should be requested 
     *  for each update transaction. 
     *
     *  @param  cyclicTimePeriodIds the <code> Ids </code> of the <code> 
     *          CyclicTimePeriod </code> 
     *  @return the cyclic time period form 
     *  @throws org.osid.NotFoundException a <code> cyclicTimePeriodId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.batch.CyclicTimePeriodBatchFormList getCyclicTimePeriodFormsForUpdate(org.osid.id.IdList cyclicTimePeriodIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing cyclic time periods. This method returns an error if 
     *  the entire operation fails. Otherwise, the status of an individual 
     *  update operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  cyclicTimePeriodForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCyclicTimePeriods(org.osid.calendaring.cycle.batch.CyclicTimePeriodBatchFormList cyclicTimePeriodForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> CyclicTimePeriods </code> in this <code> Calendar 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCyclicTimePeriods()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes cyclic time periods for the given <code> Ids. </code> 
     *
     *  @param  cyclicTimePeriodIds the <code> Ids </code> of the cyclic time 
     *          periods to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> cyclicTimePeriodIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCyclicTimePeriods(org.osid.id.IdList cyclicTimePeriodIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> CyclicTimePeriod </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CyclicTimePeriod </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another cyclic time period, it is reassigned 
     *  to the given cyclic time period <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCyclicTimePeriods(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
