/**
 * <p>The Open Service Interface Definitions for the org.osid.calendaring
 * service.</p>
 * 
 * <p>The Calendaring OSID manages events, commitments and calendars. The 
 * Calendaring OSID offers a rich set of event management services. </p> 
 * <h4> Event </h4> 
 * 
 * <p> An <code> Event </code> is range of time associated with a <code> 
 * Location </code> and event sponsors. <code> Events </code> may be managed 
 * singularly, or be generated of of one of the typs of events listed below. 
 * </p> 
 * <h4> Offset Events </h4> 
 * 
 * <p> An <code> OffSetEvent </code> is an <code> OsidRule </code> for 
 * generating an <code> Event </code> off of another Event. An <code> 
 * OffsetEvent </code> may be offset by a fixed period of time, a weekday, or 
 * include an external <code> Rule </code> to determine the offset. Example 
 * <code> OffsetEvents </code> are "the first Tuesday after Labor Day" or "24 
 * hours before a due date." </p> 
 * <h4> Superseding Events </h4> 
 * 
 * <p> A <code> SupersedingEvent </code> is an <code> OsidRule </code> for 
 * replacing another <code> Event. </code> Typically, <code> SupersedingEvents 
 * </code> are used for replacing a generated <code> Event </code> from a 
 * recurring event series. <code> Events </code> may be superseded by date or 
 * position in a recruring even seriest. Examples are "replace the event on 
 * 12/25 with an event scheduled for 12/26" or "replace the 10th event in a 
 * course schedule with an exam." </p> 
 * <h4> Recurring Events </h4> 
 * 
 * <p> A <code> RecurringEvent </code> generates a series of <code> Events 
 * </code> from a Schedule. A <code> Schedule </code> is a series of times and 
 * locations. </p> 
 * 
 * <p> A RecurringEvent may include <code> SupersedingEvents </code> to 
 * replace specific events in the series with another <code> Event </code> 
 * which may, in turn, be another RecurringEvent. <code> RecurringEvents 
 * </code> may also have a set of blackout dates in which <code> Event </code> 
 * generation is suuppressed. </p> 
 * <h4> Schedules </h4> 
 * 
 * <p> A <code> Schedule </code> describes a repeating time and Location. 
 * <code> Schedules </code> may be bounded by dates or by using a <code> 
 * TimePeriod. </code> A <code> TimePeriod </code> is a reusable date range 
 * and may include a set of exception <code> Events </code> to define a set of 
 * time ranges that any <code> RecurringEvent </code> mapped to the <code> 
 * TimePeriod </code> may not occur. </p> 
 * 
 * <p> <code> Schedules </code> are composed of <code> ScheduleSlots. </code> 
 * <code> ScheduleSlots </code> are normalized weekly time slots. A <code> 
 * ScheduleSlot </code> may be composed of other <code> ScheduleSlots. </code> 
 * </p> 
 * 
 * <p> To make a <code> RecurringEvent </code> for MWF 3pm in room 26-100 
 * during the summer except July 4th: </p> 
 * 
 * <ul>
 *     <li> A <code> ScheduleSlot </code> for MWF 3pm is created. </li> 
 *     <li> A <code> Schedule </code> is created using the ScheduleSlot for 
 *     room 10-250 in the summer <code> TimePeriod. </code> </li> 
 *     <li> A <code> RecurringEvent </code> is created using the Schedule. 
 *     </li> 
 *     <li> A blackout date for Independence Day is added to the <code> 
 *     RecurringEvent. </code> </li> 
 * </ul>
 * 
 * <h4> Commitments </h4> 
 * 
 * <p> <code> Commitments </code> are <code> OsidRelationships </code> between 
 * <code> Resources </code> and Events. <code> Commitments </code> may include 
 * any data specific to the relationship. </p> 
 * <h4> Calendaring Catalogging </h4> 
 * 
 * <p> <code> Events </code> and <code> Schedules </code> are cataloged into 
 * <code> Calendars. </code> The <code> Calendar </code> is simply an <code> 
 * OsidCatalog </code> representing a collection of <code> Events </code> that 
 * may be federated using the OSID hierarchy pattern to create virtual 
 * calendars. </p> 
 * <h4> Calendaring Rules </h4> 
 * 
 * <p> The Calendaring OSID includes a rules package for managing the behavior 
 * of <code> Commitments </code> and <code> Events. It also includes </code> a 
 * Calendaring Cycle OSID for managing canonical events and time periods as 
 * well as a Calendaring Mason OSID for defining rules for building events and 
 * time periods. The Calendaring Batch OSID manages <code> Events, </code> 
 * <code> Commitments, </code> and <code> TimePeriods </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004 Massachusetts Institute of Technology. </p> 
 * 
 * <p> Copyright &copy; 2008-2011 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.calendaring;
