//
// org.osid.calendaring.rules.CalendaringRulesManager
//
//     The OSID Java specification for org.osid.calendaring.rules.CalendaringRulesManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>The calendaring rules manager provides access to calendaring rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RecurringEventEnablerLookupSession: </code> a session to 
 *      retrieve recurring event enablers </li> 
 *      <li> <code> RecurringEventEnablerQuerySession: </code> a session to 
 *      query for recurring event enablers </li> 
 *      <li> <code> RecurringEventEnablerSearchSession: </code> a session to 
 *      search for recurring event enablers </li> 
 *      <li> <code> RecurringEventEnablerAdminSession: </code> a session to 
 *      create and delete recurring event enablers </li> 
 *      <li> <code> RecurringEventEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to recurring event enabler 
 *      changes </li> 
 *      <li> <code> RecurringEventEnablerCalendarSession: </code> a session to 
 *      look up recurring event enabler calendar mappings </li> 
 *      <li> <code> RecurringEventEnablerCalendarAssignmentSession: </code> a 
 *      session to manage recurring event enabler to calendar mappings </li> 
 *      <li> <code> RecurringEventEnablerSmartCalendarSession: </code> a 
 *      session to manage dynamic calendars of recurring event enablers </li> 
 *      <li> <code> RecurringEventEnablerRuleLookupSession: </code> a session 
 *      to look up recurring event enabler mappings </li> 
 *      <li> <code> RecurringEventEnablerRuleApplicationSession: </code> a 
 *      session to apply recurring event enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> OffsetEventEnablerLookupSession: </code> a session to 
 *      retrieve offset event enablers </li> 
 *      <li> <code> OffsetEventEnablerQuerySession: </code> a session to query 
 *      for offset event enablers </li> 
 *      <li> <code> OffsetEventEnablerSearchSession: </code> a session to 
 *      search for offset event enablers </li> 
 *      <li> <code> OffsetEventEnablerAdminSession: </code> a session to 
 *      create and delete offset event enablers </li> 
 *      <li> <code> OffsetEventEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to offset event enabler changes 
 *      </li> 
 *      <li> <code> OffsetEventEnablerCalendarSession: </code> a session to 
 *      look up offset event enabler calendar mappings </li> 
 *      <li> <code> OffsetEventEnablerCalendarAssignmentSession: </code> a 
 *      session to manage offset event enabler to calendar mappings </li> 
 *      <li> <code> OffsetEventEnablerSmartCalendarSession: </code> a session 
 *      to manage dynamic calendars of offset event enablers </li> 
 *      <li> <code> OffsetEventEnablerRuleLookupSession: </code> a session to 
 *      look up offset event enabler mappings </li> 
 *      <li> <code> OffsetEventEnablerRuleApplicationSession: </code> a 
 *      session to apply offset event enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SupersedingEventEnablerLookupSession: </code> a session to 
 *      retrieve superseding event enablers </li> 
 *      <li> <code> SupersedingEventEnablerQuerySession: </code> a session to 
 *      query for superseding event enablers </li> 
 *      <li> <code> SupersedingEventEnablerSearchSession: </code> a session to 
 *      search for superseding event enablers </li> 
 *      <li> <code> SupersedingEventEnablerAdminSession: </code> a session to 
 *      create and delete superseding event enablers </li> 
 *      <li> <code> SupersedingEventEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to superseding event 
 *      enabler changes </li> 
 *      <li> <code> SupersedingEventEnablerCalendarSession: </code> a session 
 *      to look up superseding event enabler calendar mappings </li> 
 *      <li> <code> SupersedingEventEnablerCalendarAssignmentSession: </code> 
 *      a session to manage superseding event enabler to calendar mappings 
 *      </li> 
 *      <li> <code> SupersedingEventEnablerSmartCalendarSession: </code> a 
 *      session to manage dynamic calendars of superseding event enablers 
 *      </li> 
 *      <li> <code> SupersedingEventEnablerRuleLookupSession: </code> a 
 *      session to look up superseding event enabler mappings </li> 
 *      <li> <code> SupersedingEventEnablerRuleApplicationSession: </code> a 
 *      session to apply superseding event enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CommitmentEnablerLookupSession: </code> a session to 
 *      retrieve commitment enablers </li> 
 *      <li> <code> CommitmentEnablerQuerySession: </code> a session to query 
 *      for commitment enablers </li> 
 *      <li> <code> CommitmentEnablerSearchSession: </code> a session to 
 *      search for commitment enablers </li> 
 *      <li> <code> CommitmentEnablerAdminSession: </code> a session to create 
 *      and delete commitment enablers </li> 
 *      <li> <code> CommitmentEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to commitment enabler changes </li> 
 *      <li> <code> CommitmentEnablerCalendarSession: </code> a session to 
 *      look up commitment enabler calendar mappings </li> 
 *      <li> <code> CommitmentEnablerCalendarAssignmentSession: </code> a 
 *      session to manage commitment enabler to calendar mappings </li> 
 *      <li> <code> CommitmentEnablerSmartCalendarSession: </code> a session 
 *      to manage dynamic calendars of commitment enablers </li> 
 *      <li> <code> CommitmentEnablerRuleLookupSession: </code> a session to 
 *      look up commitment enabler to commitment mappings </li> 
 *      <li> <code> CommitmentEnablerRuleApplicationSession: </code> a session 
 *      to apply commitment enablers to commitments </li> 
 *  </ul>
 *  
 */

public interface CalendaringRulesManager
    extends org.osid.OsidManager,
            org.osid.calendaring.rules.CalendaringRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler lookup service. 
     *
     *  @return a <code> RecurringEventEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerLookupSession getRecurringEventEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerLookupSession getRecurringEventEnablerLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler query service. 
     *
     *  @return a <code> RecurringEventEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerQuerySession getRecurringEventEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerQuerySession getRecurringEventEnablerQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler search service. 
     *
     *  @return a <code> RecurringEventEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerSearchSession getRecurringEventEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enablers earch service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerSearchSession getRecurringEventEnablerSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler administration service. 
     *
     *  @return a <code> RecurringEventEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerAdminSession getRecurringEventEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler administration service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if 
     *              supportsRecurringEventEnablerAdmin() and 
     *              supportsVisibleFederation() are true. 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerAdminSession getRecurringEventEnablerAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler notification service. 
     *
     *  @param  recurringEventEnablerReceiver the notification callback 
     *  @return a <code> RecurringEventEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerNotificationSession getRecurringEventEnablerNotificationSession(org.osid.calendaring.rules.RecurringEventEnablerReceiver recurringEventEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler notification service for the given calendar. 
     *
     *  @param  recurringEventEnablerReceiver the notification callback 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no calendar found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventEnablerReceiver </code> or <code> calendarId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerNotificationSession getRecurringEventEnablerNotificationSessionForCalendar(org.osid.calendaring.rules.RecurringEventEnablerReceiver recurringEventEnablerReceiver, 
                                                                                                                                      org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup recurring event 
     *  enabler/calendar mappings for recurring event enablers. 
     *
     *  @return a <code> RecurringEventEnablerCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if 
     *              supportsRecurringEventEnablerCalendar() is true. 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerCalendarSession getRecurringEventEnablerCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  recurring event enablers to calendars. 
     *
     *  @return an <code> RecurringEventEnablerCalendarAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerCalendarAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerCalendarAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerCalendarAssignmentSession getRecurringEventEnablerCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage recurring event enabler 
     *  smart calendars. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerSmartCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerSmartCalendar() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerSmartCalendarSession getRecurringEventEnablerSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler mapping lookup service for looking up the rules. 
     *
     *  @return a <code> RecurringEventEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerRuleLookupSession getRecurringEventEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler mapping lookup service for the given calendar for 
     *  looking up rules. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerRuleLookupSession getrecurringEventEnablerRuleLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler assignment service to apply enablers. 
     *
     *  @return a <code> RecurringEventEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerRuleApplicationSession getRecurringEventEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the recurring 
     *  event enabler assignment service for the given calendar to apply 
     *  enablers. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> RecurringEventEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecurringEventEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecurringEventEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.RecurringEventEnablerRuleApplicationSession getRecurringEventEnablerRuleApplicationSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler lookup service. 
     *
     *  @return an <code> OffsetEventEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerLookupSession getOffsetEventEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerLookupSession getOffsetEventEnablerLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler query service. 
     *
     *  @return an <code> OffsetEventEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerQuerySession getOffsetEventEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerQuerySession getOffsetEventEnablerQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler search service. 
     *
     *  @return an <code> OffsetEventEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerSearchSession getOffsetEventEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enablers earch service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerSearchSession getOffsetEventEnablerSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler administration service. 
     *
     *  @return an <code> OffsetEventEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerAdminSession getOffsetEventEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler administration service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerAdminSession getOffsetEventEnablerAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler notification service. 
     *
     *  @param  offsetEventEnablerReceiver the notification callback 
     *  @return an <code> OffsetEventEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerNotificationSession getOffsetEventEnablerNotificationSession(org.osid.calendaring.rules.OffsetEventEnablerReceiver offsetEventEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler notification service for the given calendar. 
     *
     *  @param  offsetEventEnablerReceiver the notification callback 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no calendar found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerReceiver </code> or <code> calendarId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerNotificationSession getOffsetEventEnablerNotificationSessionForCalendar(org.osid.calendaring.rules.OffsetEventEnablerReceiver offsetEventEnablerReceiver, 
                                                                                                                                org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup offset event 
     *  enabler/calendar mappings for offset event enablers. 
     *
     *  @return an <code> OffsetEventEnablerCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerCalendarSession getOffsetEventEnablerCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning offset 
     *  event enablers to calendars. 
     *
     *  @return an <code> OffsetEventEnablerCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerCalendarAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerCalendarAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerCalendarAssignmentSession getOffsetEventEnablerCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage offset event enabler 
     *  smart calendars. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerSmartCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerSmartCalendar() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerSmartCalendarSession getOffsetEventEnablerSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler mapping lookup service for looking up the rules. 
     *
     *  @return an <code> OffsetEventEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerRuleLookupSession getOffsetEventEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler mapping lookup service for the given calendar for looking up 
     *  rules. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerRuleLookupSession getOffsetEventEnablerRuleLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler assignment service to apply enablers. 
     *
     *  @return an <code> OffsetEventEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerRuleApplicationSession getOffsetEventEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offset event 
     *  enabler assignment service for the given calendar to apply enablers. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return an <code> OffsetEventEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOffsetEventEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOffsetEventEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerRuleApplicationSession getOffsetEventEnablerRuleApplicationSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler lookup service. 
     *
     *  @return a <code> SupersedingEventEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerLookupSession getSupersedingEventEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerLookupSession getSupersedingEventEnablerLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler query service. 
     *
     *  @return a <code> SupersedingEventEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerQuerySession getSupersedingEventEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerQuerySession getSupersedingEventEnablerQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler search service. 
     *
     *  @return a <code> SupersedingEventEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerSearchSession getSupersedingEventEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enablers earch service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerSearchSession getSupersedingEventEnablerSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler administration service. 
     *
     *  @return a <code> SupersedingEventEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerAdminSession getSupersedingEventEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler administration service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerAdminSession getSupersedingEventEnablerAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler notification service. 
     *
     *  @param  supersedingEventEnablerReceiver the notification callback 
     *  @return a <code> SupersedingEventEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerNotificationSession getSupersedingEventEnablerNotificationSession(org.osid.calendaring.rules.SupersedingEventEnablerReceiver supersedingEventEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler notification service for the given calendar. 
     *
     *  @param  supersedingEventEnablerReceiver the notification callback 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no calendar found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerReceiver </code> or <code> calendarId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerNotificationSession getSupersedingEventEnablerNotificationSessionForCalendar(org.osid.calendaring.rules.SupersedingEventEnablerReceiver supersedingEventEnablerReceiver, 
                                                                                                                                          org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup superseding event 
     *  enabler/calendar mappings for superseding event enablers. 
     *
     *  @return a <code> SupersedingEventEnablerCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerCalendar() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerCalendarSession getSupersedingEventEnablerCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  superseding event enablers to calendars. 
     *
     *  @return a <code> SupersedingEventEnablerCalendarAssignmentSession 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerCalendarAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerCalendarAssignment() 
     *              </code> is <code> true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerCalendarAssignmentSession getSupersedingEventEnablerCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage superseding event 
     *  enabler smart calendars. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerSmartCalendar() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerSmartCalendar() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerSmartCalendarSession getSupersedingEventEnablerSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler mapping lookup service for looking up the rules. 
     *
     *  @return a <code> SupersedingEventEnablerRuleSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerRuleLookupSession getSupersedingEventEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler mapping lookup service for the given calendar for 
     *  looking up rules. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerRuleLookupSession getSupersedingEventEnablerRuleLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler assignment service to apply enablers. 
     *
     *  @return a <code> SupersedingEventEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerRuleApplication() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerRuleApplicationSession getSupersedingEventEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the superseding 
     *  event enabler assignment service for the given calendar to apply 
     *  enablers. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> SupersedingEventEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSupersedingEventEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSupersedingEventEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.SupersedingEventEnablerRuleApplicationSession getSupersedingEventEnablerRuleApplicationSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler lookup service. 
     *
     *  @return a <code> CommitmentEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerLookupSession getCommitmentEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerLookupSession getCommitmentEnablerLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler query service. 
     *
     *  @return a <code> CommitmentEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerQuerySession getCommitmentEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler query service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerQuerySession getCommitmentEnablerQuerySessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler search service. 
     *
     *  @return a <code> CommitmentEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerSearchSession getCommitmentEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enablers earch service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerSearchSession getCommitmentEnablerSearchSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler administration service. 
     *
     *  @return a <code> CommitmentEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerAdminSession getCommitmentEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler administration service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerAdminSession getCommitmentEnablerAdminSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler notification service. 
     *
     *  @param  commitmentEnablerReceiver the notification callback 
     *  @return a <code> CommitmentEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerNotificationSession getCommitmentEnablerNotificationSession(org.osid.calendaring.rules.CommitmentEnablerReceiver commitmentEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler notification service for the given calendar. 
     *
     *  @param  commitmentEnablerReceiver the notification callback 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no calendar found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerReceiver </code> or <code> calendarId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerNotificationSession getCommitmentEnablerNotificationSessionForCalendar(org.osid.calendaring.rules.CommitmentEnablerReceiver commitmentEnablerReceiver, 
                                                                                                                              org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup commitment 
     *  enabler/calendar mappings for commitment enablers. 
     *
     *  @return a <code> CommitmentEnablerCalendarSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerCalendar() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerCalendarSession getCommitmentEnablerCalendarSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  commitment enablers to calendars for commitment. 
     *
     *  @return a <code> CommitmentEnablerCalendarAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerCalendarAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerCalendarAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerCalendarAssignmentSession getCommitmentEnablerCalendarAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage commitment enabler smart 
     *  calendars. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerSmartCalendarSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerSmartCalendar() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerSmartCalendar() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerSmartCalendarSession getCommitmentEnablerSmartCalendarSession(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler mapping lookup service. 
     *
     *  @return a <code> CommitmentEnablertRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerRuleLookupSession getCommitmentEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler mapping lookup service for the given calendar. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerRuleLookupSession getCommitmentEnablerRuleLookupSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler assignment service to apply enablers. 
     *
     *  @return a <code> CommitmentEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerRuleApplicationSession getCommitmentEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the commitment 
     *  enabler assignment service for the given calendar to apply enablers. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return a <code> CommitmentEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Calendar </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommitmentEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommitmentEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.rules.CommitmentEnablerRuleApplicationSession getCommitmentEnablerRuleApplicationSessionForCalendar(org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
