//
// org.osid.calendaring.rules.CalendaringRulesProfile
//
//     The OSID Java specification for org.osid.calendaring.rules.CalendaringRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>The calendaring rules profile describes the interoperability among 
 *  calendaring rules services. </p>
 */

public interface CalendaringRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up recurring event enablers is supported. 
     *
     *  @return true if recurring event enabler lookup is supported, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerLookup();


    /**
     *  Tests if querying recurring event enablers is supported. 
     *
     *  @return true if recurring event enabler query is supported, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerQuery();


    /**
     *  Tests if searching recurring event enablers is supported. 
     *
     *  @return true if recurring event enabler search is supported, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerSearch();


    /**
     *  Tests if an recurring event enabler administrative service is 
     *  supported. 
     *
     *  @return true if recurring event enabler administration is supported, 
     *          false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerAdmin();


    /**
     *  Tests if an recurring event enabler notification service is supported. 
     *
     *  @return true if recurring event enabler notification is supported, 
     *          false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerNotification();


    /**
     *  Tests if an recurring event enabler calendar lookup service is 
     *  supported. 
     *
     *  @return true if an recurring event enabler calendar lookup service is 
     *          supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerCalendar();


    /**
     *  Tests if an recurring event enabler calendar service is supported. 
     *
     *  @return true if recurring event enabler calendar assignment service is 
     *          supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerCalendarAssignment();


    /**
     *  Tests if an recurring event enabler calendar lookup service is 
     *  supported. 
     *
     *  @return true if an recurring event enabler calendar service is 
     *          supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerSmartCalendar();


    /**
     *  Tests if an recurring event enabler rule lookup service is supported. 
     *
     *  @return true if an recurring event enabler rule lookup service is 
     *          supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerRuleLookup();


    /**
     *  Tests if an recurring event enabler rule application service is 
     *  supported. 
     *
     *  @return true if recurring event enabler rule application service is 
     *          supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerRuleApplication();


    /**
     *  Tests if looking up offset event enablers is supported. 
     *
     *  @return <code> true </code> if offset event enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerLookup();


    /**
     *  Tests if querying offset event enablers is supported. 
     *
     *  @return <code> true </code> if offset event enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerQuery();


    /**
     *  Tests if searching offset event enablers is supported. 
     *
     *  @return <code> true </code> if offset event enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerSearch();


    /**
     *  Tests if an offset event enabler administrative service is supported. 
     *
     *  @return <code> true </code> if offset event enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerAdmin();


    /**
     *  Tests if an offset event enabler notification service is supported. 
     *
     *  @return <code> true </code> if offset event enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerNotification();


    /**
     *  Tests if an offset event enabler calendar lookup service is supported. 
     *
     *  @return <code> true </code> if an offset event enabler calendar lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerCalendar();


    /**
     *  Tests if an offset event enabler calendar service is supported. 
     *
     *  @return <code> true </code> if offset event enabler calendar 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerCalendarAssignment();


    /**
     *  Tests if an offset event enabler calendar lookup service is supported. 
     *
     *  @return <code> true </code> if an offset event enabler calendar 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerSmartCalendar();


    /**
     *  Tests if an offset event enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an offset event enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerRuleLookup();


    /**
     *  Tests if an offset event enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if offset event enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerRuleApplication();


    /**
     *  Tests if looking up superseding event enablers is supported. 
     *
     *  @return <code> true </code> if superseding event enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerLookup();


    /**
     *  Tests if querying superseding event enablers is supported. 
     *
     *  @return <code> true </code> if superseding event enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerQuery();


    /**
     *  Tests if searching superseding event enablers is supported. 
     *
     *  @return <code> true </code> if superseding event enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerSearch();


    /**
     *  Tests if an superseding event enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if superseding event enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerAdmin();


    /**
     *  Tests if an superseding event enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if superseding event enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerNotification();


    /**
     *  Tests if an superseding event enabler calendar lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an superseding event enabler calendar 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerCalendar();


    /**
     *  Tests if an superseding event enabler calendar service is supported. 
     *
     *  @return <code> true </code> if superseding event enabler calendar 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerCalendarAssignment();


    /**
     *  Tests if an superseding event enabler calendar lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an superseding event enabler calendar 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerSmartCalendar();


    /**
     *  Tests if an superseding event enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an superseding event enabler rule 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerRuleLookup();


    /**
     *  Tests if an superseding event enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if superseding event enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerRuleApplication();


    /**
     *  Tests if looking up commitment enablers is supported. 
     *
     *  @return <code> true </code> if commitment enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerLookup();


    /**
     *  Tests if querying commitment enablers is supported. 
     *
     *  @return <code> true </code> if commitment enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerQuery();


    /**
     *  Tests if searching commitment enablers is supported. 
     *
     *  @return <code> true </code> if commitment enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerSearch();


    /**
     *  Tests if a commitment enabler administrative service is supported. 
     *
     *  @return <code> true </code> if commitment enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerAdmin();


    /**
     *  Tests if a commitment enabler notification service is supported. 
     *
     *  @return <code> true </code> if commitment enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerNotification();


    /**
     *  Tests if a commitment enabler calendar lookup service is supported. 
     *
     *  @return <code> true </code> if a commitment enabler calendar lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerCalendar();


    /**
     *  Tests if a commitment enabler calendar service is supported. 
     *
     *  @return <code> true </code> if commitment enabler calendar assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerCalendarAssignment();


    /**
     *  Tests if a commitment enabler calendar lookup service is supported. 
     *
     *  @return <code> true </code> if a commitment enabler calendar service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerSmartCalendar();


    /**
     *  Tests if a commitment enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a commitment enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerRuleLookup();


    /**
     *  Tests if a commitment enabler rule application service is supported. 
     *
     *  @return <code> true </code> if commitment enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerRuleApplication();


    /**
     *  Gets the supported <code> RecurringEventEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> RecurringEventEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRecurringEventEnablerRecordTypes();


    /**
     *  Tests if the given <code> RecurringEventEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  recurringEventEnablerRecordType a <code> Type </code> 
     *          indicating a <code> RecurringEventEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerRecordType(org.osid.type.Type recurringEventEnablerRecordType);


    /**
     *  Gets the supported <code> RecurringEventEnabler </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> RecurringEventEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRecurringEventEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> RecurringEventEnabler </code> search record 
     *  interface type is supported. 
     *
     *  @param  recurringEventEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> RecurringEventEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          recurringEventEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecurringEventEnablerSearchRecordType(org.osid.type.Type recurringEventEnablerSearchRecordType);


    /**
     *  Gets the supported <code> OffsetEventEnabler </code> record interface 
     *  types. 
     *
     *  @return a list containing the supported <code> OffsetEventEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOffsetEventEnablerRecordTypes();


    /**
     *  Tests if the given <code> OffsetEventEnabler </code> record interface 
     *  type is supported. 
     *
     *  @param  offsetEventEnablerRecordType a <code> Type </code> indicating 
     *          an <code> OffsetEventEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerRecordType(org.osid.type.Type offsetEventEnablerRecordType);


    /**
     *  Gets the supported <code> OffsetEventEnabler </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> OffsetEventEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOffsetEventEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> OffsetEventEnabler </code> search record 
     *  interface type is supported. 
     *
     *  @param  offsetEventEnablerSearchRecordType a <code> Type </code> 
     *          indicating an <code> OffsetEventEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOffsetEventEnablerSearchRecordType(org.osid.type.Type offsetEventEnablerSearchRecordType);


    /**
     *  Gets the supported <code> SupersedingEventEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> SupersedingEventEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSupersedingEventEnablerRecordTypes();


    /**
     *  Tests if the given <code> SupersedingEventEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  supersedingEventEnablerRecordType a <code> Type </code> 
     *          indicating an <code> SupersedingEventEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerRecordType(org.osid.type.Type supersedingEventEnablerRecordType);


    /**
     *  Gets the supported <code> SupersedingEventEnabler </code> search 
     *  record interface types. 
     *
     *  @return a list containing the supported <code> SupersedingEventEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSupersedingEventEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> SupersedingEventEnabler </code> search 
     *  record interface type is supported. 
     *
     *  @param  supersedingEventEnablerSearchRecordType a <code> Type </code> 
     *          indicating an <code> SupersedingEventEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          supersedingEventEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSupersedingEventEnablerSearchRecordType(org.osid.type.Type supersedingEventEnablerSearchRecordType);


    /**
     *  Gets the supported <code> CommitmentEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> CommitmentEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommitmentEnablerRecordTypes();


    /**
     *  Tests if the given <code> CommitmentEnabler </code> record type is 
     *  supported. 
     *
     *  @param  commitmentEnablerRecordType a <code> Type </code> indicating a 
     *          <code> CommitmentEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerRecordType(org.osid.type.Type commitmentEnablerRecordType);


    /**
     *  Gets the supported <code> CommitmentEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> CommitmentEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommitmentEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> CommitmentEnabler </code> search record type 
     *  is supported. 
     *
     *  @param  commitmentEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> CommitmentEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          commitmentEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommitmentEnablerSearchRecordType(org.osid.type.Type commitmentEnablerSearchRecordType);
}
