//
// org.osid.calendaring.rules.OffsetEventEnablerCalendarAssignmentSession
//
//     The OSID Java specification for org.osid.calendaring.rules.OffsetEventEnablerCalendarAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session provides methods to re-assign <code> OffsetEventEnabler 
 *  </code> to <code> Calendar </code> mappings. An <code> OffsetEventEnabler 
 *  </code> may appear in multiple <code> Calendar </code> objects and 
 *  removing the last reference to an <code> OffsetEventEnabler </code> is the 
 *  equivalent of deleting it. Each <code> Calendar </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> OffsetEventEnabler </code> to another 
 *  <code> Calendar </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface OffsetEventEnablerCalendarAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter offset event enabler/calendar mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignOffsetEventEnablers();


    /**
     *  Tests if this user can alter offset event enabler/calendar mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignOffsetEventEnablersToCalendar(org.osid.id.Id calendarId);


    /**
     *  Gets a list of calendars including and under the given calendar node 
     *  in which any offset event enabler can be assigned. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @return list of assignable calendar <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCalendarIds(org.osid.id.Id calendarId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of calendars including and under the given calendar node 
     *  in which a specific offset event enabler can be assigned. 
     *
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @param  eventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> 
     *  @return list of assignable calendar <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> calendarId </code> or 
     *          <code> eventEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCalendarIdsForOffsetEventEnabler(org.osid.id.Id calendarId, 
                                                                            org.osid.id.Id eventEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> OffsetEventEnabler </code> to an <code> 
     *  Calendar. </code> 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> offsetEventEnablerId 
     *          </code> already mapped to <code> calendarId </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          or <code> calendarId </code> not found 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignOffsetEventEnablerToCalendar(org.osid.id.Id offsetEventEnablerId, 
                                                   org.osid.id.Id calendarId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> OffsetEventEnabler </code> from an <code> Calendar. 
     *  </code> 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> 
     *  @param  calendarId the <code> Id </code> of the <code> Calendar 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          or <code> calendarId </code> not found or <code> 
     *          offsetEventEnablerId </code> not assigned to <code> calendarId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId 
     *          </code> or <code> calendarId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignOffsetEventEnablerFromCalendar(org.osid.id.Id offsetEventEnablerId, 
                                                       org.osid.id.Id calendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> OffsetEventEnabler </code> from one <code> Calendar 
     *  </code> to another. Mappings to other <code> Calendars </code> are 
     *  unaffected. 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> 
     *  @param  fromCalendarId the <code> Id </code> of the current <code> 
     *          Calendar </code> 
     *  @param  toCalendarId the <code> Id </code> of the destination <code> 
     *          Calendar </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          not mapped to <code> fromCalendarId </code> 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId, 
     *          fromCalendarId, </code> or <code> toCalendarId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignOffsetEventEnablerToCalendar(org.osid.id.Id offsetEventEnablerId, 
                                                     org.osid.id.Id fromCalendarId, 
                                                     org.osid.id.Id toCalendarId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
