//
// org.osid.calendaring.rules.OffsetEventEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.calendaring.rules.OffsetEventEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session provides methods to apply <code> OffsetEventEnablers 
 *  </code> to <code> OffsetEvents. </code> An <code> OffsetEvent </code> with 
 *  multiple <code> OffsetEventEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> OffsetEvent. 
 *  </code> </p>
 */

public interface OffsetEventEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the calendar 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter offset event enabler/offset event 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignOffsetEventEnablerRules();


    /**
     *  Adds an existing <code> OffsetEventEnabler </code> to an <code> 
     *  OffsetEvents. </code> 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> 
     *  @param  offsetEventId the <code> Id </code> of the <code> OffsetEvent 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> offsetEventEnablerId 
     *          </code> already applied to <code> offsetEventId </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          or <code> offsetEventId </code> not found 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId 
     *          </code> or <code> offsetEventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignOffsetEventEnablerToOffsetEvent(org.osid.id.Id offsetEventEnablerId, 
                                                      org.osid.id.Id offsetEventId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> OffsetEventEnabler </code> from an <code> 
     *  OffsetEvent. </code> 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of the <code> 
     *          OffsetEventEnabler </code> 
     *  @param  offsetEventId the <code> Id </code> of the <code> OffsetEvent 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId </code> 
     *          or <code> offsetEventId </code> not found or <code> 
     *          offsetEventEnablerId </code> not applied to <code> 
     *          offsetEventId </code> 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId 
     *          </code> or <code> offsetEventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignOffsetEventEnablerFromOffsetEvent(org.osid.id.Id offsetEventEnablerId, 
                                                          org.osid.id.Id offsetEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> OffsetEventEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> OffsetEventEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceOffsetEventEnablers();


    /**
     *  Reorders offset event enablers for an offset event by moving the 
     *  specified offset event enabler in front of a reference offset event 
     *  enabler. 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of an <code> 
     *          OffsetEventEnabler </code> 
     *  @param  offsetEventId the <code> Id </code> of an <code> OffsetEvent 
     *          </code> 
     *  @param  referenceId the reference offset event enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId, 
     *          offsetEventId, </code> or <code> referenceId </code> not found 
     *          or, <code> offsetEventEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> offsetEventId </code> 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId, 
     *          offsetEventId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveOffsetEventEnablerAhead(org.osid.id.Id offsetEventEnablerId, 
                                            org.osid.id.Id offsetEventId, 
                                            org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders offset event enablers for an offset event by moving the 
     *  specified offset event enabler behind a reference offset event 
     *  enabler. 
     *
     *  @param  offsetEventEnablerId the <code> Id </code> of an <code> 
     *          OffsetEventEnabler </code> 
     *  @param  offsetEventId the <code> Id </code> of an <code> OffsetEvent 
     *          </code> 
     *  @param  referenceId the reference offset event enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventEnablerId, 
     *          offsetEventId, </code> or <code> referenceId </code> not found 
     *          or, <code> offsetEventEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> offsetEventId </code> 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerId, 
     *          offsetEventId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveOffsetEventEnablerBehind(org.osid.id.Id offsetEventEnablerId, 
                                             org.osid.id.Id offsetEventId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of offset event enablers for an offset event. 
     *
     *  @param  offsetEventEnablerIds the <code> Ids </code> for a set of 
     *          <code> OffsetEventEnablers </code> 
     *  @param  offsetEventId the <code> Id </code> of an <code> OffsetEvent 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> offsetEventId </code> not 
     *          found or, an <code> offsetEventEnablerId </code> not related 
     *          to <code> offsetEventId </code> 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerIds 
     *          </code> or <code> offsetEventId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderOffsetEventEnablers(org.osid.id.Id[] offsetEventEnablerIds, 
                                         org.osid.id.Id offsetEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
