//
// org.osid.calendaring.rules.OffsetEventEnablerSearchSession
//
//     The OSID Java specification for org.osid.calendaring.rules.OffsetEventEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  OffsetEventEnabler </code> objects. The search query is constructed using 
 *  the <code> OffsetEventEnablerQuery. </code> </p> 
 *  
 *  <p> <code> getOffsetEventEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> OffsetEventEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getOffsetEventEnablersBySearch(). </code> It accepts an <code> 
 *  OffsetEventEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  calendaring. <code> getOffsetEventEnablersBySearch() </code> returns an 
 *  <code> OffsetEventEnablerSearchResults </code> that can be used to access 
 *  the resulting <code> OffsetEventEnablerList </code> or be used to perform 
 *  a search within the result set through <code> OffsetEventEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated calendar view: searches include offset event enablers 
 *      in calendars of which this calendar is an ancestor in the calendar 
 *      hierarchy </li> 
 *      <li> isolated calendar view: searches are restricted to offset event 
 *      enablers in this calendar </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> OffsetEventEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> OffsetEventEnablerQuery. </code> </p>
 */

public interface OffsetEventEnablerSearchSession
    extends org.osid.calendaring.rules.OffsetEventEnablerQuerySession {


    /**
     *  Gets an offset event enabler search. 
     *
     *  @return the offset event enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerSearch getOffsetEventEnablerSearch();


    /**
     *  Gets an offset event enabler search order. The <code> 
     *  OffsetEventEnablerSearchOrder </code> is supplied to an <code> 
     *  OffsetEventEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the offset event enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerSearchOrder getOffsetEventEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  offsetEventEnablerQuery the offset event enabler query 
     *  @param  offsetEventEnablerSearch the offset event enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> offsetEventEnablerQuery 
     *          </code> or <code> offsetEventEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> offsetEventEnablerQuery 
     *          </code> or <code> offsetEventEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerSearchResults getOffsetEventEnablersBySearch(org.osid.calendaring.rules.OffsetEventEnablerQuery offsetEventEnablerQuery, 
                                                                                                     org.osid.calendaring.rules.OffsetEventEnablerSearch offsetEventEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offset event enabler query from an inspector. The inspector is 
     *  available from an <code> OffsetEventEnablerSearchResults. </code> 
     *
     *  @param  offsetEventEnablerQueryInspector an offset event enabler query 
     *          inspector 
     *  @return the offset event enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          offsetEventEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          offsetEventEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.rules.OffsetEventEnablerQuery getOffsetEventEnablerQueryFromInspector(org.osid.calendaring.rules.OffsetEventEnablerQueryInspector offsetEventEnablerQueryInspector);
}
