//
// org.osid.calendaring.rules.RecurringEventEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.calendaring.rules.RecurringEventEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.calendaring.rules;


/**
 *  <p>This session provides methods to apply <code> RecurringEventEnablers 
 *  </code> to <code> RecurringEvents. </code> A <code> RecurringEvent </code> 
 *  with multiple <code> RecurringEventEnablers </code> means any positive 
 *  rule evaluation across the enablers result in an effective <code> 
 *  RecurringEvent. </code> </p>
 */

public interface RecurringEventEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Calendar </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Calendar Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCalendarId();


    /**
     *  Gets the <code> Calendar </code> associated with this session. 
     *
     *  @return the calendar 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Calendar getCalendar()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter recurring event enabler/recurring event 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRecurringEventEnablerRules();


    /**
     *  Adds an existing <code> RecurringEventEnabler </code> to a <code> 
     *  RecurringEvent. </code> 
     *
     *  @param  recurringEventEnablerId the <code> Id </code> of the <code> 
     *          RecurringEventEnabler </code> 
     *  @param  recurringEventId the <code> Id </code> of the <code> 
     *          RecurringEvent </code> 
     *  @throws org.osid.AlreadyExistsException <code> recurringEventEnablerId 
     *          </code> already applied to <code> recurringEventId </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventEnablerId 
     *          </code> or <code> recurringEventId </code> not found 
     *  @throws org.osid.NullArgumentException <code> recurringEventEnablerId 
     *          </code> or <code> recurringEventId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRecurringEventEnablerToRecurringEvent(org.osid.id.Id recurringEventEnablerId, 
                                                            org.osid.id.Id recurringEventId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RecurringEventEnabler </code> from a <code> 
     *  RecurringEvent. </code> 
     *
     *  @param  recurringEventEnablerId the <code> Id </code> of the <code> 
     *          RecurringEventEnabler </code> 
     *  @param  recurringEventId the <code> Id </code> of the <code> 
     *          RecurringEvent </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventEnablerId 
     *          </code> or <code> recurringEventId </code> not found or <code> 
     *          recurringEventEnablerId </code> not applied to <code> 
     *          recurringEventId </code> 
     *  @throws org.osid.NullArgumentException <code> recurringEventEnablerId 
     *          </code> or <code> recurringEventId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRecurringEventEnablerFromRecurringEvent(org.osid.id.Id recurringEventEnablerId, 
                                                                org.osid.id.Id recurringEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> RecurringEventEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RecurringEventEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceRecurringEventEnablers();


    /**
     *  Reorders recurring event enablers for a recurring event by moving the 
     *  specified recurring event enabler in front of a reference recurring 
     *  event enabler. 
     *
     *  @param  recurringEventEnablerId the <code> Id </code> of a <code> 
     *          RecurringEventEnabler </code> 
     *  @param  recurringEventId the <code> Id </code> of a <code> 
     *          RecurringEvent </code> 
     *  @param  referenceId the reference recurring event enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventEnablerId, 
     *          recurringEventId, </code> or <code> referenceId </code> not 
     *          found or, <code> recurringEventEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> recurringEventId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> recurringEventEnablerId, 
     *          recurringEventId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRecurringEventEnablerAhead(org.osid.id.Id recurringEventEnablerId, 
                                               org.osid.id.Id recurringEventId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders recurring event enablers for a recurring event by moving the 
     *  specified recurring event enabler behind a reference recurring event 
     *  enabler. 
     *
     *  @param  recurringEventEnablerId the <code> Id </code> of a <code> 
     *          RecurringEventEnabler </code> 
     *  @param  recurringEventId the <code> Id </code> of a <code> 
     *          RecurringEvent </code> 
     *  @param  referenceId the reference recurring event enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventEnablerId, 
     *          recurringEventId, </code> or <code> referenceId </code> not 
     *          found or, <code> recurringEventEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> recurringEventId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> recurringEventEnablerId, 
     *          recurringEventId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRecurringEventEnablerBehind(org.osid.id.Id recurringEventEnablerId, 
                                                org.osid.id.Id recurringEventId, 
                                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of recurring event enablers for a recurring event. 
     *
     *  @param  recurringEventEnablerIds the <code> Ids </code> for a set of 
     *          <code> RecurringEventEnablers </code> 
     *  @param  recurringEventId the <code> Id </code> of a <code> 
     *          RecurringEvent </code> 
     *  @throws org.osid.NotFoundException <code> recurringEventEnablerId 
     *          </code> not related to <code> recurringEventId </code> 
     *  @throws org.osid.NullArgumentException <code> rceurringEventEnablerIds 
     *          </code> or <code> recurringEventId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderRecurringEventEnablers(org.osid.id.Id[] recurringEventEnablerIds, 
                                            org.osid.id.Id recurringEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
