//
// org.osid.cataloging.CatalogSession
//
//     The OSID Java specification for org.osid.cataloging.CatalogSession.
//
// Copyright (C) 2006-2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging;


/**
 *  <p>This session provides methods to retrieve <code> Id </code> to <code> 
 *  Catalog </code> mappings. An Id may appear in multiple <code> Catalogs. 
 *  </code> Each <code> Catalog </code> may have its own authorizations as to 
 *  who is allowed to look at it. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> federated view: entries are accessible from the specified <code> 
 *      Catalog </code> and any descendant catalogs in the <code> Catalog 
 *      </code> hierarchy </li> 
 *      <li> isolated view: entries are accessible from the specified <code> 
 *      Catalog </code> only </li> 
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there a particular element is 
 *  inaccessible. For example, a hierarchy output can be plugged into a lookup 
 *  method to retrieve all objects known to a hierarchy, but it may not be 
 *  necessary to break execution if a node from the hierarchy no longer 
 *  exists. However, some administrative applications may need to know whether 
 *  it had retrieved an entire set of objects and may sacrifice some 
 *  interoperability for the sake of precision. </p>
 */

public interface CatalogSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of <code> Id </code> to <code> 
     *  Catalog </code> mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCatalogView();


    /**
     *  A complete view of the <code> Id </code> and <code> Catalog </code> 
     *  returns is desired. Methods will return what is requested or result in 
     *  an error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCatalogView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries from descendant catalogs in the catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to the specified catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogView();


    /**
     *  Gets the list of <code> Ids </code> map to a <code> Catalog. </code> 
     *
     *  @param  catalogId a catalog <code> Id </code> 
     *  @return list of <code> Ids </code> mapped to the given <code> 
     *          catalogId </code> 
     *  @throws org.osid.NotFoundException <code> catalogId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdsByCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Ids </code> map to a lst of <code> Catalogs. 
     *  </code> 
     *
     *  @param  catalogIds an <code> Id </code> 
     *  @return list of catalogs containing the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIdsByCatalogs(org.osid.id.IdList catalogIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Catalog Ids </code> mapped to an <code> Id. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @return list of catalog <code> Ids </code> containing the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCatalogIdsById(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Catalogs </code> mapped to an <code> Id. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @return list of catalogs containing the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.CatalogList getCatalogsById(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
