//
// org.osid.cataloging.rules.CatalogEnablerAdminSession
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>This session creates and removes catalog enablers. The data for create 
 *  and update is provided via the <code> CatalogEnablerForm. </code> </p>
 */

public interface CatalogEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalog </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Catalog Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogId();


    /**
     *  Gets the <code> Catalog </code> associated with this session. 
     *
     *  @return the catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.Catalog getCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create catalog enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> CatalogEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CatalogEnabler </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCatalogEnabler();


    /**
     *  Tests if this user can create a single <code> CatalogEnabler </code> 
     *  using the desired record types. While <code> 
     *  CatalogingRulesManager.getCatalogEnablerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> CatalogEnabler. 
     *  </code> Providing an empty array tests if a <code> CatalogEnabler 
     *  </code> can be created with no records. 
     *
     *  @param  catalogEnablerRecordTypes array of catalog enabler record 
     *          types 
     *  @return <code> true </code> if <code> CatalogEnabler </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          catalogEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCatalogEnablerWithRecordTypes(org.osid.type.Type[] catalogEnablerRecordTypes);


    /**
     *  Gets the catalog enabler form for creating new catalog enablers. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  catalogEnablerRecordTypes array of catalog enabler record 
     *          types 
     *  @return the catalog enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          catalogEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnablerForm getCatalogEnablerFormForCreate(org.osid.type.Type[] catalogEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CatalogEnabler. </code> 
     *
     *  @param  catalogEnablerForm the form for this <code> CatalogEnabler 
     *          </code> 
     *  @return the new <code> CatalogEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> catalogEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> catalogEnablerForm 
     *          </code> did not originate from <code> 
     *          getCatalogEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnabler createCatalogEnabler(org.osid.cataloging.rules.CatalogEnablerForm catalogEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update catalog enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> CatalogEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CatalogEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCatalogEnablers();


    /**
     *  Gets the catalog enabler form for updating an existing catalog 
     *  enabler. A new catalog enabler form should be requested for each 
     *  update transaction. 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> 
     *  @return the catalog enabler form 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.CatalogEnablerForm getCatalogEnablerFormForUpdate(org.osid.id.Id catalogEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing catalog enabler. 
     *
     *  @param  catalogEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> catalogEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> catalogEnablerForm 
     *          </code> did not originate from <code> 
     *          getCatalogEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCatalogEnabler(org.osid.cataloging.rules.CatalogEnablerForm catalogEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete catalog enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> CatalogEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CatalogEnabler </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCatalogEnablers();


    /**
     *  Deletes a <code> CatalogEnabler. </code> 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCatalogEnabler(org.osid.id.Id catalogEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for catalog 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CatalogEnabler </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCatalogEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CatalogEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CatalogEnabler </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another catalog enabler. it is 
     *  reassigned to the given catalog enabler <code> Id. </code> 
     *
     *  @param  catalogEnablerId the <code> Id </code> of a <code> 
     *          CatalogEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> catalogEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCatalogEnabler(org.osid.id.Id catalogEnablerId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
