//
// org.osid.cataloging.rules.CatalogEnablerNotificationSession
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogEnablerNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> CatalogEnabler </code> objects in this <code> Catalog. </code> 
 *  This also includes existing <code> CatalogEnablers </code> that may appear 
 *  or disappear due to changes in the <code> Catalog </code> hierarchy, This 
 *  session is intended for consumers needing to synchronize their state with 
 *  this service without the use of polling. Notifications are cancelled when 
 *  this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> CatalogEnablerLookupSession. </code> </p>
 */

public interface CatalogEnablerNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalog </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Catalog Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogId();


    /**
     *  Gets the <code> Catalog </code> associated with this session. 
     *
     *  @return the catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.Catalog getCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> CatalogEnabler </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForCatalogEnablerNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include enablers in catalogs which are children of this catalog in the 
     *  catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeCatalogEnablerNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableCatalogEnablerNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableCatalogEnablerNotifications();


    /**
     *  Acknowledge a catalog notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeCatalogEnablerNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new catalog enablers. <code> 
     *  CatalogEnablerReceiver.newCatalogEnabler() </code> is invoked when a 
     *  new <code> CatalogEnabler </code> appears in this catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewCatalogEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated catalog enablers. <code> 
     *  CatalogEnablerReceiver.changedCatalogEnabler() </code> is invoked when 
     *  a catalog enabler in this catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCatalogEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated catalog enabler. <code> 
     *  ProvisionableReceiver.changedCatalogEnabler() </code> is invoked when 
     *  the specified catalog enabler in this catalog is changed. 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedCatalogEnabler(org.osid.id.Id catalogEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted catalog enablers. <code> 
     *  CatalogEnablerReceiver.deletedCatalogEnabler() </code> is invoked when 
     *  a catalog enabler is deleted or removed from this catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCatalogEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted catalog enabler. <code> 
     *  CatalogEnablerReceiver.deletedCatalogEnabler() </code> is invoked when 
     *  the specified catalog enabler is deleted or removed from this catalog. 
     *
     *  @param  catalogEnablerId the <code> Id </code> of the <code> 
     *          CatalogEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedCatalogEnabler(org.osid.id.Id catalogEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
