//
// org.osid.cataloging.rules.CatalogEnablerQuery
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>This is the query for searching catalog enablers. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface CatalogEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the catalog. 
     *
     *  @param  catalogId the catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledCatalogId(org.osid.id.Id catalogId, boolean match);


    /**
     *  Clears the catalog <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCatalogIdTerms();


    /**
     *  Tests if a <code> CatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a catalog query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledCatalogQuery();


    /**
     *  Gets the query for a catalog. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.CatalogQuery getRuledCatalogQuery();


    /**
     *  Matches enablers mapped to any catalog. 
     *
     *  @param  match <code> true </code> for enablers mapped to any catalog, 
     *          <code> false </code> to match enablers mapped to no catalog 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledCatalog(boolean match);


    /**
     *  Clears the catalog query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCatalogTerms();


    /**
     *  Matches enablers mapped to the catalog. 
     *
     *  @param  catalogId the catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCatalogId(org.osid.id.Id catalogId, boolean match);


    /**
     *  Clears the catalog <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogIdTerms();


    /**
     *  Tests if a <code> CatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a catalog query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogQuery();


    /**
     *  Gets the query for a catalog. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the catalog query 
     *  @throws org.osid.UnimplementedException <code> supportsCatalogQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogQuery() </code> is <code> true. </code> 
     */

    public org.osid.cataloging.CatalogQuery getCatalogQuery();


    /**
     *  Clears the catalog query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogTerms();


    /**
     *  Gets the catalog enabler query record corresponding to the given 
     *  <code> CatalogEnabler </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  catalogEnablerRecordType a catalog enabler record type 
     *  @return the catalog enabler query record 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(catalogEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.cataloging.rules.records.CatalogEnablerQueryRecord getCatalogEnablerQueryRecord(org.osid.type.Type catalogEnablerRecordType)
        throws org.osid.OperationFailedException;
}
