//
// org.osid.cataloging.rules.CatalogingRulesManager
//
//     The OSID Java specification for org.osid.cataloging.rules.CatalogingRulesManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.cataloging.rules;


/**
 *  <p>The catalogingrules manager provides access to cataloging rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CatalogEnablerLookupSession: </code> a session to retrieve 
 *      catalog enablers </li> 
 *      <li> <code> CatalogEnablerQuerySession: </code> a session to query for 
 *      catalog enablers </li> 
 *      <li> <code> CatalogEnablerSearchSession: </code> a session to search 
 *      for catalog enablers </li> 
 *      <li> <code> CatalogEnablerAdminSession: </code> a session to create 
 *      and delete catalog enablers </li> 
 *      <li> <code> CatalogEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to catalog enabler changes </li> 
 *      <li> <code> CatalogEnablerCatalogSession: </code> a session to look up 
 *      catalog enabler catalog mappings </li> 
 *      <li> <code> CatalogEnablerCatalogAssignmentSession: </code> a session 
 *      to manage catalog enabler to catalog mappings </li> 
 *      <li> <code> CatalogEnablerSmartCatalogSession: </code> a session to 
 *      manage dynamic catalogs of catalog enablers </li> 
 *      <li> <code> CatalogEnableRuleLookupSession: </code> a session to look 
 *      up catalog enabler to catalog mappings </li> 
 *      <li> <code> CatalogEnablerRuleApplicationSession: </code> a session to 
 *      apply catalog enablers to catalogs </li> 
 *  </ul>
 *  
 */

public interface CatalogingRulesManager
    extends org.osid.OsidManager,
            org.osid.cataloging.rules.CatalogingRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler lookup service. 
     *
     *  @return a <code> CatalogEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerLookupSession getCatalogEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler lookup service for the given catalog. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalog </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerLookupSession getCatalogEnablerLookupSessionForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler query service. 
     *
     *  @return a <code> CatalogEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerQuerySession getCatalogEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler query service for the given catalog. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalog </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerQuerySession getCatalogEnablerQuerySessionForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler search service. 
     *
     *  @return a <code> CatalogEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerSearchSession getCatalogEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enablers earch service for the given catalog. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalog </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerSearchSession getCatalogEnablerSearchSessionForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler administration service. 
     *
     *  @return a <code> CatalogEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerAdminSession getCatalogEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler administration service for the given catalog. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalog </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerAdminSession getCatalogEnablerAdminSessionForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler notification service. 
     *
     *  @param  catalogEnablerReceiver the notification callback 
     *  @return a <code> CatalogEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerNotificationSession getCatalogEnablerNotificationSession(org.osid.cataloging.rules.CatalogEnablerReceiver catalogEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler notification service for the given catalog. 
     *
     *  @param  catalogEnablerReceiver the notification callback 
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no catalog found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogEnablerReceiver 
     *          </code> or <code> catalogId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerNotificationSession getCatalogEnablerNotificationSessionForCatalog(org.osid.cataloging.rules.CatalogEnablerReceiver catalogEnablerReceiver, 
                                                                                                                      org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup catalog enabler/catalog 
     *  mappings for cataloging enablers. 
     *
     *  @return a <code> CatalogEnablerCatalogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerCatalog() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerCatalogSession getCatalogEnablerCatalogSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning catalog 
     *  enablers to catalogs for cataloging. 
     *
     *  @return a <code> CatalogEnablerCatalogAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerCatalogAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerCatalogAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerCatalogAssignmentSession getCatalogEnablerCatalogAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage catalog enabler smart 
     *  catalogs. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerSmartCatalogSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalog </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerSmartCatalog() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerSmartCatalog() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerSmartCatalogSession getCatalogEnablerSmartCatalogSession(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler mapping lookup service for looking up the rules applied to the 
     *  catalog. 
     *
     *  @return a <code> CatalogEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerRuleLookupSession getCatalogEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler mapping lookup service for the given catalog for looking up 
     *  rules applied to a catalog. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalog </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerRuleLookupSession getCatalogEnablerRuleLookupSessionForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler assignment service to apply enablers to catalogs. 
     *
     *  @return a <code> CatalogEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerRuleApplicationSession getCatalogEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalog 
     *  enabler assignment service for the given catalog to apply enablers to 
     *  catalogs. 
     *
     *  @param  catalogId the <code> Id </code> of the <code> Catalog </code> 
     *  @return a <code> CatalogEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalog </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.cataloging.rules.CatalogEnablerRuleApplicationSession getCatalogEnablerRuleApplicationSessionForCatalog(org.osid.id.Id catalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
