//
// org.osid.checklist.ChecklistQuery
//
//     The OSID Java specification for org.osid.checklist.ChecklistQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>This is the query for searching for checklists. Each method specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ChecklistQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the todo <code> Id </code> for this query to match todos assigned 
     *  to checklists. 
     *
     *  @param  todoId a todo <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> todoId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTodoId(org.osid.id.Id todoId, boolean match);


    /**
     *  Clears the todo <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTodoIdTerms();


    /**
     *  Tests if a todo query is available. 
     *
     *  @return <code> true </code> if a todo query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoQuery();


    /**
     *  Gets the query for a todo. 
     *
     *  @return the todo query 
     *  @throws org.osid.UnimplementedException <code> supportsTodoQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTodoQuery() </code> is <code> true. </code> 
     */

    public org.osid.checklist.TodoQuery getTodoQuery();


    /**
     *  Matches checklists with any todo. 
     *
     *  @param  match <code> true </code> to match checklists with any todo, 
     *          <code> false </code> to match checklists with no todos 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTodo(boolean match);


    /**
     *  Clears the todo terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTodoTerms();


    /**
     *  Sets the checklist <code> Id </code> for this query to match 
     *  checklists that have the specified checklist as an ancestor. 
     *
     *  @param  checklistId a checklist <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, a <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorChecklistId(org.osid.id.Id checklistId, 
                                         boolean match);


    /**
     *  Clears the ancestor checklist <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorChecklistIdTerms();


    /**
     *  Tests if a <code> ChecklistQuery </code> is available. 
     *
     *  @return <code> true </code> if a checklist query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorChecklistQuery();


    /**
     *  Gets the query for a checklist. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the checklist query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorChecklistQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorChecklistQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.ChecklistQuery getAncestorChecklistQuery();


    /**
     *  Matches checklists with any ancestor. 
     *
     *  @param  match <code> true </code> to match checklists with any 
     *          ancestor, <code> false </code> to match root checklists 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorChecklist(boolean match);


    /**
     *  Clears the ancestor checklist terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorChecklistTerms();


    /**
     *  Sets the checklist <code> Id </code> for this query to match 
     *  checklists that have the specified checklist as a descendant. 
     *
     *  @param  checklistId a checklist <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> checklistId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantChecklistId(org.osid.id.Id checklistId, 
                                           boolean match);


    /**
     *  Clears the descendant checklist <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantChecklistIdTerms();


    /**
     *  Tests if a <code> ChecklistQuery </code> is available. 
     *
     *  @return <code> true </code> if a checklist query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantChecklistQuery();


    /**
     *  Gets the query for a checklist. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the checklist query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantChecklistQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantChecklistQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.checklist.ChecklistQuery getDescendantChecklistQuery();


    /**
     *  Matches checklists with any descendant. 
     *
     *  @param  match <code> true </code> to match checklists with any 
     *          descendant, <code> false </code> to match leaf checklists 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantChecklist(boolean match);


    /**
     *  Clears the descendant checklist terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantChecklistTerms();


    /**
     *  Gets the checklist query record corresponding to the given <code> 
     *  Checklist </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested boolean <code> OR </code> term. 
     *
     *  @param  checklistRecordType a checklist record type 
     *  @return the checklist query record 
     *  @throws org.osid.NullArgumentException <code> checklistRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(checklistRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.records.ChecklistQueryRecord getChecklistQueryRecord(org.osid.type.Type checklistRecordType)
        throws org.osid.OperationFailedException;
}
