//
// org.osid.checklist.ChecklistQueryInspector
//
//     The OSID Java specification for org.osid.checklist.ChecklistQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>This is the query inspector for examining checklist queries. </p>
 */

public interface ChecklistQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the todo <code> Id </code> terms. 
     *
     *  @return the todo <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTodoIdTerms();


    /**
     *  Gets the todo terms. 
     *
     *  @return the todo terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoQueryInspector[] getTodoTerms();


    /**
     *  Gets the ancestor checklist <code> Id </code> terms. 
     *
     *  @return the ancestor checklist <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorChecklistIdTerms();


    /**
     *  Gets the ancestor checklist terms. 
     *
     *  @return the ancestor checklist terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.ChecklistQueryInspector[] getAncestorChecklistTerms();


    /**
     *  Gets the descendant checklist <code> Id </code> terms. 
     *
     *  @return the descendant checklist <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantChecklistIdTerms();


    /**
     *  Gets the descendant checklist terms. 
     *
     *  @return the descendant checklist terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.ChecklistQueryInspector[] getDescendantChecklistTerms();


    /**
     *  Gets the checklist query inspector record corresponding to the given 
     *  <code> Checklist </code> record <code> Type. </code> 
     *
     *  @param  checklistRecordType a checklist record type 
     *  @return the checklist query inspector record 
     *  @throws org.osid.NullArgumentException <code> checklistRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(checklistRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.records.ChecklistQueryInspectorRecord getChecklistQueryInspectorRecord(org.osid.type.Type checklistRecordType)
        throws org.osid.OperationFailedException;
}
