//
// org.osid.checklist.TodoAdminSession
//
//     The OSID Java specification for org.osid.checklist.TodoAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>This session creates, updates, and deletes <code> Todos. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Todo, </code> an <code> TodoForm </code> is requested using <code> 
 *  getTodoFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> TodoForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> TodoForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> TodoForm </code> corresponds 
 *  to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> TodoForms </code> are requested to the <code> Todo 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getTodoFormForUpdate(). </code> Similarly, the <code> TodoForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> TodoForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Todos. </code> To unmap an <code> 
 *  Todo </code> from the current <code> Checklist, </code> the <code> 
 *  TodoChecklistAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Bid </code> itself thus removing 
 *  it from all known <code> Checklist </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface TodoAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Checklist </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Checklist Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getChecklistId();


    /**
     *  Gets the <code> Checklist </code> associated with this session. 
     *
     *  @return the checklist 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Checklist getChecklist()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create todos. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Todo </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Todo </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTodos();


    /**
     *  Tests if this user can create a single <code> Todo </code> using the 
     *  desired record types. While <code> 
     *  ChecklistManager.getTodoRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Todo. </code> Providing an 
     *  empty array tests if a <code> Todo </code> can be created with no 
     *  records. 
     *
     *  @param  todoRecordTypes array of todo record types 
     *  @return <code> true </code> if <code> Todo </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> todoRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateTodoWithRecordTypes(org.osid.type.Type[] todoRecordTypes);


    /**
     *  Gets the todo form for creating new todos. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  todoRecordTypes array of todo record types 
     *  @return the todo form 
     *  @throws org.osid.NullArgumentException <code> todoRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoForm getTodoFormForCreate(org.osid.type.Type[] todoRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Todo. </code> 
     *
     *  @param  todoForm the form for this <code> Todo </code> 
     *  @return the new <code> Todo </code> 
     *  @throws org.osid.IllegalStateException <code> todoForm </code> already 
     *          used for a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> todoForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> todoForm </code> did not 
     *          originate from <code> getTodoFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Todo createTodo(org.osid.checklist.TodoForm todoForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update todos. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Todo </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Todo </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateTodos();


    /**
     *  Gets the todo form for updating an existing todo. A new todo form 
     *  should be requested for each update transaction. 
     *
     *  @param  todoId the <code> Id </code> of the <code> Todo </code> 
     *  @return the todo form 
     *  @throws org.osid.NotFoundException <code> todoId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> todoId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoForm getTodoFormForUpdate(org.osid.id.Id todoId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing todo. 
     *
     *  @param  todoForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> todoForm </code> already 
     *          used for an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> todoId </code> or <code> 
     *          todoForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> todoForm </code> did not 
     *          originate from <code> getTodoFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateTodo(org.osid.checklist.TodoForm todoForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete todos. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Todo </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Todo </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteTodos();


    /**
     *  Deletes a <code> Todo. </code> 
     *
     *  @param  todoId the <code> Id </code> of the <code> Todo </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> todoId </code> not found 
     *  @throws org.osid.NullArgumentException <code> todoId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteTodo(org.osid.id.Id todoId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Comnents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Todo </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageTodoAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Todo </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Todo </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another todo, it is reassigned to the given todo <code> 
     *  Id. </code> 
     *
     *  @param  todoId the <code> Id </code> of a <code> Todo </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> todoId </code> not found 
     *  @throws org.osid.NullArgumentException <code> todoId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasTodo(org.osid.id.Id todoId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage todo dependencies <code> . </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known changing an alias will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Todo </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDependencies();


    /**
     *  Adds a todo as a dependency for another todo. 
     *
     *  @param  dependentTodoId the <code> Id </code> of the dependency <code> 
     *          Todo </code> 
     *  @param  dependencyTodoId the <code> Id </code> of the <code> Todo 
     *          </code> dependency 
     *  @throws org.osid.AlreadyExistsException <code> dependentTodoId </code> 
     *          is already dependent upon <code> dependencyTodoId </code> or 
     *          vice-versa 
     *  @throws org.osid.NotFoundException <code> dependentTodoId </code> or 
     *          <code> dependencyTodoId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> dependentTodoId </code> 
     *          or <code> dependencyTodoId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addDependency(org.osid.id.Id dependentTodoId, 
                              org.osid.id.Id dependencyTodoId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a todo as a dependency from another todo. 
     *
     *  @param  dependentTodoId the <code> Id </code> of the dependency <code> 
     *          Todo </code> 
     *  @param  dependencyTodoId the <code> Id </code> of the <code> Todo 
     *          </code> dependency 
     *  @throws org.osid.NotFoundException <code> dependentTodoId </code> or 
     *          <code> dependencyTodoId </code> is not found, or <code> 
     *          dependentTodoId </code> not dependent upon <code> 
     *          dependencyTodoId </code> 
     *  @throws org.osid.NullArgumentException <code> dependentTodoId </code> 
     *          or <code> dependencyTodoId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeDependency(org.osid.id.Id dependentTodoId, 
                                 org.osid.id.Id dependencyTodoId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
