//
// org.osid.checklist.TodoLookupSession
//
//     The OSID Java specification for org.osid.checklist.TodoLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>This session defines methods for retrieving todos. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated checklist view: All todo methods in this session 
 *      operate, retrieve and pertain to todos defined explicitly in the 
 *      current checklist. Using an isolated view is useful for managing todos 
 *      with the <code> TodoAdminSession. </code> </li> 
 *      <li> federated checklist view: All todo lookup methods in this session 
 *      operate, retrieve and pertain to all todos defined in this checklist 
 *      and any other checklists implicitly available in this checklist 
 *      through checklist inheritence. </li> 
 *      <li> effective todo view: All todo lookup methods return todos where 
 *      the current dates falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective todo view: Todos of any effective date are 
 *      returned. </li> 
 *      <li> sequestered todo viiew: All event methods suppress sequestered 
 *      todos. </li> 
 *      <li> unsequestered todo view: All event methods return all todos. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedChecklistView() </code> and <code> 
 *  useIsolatedChecklistView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface TodoLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Checklist </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Checklist Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getChecklistId();


    /**
     *  Gets the <code> Checklist </code> associated with this session. 
     *
     *  @return the checklist 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Checklist getChecklist()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this checklist. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if checklist reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupTodos();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeTodoView();


    /**
     *  A complete view of the <code> Todo </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryTodoView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include todos in checklists which are children of this checklist in 
     *  the checklist hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedChecklistView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this checklist only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedChecklistView();


    /**
     *  Only todos whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveTodoView();


    /**
     *  All todos of any effective dates are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveTodoView();


    /**
     *  The returns from the lookup methods omit sequestered todos. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredTodoView();


    /**
     *  All todos are returned including sequestered todos. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredTodoView();


    /**
     *  Gets the <code> Todo </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Todo </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Todo </code> and retained for compatibility. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @param  todoId the <code> Id </code> of the <code> Todo </code> to 
     *          retrieve 
     *  @return the returned <code> Todo </code> 
     *  @throws org.osid.NotFoundException no <code> Todo </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> todoId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Todo getTodo(org.osid.id.Id todoId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  todos specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible todos may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @param  todoIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Todo list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> todoIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByIds(org.osid.id.IdList todoIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> corresponding to the given todo genus 
     *  <code> Type </code> which does not include todos of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  todos or an error results. Otherwise, the returned list may contain 
     *  only those todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @param  todoGenusType a todo genus type 
     *  @return the returned <code> Todo </code> list 
     *  @throws org.osid.NullArgumentException <code> todoGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByGenusType(org.osid.type.Type todoGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> corresponding to the given todo genus 
     *  <code> Type </code> and include any additional todos with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  todos or an error results. Otherwise, the returned list may contain 
     *  only those todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @param  todoGenusType a todo genus type 
     *  @return the returned <code> Todo </code> list 
     *  @throws org.osid.NullArgumentException <code> todoGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByParentGenusType(org.osid.type.Type todoGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> containing the given todo record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  todos or an error results. Otherwise, the returned list may contain 
     *  only those todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *
     *  @param  todoRecordType a todo record type 
     *  @return the returned <code> Todo </code> list 
     *  @throws org.osid.NullArgumentException <code> todoRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByRecordType(org.osid.type.Type todoRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> with starting effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  This method return sthe same results in either effective status mode. 
     *  
     *  In plenary mode, the returned list contains all known todos or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Todo </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosOnDate(org.osid.calendaring.DateTime from, 
                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> at the given priority <code> Type 
     *  </code> or higher. 
     *  
     *  In plenary mode, the returned list contains all known todos or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *
     *  @param  priorityType a priority type 
     *  @return the returned <code> Todo </code> list 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByPriority(org.osid.type.Type priorityType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> with a due date within the given date 
     *  range inclusive <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  todos or an error results. Otherwise, the returned list may contain 
     *  only those todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Todo </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByDueDate(org.osid.calendaring.DateTime from, 
                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> TodoList </code> of todos dependent upon the given todo. 
     *  
     *  In plenary mode, the returned list contains all known todos or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @param  dependencyTodoId a todo 
     *  @return the returned <code> Todo </code> list 
     *  @throws org.osid.NullArgumentException <code> dependencyTodoId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByDependency(org.osid.id.Id dependencyTodoId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all todos. 
     *  
     *  In plenary mode, the returned list contains all known todos or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  todos that are accessible through this session. 
     *  
     *  In effective mode, todos are returned that are currently effective. In 
     *  any effective mode, effective todos and those currently expired are 
     *  returned. 
     *  
     *  In sequestered mode, no sequestered todos are returned. In 
     *  unsequestered mode, all todos are returned. 
     *
     *  @return a list of todos 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodos()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
