//
// org.osid.checklist.TodoQuerySession
//
//     The OSID Java specification for org.osid.checklist.TodoQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist;


/**
 *  <p>This session provides methods for searching <code> Todo </code> 
 *  objects. The search query is constructed using the <code> TodoQuery. 
 *  </code> The todo record <code> Type </code> also specifies the record for 
 *  the todo query. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> isolated checklist view: All todo methods in this session 
 *      operate, retrieve and pertain to todos defined explicitly in the 
 *      current checklist. Using an isolated view is useful for managing todos 
 *      with the TodoAdminSession. </li> 
 *      <li> federated checklist view: All todo lookup methods in this session 
 *      operate, retrieve and pertain to all todos defined in this checklist 
 *      and any other checklists implicitly available in this checklist 
 *      through checklist inheritence. </li> 
 *      <li> sequestered todo viiew: All event methods suppress sequestered 
 *      todos. </li> 
 *      <li> unsequestered todo view: All event methods return all todos. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Todos may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> TodoQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface TodoQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Checklist </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Checklist Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getChecklistId();


    /**
     *  Gets the <code> Checklist </code> associated with this session. 
     *
     *  @return the checklist 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.Checklist getChecklist()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform todo searches. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchTodos();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include todos in checklists which are children of this checklist in 
     *  the checklist hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedChecklistView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this checklist only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedChecklistView();


    /**
     *  The returns from the search methods omit sequestered todos. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredTodoView();


    /**
     *  All todos are returned including sequestered todos. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredTodoView();


    /**
     *  Gets a todo query. 
     *
     *  @return the todo query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoQuery getTodoQuery();


    /**
     *  Gets a list of todos matching the given search. 
     *
     *  @param  todoQuery the search query array 
     *  @return the returned <code> TodoList </code> 
     *  @throws org.osid.NullArgumentException <code> todoQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> todoQuery </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.TodoList getTodosByQuery(org.osid.checklist.TodoQuery todoQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
