//
// org.osid.checklist.mason.ChecklistMasonProfile
//
//     The OSID Java specification for org.osid.checklist.mason.ChecklistMasonProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>The checklist mason profile describes the interoperability among 
 *  checklist mason services. </p>
 */

public interface ChecklistMasonProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up todo producers is supported. 
     *
     *  @return <code> true </code> if todo producer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerLookup();


    /**
     *  Tests if querying todo producers is supported. 
     *
     *  @return <code> true </code> if todo producer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerQuery();


    /**
     *  Tests if searching todo producers is supported. 
     *
     *  @return <code> true </code> if todo producer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerSearch();


    /**
     *  Tests if a todo producer administrative service is supported. 
     *
     *  @return <code> true </code> if todo producer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerAdmin();


    /**
     *  Tests if a todo producer notification service is supported. 
     *
     *  @return <code> true </code> if todo producer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerNotification();


    /**
     *  Tests if a todo producer checklist lookup service is supported. 
     *
     *  @return <code> true </code> if a todo producer checklist lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerChecklist();


    /**
     *  Tests if a todo producer checklist service is supported. 
     *
     *  @return <code> true </code> if todo producer checklist assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerChecklistAssignment();


    /**
     *  Tests if a todo producer checklist lookup service is supported. 
     *
     *  @return <code> true </code> if a todo producer checklist service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerSmartChecklist();


    /**
     *  Gets the supported <code> TodoProducer </code> record types. 
     *
     *  @return a list containing the supported <code> TodoProducer </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTodoProducerRecordTypes();


    /**
     *  Tests if the given <code> TodoProducer </code> record type is 
     *  supported. 
     *
     *  @param  todoProducerRecordType a <code> Type </code> indicating a 
     *          <code> TodoProducer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> todoProducerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerRecordType(org.osid.type.Type todoProducerRecordType);


    /**
     *  Gets the supported <code> TodoProducer </code> search record types. 
     *
     *  @return a list containing the supported <code> TodoProducer </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getTodoProducerSearchRecordTypes();


    /**
     *  Tests if the given <code> TodoProducer </code> search record type is 
     *  supported. 
     *
     *  @param  todoProducerSearchRecordType a <code> Type </code> indicating 
     *          a <code> TodoProducer </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          todoProducerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTodoProducerSearchRecordType(org.osid.type.Type todoProducerSearchRecordType);
}
