//
// org.osid.checklist.mason.TodoProducerForm
//
//     The OSID Java specification for org.osid.checklist.mason.TodoProducerForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.checklist.mason;


/**
 *  <p>This is the form for creating and updating <code> TodoProducers. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  TodoProducerAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface TodoProducerForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for a creation rule flag. 
     *
     *  @return metadata for a creation operation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreationRuleMetadata();


    /**
     *  Sets the cyclic event. 
     *
     *  @param  creation the new creationr ule flag 
     *  @throws org.osid.InvalidArgumentException <code> creation </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreationRule(boolean creation);


    /**
     *  Clears the creation rule flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreationRule();


    /**
     *  Gets the metadata for a cyclic event. 
     *
     *  @return metadata for a cyclic event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCyclicEventMetadata();


    /**
     *  Sets the cyclic event. 
     *
     *  @param  cyclicEventId the new cyclic event 
     *  @throws org.osid.InvalidArgumentException <code> cyclicEventId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCyclicEvent(org.osid.id.Id cyclicEventId);


    /**
     *  Clears the cyclic event. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCyclicEvent();


    /**
     *  Gets the metadata for a cyclic event. 
     *
     *  @return metadata for a cyclic event 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStockMetadata();


    /**
     *  Sets the stock. 
     *
     *  @param  stockId the new stock 
     *  @throws org.osid.InvalidArgumentException <code> stockId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStock(org.osid.id.Id stockId);


    /**
     *  Clears the stock. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStock();


    /**
     *  Gets the metadata for the stock level. 
     *
     *  @return metadata for the stock level 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStockLevelMetadata();


    /**
     *  Sets the stock level. 
     *
     *  @param  level the new stock level 
     *  @throws org.osid.InvalidArgumentException <code> level </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStockLevel(long level);


    /**
     *  Clears the stock level. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockLevel();


    /**
     *  Gets the <code> TodoProducerFormRecord </code> corresponding to the 
     *  given todo producer record <code> Type. </code> 
     *
     *  @param  todoProducerRecordType a todo producer record type 
     *  @return the todo producer form record 
     *  @throws org.osid.NullArgumentException <code> todoProducerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(todoProducerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.checklist.mason.records.TodoProducerFormRecord getTodoProducerFormRecord(org.osid.type.Type todoProducerRecordType)
        throws org.osid.OperationFailedException;
}
