//
// org.osid.commenting.CommentAdminSession
//
//     The OSID Java specification for org.osid.commenting.CommentAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This session creates, updates, and deletes <code> Comments. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Comment, </code> a <code> CommentForm </code> is requested using <code> 
 *  getCommentFormForCreate() </code> specifying the desired relationship 
 *  peers and record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> CommentForm </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> CommentForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> CommentForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CommentForms </code> are requested to the <code> 
 *  Comment </code> <code> Id </code> that is to be updated using <code> 
 *  getCommentFormForUpdate(). </code> Similarly, the <code> CommentForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> CommentForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Comments. </code> To unmap a 
 *  <code> Comment </code> from the current <code> Book, </code> the <code> 
 *  CommentBookAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Comment </code> itself thus 
 *  removing it from all known <code> Book </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CommentAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Book </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Book Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBookId();


    /**
     *  Gets the <code> Book </code> associated with this session. 
     *
     *  @return the book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.Book getBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create comments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Comment </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Comment </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateComments();


    /**
     *  Tests if this user can create a single <code> Comment </code> using 
     *  the desired record types. While <code> 
     *  CommentingManager.getCommentRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Comment. </code> Providing 
     *  an empty array tests if a <code> Comment </code> can be created with 
     *  no records. 
     *
     *  @param  commentRecordTypes array of comment record types 
     *  @return <code> true </code> if <code> Comment </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> commentRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCommentWithRecordTypes(org.osid.type.Type[] commentRecordTypes);


    /**
     *  Gets the comment form for creating new comments. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  referenceId the <code> Id </code> for the reference object 
     *  @param  commentRecordTypes array of comment record types 
     *  @return the comment form 
     *  @throws org.osid.NullArgumentException <code> referenceId or 
     *          commentRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentForm getCommentFormForCreate(org.osid.id.Id referenceId, 
                                                                   org.osid.type.Type[] commentRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Comment. </code> 
     *
     *  @param  commentForm the form for this <code> Comment </code> 
     *  @return the new <code> Comment </code> 
     *  @throws org.osid.IllegalStateException <code> commentForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> commentForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commentForm </code> did 
     *          not originate from <code> getCommentFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.Comment createComment(org.osid.commenting.CommentForm commentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update comments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Comment </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Comment </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateComments();


    /**
     *  Gets the comment form for updating an existing comment. A new comment 
     *  form should be requested for each update transaction. 
     *
     *  @param  commentId the <code> Id </code> of the <code> Comment </code> 
     *  @return the comment form 
     *  @throws org.osid.NotFoundException <code> commentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> commentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentForm getCommentFormForUpdate(org.osid.id.Id commentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing comment. 
     *
     *  @param  commentForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> commentForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> commentForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commentForm </code> did 
     *          not originate from <code> getCommentFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateComment(org.osid.commenting.CommentForm commentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete comments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Comment </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Comment </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteComments();


    /**
     *  Deletes a <code> Comment. </code> 
     *
     *  @param  commentId the <code> Id </code> of the <code> Comment </code> 
     *          to remove 
     *  @throws org.osid.NotFoundException <code> commentId </code> not found 
     *  @throws org.osid.NullArgumentException <code> commentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteComment(org.osid.id.Id commentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Comnents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Comment </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCommentAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Comment </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Comment </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another comment, it is reassigned to the given 
     *  comment <code> Id. </code> 
     *
     *  @param  commentId the <code> Id </code> of a <code> Comment </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> commentId </code> not found 
     *  @throws org.osid.NullArgumentException <code> commentId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasComment(org.osid.id.Id commentId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
