//
// org.osid.commenting.CommentBookAssignmentSession
//
//     The OSID Java specification for org.osid.commenting.CommentBookAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This session provides methods to re-assign <code> Comments </code> to 
 *  <code> Books. </code> A <code> Comment </code> may map to multiple <code> 
 *  Books </code> and removing the last reference to a <code> Comment </code> 
 *  is the equivalent of deleting it. Each <code> Book </code> may have its 
 *  own authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Comment </code> to another <code> Book 
 *  </code> is not a copy operation (eg: does not change its <code> Id </code> 
 *  ). </p>
 */

public interface CommentBookAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter comment/book mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignComments();


    /**
     *  Tests if this user can alter comment/book mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCommentsToBook(org.osid.id.Id bookId);


    /**
     *  Gets a list of books including and under the given book node in which 
     *  any comment can be assigned. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @return list of assignable book <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> bookId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBookIds(org.osid.id.Id bookId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of books including and under the given book node in which 
     *  a specific comment can be assigned. 
     *
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @param  commentId the <code> Id </code> of the <code> Comment </code> 
     *  @return list of assignable book <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> bookId </code> or <code> 
     *          commentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBookIdsForComment(org.osid.id.Id bookId, 
                                                             org.osid.id.Id commentId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Comment </code> to a <code> Book. </code> 
     *
     *  @param  commentId the <code> Id </code> of the <code> Comment </code> 
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @throws org.osid.AlreadyExistsException <code> commentId </code> is 
     *          already assigned to <code> bookId </code> 
     *  @throws org.osid.NotFoundException <code> commentId </code> or <code> 
     *          bookId </code> not found 
     *  @throws org.osid.NullArgumentException <code> commentId </code> or 
     *          <code> bookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCommentToBook(org.osid.id.Id commentId, 
                                    org.osid.id.Id bookId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Comment </code> from a <code> Book. </code> 
     *
     *  @param  commentId the <code> Id </code> of the <code> Comment </code> 
     *  @param  bookId the <code> Id </code> of the <code> Book </code> 
     *  @throws org.osid.NotFoundException <code> commentId </code> or <code> 
     *          bookId </code> not found or <code> commentId </code> not 
     *          assigned to <code> bookId </code> 
     *  @throws org.osid.NullArgumentException <code> commentId </code> or 
     *          <code> bookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCommentFromBook(org.osid.id.Id commentId, 
                                        org.osid.id.Id bookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Credit </code> from one <code> Book </code> to another. 
     *  Mappings to other <code> Books </code> are unaffected. 
     *
     *  @param  commentId the <code> Id </code> of the <code> Comment </code> 
     *  @param  fromBookId the <code> Id </code> of the current <code> Book 
     *          </code> 
     *  @param  toBookId the <code> Id </code> of the destination <code> Book 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> commentId, fromBookId, 
     *          </code> or <code> toBookId </code> not found or <code> comment 
     *          </code> not mapped to <code> fromBookId </code> 
     *  @throws org.osid.NullArgumentException <code> commentId, bookIdId, 
     *          </code> or <code> toBookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignCommentToBook(org.osid.id.Id commentId, 
                                      org.osid.id.Id fromBookId, 
                                      org.osid.id.Id toBookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
