//
// org.osid.commenting.CommentQuerySession
//
//     The OSID Java specification for org.osid.commenting.CommentQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.commenting;


/**
 *  <p>This session provides methods for searching <code> Comment </code> 
 *  objects. The search query is constructed using the <code> CommentQuery. 
 *  </code> The book record <code> Type </code> also specifies the record for 
 *  the book query. </p> 
 *  
 *  <p> Comments may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> CommentQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface CommentQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Book </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Book Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBookId();


    /**
     *  Gets the <code> Book </code> associated with this session. 
     *
     *  @return the book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.Book getBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform comment searches. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchComments();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include comments in books which are children of this book in the book 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBookView();


    /**
     *  Gets a comment query. 
     *
     *  @return the comment query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentQuery getCommentQuery();


    /**
     *  Gets a list of comments matching the given search. 
     *
     *  @param  commentQuery the search query array 
     *  @return the returned <code> CommentList </code> 
     *  @throws org.osid.NullArgumentException <code> commentQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commentQuery </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.commenting.CommentList getCommentsByQuery(org.osid.commenting.CommentQuery commentQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
