//
// org.osid.communication.CommunicationSession
//
//     The OSID Java specification for org.osid.communication.CommunicationSession.
//
// Copyright (C) 2010,2014 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.communication;


/**
 *  <p>This session defines methods to process communications. Notifications 
 *  are cancelled when this session is closed. </p>
 */

public interface CommunicationSession
    extends org.osid.OsidSession {


    /**
     *  Register for notifications of new communiques. <code> 
     *  CommunicationReceiver.newCommunique() </code> is invoked when a new 
     *  <code> Communique </code> is sent. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForCommuniques()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Sends a nonce response indicating that operations should continue or 
     *  abort. 
     *
     *  @param  communiqueId the <code> Id </code> of a communique 
     *  @throws org.osid.IllegalStateException <code> 
     *          Communique.respondViaOption() </code> or <code> 
     *          Communique.respondViaForm() </code> is <code> true </code> , 
     *          or a response was already supplied 
     *  @throws org.osid.InvalidArgumentException <code> communiqueId </code> 
     *          not valid 
     *  @throws org.osid.NullArgumentException <code> communiqueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledge(org.osid.id.Id communiqueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Responds to a communique requiring a response option. 
     *
     *  @param  responseOptionId the <code> Id </code> of a response option 
     *  @throws org.osid.IllegalStateException <code> 
     *          Communique.respondViaOption() </code> is <code> false or a 
     *          response was already supplied </code> 
     *  @throws org.osid.InvalidArgumentException <code> responseOptionId 
     *          </code> not valid 
     *  @throws org.osid.NullArgumentException <code> responseOptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void respondViaOption(org.osid.id.Id responseOptionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the response form for submitting form-based responses. 
     *
     *  @param  communiqueId the <code> Id </code> of a communique 
     *  @return a response form 
     *  @throws org.osid.IllegalStateException <code> 
     *          Communique.respondViaForm() </code> is <code> false </code> 
     *  @throws org.osid.InvalidArgumentException <code> communiqueId </code> 
     *          not valid 
     *  @throws org.osid.NullArgumentException <code> communiqueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.communication.ResponseForm getResponseForm(org.osid.id.Id communiqueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Responds to a communique requiring form input. 
     *
     *  @param  responseForm a response form 
     *  @throws org.osid.IllegalStateException <code> responseForm </code> 
     *          already used in a response transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> responseForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> responseForm </code> did 
     *          not originate from <code> getResponseForm() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void respondViaForm(org.osid.communication.ResponseForm responseForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
