//
// org.osid.communication.Communique
//
//     The OSID Java specification for org.osid.communication.Communique.
//
// Copyright (C) 2010,2014 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.communication;


/**
 *  <p>A communique is a message to a user handled through an application. 
 *  Communiques may require some form of acknowledgement ranging from a simple 
 *  confirmation to data input. </p>
 */

public interface Communique
    extends org.osid.OsidObject {


    /**
     *  Gets the message. 
     *
     *  @return the message 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMessage();


    /**
     *  Gets the message level for this communique. 
     *
     *  @return the message level 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.communication.CommuniqueLevel getLevel();


    /**
     *  Tests if the provider is blocking for a response. A response may take 
     *  the form of s simple acknowledgement, a selection among a list of 
     *  options, or a form input. 
     *
     *  @return <code> true </code> if the provider is blocking for a response 
     *          <code> false </code> if no response is required 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isResponseRequired();


    /**
     *  Tests if the provider is blocking on a choice selection. If <code> 
     *  respondViaForm() </code> is <code> true, </code> then this method must 
     *  return <code> false. </code> If <code> isResponseRequired() </code> is 
     *  <code> false </code> and <code> respondViaOption() </code> is <code> 
     *  true, </code> then a response is optional. 
     *
     *  @return <code> true </code> if the provider accepts a selection input, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean respondViaOption();


    /**
     *  Gets a list of possible response choices to this communique. 
     *
     *  @return a list of possible responses 
     *  @throws org.osid.IllegalStateException <code> respondViaOption() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.communication.ResponseOption[] getResponseOptions();


    /**
     *  Tests if the provider is blocking on a form input. If <code> 
     *  respondViaOption() </code> is <code> true, </code> then this method 
     *  must return <code> false </code> . If <code> isResponseRequired() 
     *  </code> is false and <code> respondViaForm() </code> is <code> true 
     *  </code> , then a response is optional. 
     *
     *  @return <code> true </code> if the provider accepts form input, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean respondViaForm();


    /**
     *  Gets the communique record corresponding to the given <code> 
     *  Communique </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  communiqueRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(communiqueRecordType) </code> is <code> true </code> . 
     *
     *  @param  communiqueRecordType the type of the record to retrieve 
     *  @return the communique record 
     *  @throws org.osid.NullArgumentException <code> communiqueRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(communiqueRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.communication.records.CommuniqueRecord getCommuniqueRecord(org.osid.type.Type communiqueRecordType)
        throws org.osid.OperationFailedException;
}
