//
// org.osid.communication.ResponseForm
//
//     The OSID Java specification for org.osid.communication.ResponseForm.
//
// Copyright (C) 2010,2014 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.communication;


/**
 *  <p>This is the form for submitting <code> Responses. </code> </p>
 */

public interface ResponseForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for all the fields. Some fields may be required and 
     *  others optional. 
     *
     *  @return the metadata 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata[] getMetadata();


    /**
     *  Sets a value for a given field. 
     *
     *  @param  id the <code> Id </code> of the metadata field 
     *  @param  value the value 
     *  @throws org.osid.InvalidArgumentException <code> id </code> or <code> 
     *          value </code> is invalid 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          value </code> is <code> null </code> 
     *  @throws org.osid.NoAccessException <code> value </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValue(org.osid.id.Id id, java.lang.Object value);


    /**
     *  Clears a value. 
     *
     *  @param  id the <code> Id </code> of the metadata field 
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValue(org.osid.id.Id id);


    /**
     *  Gets the <code> ResponseFormRecord </code> corresponding to the given 
     *  response record <code> Type. </code> 
     *
     *  @param  responseRecordType a response record type 
     *  @return the response form record 
     *  @throws org.osid.NullArgumentException <code> responseRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(responseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.communication.records.ResponseFormRecord getResponseFormRecord(org.osid.type.Type responseRecordType)
        throws org.osid.OperationFailedException;
}
