//
// org.osid.configuration.ConfigurationForm
//
//     The OSID Java specification for org.osid.configuration.ConfigurationForm.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This is the form for creating and updating configuration objects. 
 *  <code> </code> Like all <code> OsidForm </code> objects, various data 
 *  elements may be set here for use in the create and update methods in the 
 *  <code> ConfigurationAdminSession. </code> For each data element that may 
 *  be set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface ConfigurationForm
    extends org.osid.OsidCatalogForm {


    /**
     *  Gets the metadata for the registry flag. 
     *
     *  @return metadata for the registry 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRegistryMetadata();


    /**
     *  Sets the registry flag that indicates if the parameters mapped to this 
     *  configuration contain no values. 
     *
     *  @param  registry <code> true </code> if the parameters in this 
     *          configuration cannot contain values, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.InvalidArgumentException <code> registry </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> registry </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRegistry(boolean registry);


    /**
     *  Gets the <code> ConfigurationFormRecord </code> corresponding to the 
     *  given configuration record interface <code> Type. </code> 
     *
     *  @param  configurationRecordType a configuration record type 
     *  @return the configuration form record 
     *  @throws org.osid.NullArgumentException <code> configurationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(configurationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ConfigurationFormRecord getConfigurationFormRecord(org.osid.type.Type configurationRecordType)
        throws org.osid.OperationFailedException;
}
