//
// org.osid.configuration.ConfigurationProfile
//
//     The OSID Java specification for org.osid.configuration.ConfigurationProfile.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>The <code> ConfigurationProfile </code> describes the profile of the 
 *  configuration service. </p>
 */

public interface ConfigurationProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible for this service. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a configuration value retrieval service. 
     *
     *  @return <code> true </code> if value retrieval is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueRetrieval();


    /**
     *  Tests for the availability of a configuration value lookup service. 
     *
     *  @return <code> true </code> if value lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueLookup();


    /**
     *  Tests for the availability of a configuration value query service. 
     *
     *  @return <code> true </code> if value query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueQuery();


    /**
     *  Tests for the availability of a configuration value search service. 
     *
     *  @return <code> true </code> if value search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueSearch();


    /**
     *  Tests for the availability of a configuration value administration 
     *  service. 
     *
     *  @return <code> true </code> if value administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueAdmin();


    /**
     *  Tests for the availability of a configuration value notification 
     *  service. 
     *
     *  @return <code> true </code> if value notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueNotification();


    /**
     *  Tests for the availability of a parameter lookup service. 
     *
     *  @return <code> true </code> if parameter lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterLookup();


    /**
     *  Tests for the availability of a parameter query service. 
     *
     *  @return <code> true </code> if parameter query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterQuery();


    /**
     *  Tests for the availability of a parameter search service. 
     *
     *  @return <code> true </code> if parameter search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterSearch();


    /**
     *  Tests for the availability of a parameter update service. 
     *
     *  @return <code> true </code> if parameter update is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsParameterAdmin();


    /**
     *  Tests for the availability of a parameter notification service. 
     *
     *  @return <code> true </code> if parameter notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterNotification();


    /**
     *  Tests for the availability of a service to lookup mappings of 
     *  parameters to configurations. 
     *
     *  @return <code> true </code> if parameter configuration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsParameterConfiguration();


    /**
     *  Tests for the availability of a service to map parameters to 
     *  configurations. 
     *
     *  @return <code> true </code> if parameter configuration assignment is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsParameterConfigurationAssignment();


    /**
     *  Tests for the availability of a parameter smart configuration service. 
     *
     *  @return <code> true </code> if parameter smart configuration service 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsParameterSmartConfiguration();


    /**
     *  Tests for the availability of a configuration lookup service. 
     *
     *  @return <code> true </code> if configuration lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationLookup();


    /**
     *  Tests for the availability of a configuration query service. 
     *
     *  @return <code> true </code> if configuration query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationQuery();


    /**
     *  Tests for the availability of a configuration search service. 
     *
     *  @return <code> true </code> if configuration search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationSearch();


    /**
     *  Tests for the availability of a configuration admin service. 
     *
     *  @return <code> true </code> if configuration admin is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationAdmin();


    /**
     *  Tests for the availability of a notification service for subscribing 
     *  to changes to configurations. 
     *
     *  @return <code> true </code> if a configuration notification service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationNotification();


    /**
     *  Tests for the availability of a configuration hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if a configuration hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationHierarchy();


    /**
     *  Tests for the availability of a configuration hierarchy design 
     *  service. 
     *
     *  @return <code> true </code> if a configuration hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationHierarchyDesign();


    /**
     *  Tests for the availability of a configuration batch service. 
     *
     *  @return <code> true </code> if a configuration batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationBatch();


    /**
     *  Tests for the availability of a configuration rules service. 
     *
     *  @return <code> true </code> if a configuration rules service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationRules();


    /**
     *  Gets the supported value condition record types. 
     *
     *  @return a list containing the supported <code> ValueCondition </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getValueConditionRecordTypes();


    /**
     *  Tests if the given <code> ValueCondition </code> record type is 
     *  supported. 
     *
     *  @param  valueConditionRecordType a <code> Type </code> indicating a 
     *          <code> ValueCondition </code> record type 
     *  @return <code> true </code> if the given value condition record <code> 
     *          Type </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> valueConditionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueConditionRecordType(org.osid.type.Type valueConditionRecordType);


    /**
     *  Gets all the value record types supported. 
     *
     *  @return the list of supported value record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getValueRecordTypes();


    /**
     *  Tests if a given value record type is supported. 
     *
     *  @param  valueRecordType the value record type 
     *  @return <code> true </code> if the value record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> valueRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueRecordType(org.osid.type.Type valueRecordType);


    /**
     *  Gets all the value search record types supported. 
     *
     *  @return the list of supported value search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getValueSearchRecordTypes();


    /**
     *  Tests if a given value search type is supported. 
     *
     *  @param  valueSearchRecordType the value search record type 
     *  @return <code> true </code> if the value search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> valueSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsValueSearchRecordType(org.osid.type.Type valueSearchRecordType);


    /**
     *  Gets all the parameter record types supported. 
     *
     *  @return the list of supported parameter record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParameterRecordTypes();


    /**
     *  Tests if a given parameter record type is supported. 
     *
     *  @param  parameterRecordType a parameter record type 
     *  @return <code> true </code> if the parameter record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> parameterRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterRecordType(org.osid.type.Type parameterRecordType);


    /**
     *  Gets all the parameter search record types supported. 
     *
     *  @return the list of supported parameter search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getParameterSearchRecordTypes();


    /**
     *  Tests if a given parameter search record type is supported. 
     *
     *  @param  parameterSearchRecordType the value search type 
     *  @return <code> true </code> if the parameter search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterSearchRecordType(org.osid.type.Type parameterSearchRecordType);


    /**
     *  Gets all the configuration record types supported. 
     *
     *  @return the list of supported configuration record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getConfigurationRecordTypes();


    /**
     *  Tests if a given configuration record type is supported. 
     *
     *  @param  configurationRecordType a configuration record type 
     *  @return <code> true </code> if the configuration record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> configurationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationRecordType(org.osid.type.Type configurationRecordType);


    /**
     *  Gets all the configuration search record types supported. 
     *
     *  @return the list of supported configuration search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getConfigurationSearchRecordTypes();


    /**
     *  Tests if a given configuration search record type is supported. 
     *
     *  @param  configurationSearchRecordType the configuration search record 
     *          type 
     *  @return <code> true </code> if the configuration search record type is 
     *          support <code> e </code> d, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          configurationSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationSearchRecordType(org.osid.type.Type configurationSearchRecordType);
}
