//
// org.osid.configuration.ConfigurationProxyManager
//
//     The OSID Java specification for org.osid.configuration.ConfigurationProxyManager.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>The configuration manager provides access to sessions to retrieve and 
 *  manage configurations. Methods in this manager support the passing a 
 *  <code> Proxy. </code> A manager may support federation in that values can 
 *  be accessed in a specified configuration and paramaters may be defined in 
 *  a specified registry. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ValueRetrievalSession: </code> a basic session for 
 *      retrieving configuration values </li> 
 *      <li> <code> ValueLookupSession: </code> a basic session for looking up 
 *      configuration values </li> 
 *      <li> <code> ValueQuerySession: </code> a basic session for querying 
 *      configuration values </li> 
 *      <li> <code> ValueSearchSession: </code> a basic session for searching 
 *      configuration values </li> 
 *      <li> <code> ValueAdminSession: </code> a session for setting and 
 *      changing configuration values </li> 
 *      <li> <code> ValueNotificationSession: </code> a session for 
 *      subscribing to changes of configuration values </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ParameterLookupSession: </code> a session for retrieving 
 *      defined parameters </li> 
 *      <li> <code> ParameterQuerySession: </code> a session for querying 
 *      defined parameters </li> 
 *      <li> <code> ParameterSearchSession: </code> a session for searching 
 *      defined parameters </li> 
 *      <li> <code> ParameterAdminSession: </code> a session for creating, 
 *      updating and deleting parameter definitions </li> 
 *      <li> <code> ParameterNoitificationSession: </code> a session for 
 *      subscribing to adds and changes of parameters </li> 
 *      <li> <code> ParamaterRegistrySession: </code> a session for examining 
 *      mappings of parameters to registries </li> 
 *      <li> <code> ParamaterRegistryAssignmentSession: </code> a session for 
 *      making mappings of parameters to registries </li> 
 *      <li> <code> ParameterConfigurationSession: </code> a session for 
 *      examining mappings of parameters to configurations </li> 
 *      <li> <code> ParameterConfigurationAssignmentSession: </code> a session 
 *      for mapping parameters to configurations </li> 
 *      <li> <code> ParameterSmartConfigurationSession: </code> a session for 
 *      managing smart configurations of parameters </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ConfigurationLookupSession: </code> a session for 
 *      retrieving configurations </li> 
 *      <li> <code> ConfigurationQuerySession: </code> a session for querying 
 *      configurations </li> 
 *      <li> <code> ConfigurationSearchSession: </code> a session for 
 *      searching configurations </li> 
 *      <li> <code> ConfigurationAdminSession: </code> a session for creating 
 *      and updating configurations </li> 
 *      <li> <code> ConfigurationNotificationSession: </code> a session for 
 *      subscribing to adds and changes to configurations </li> 
 *      <li> <code> ConfigurationHierarchySession: </code> a session for 
 *      traversing a hierarchy of configurations </li> 
 *      <li> <code> ConfigurationHierarchyDesignSession: </code> a session for 
 *      managing a hierarchy of configurations </li> 
 *  </ul>
 *  
 */

public interface ConfigurationProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.configuration.ConfigurationProfile {


    /**
     *  Gets a configuration value retrieval session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueRetrievalSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueRetrieval() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueRetrieval() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ValueRetrievalSession getValueRetrievalSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a configuration value retrieval session using the supplied 
     *  configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ValueRetrievalSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueRetrieval() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> False </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsValueRetrieval() </code> are <code> true </code> 
     */

    public org.osid.configuration.ValueRetrievalSession getValueRetrievalSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a configuration value lookup session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueLookup() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ValueLookupSession getValueLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a configuration value lookup session using the supplied 
     *  configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ValueLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> False </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsValueLookup() </code> are <code> true </code> 
     */

    public org.osid.configuration.ValueLookupSession getValueLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a configuration value query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueQuery() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ValueQuerySession getValueQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a configuration value query session using the supplied 
     *  configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ValueQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> False </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsValueQuery() </code> are <code> true </code> 
     */

    public org.osid.configuration.ValueQuerySession getValueQuerySessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a configuration value search session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueLookup() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ValueSearchSession getValueSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a configuration value search session using the supplied 
     *  configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ValueSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> False </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsValueSearch() </code> are <code> true </code> 
     */

    public org.osid.configuration.ValueSearchSession getValueSearchSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a value notification session. 
     *
     *  @param  valueReceiver notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ValueNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> valueReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ValueNotificationSession getValueNotificationSession(org.osid.configuration.ValueReceiver valueReceiver, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a value notification session using the specified configuration 
     *
     *  @param  valueReceiver notification callback 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ValueNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> valueReceiver, 
     *          configurationId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsValueNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsValueNotification() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ValueNotificationSession getValueNotificationSessionForConfiguration(org.osid.configuration.ValueReceiver valueReceiver, 
                                                                                                       org.osid.id.Id configurationId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a configuration value administration session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ValueAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsValueAdmin() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ValueAdminSession getValueAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a value administration session using the supplied configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ValueAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsValueSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsValueAdmin() </code> are <code> true. </code> 
     */

    public org.osid.configuration.ValueAdminSession getValueAdminSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a parameter lookup session 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterLookup() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ParameterLookupSession getParameterLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a parameter lookup session using the supplied configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ParamaterLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsParameterLookup() </code> are <code> true. </code> 
     */

    public org.osid.configuration.ParameterLookupSession getParameterLookupSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a parameter query session 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterQuery() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ParameterQuerySession getParameterQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a parameter query session using the supplied configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ParamaterQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsParameterQuery() </code> are <code> true. </code> 
     */

    public org.osid.configuration.ParameterQuerySession getParameterQuerySessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a parameter search session 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterSearch() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ParameterSearchSession getParameterSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a parameter search session using the supplied configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ParamaterSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsParameterSearch() </code> are <code> true. </code> 
     */

    public org.osid.configuration.ParameterSearchSession getParameterSearchSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a parameter administration session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterAdmin() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ParameterAdminSession getParameterAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a parameter administration session using the supplied 
     *  configuration. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsParameterAdmin() </code> are <code> true. </code> 
     */

    public org.osid.configuration.ParameterAdminSession getParameterAdminSessionForConfiguration(org.osid.id.Id configurationId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a parameter notification session. 
     *
     *  @param  parameterReceiver notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> parameterReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ParameterNotificationSession getParameterNotificationSession(org.osid.configuration.ParameterReceiver parameterReceiver, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a parameter notification session using the specified 
     *  configuration. 
     *
     *  @param  parameterReceiver notification callback 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> registryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> parameterReceiver, 
     *          configurationId, </code> or <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVisibleFederation() </code> and <code> 
     *              supportsParameterNotification() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ParameterNotificationSession getParameterNotificationSessionForConfiguration(org.osid.configuration.ParameterReceiver parameterReceiver, 
                                                                                                               org.osid.id.Id configurationId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a session for examining mappings of parameters to configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterConfigurationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterConfiguration() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterConfiguration() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ParameterConfigurationSession getParameterConfigurationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a session for managing mappings of parameters to configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ParameterConfigurationAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterConfigurationAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterConfigurationAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.configuration.ParameterConfigurationAssignmentSession getParameterConfigurationAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a session for managing smart configurations of parameters. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> to use 
     *  @param  proxy a proxy 
     *  @return a <code> ParameterSmartConfigurationSession </code> 
     *  @throws org.osid.NotFoundException <code> configurationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> configuratinId </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterSmartConfiguration() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterSmartConfiguration() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.ParameterSmartConfigurationSession getParameterSmartConfigurationSession(org.osid.id.Id configurationId, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a configuration lookup session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ConfigurationLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationLookupSession getConfigurationLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a configuration query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ConfigurationQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationQuerySession getConfigurationQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a configuration search session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ConfigurationSearchSession </code> 
     *  @throws org.osid.OperationFailedException <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.NullArgumentException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationSearchSession getConfigurationSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscribing to changes to 
     *  configurations. 
     *
     *  @param  configurationReceiver notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ConfigurationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> configurationReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.ConfigurationNotificationSession getConfigurationNotificationSession(org.osid.configuration.ConfigurationReceiver configurationReceiver, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a configuration administration session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ConfigurationAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationAdminSession getConfigurationAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a hierarchy traversal service for configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ConfiguraqtionHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationHierarchy() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationHierarchySession getConfigurationHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a hierarchy design service for configurations. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ConfigurationHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationHierarchyDesign() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.configuration.ConfigurationHierarchyDesignSession getConfigurationHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ConfigurationProxyManager. </code> 
     *
     *  @return a <code> ConfigurationBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationBatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.batch.ConfigurationBatchProxyManager getConfigurationBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> ConfigurationProxyManager. </code> 
     *
     *  @return a <code> ConfigurationRulesProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationRules() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationRules() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.rules.ConfigurationRulesProxyManager getConfigurationRulesProxyManager()
        throws org.osid.OperationFailedException;
}
