//
// org.osid.configuration.Parameter
//
//     The OSID Java specification for org.osid.configuration.Parameter.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>A parameter is used to map configuration values to an identifier and 
 *  syntax. The type of the value must be used across all values of the same 
 *  parameter. The values associated with a parameter should be queried 
 *  through the <code> ValueLookupSession. </code> </p>
 */

public interface Parameter
    extends org.osid.OsidRule {


    /**
     *  Gets the syntax for the values of this parameter. 
     *
     *  @return the syntax of the values 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Syntax getValueSyntax();


    /**
     *  Gets the type of the value if the syntax is a coordinate. 
     *
     *  @return the type of the values 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          COORDINATE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getValueCoordinateType();


    /**
     *  Tests if the coordinate supports the given coordinate <code> Type. 
     *  </code> 
     *
     *  @param  coordinateType a coordinate type 
     *  @return <code> true </code> if the coordinate values associated with 
     *          this parameter implement the given coordinate <code> Type, 
     *          </code> <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          COORDINATE </code> 
     *  @throws org.osid.NullArgumentException <code> coordinateType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean implementsValueCoordinateType(org.osid.type.Type coordinateType);


    /**
     *  Gets the type of the value if the syntax is a heading. 
     *
     *  @return the type of the values 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          HEADING </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getValueHeadingType();


    /**
     *  Tests if the heading supports the given heading <code> Type. </code> 
     *
     *  @param  headingType a heading type 
     *  @return <code> true </code> if the heading values associated with this 
     *          parameter implement the given heading <code> Type, </code> 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          HEADING </code> 
     *  @throws org.osid.NullArgumentException <code> headingType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean implementsValueHeadingType(org.osid.type.Type headingType);


    /**
     *  Gets the type of the value if the syntax is an object. 
     *
     *  @return the type of the values 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          OBJECT </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getValueObjectType();


    /**
     *  Tests if the object supports the given <code> Type. </code> This 
     *  method should be checked before retrieving the object value. 
     *
     *  @param  valueType a type 
     *  @return <code> true </code> if the obect values associated with this 
     *          parameter implement the given <code> Type, </code> <code> 
     *          false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          OBJECT </code> 
     *  @throws org.osid.NullArgumentException <code> valueType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean implementsValueObjectType(org.osid.type.Type valueType);


    /**
     *  Gets the type of the value if the syntax is a spatial unit. 
     *
     *  @return the type of the values 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          SPATIALUNIT </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getValueSpatialUnitRecordType();


    /**
     *  Tests if the spatial unit supports the given record <code> Type. 
     *  </code> 
     *
     *  @param  spatialUnitRecordType a spatial unit record type 
     *  @return <code> true </code> if the spatial unit values associated with 
     *          this parameter implement the given record <code> Type, </code> 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          SPATIALUNIT </code> 
     *  @throws org.osid.NullArgumentException <code> spatialUnitRecordTYpe 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean implementsValueSpatialUnitRecordType(org.osid.type.Type spatialUnitRecordType);


    /**
     *  Gets the type of the value if the syntax is a version. 
     *
     *  @return the type of the values 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          VERSION </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getValueVersionScheme();


    /**
     *  Tests if the version supports the given version <code> Type. </code> 
     *
     *  @param  versionType a version type 
     *  @return <code> true </code> if the version values associated with this 
     *          parameter implement the given version <code> Type, </code> 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> getValueSyntax() != 
     *          VERSION </code> 
     *  @throws org.osid.NullArgumentException <code> versionType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean implementsValueVersionScheme(org.osid.type.Type versionType);


    /**
     *  Tests if if the values assigned to this parameter will be shuffled or 
     *  values are sorted by index. 
     *
     *  @return <code> true </code> if the values are shuffled, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean areValuesShuffled();


    /**
     *  Gets the parameter record corresponding to the given <code> Parameter 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  parameterRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(parameterRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  parameterRecordType the type of parameter record to retrieve 
     *  @return the parameter record 
     *  @throws org.osid.NullArgumentException <code> parameterRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(parameterRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ParameterRecord getParameterRecord(org.osid.type.Type parameterRecordType)
        throws org.osid.OperationFailedException;
}
