//
// org.osid.configuration.ParameterForm
//
//     The OSID Java specification for org.osid.configuration.ParameterForm.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This is the form for creating and updating <code> Parameters. </code> 
 *  Various data elements may be set here for use in the create and update 
 *  methods in the <code> ParameterAdminSession. </code> For each data element 
 *  that may be set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface ParameterForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for the value syntax. 
     *
     *  @return metadata for the value syntax 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getValueSyntaxMetadata();


    /**
     *  Sets a value syntax. 
     *
     *  @param  syntax the new value type 
     *  @throws org.osid.InvalidArgumentException <code> syntax </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> syntax </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValueSyntax(org.osid.Syntax syntax);


    /**
     *  Clears the value syntax. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() is true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueSyntax();


    /**
     *  Gets the metadata for the coordinate type for coordinate values. 
     *
     *  @return metadata for the coordinate type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getValueCoordinateTypeMetadata();


    /**
     *  Sets a coordinate type. 
     *
     *  @param  coordinateType the new coordinate type 
     *  @throws org.osid.InvalidArgumentException <code> coordinateType 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> coordinateType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValueCoordinateType(org.osid.type.Type coordinateType);


    /**
     *  Clears the coordinate type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() is true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueCoordinateType();


    /**
     *  Gets the metadata for the heading type for coordinate values. 
     *
     *  @return metadata for the heading type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getValueHeadingTypeMetadata();


    /**
     *  Sets a heading type. 
     *
     *  @param  headingType the new heading type 
     *  @throws org.osid.InvalidArgumentException <code> headingType </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> headingType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValueHeadingType(org.osid.type.Type headingType);


    /**
     *  Clears the heading type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() is true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueHeadingType();


    /**
     *  Gets the metadata for the object value type for object values. 
     *
     *  @return metadata for the object type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getValueObjectTypeMetadata();


    /**
     *  Sets an object value type. 
     *
     *  @param  objectType the new object type 
     *  @throws org.osid.InvalidArgumentException <code> objectType </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> objectType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValueObjectType(org.osid.type.Type objectType);


    /**
     *  Clears the object value type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() is true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueObjectType();


    /**
     *  Gets the metadata for the spatial unit record type for coordinate 
     *  values. 
     *
     *  @return metadata for the spatial unit record type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getValueSpatialUnitRecordTypeMetadata();


    /**
     *  Sets a spatial unit record type. 
     *
     *  @param  spatialUnitRecordType the new spatial unit record type 
     *  @throws org.osid.InvalidArgumentException <code> spatialUnitRecordType 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> spatialUnitRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValueSpatialUnitRecordType(org.osid.type.Type spatialUnitRecordType);


    /**
     *  Clears the spatial unit record type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() is true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueSpatialUnitRecordType();


    /**
     *  Gets the metadata for the version type for object values. 
     *
     *  @return metadata for the version type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getValueVersionSchemeMetadata();


    /**
     *  Sets a version type. 
     *
     *  @param  versionType the new version type 
     *  @throws org.osid.InvalidArgumentException <code> versionType </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> versionType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValueVersionScheme(org.osid.type.Type versionType);


    /**
     *  Clears the version value type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() is true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueVersionScheme();


    /**
     *  Gets the metadata for the shuffle type. 
     *
     *  @return metadata for the shuffle flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getValuesShuffledMetadata();


    /**
     *  Sets the shuffle order. 
     *
     *  @param  shuffle <code> true </code> to shuffle values by weight, 
     *          <code> false </code> to order values by index 
     *  @throws org.osid.InvalidArgumentException <code> shuffle </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setValuesShuffled(boolean shuffle);


    /**
     *  Clears the shuffle flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() is true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValuesShuffled();


    /**
     *  Gets the <code> ParameterFormRecord </code> corresponding to the given 
     *  parameter record <code> Type. </code> 
     *
     *  @param  parameterRecordType a parameter record type 
     *  @return the parameter form record 
     *  @throws org.osid.NullArgumentException <code> parameterRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(parameterRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ParameterFormRecord getParameterFormRecord(org.osid.type.Type parameterRecordType)
        throws org.osid.OperationFailedException;
}
