//
// org.osid.configuration.ParameterSearchSession
//
//     The OSID Java specification for org.osid.configuration.ParameterSearchSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session provides methods for searching <code> Parameter </code> 
 *  objects. The search query is constructed using the <code> ParameterQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getParametersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Parameters. </code> A more advanced search may be 
 *  performed with <code> getParametersBySearch(). </code> It accepts a <code> 
 *  ParameterSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getParametersBySearch() </code> returns a <code> 
 *  ParameterSearchResults </code> that can be used to access the resulting 
 *  <code> ParameterList </code> or be used to perform a search within the 
 *  result set through <code> ParameterSearch. </code> </p> 
 *  
 *  <p> Two views of the configuration data are defined; </p> 
 *  
 *  <ul>
 *      <li> federated: parameters defined in configurations that are a parent 
 *      of this configuration in the configuration hierarchy are included 
 *      </li> 
 *      <li> isolated: parameters are contained to within this configuration 
 *      </li> 
 *  </ul>
 *  
 */

public interface ParameterSearchSession
    extends org.osid.configuration.ParameterQuerySession {


    /**
     *  Gets a parameter search. 
     *
     *  @return the parameter search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterSearch getParameterSearch();


    /**
     *  Gets a parameter entry search order. The <code> 
     *  ParameterEntrySearchOrder </code> is supplied to an <code> 
     *  ParameterEntrySearch </code> to specify the ordering of results. 
     *
     *  @return the parameter search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterSearchOrder getParameterSearchOrder();


    /**
     *  Gets a list of <code> Parameters </code> matching the given search 
     *  query using the given search. 
     *
     *  @param  parameterQuery the parameter query 
     *  @param  parameterSearch the parameter search 
     *  @return the parameter search results 
     *  @throws org.osid.NullArgumentException <code> parameterQuery </code> 
     *          or <code> parameterSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> parameterQuery </code> or 
     *          <code> parameterSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterSearchResults getParametersBySearch(org.osid.configuration.ParameterQuery parameterQuery, 
                                                                               org.osid.configuration.ParameterSearch parameterSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a parameter query from an inspector. The inspector is available 
     *  from a <code> ParameterSearchResults. </code> 
     *
     *  @param  parameterQueryInspector a parameter query inspector 
     *  @return the parameter query 
     *  @throws org.osid.NullArgumentException <code> parameterQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> parameterQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterQuery getParameterQueryFromInspector(org.osid.configuration.ParameterQueryInspector parameterQueryInspector);
}
