//
// org.osid.configuration.ParameterSmartConfigurationSession
//
//     The OSID Java specification for org.osid.configuration.ParameterSmartConfigurationSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ParameterQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Configuration </code> to create a 
 *  virtual collection of <code> Parameters. </code> The parameters may be 
 *  sequenced using the <code> ParameterSearchOrder </code> from this session. 
 *  </p> 
 *  
 *  <p> This <code> Configuration </code> has a default query that matches any 
 *  parameter and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> ParameterQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  ParameterQuery. </code> </p>
 */

public interface ParameterSmartConfigurationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the <code> Configuration </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart configurations. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart cobfiguration management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartConfigurations();


    /**
     *  Gets a parameter query. 
     *
     *  @return the parameter query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterQuery getParameterQuery();


    /**
     *  Gets a parameter search order. 
     *
     *  @return the parameter search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterSearchOrder getParameterSearchOrder();


    /**
     *  Applies a parameter query to this configuration. 
     *
     *  @param  parameterQuery the parameter query 
     *  @throws org.osid.NullArgumentException <code> parameterQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> parameterQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyParameterQuery(org.osid.configuration.ParameterQuery parameterQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a parameter query inspector for this configuration. 
     *
     *  @return the parameter query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterQueryInspector inspecParameterQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a parameter search order to this configuration. 
     *
     *  @param  parameterSearchOrder the parameter search order 
     *  @throws org.osid.NullArgumentException <code> parameterSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> parameterSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyParameterSequencing(org.osid.configuration.ParameterSearchOrder parameterSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a parameter query from an inspector. 
     *
     *  @param  parameterQueryInspector a parameter query inspector 
     *  @return the parameter query 
     *  @throws org.osid.NullArgumentException <code> parameterQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> parameterQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ParameterQuery getParameterQueryFromInspector(org.osid.configuration.ParameterQueryInspector parameterQueryInspector);
}
