//
// org.osid.configuration.Value
//
//     The OSID Java specification for org.osid.configuration.Value.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This interface specifies the value of a configuration parameter. </p>
 */

public interface Value
    extends org.osid.OsidObject,
            org.osid.Operable,
            org.osid.Subjugateable {


    /**
     *  Gets the parameter <code> Id </code> of this value. 
     *
     *  @return the parameter <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getParameterId();


    /**
     *  Gets the parameter of this value. 
     *
     *  @return the parameter 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Parameter getParameter()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the priority of this value. If the values for this parameter are 
     *  not shuffled, the priority indicates a static ordering of the values 
     *  from lowest to highest. If the values for this parameter are shuffled, 
     *  the priority effects the weight with greater numbers having greater 
     *  weights. 
     *
     *  @return the index of this value 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getPriority();


    /**
     *  Gets the value if it is a boolean. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          BOOLEAN </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean getBooleanValue();


    /**
     *  Gets the value if it is a byte. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          BYTE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public byte[] getBytesValue();


    /**
     *  Gets the value if it is a cardinal. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          CARDINAL </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getCardinalValue();


    /**
     *  Gets the value if it is a coordinate. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          COORDINATE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Coordinate getCoordinateValue();


    /**
     *  Gets the value if it is a currency. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          CURRENCY </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getCurrencyValue();


    /**
     *  Gets the value if it is a <code> DateTime. </code> 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DATETIME </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDateTimeValue();


    /**
     *  Gets the value if it is a decimal. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DECIMAL </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getDecimalValue();


    /**
     *  Gets the value if it is a <code> Distance. </code> 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DISTANCE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Distance getDistanceValue();


    /**
     *  Gets the value if it is a <code> Duration. </code> 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          DURATION </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getDurationValue();


    /**
     *  Gets the value if it is a <code> Heading. </code> 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          HEADING </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Heading getHeadingValue();


    /**
     *  Gets the value if it is an <code> Id. </code> 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          ID </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getIdValue();


    /**
     *  Gets the value if it is an integer. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          INTEGER </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getIntegerValue();


    /**
     *  Gets the value if it is an object. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          OBJECT </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.lang.Object getObjectValue();


    /**
     *  Gets the value if it is a spatial unit. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          SPATIALUNIT </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.SpatialUnit getSpatialUnitValue();


    /**
     *  Gets the value if it is a speed. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          SPEED </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Speed getSpeedValue();


    /**
     *  Gets the value if it is a string. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          STRING </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getStringValue();


    /**
     *  Gets the value if it is a time. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          TIME </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Time getTimeValue();


    /**
     *  Gets the value if it is a <code> Type. </code> 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          TYPE </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTypeValue();


    /**
     *  Gets the value if it is a version. 
     *
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> Parameter.getSyntax() != 
     *          VERSION </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Version getVersionValue();


    /**
     *  Gets the value record corresponding to the given <code> Value </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> valueRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(valueRecordType) </code> is <code> true </code> . 
     *
     *  @param  valueRecordType the type of value record to retrieve 
     *  @return the value record 
     *  @throws org.osid.NullArgumentException <code> valueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(valueRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ValueRecord getValueRecord(org.osid.type.Type valueRecordType)
        throws org.osid.OperationFailedException;
}
