//
// org.osid.configuration.ValueAdminSession
//
//     The OSID Java specification for org.osid.configuration.ValueAdminSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session creates, updates, and deletes <code> Values </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Value, </code> a <code> ValueForm </code> is requested using <code> 
 *  getValueFormForCreate() </code> specifying the desired parameter and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> ValueForm </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> ValueForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  ValueForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ValueForms </code> are requested to the <code> 
 *  Value </code> <code> Id </code> that is to be updated using <code> 
 *  getValueFormForUpdate(). </code> Similarly, the <code> ValueForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> ValueForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ValueAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration </code> <code> Id </code> associated 
     *          with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the <code> Configuration </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if applying conditions to values is supported. 
     *
     *  @return <code> true </code> if <code> Value </code> conditions are 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportValueConditions();


    /**
     *  Tests if this user can create <code> Values. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Value </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Value </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateValues();


    /**
     *  Tests if this user can create a single <code> Value </code> using the 
     *  desired record types. While <code> 
     *  ConfigurationManager.getValueRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Value. </code> Providing 
     *  an empty array tests if a <code> Value </code> can be created with no 
     *  records. 
     *
     *  @param  valueRecordTypes array of value record types 
     *  @return <code> true </code> if <code> Value </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> valueRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateValueWithRecordTypes(org.osid.type.Type[] valueRecordTypes);


    /**
     *  Gets the form for creating new values. A new form should be requested 
     *  for each create transaction. 
     *
     *  @param  parameterId the parameter 
     *  @param  valueRecordTypes array of value record types 
     *  @return the value form 
     *  @throws org.osid.NotFoundException <code> parameterId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> or 
     *          <code> valueRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueForm getValueFormForCreate(org.osid.id.Id parameterId, 
                                                                  org.osid.type.Type[] valueRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a value. 
     *
     *  @param  valueForm the form 
     *  @return the value 
     *  @throws org.osid.IllegalStateException <code> valueForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> valueForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueForm </code> did not 
     *          originate from <code> getValueFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Value createValue(org.osid.configuration.ValueForm valueForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Values. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Value </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Value </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateValues();


    /**
     *  Gets the value form for updating an existing value. A new value form 
     *  should be requested for each update transaction. 
     *
     *  @param  valueId the <code> Id </code> of the <code> Value </code> 
     *  @return the value form 
     *  @throws org.osid.NotFoundException the value is not found 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> or 
     *          <code> valueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueForm getValueFormForUpdate(org.osid.id.Id valueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing value. 
     *
     *  @param  valueForm the form containing the elemnts to be updated 
     *  @throws org.osid.IllegalStateException <code> valueForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> parameterId, valueId 
     *          </code> or <code> valueForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueForm </code> did not 
     *          originate from <code> getValueFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateValue(org.osid.configuration.ValueForm valueForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Values. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Value </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Value </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteValues();


    /**
     *  Deletes the specified value. 
     *
     *  @param  valueId the <code> Id </code> of the <code> Value </code> to 
     *          delete 
     *  @throws org.osid.NotFoundException <code> valueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> valueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteValue(org.osid.id.Id valueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Values. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Value </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageValueAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Value </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Value </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another value it is reassigned to the given value <code> 
     *  Id. </code> 
     *
     *  @param  valueId the <code> Id </code> of a <code> Value </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> valueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> valueId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasValue(org.osid.id.Id valueId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
