//
// org.osid.configuration.ValueLookupSession
//
//     The OSID Java specification for org.osid.configuration.ValueLookupSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session is used to retrieve configuration values. Two views of the 
 *  configuration data are defined: </p> 
 *  
 *  <ul>
 *      <li> federated: parameters defined in configurations that are a parent 
 *      of this configuration in the configuration hierarchy are included 
 *      </li> 
 *      <li> isolated: parameters are contained to within this configuration 
 *      </li> 
 *      <li> conditional: values are filtered that do not pass any defined 
 *      conditions, whether or not they are explciity passed into the lookup 
 *      methods of this session </li> 
 *      <li> unconditional: values are filtered only for the conditions that 
 *      are explicity passed as parameters. Any conditions defined for the 
 *      value that do not require explicit data for retrieval are ignored. 
 *      </li> 
 *      <li> active value view: All value lookup methods return active values. 
 *      </li> 
 *      <li> any status value view: Values of any active or inactive status 
 *      are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Values are not OSID objects and are obtained using a reference to a 
 *  Parameter. </p>
 */

public interface ValueLookupSession
    extends org.osid.configuration.ValueRetrievalSession {


    /**
     *  Only active values are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveValueView();


    /**
     *  All active and inactive values are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusValueView();


    /**
     *  Gets the <code> Value </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Value 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Value </code> and retained for compatibility. 
     *
     *  @param  valueId the <code> Id </code> of the <code> Value </code> to 
     *          retrieve 
     *  @return the returned <code> Value </code> 
     *  @throws org.osid.NotFoundException no <code> Value </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> valueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Value getValue(org.osid.id.Id valueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  values specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Values </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  valueIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Value </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> valueIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByIds(org.osid.id.IdList valueIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueList </code> corresponding to the given value genus 
     *  <code> Type </code> which does not include values of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  values or an error results. Otherwise, the returned list may contain 
     *  only those values that are accessible through this session. 
     *  
     *  In active mode, values are returned that are currently active. In any 
     *  status mode, active and inactive values are returned. 
     *
     *  @param  valueGenusType a value genus type 
     *  @return the returned <code> Value list </code> 
     *  @throws org.osid.NullArgumentException <code> valueGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByGenusType(org.osid.type.Type valueGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueList </code> corresponding to the given value genus 
     *  <code> Type </code> and include any additional values with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  values or an error results. Otherwise, the returned list may contain 
     *  only those values that are accessible through this session. 
     *  
     *  In active mode, values are returned that are currently active. In any 
     *  status mode, active and inactive values are returned. 
     *
     *  @param  valueGenusType a value genus type 
     *  @return the returned <code> Value list </code> 
     *  @throws org.osid.NullArgumentException <code> valueGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByParentGenusType(org.osid.type.Type valueGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ValueList </code> corresponding to the given value 
     *  record <code> Type </code> which does not include values of record 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  values or an error results. Otherwise, the returned list may contain 
     *  only those values that are accessible through this session. 
     *  
     *  In active mode, values are returned that are currently active. In any 
     *  status mode, active and inactive values are returned. 
     *
     *  @param  valueRecordType a value type 
     *  @return the returned <code> Value </code> list 
     *  @throws org.osid.NullArgumentException <code> valueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByRecordType(org.osid.type.Type valueRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all the values in this configuration. In plenary mode, all values 
     *  are returned or an error results. In comparative mode, inaccessible 
     *  values may be omitted. 
     *  
     *  In plenary mode, the returned list contains all known values or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  values that are accessible through this session. 
     *  
     *  In active mode, values are returned that are currently active. In any 
     *  status mode, active and inactive values are returned. 
     *
     *  @return the value list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the values in this configuration based on a condition. <code> 
     *  </code> The condition specified is applied to any or all parameters in 
     *  this configuration as applicable. In plenary mode, all values are 
     *  returned or an error results. In comparative mode, inaccessible values 
     *  may be omitted. 
     *
     *  @param  valueCondition a value condition 
     *  @return the value list 
     *  @throws org.osid.NullArgumentException <code> valueCondition </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueCondition </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesOnCondition(org.osid.configuration.ValueCondition valueCondition)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
