//
// org.osid.configuration.ValueNotificationSession
//
//     The OSID Java specification for org.osid.configuration.ValueNotificationSession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session defines methods to receive notifications on changes to 
 *  <code> Values. </code> A particular value in a set may have been added or 
 *  deleted, but all changes appear as a change to a parameter. Once a change 
 *  notification is received, the new value list can be obtained through the 
 *  <code> ValueLookupSession. </code> This session is intended for adapters 
 *  and providers needing to synchronize their state with this service without 
 *  the use of polling. Notifications are cancelled when this session is 
 *  closed. </p> 
 *  
 *  <p> Two views are defined; </p> 
 *  
 *  <ul>
 *      <li> federated: parameters defined in configurations that are a parent 
 *      of this configuration in the configuration hierarchy are included for 
 *      notifications </li> 
 *      <li> isolated: notifications are restricted to parameters are defined 
 *      to within this configuration </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> federateValuerView() </code> and <code> 
 *  isolateValueView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface ValueNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration </code> <code> Id </code> associated 
     *          with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the <code> Configuration </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Value </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForValueNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include parameters in configurations of which this configuration is a 
     *  child in the configuration hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedConfigurationView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications for parameter values to this configuration 
     *  only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedConfigurationView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeValueNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableValueNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableValueNotifications();


    /**
     *  Acknowledge a value notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeValueNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notifications of new values. <code> 
     *  ValueReceiver.newValues() </code> is invoked when a new <code> Value 
     *  </code> is added to this configuration. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewValues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notifications of new values for the given 
     *  parameter. <code> ValueReceiver.newValues() </code> is invoked when a 
     *  new <code> Value </code> is added to this configuration. 
     *
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewValuesForParameter(org.osid.id.Id parameterId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notification of updated parameter values in 
     *  this configuration. <code> ValueReceiver.changedValues() </code> is 
     *  invoked when a <code> Value </code> is changed in this configuration. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedValues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notifications of changed values for the given 
     *  parameter. <code> ValueReceiver.changedValues() </code> is invoked 
     *  when a <code> Value </code> is updated to this configuration. 
     *
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedValuesForParameter(org.osid.id.Id parameterId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notifications of an update to a value in this 
     *  configuration. <code> ValueReceiver.changedValues() </code> is invoked 
     *  when the specified <code> Value </code> is updated in this 
     *  configuration. 
     *
     *  @param  valueId the <code> Id </code> of the <code> Value </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> valueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedValue(org.osid.id.Id valueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notification of deleted values in this 
     *  configuration. <code> ValueReceiver.changedValues() </code> is invoked 
     *  when a <code> Value </code> is removed from this configuration. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedValues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notifications of changed values for the given 
     *  parameter. <code> ValueReceiver.changedValues() </code> is invoked 
     *  when a <code> Value </code> is removed from this configuration. 
     *
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedValuesForParameter(org.osid.id.Id parameterId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Assigns a callback for notifications of an update to a value in this 
     *  configuration. <code> ValueReceiver.changedValues() </code> is invoked 
     *  when the specified <code> Value </code> is removed from this 
     *  configuration. 
     *
     *  @param  valueId the <code> Id </code> of the <code> Value </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> valueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedValue(org.osid.id.Id valueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
