//
// org.osid.configuration.ValueQuery
//
//     The OSID Java specification for org.osid.configuration.ValueQuery.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>The interface to query a value. </p>
 */

public interface ValueQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidOperableQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Adds a priority match. Multiple ranges can be added to perform a 
     *  boolean <code> OR </code> among them. 
     *
     *  @param  low start priority value 
     *  @param  high end priority value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPriority(long low, long high, boolean match);


    /**
     *  Matches values with any priority. 
     *
     *  @param  match <code> true </code> if to match values with any 
     *          priority, <code> false </code> to match values with no 
     *          priority 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPriority(boolean match);


    /**
     *  Clears the priority terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriorityTerms();


    /**
     *  Adds a boolean match. 
     *
     *  @param  value a boolean value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBooleanValue(boolean value, boolean match);


    /**
     *  Clears the boolean value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBooleanValueTerms();


    /**
     *  Adds a byte string match. Multiple byte arrays can be added to perform 
     *  a boolean <code> OR </code> among them. 
     *
     *  @param  value a byte value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @param  partial <code> true </code> if for a partial match, <code> 
     *          false </code> for complete match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBytesValue(byte[] value, boolean match, boolean partial);


    /**
     *  Clears the bytes value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBytesValueTerms();


    /**
     *  Adds a cardinal match within the given range inclusive. Multiple 
     *  ranges can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  low start cardinal value 
     *  @param  high end cardinal value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCardinalValue(long low, long high, boolean match);


    /**
     *  Clears the cardinal value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCardinalValueTerms();


    /**
     *  Adds a coordinate match for coordinates inside the specified 
     *  coordinate. Multiple ranges can be added to perform a boolean <code> 
     *  OR </code> among them. 
     *
     *  @param  coordinate a coordinate value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> coordinate </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCoordinateValue(org.osid.mapping.Coordinate coordinate, 
                                     boolean match);


    /**
     *  Clears the coordinate value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCoordinateValueTerms();


    /**
     *  Adds a curency match within the given range inclusive. Multiple ranges 
     *  can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  low start currency value 
     *  @param  high a currency value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCurrencyValue(org.osid.financials.Currency low, 
                                   org.osid.financials.Currency high, 
                                   boolean match);


    /**
     *  Clears the currency value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCurrencyValueTerms();


    /**
     *  Adds a <code> DateTime </code> range match within the given range 
     *  inclusive. Multiple ranges can be added to perform a boolean <code> OR 
     *  </code> among them. 
     *
     *  @param  low start datetime value 
     *  @param  high end datetime value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDateTimeValue(org.osid.calendaring.DateTime low, 
                                   org.osid.calendaring.DateTime high, 
                                   boolean match);


    /**
     *  Clears the date time value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDateTimeValueTerms();


    /**
     *  Adds a decimal match within the given range inclusive. Multiple ranges 
     *  can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  low start decimal value 
     *  @param  high end decimal value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDecimalValue(java.math.BigDecimal low, 
                                  java.math.BigDecimal high, boolean match);


    /**
     *  Clears the decimal value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDecimalValueTerms();


    /**
     *  Adds a <code> Distance </code> range match within the given range 
     *  inclusive. Multiple ranges can be added to perform a boolean <code> OR 
     *  </code> among them. 
     *
     *  @param  low start distance value 
     *  @param  high end distance value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistanceValue(org.osid.mapping.Distance low, 
                                   org.osid.mapping.Distance high, 
                                   boolean match);


    /**
     *  Clears the distance value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistanceValueTerms();


    /**
     *  Adds a <code> Duration </code> range match within the given range 
     *  inclusive. Multiple ranges can be added to perform a boolean <code> OR 
     *  </code> among them. 
     *
     *  @param  low start duration value 
     *  @param  high end duration value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDurationValue(org.osid.calendaring.Duration low, 
                                   org.osid.calendaring.Duration high, 
                                   boolean match);


    /**
     *  Clears the duration value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDurationValueTerms();


    /**
     *  Adds a <code> Heading </code> range match within the given range 
     *  inclusive. Multiple ranges can be added to perform a boolean <code> OR 
     *  </code> among them. 
     *
     *  @param  low start heading value 
     *  @param  high end heading value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchHeadingValue(org.osid.mapping.Heading low, 
                                  org.osid.mapping.Heading high, boolean match);


    /**
     *  Clears the heading value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHeadingValueTerms();


    /**
     *  Adds an <code> Id </code> to match. Multiple <code> Ids </code> can be 
     *  added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  value an <code> Id </code> value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIdValue(org.osid.id.Id value, boolean match);


    /**
     *  Clears the Id value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIdValueTerms();


    /**
     *  Adds an integer match within the given range inclusive. Multiple 
     *  ranges can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  low start integer value 
     *  @param  high end integer value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIntegerValue(long low, long high, boolean match);


    /**
     *  Clears the integer value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIntegerValueTerms();


    /**
     *  Adds a spatial unit match within the given spatial unit inclusive. 
     *  Multiple ranges can be added to perform a boolean <code> OR </code> 
     *  among them. 
     *
     *  @param  value a spatial unit 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSpatialUnitValue(org.osid.mapping.SpatialUnit value, 
                                      boolean match);


    /**
     *  Clears the spatial unit value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpatialUnitValueTerms();


    /**
     *  Adds a speed match within the given range inclusive. Multiple ranges 
     *  can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  low start speed value 
     *  @param  high end speed value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSpeedValue(org.osid.mapping.Speed low, 
                                org.osid.mapping.Speed high, boolean match);


    /**
     *  Clears the speed value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpeedValueTerms();


    /**
     *  Adds a string match. Multiple strings can be added to perform a 
     *  boolean <code> OR </code> among them. 
     *
     *  @param  value string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> value is </code> not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> value </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStringValue(String value, 
                                 org.osid.type.Type stringMatchType, 
                                 boolean match);


    /**
     *  Clears the string value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStringValueTerms();


    /**
     *  Adds a time match within the given range inclusive. Multiple ranges 
     *  can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  low start time value 
     *  @param  high end time value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeValue(org.osid.calendaring.Time low, 
                               org.osid.calendaring.Time high, boolean match);


    /**
     *  Clears the time value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeValueTerms();


    /**
     *  Adds a <code> Type </code> match. Multiple types can be added to 
     *  perform a boolean <code> OR </code> among them. 
     *
     *  @param  value type to match 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> value </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTypeValue(org.osid.type.Type value, boolean match);


    /**
     *  Clears the type value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTypeValueTerms();


    /**
     *  Adds a <code> Version </code> match within the given range inclusive. 
     *  Multiple queries can be added to perform a boolean <code> OR </code> 
     *  among them. 
     *
     *  @param  low start version value 
     *  @param  high end version value 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVersionValue(org.osid.installation.Version low, 
                                  org.osid.installation.Version high, 
                                  boolean match);


    /**
     *  Clears the version value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersionValueTerms();


    /**
     *  Adds a <code> Type </code> to match on the type of object. Multiple 
     *  types can be added to perform a boolean <code> OR </code> among them. 
     *
     *  @param  objectType type to match 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchObjectValueType(org.osid.type.Type objectType, 
                                     boolean match);


    /**
     *  Clears the object value type value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearObjectValueTypeTerms();


    /**
     *  Adds an object match. Multiple objects can be added to perform a 
     *  boolean <code> OR </code> among them. 
     *
     *  @param  object object to match 
     *  @param  objectType type of object 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> object </code> or <code> 
     *          objectType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchObjectValue(java.lang.Object object, 
                                 org.osid.type.Type objectType, boolean match);


    /**
     *  Clears the object value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearObjectValueTerms();


    /**
     *  Adds a parameter <code> Id </code> for this query. 
     *
     *  @param  parameterId a parameter <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchParameterId(org.osid.id.Id parameterId, boolean match);


    /**
     *  Clears the parameter <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParameterIdTerms();


    /**
     *  Tests if a <code> ParameterQuery </code> is available. 
     *
     *  @return <code> true </code> if a parameter query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsParameterQuery();


    /**
     *  Gets the query for a parameter. 
     *
     *  @return the parameter query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParameterQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParameterQuery() </code> is <code> true. </code> 
     */

    public org.osid.configuration.ParameterQuery getParameterQuery();


    /**
     *  Clears the parameter terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearParameterTerms();


    /**
     *  Sets the configuration <code> Id </code> for this query. 
     *
     *  @param  configurationId a configuration <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConfigurationId(org.osid.id.Id configurationId, 
                                     boolean match);


    /**
     *  Clears the configuration <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConfigurationIdTerms();


    /**
     *  Tests if a <code> ConfigurationQuery </code> is available. 
     *
     *  @return <code> true </code> if a configuration query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationQuery();


    /**
     *  Gets the query for a configuration. 
     *
     *  @return the configuration query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationQuery getConfigurationQuery();


    /**
     *  Clears the configuration <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConfigurationTerms();


    /**
     *  Gets the value query record corresponding to the given <code> Value 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  valueRecordType a value record type 
     *  @return the value query record 
     *  @throws org.osid.NullArgumentException <code> valueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(valueRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.records.ValueQueryRecord getValueQueryRecord(org.osid.type.Type valueRecordType)
        throws org.osid.OperationFailedException;
}
