//
// org.osid.configuration.ValueQuerySession
//
//     The OSID Java specification for org.osid.configuration.ValueQuerySession.
//
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration;


/**
 *  <p>This session provides methods for searching <code> Value </code> 
 *  objects. The search query is constructed using the <code> ValueQuery. 
 *  </code> The parameter <code> Type </code> also specifies the record for 
 *  the value query. </p> 
 *  
 *  <p> Two views of the configuration data are defined; </p> 
 *  
 *  <ul>
 *      <li> federated: values defined in configurations that are a parent of 
 *      this configuration in the configuration hierarchy are included </li> 
 *      <li> isolated: values are contained to within this configuration </li> 
 *  </ul>
 *  
 */

public interface ValueQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration </code> <code> Id </code> associated 
     *          with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the <code> Configuration </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Value </code> searches. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchValues();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include values from parent configurations in the configuration 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedConfigurationView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this configuration only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedConfigurationView();


    /**
     *  Gets a value query. 
     *
     *  @return the value query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueQuery getValueQuery();


    /**
     *  Gets a list of <code> Values </code> matching the given value query. 
     *
     *  @param  valueQuery the value query 
     *  @return the returned <code> ValueList </code> 
     *  @throws org.osid.NullArgumentException <code> valueQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException a query form is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.ValueList getValuesByQuery(org.osid.configuration.ValueQuery valueQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
