/**
 * <p>The Open Service Interface Definitions for the org.osid.configuration
 * service.</p>
 * 
 * <p>The Configuration OSID defines a set of interfaces for configuration 
 * retrieval and management. The Configuration service may be used to store 
 * user profiles or as a means to assist OSID implementors modularize 
 * configuration data. </p> 
 * <h4> Parameters </h4> 
 * 
 * <p> Configuration data is expressed through a set of <code> Parameters and 
 * Values. </code> A <code> Parameter </code> is an <code> OsidRule </code> 
 * with a unique <code> Id </code> and a syntax that indicates a primitive 
 * type. A <code> Parameter </code> may map to zero or more Values of the same 
 * syntax. An application requesting a configuration looks up <code> Values 
 * </code> given a <code> Parameter </code> <code> Id </code> through a <code> 
 * ValueLookupSession. </code> </p> 
 * 
 * <p> <code> </code> As an <code> OsidRule </code> , <code> Parameters 
 * </code> may resolve to implicitly created <code> Values </code> based on 
 * external rule evaluations. </p> 
 * <h4> Values </h4> 
 * 
 * <p> <code> Values </code> represent primitive types that are assigned to 
 * <code> Parameters </code> and constrained by the syntax specified in its 
 * <code> Parameter. </code> In the most basic case, a single <code> Value 
 * </code> is created for a <code> Parameter </code> and returned when the 
 * <code> Parameter </code> is resolved. <code> Parameters </code> can have 
 * multiple <code> Values </code> where the Configuration OSID Consumer can 
 * request all <code> Values, </code> or a single <code> Value </code> 
 * selected by the OSID Provider. </p> 
 * 
 * <p> <code> Values </code> are <code> Operable </code> such that Values in 
 * multi-valued <code> Parameter </code> may be enabled or disabled manually 
 * or based on a rule. For example, the configuration of a service may change 
 * based on time of day or may change based on some out-of-band context. 
 * <code> Value </code> retrievals in the <code> ValueRetrievalSession </code> 
 * support passing of a <code> ValueCondition </code> to supply contextual 
 * information to feed the rule evaluation. </p> 
 * <h4> Configuration Cataloging </h4> 
 * 
 * <p> To create a configuration for an application, a <code> Configuration 
 * </code> object is created. The <code> Configuration </code> maps a set of 
 * <code> Parameters </code> and their <code> Values. </code> A <code> 
 * Configuration </code> may be positioned as a child of another <code> 
 * Configuration </code> to inherit its <code> Parameters </code> and <code> 
 * Values. </code> The desired <code> Parameters </code> are then mapped to 
 * the <code> Configuration </code> and <code> Values </code> assigned. </p> 
 * 
 * <p> <code> Parameters </code> may be stored without values in separate 
 * <code> Configurations </code> for reuse or standardization. </p> 
 * 
 * <p> OSID Provider implementations should get their configurations via the 
 * <code> OsidRuntimeManager. </code> </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Configuration OSID includes a rules subpackage for governing the 
 * available <code> Values </code> for a <code> Parameter </code> based on a 
 * set of rules and an Configuration Batch OSID for managing parameters and 
 * values in bulk. </p> 
 * <h4> Example </h4> 
 * <pre>
 *      
 *      
 *      Id parameterId = what I'm looking for;
 *      
 *      ValueLookupSession valueSession = mgr.getValueLookupSession();
 *      valueSession.federateParameterView();
 *      
 *      if (valueSession.parameterExists(parameterId)) {
 *          Parameter param = valueSession.getParameter(parameterId);
 *          ValueList values = valueSession.getValues(param.getId());
 *          while (values.hasNext()) {
 *              Value value = values.getNextValue();
 *              if (param.implementsType(typeString)
 *                  String value = (String) param.getValue();
 *              else 
 *                  print "unexpected type";
 *          }
 *      }
 *      
 *              
 *      
 * </pre>
 * 
 * 
 * <p> </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2009-2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.configuration;
