//
// org.osid.configuration.rules.ParameterProcessorConfigurationAssignmentSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorConfigurationAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods to re-assign <code> ParameterProcessor 
 *  </code> to <code> Configuration </code> mappings. A <code> 
 *  ParameterProcessor </code> may appear in multiple <code> Configuration 
 *  </code> objects and removing the last reference to a <code> 
 *  ParameterProcessor </code> is the equivalent of deleting it. Each <code> 
 *  Configuration </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> ParameterProcessor </code> to another 
 *  <code> Configuration </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface ParameterProcessorConfigurationAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter parameter processor/configuration 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignParameterProcessors();


    /**
     *  Tests if this user can alter parameter processor/configuration 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignParameterProcessorsToConfiguration(org.osid.id.Id configurationId);


    /**
     *  Gets a list of configurations including and under the given 
     *  configuration node in which any parameter processor can be assigned. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @return list of assignable configuration <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableConfigurationIds(org.osid.id.Id configurationId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of configurations including and under the given 
     *  configuration node in which a specific parameter processor can be 
     *  assigned. 
     *
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @return list of assignable configuration <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          or <code> parameterProcessorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableConfigurationIdsForParameterProcessor(org.osid.id.Id configurationId, 
                                                                                 org.osid.id.Id parameterProcessorId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ParameterProcessor </code> to an <code> 
     *  Configuration. </code> 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @throws org.osid.AlreadyExistsException <code> parameterProcessorId 
     *          </code> is already assigned to <code> configurationId </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          or <code> configurationId </code> not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> or <code> configurationId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignParameterProcessorToConfiguration(org.osid.id.Id parameterProcessorId, 
                                                        org.osid.id.Id configurationId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ParameterProcessor </code> from a <code> 
     *  Configuration. </code> 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @param  configurationId the <code> Id </code> of the <code> 
     *          Configuration </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          or <code> configurationId </code> not found or <code> 
     *          parameterProcessorId </code> is not assigned to <code> 
     *          configurationId </code> 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> or <code> configurationId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignParameterProcessorFromConfiguration(org.osid.id.Id parameterProcessorId, 
                                                            org.osid.id.Id configurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> ParameterProcessor </code> from one <code> 
     *  Configuration </code> to another. Mappings to other <code> 
     *  Configurations </code> are unaffected. 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @param  fromConfigurationId the <code> Id </code> of the current 
     *          <code> Configuration </code> 
     *  @param  toConfigurationId the <code> Id </code> of the destination 
     *          <code> Configuration </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId 
     *          fromConfigurationId, </code> or <code> toConfigurationId 
     *          </code> not found or <code> parameterProcessorId </code> not 
     *          mapped to <code> fromConfigurationId </code> 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId, 
     *          fromConfigurationId, </code> or <code> toConfigurationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignParameterProcessorToConfiguration(org.osid.id.Id parameterProcessorId, 
                                                          org.osid.id.Id fromConfigurationId, 
                                                          org.osid.id.Id toConfigurationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
