//
// org.osid.configuration.rules.ParameterProcessorEnablerAdminSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session creates and removes parameter processor enablers. The data 
 *  for create and update is provided via the <code> 
 *  ParameterProcessorEnablerForm. </code> </p>
 */

public interface ParameterProcessorEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create parameter processor enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> ParameterProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessorEnabler 
     *          </code> creation is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateParameterProcessorEnabler();


    /**
     *  Tests if this user can create a single <code> 
     *  ParameterProcessorEnabler </code> using the desired record types. 
     *  While <code> 
     *  ConfigurationRulesManager.getParameterProcessorEnablerRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> ParameterProcessorEnabler. </code> Providing an empty array 
     *  tests if a <code> ParameterProcessorEnabler </code> can be created 
     *  with no records. 
     *
     *  @param  parameterProcessorEnablerRecordTypes array of parameter 
     *          processor enabler record types 
     *  @return <code> true </code> if <code> ParameterProcessorEnabler 
     *          </code> creation using the specified record <code> Types 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateParameterProcessorEnablerWithRecordTypes(org.osid.type.Type[] parameterProcessorEnablerRecordTypes);


    /**
     *  Gets the parameter processor enabler form for creating new parameter 
     *  processor enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  parameterProcessorEnablerRecordTypes array of parameter 
     *          processor enabler record types 
     *  @return the parameter processor enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerForm getParameterProcessorEnablerFormForCreate(org.osid.type.Type[] parameterProcessorEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ParameterProcessorEnabler. </code> 
     *
     *  @param  parameterProcessorEnablerForm the form for this <code> 
     *          ParameterProcessorEnabler </code> 
     *  @return the new <code> ParameterProcessorEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          parameterProcessorEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          parameterProcessorEnablerForm </code> did not originate from 
     *          <code> getParameterProcessorEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorEnabler createParameterProcessorEnabler(org.osid.configuration.rules.ParameterProcessorEnablerForm parameterProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update parameter processor enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> ParameterProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessorEnabler 
     *          </code> modification is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateParameterProcessorEnablers();


    /**
     *  Gets the parameter processor enabler form for updating an existing 
     *  parameter processor enabler. A new parameter processor enabler form 
     *  should be requested for each update transaction. 
     *
     *  @param  parameterProcessorEnablerId the <code> Id </code> of the 
     *          <code> ParameterProcessorEnabler </code> 
     *  @return the parameter processor enabler form 
     *  @throws org.osid.NotFoundException <code> parameterProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ParameterProcessorEnablerForm getParameterProcessorEnablerFormForUpdate(org.osid.id.Id parameterProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing parameter processor enabler. 
     *
     *  @param  parameterProcessorEnablerForm the form containing the elements 
     *          to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          parameterProcessorEnablerForm </code> already used in an 
     *          update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          parameterProcessorEnablerForm </code> did not originate from 
     *          <code> getParameterProcessorEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateParameterProcessorEnabler(org.osid.configuration.rules.ParameterProcessorEnablerForm parameterProcessorEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete parameter processor enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> ParameterProcessorEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessorEnabler 
     *          </code> deletion is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteParameterProcessorEnablers();


    /**
     *  Deletes a <code> ParameterProcessorEnabler. </code> 
     *
     *  @param  parameterProcessorEnablerId the <code> Id </code> of the 
     *          <code> ParameterProcessorEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> parameterProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteParameterProcessorEnabler(org.osid.id.Id parameterProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for parameter 
     *  processor enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessorEnabler 
     *          </code> aliasing is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageParameterProcessorEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> ParameterProcessorEnabler 
     *  </code> for the purpose of creating compatibility. The primary <code> 
     *  Id </code> of the <code> ParameterProcessorEnabler </code> is 
     *  determined by the provider. The new <code> Id </code> performs as an 
     *  alias to the primary <code> Id </code> . If the alias is a pointer to 
     *  another parameter processor enabler. it is reassigned to the given 
     *  parameter processor enabler <code> Id. </code> 
     *
     *  @param  parameterProcessorEnablerId the <code> Id </code> of a <code> 
     *          ParameterProcessorEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> parameterProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorEnablerId </code> or <code> aliasId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasParameterProcessorEnabler(org.osid.id.Id parameterProcessorEnablerId, 
                                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
