//
// org.osid.configuration.rules.ParameterProcessorQuery
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This is the query for searching parameter processors. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface ParameterProcessorQuery
    extends org.osid.OsidProcessorQuery {


    /**
     *  Matches mapped to the parameter. 
     *
     *  @param  parameterId the parameter <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> parameterId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledParameterId(org.osid.id.Id parameterId, 
                                      boolean match);


    /**
     *  Clears the parameter <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledParameterIdTerms();


    /**
     *  Tests if a <code> ParameterQuery </code> is available. 
     *
     *  @return <code> true </code> if a parameter query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledParameterQuery();


    /**
     *  Gets the query for a parameter. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the parameter query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledParameterQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledParameterQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ParameterQuery getRuledParameterQuery();


    /**
     *  Matches mapped to any parameter. 
     *
     *  @param  match <code> true </code> for mapped to any parameter, <code> 
     *          false </code> to match mapped to no parameters 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledParameter(boolean match);


    /**
     *  Clears the parameter query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledParameterTerms();


    /**
     *  Matches mapped to the configuration. 
     *
     *  @param  configurationId the configuration <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> configurationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConfigurationId(org.osid.id.Id configurationId, 
                                     boolean match);


    /**
     *  Clears the configuration <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConfigurationIdTerms();


    /**
     *  Tests if a <code> ConfigurationQuery </code> is available. 
     *
     *  @return <code> true </code> if a configuration query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationQuery();


    /**
     *  Gets the query for a configuration. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the configuration query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConfigurationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConfigurationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.configuration.ConfigurationQuery getConfigurationQuery();


    /**
     *  Clears the configuration query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConfigurationTerms();


    /**
     *  Gets the parameter processor query record corresponding to the given 
     *  <code> ParameterProcessor </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  parameterProcessorRecordType a parameter processor record type 
     *  @return the parameter processor query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          parameterProcessorRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(parameterProcessorRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.records.ParameterProcessorQueryRecord getParameterProcessorQueryRecord(org.osid.type.Type parameterProcessorRecordType)
        throws org.osid.OperationFailedException;
}
