//
// org.osid.configuration.rules.ParameterProcessorRuleApplicationSession
//
//     The OSID Java specification for org.osid.configuration.rules.ParameterProcessorRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods to apply <code> ParameterProcessors 
 *  </code> to <code> Parameters. </code> </p>
 */

public interface ParameterProcessorRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Configuration </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> Configuration Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getConfigurationId();


    /**
     *  Gets the <code> Configuration </code> associated with this session. 
     *
     *  @return the configuration 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.Configuration getConfiguration()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter parameter processor/parameter mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignParameterProcessors();


    /**
     *  Adds an existing <code> ParameterProcessor </code> to a <code> 
     *  Parameter. </code> 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> parameterProcessorId 
     *          </code> is already applied to <code> parameterId </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          or <code> parameterId </code> not found 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> or <code> parameterId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignParameterProcessorToParameter(org.osid.id.Id parameterProcessorId, 
                                                    org.osid.id.Id parameterId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ParameterProcessor </code> from a <code> Parameter. 
     *  </code> 
     *
     *  @param  parameterProcessorId the <code> Id </code> of the <code> 
     *          ParameterProcessor </code> 
     *  @param  parameterId the <code> Id </code> of the <code> Parameter 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId </code> 
     *          or <code> parameterId </code> not found or <code> 
     *          parameterProcessorId </code> is not applied to <code> 
     *          parameterId </code> 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId 
     *          </code> or <code> parameterId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignParameterProcessorFromParameter(org.osid.id.Id parameterProcessorId, 
                                                        org.osid.id.Id parameterId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> ParametereProcessors. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ParameterProcessor </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceParameterProcessors();


    /**
     *  Reorders parameter processors for a parameter by moving the specified 
     *  parameter processors in front of a reference parameter. 
     *
     *  @param  parameterProcessorId the <code> Id </code> of a <code> 
     *          ParameterProcessor </code> 
     *  @param  parameterId the <code> Id </code> of a <code> Parameter 
     *          </code> 
     *  @param  referenceId the reference parameter processor <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId, 
     *          parameterId, </code> or <code> referenceId </code> not found 
     *          or, <code> parameterProcessorId, </code> or <code> referenceId 
     *          </code> not related to <code> parameterId </code> 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId, 
     *          parameterId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveParameterProcessorAhead(org.osid.id.Id parameterProcessorId, 
                                            org.osid.id.Id parameterId, 
                                            org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders parameter processors for a parameter by moving the specified 
     *  parameter processor behind a reference parameter processor. 
     *
     *  @param  parameterProcessorId the <code> Id </code> of a <code> 
     *          ParameterProcessor </code> 
     *  @param  parameterId the <code> Id </code> of a <code> Parameter 
     *          </code> 
     *  @param  referenceId the reference parameter processor <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> parameterProcessorId, 
     *          parameterId, </code> or <code> referenceId </code> not found 
     *          or, <code> parameterProcessorId, </code> or <code> referenceId 
     *          </code> not related to <code> parameterId </code> 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorId, 
     *          parameterId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveParameterProcessorBehind(org.osid.id.Id parameterProcessorId, 
                                             org.osid.id.Id parameterId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of parameter processors for a parameter. 
     *
     *  @param  parameterProcessorIds the <code> Ids </code> for a set of 
     *          <code> ParameterProcessors </code> 
     *  @param  parameterId the <code> Id </code> of a <code> Parameter 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> parameterId </code> not 
     *          found or, a <code> parameterProcessorId </code> not related to 
     *          <code> parameterId </code> 
     *  @throws org.osid.NullArgumentException <code> parameterProcessorIds 
     *          </code> or <code> parameterId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderParameterProcessors(org.osid.id.Id[] parameterProcessorIds, 
                                         org.osid.id.Id parameterId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
