//
// org.osid.configuration.rules.ValueEnablerSearchSession
//
//     The OSID Java specification for org.osid.configuration.rules.ValueEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.configuration.rules;


/**
 *  <p>This session provides methods for searching among <code> ValueEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  ValueEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getValueEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> ValueEnablers. </code> A more advanced search 
 *  may be performed with <code> getValueEnablersBySearch(). </code> It 
 *  accepts a <code> ValueEnablerSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as configuration. <code> getValueEnablersBySearch() </code> returns a 
 *  <code> ValueEnablerSearchResults </code> that can be used to access the 
 *  resulting <code> ValueEnablerList </code> or be used to perform a search 
 *  within the result set through <code> ValueEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated configuration view: searches include value enablers in 
 *      configurations of which this configuration is an ancestor in the 
 *      configuration hierarchy </li> 
 *      <li> isolated configuration view: searches are restricted to value 
 *      enablers in this configuration </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> ValueEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  ValueEnablerQuery. </code> </p>
 */

public interface ValueEnablerSearchSession
    extends org.osid.configuration.rules.ValueEnablerQuerySession {


    /**
     *  Gets a value enabler search. 
     *
     *  @return the value enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerSearch getValueEnablerSearch();


    /**
     *  Gets a value enabler search order. The <code> ValueEnablerSearchOrder 
     *  </code> is supplied to a <code> ValueEnablerSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the value enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerSearchOrder getValueEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  valueEnablerQuery the value enabler query 
     *  @param  valueEnablerSearch the value enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> valueEnablerQuery 
     *          </code> or <code> valueEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> valueEnablerQuery </code> 
     *          or <code> valueEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerSearchResults getValueEnablersBySearch(org.osid.configuration.rules.ValueEnablerQuery valueEnablerQuery, 
                                                                                           org.osid.configuration.rules.ValueEnablerSearch valueEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a value enabler query from an inspector. The inspector is 
     *  available from a <code> ValueEnablerSearchResults. </code> 
     *
     *  @param  valueEnablerQueryInspector a value enabler query inspector 
     *  @return the value enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          valueEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          valueEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.configuration.rules.ValueEnablerQuery getValueEnablerQueryFromInspector(org.osid.configuration.rules.ValueEnablerQueryInspector valueEnablerQueryInspector);
}
