//
// org.osid.contact.AddressBookQuery
//
//     The OSID Java specification for org.osid.contact.AddressBookQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This is the query for searching for address books. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface AddressBookQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the contact <code> Id </code> for this query to match contacts 
     *  assigned to address books. 
     *
     *  @param  contactId a contact <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> contactId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContactId(org.osid.id.Id contactId, boolean match);


    /**
     *  Clears the contact <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContactIdTerms();


    /**
     *  Tests if a contact query is available. 
     *
     *  @return <code> true </code> if a contact query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactQuery();


    /**
     *  Gets the query for an address book. 
     *
     *  @return the contact query 
     *  @throws org.osid.UnimplementedException <code> supportsContactQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactQuery getContactQuery();


    /**
     *  Matches address books with any contact. 
     *
     *  @param  match <code> true </code> to match address books with any 
     *          contact, <code> false </code> to match address books with no 
     *          contacts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyContact(boolean match);


    /**
     *  Clears the contact terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContactTerms();


    /**
     *  Sets the address <code> Id </code> for this query to match contacts 
     *  assigned to addresses. 
     *
     *  @param  addressId an address <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> addressId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAddressId(org.osid.id.Id addressId, boolean match);


    /**
     *  Clears the address <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressIdTerms();


    /**
     *  Tests if an <code> AddressQuery </code> is available. 
     *
     *  @return <code> true </code> if an address query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressQuery();


    /**
     *  Gets the query for an address query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the address query 
     *  @throws org.osid.UnimplementedException <code> supportsAddressQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressQuery getAddressQuery();


    /**
     *  Matches address books with any address. 
     *
     *  @param  match <code> true </code> to match address books with any 
     *          address, <code> false </code> to match address books with no 
     *          addresses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAddress(boolean match);


    /**
     *  Clears the address terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressTerms();


    /**
     *  Sets the address book <code> Id </code> for this query to match 
     *  address books that have the specified address book as an ancestor. 
     *
     *  @param  addressBookId an address book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorAddressBookId(org.osid.id.Id addressBookId, 
                                           boolean match);


    /**
     *  Clears the ancestor address book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAddressBookIdTerms();


    /**
     *  Tests if an <code> AddressBookQuery </code> is available. 
     *
     *  @return <code> true </code> if an address book query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorAddressBookQuery();


    /**
     *  Gets the query for an address book. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the address book query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorAddressBookQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorAddressBookQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressBookQuery getAncestorAddressBookQuery();


    /**
     *  Matches address books with any ancestor. 
     *
     *  @param  match <code> true </code> to match address books with any 
     *          ancestor, <code> false </code> to match root address books 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorAddressBook(boolean match);


    /**
     *  Clears the ancestor address book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAddressBookTerms();


    /**
     *  Sets the address book <code> Id </code> for this query to match 
     *  address books that have the specified address book as a descendant. 
     *
     *  @param  addressBookId an address book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantAddressBookId(org.osid.id.Id addressBookId, 
                                             boolean match);


    /**
     *  Clears the descendant address book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAddressBookIdTerms();


    /**
     *  Tests if an <code> AddressBookQuery </code> is available. 
     *
     *  @return <code> true </code> if an address book query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantAddressBookQuery();


    /**
     *  Gets the query for an address book. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the address book query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantAddressBookQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantAddressBookQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.contact.AddressBookQuery getDescendantAddressBookQuery();


    /**
     *  Matches address books with any descendant. 
     *
     *  @param  match <code> true </code> to match address books with any 
     *          descendant, <code> false </code> to match leaf address books 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantAddressBook(boolean match);


    /**
     *  Clears the descendant address book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAddressBookTerms();


    /**
     *  Gets the query record corresponding to the given <code> AddressBook 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  addressBookRecordType an address book record type 
     *  @return the address book query record 
     *  @throws org.osid.NullArgumentException <code> addressBookRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(addressBookRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.records.AddressBookQueryRecord getAddressBookQueryRecord(org.osid.type.Type addressBookRecordType)
        throws org.osid.OperationFailedException;
}
