//
// org.osid.contact.AddressBookSearchResults
//
//     The OSID Java specification for org.osid.contact.AddressBookSearchResults.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This interface provides a means to capture results of a search. </p>
 */

public interface AddressBookSearchResults
    extends org.osid.OsidSearchResults {


    /**
     *  Gets the address book list resulting from a search. 
     *
     *  @return the address book list 
     *  @throws org.osid.IllegalStateException list has already been retrieved 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookList getAddressBooks();


    /**
     *  Gets the inspector for the query to examine the terns used in the 
     *  search. 
     *
     *  @return the query inspector 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBookQueryInspector getAddressBookQueryInspector();


    /**
     *  Gets the address book search rsults record corresponding to the given 
     *  address book search record Type. This method is used to retrieve an 
     *  object implementing the requested record. 
     *
     *  @param  addressBookSearchRecordType an address book search record type 
     *  @return the address book search results record 
     *  @throws org.osid.NullArgumentException <code> 
     *          addressBookSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(addressBookSearchRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.records.AddressBookSearchResultsRecord getAddressBookSearchResultsRecord(org.osid.type.Type addressBookSearchRecordType)
        throws org.osid.OperationFailedException;
}
