//
// org.osid.contact.AddressQuery
//
//     The OSID Java specification for org.osid.contact.AddressQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This is the query for searching for addresses. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface AddressQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets a resource <code> Id. </code> 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the query for a resource query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery();


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Matches the address text. 
     *
     *  @param  address the address text 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> address </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAddressText(String address, 
                                 org.osid.type.Type stringMatchType, 
                                 boolean match);


    /**
     *  Clears the text address terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressTextTerms();


    /**
     *  Sets the contact <code> Id </code> for this query to match contacts 
     *  assigned to addresses. 
     *
     *  @param  contactId a contact <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> contactId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContactId(org.osid.id.Id contactId, boolean match);


    /**
     *  Clears the contact <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContactIdTerms();


    /**
     *  Tests if a contact query is available. 
     *
     *  @return <code> true </code> if a contact query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactQuery();


    /**
     *  Gets the query for an address. 
     *
     *  @return the contact query 
     *  @throws org.osid.UnimplementedException <code> supportsContactQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactQuery getContactQuery();


    /**
     *  Matches addresses with any contact. 
     *
     *  @param  match <code> true </code> to match addresses with any contact, 
     *          <code> false </code> to match addresses with no contacts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyContact(boolean match);


    /**
     *  Clears the contact terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContactTerms();


    /**
     *  Sets the address <code> Id </code> for this query to match contacts 
     *  assigned to address books. 
     *
     *  @param  addressBookId an address book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAddressBookId(org.osid.id.Id addressBookId, boolean match);


    /**
     *  Clears the address book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressBookIdTerms();


    /**
     *  Tests if an <code> AddressBookQuery </code> is available. 
     *
     *  @return <code> true </code> if an address book query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookQuery();


    /**
     *  Gets the query for an address book query. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the address book query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressBookQuery getAddressBookQuery();


    /**
     *  Clears the address book terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressBookTerms();


    /**
     *  Gets the address query record corresponding to the given <code> 
     *  Address </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested boolean <code> OR </code> term. 
     *
     *  @param  addressRecordType an address record type 
     *  @return the address query record 
     *  @throws org.osid.NullArgumentException <code> addressRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(addressRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.records.AddressQueryRecord getAddressQueryRecord(org.osid.type.Type addressRecordType)
        throws org.osid.OperationFailedException;
}
