//
// org.osid.contact.AddressSmartAddressBookSession
//
//     The OSID Java specification for org.osid.contact.AddressSmartAddressBookSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> AddressQuery </code> can be retrieved from this 
 *  session and mapped to this <code> AddressBook </code> to create a virtual 
 *  collection of <code> Addresses. </code> The addresses may be sequenced 
 *  using the <code> AddressSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> AddressBook </code> has a default query that matches any 
 *  address and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> AddressQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to an <code> 
 *  AddressQuery. </code> </p>
 */

public interface AddressSmartAddressBookSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AddressBook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AddressBook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressBookId();


    /**
     *  Gets the <code> AddressBook </code> associated with this session. 
     *
     *  @return the <code> AddressBook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook getAddressBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart address books. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart address book management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartAddressBooks();


    /**
     *  Gets an address query. 
     *
     *  @return the address query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressQuery getAddressQuery();


    /**
     *  Gets an address search order. 
     *
     *  @return the address search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressSearchOrder getAddressSearchOrder();


    /**
     *  Applies an address query to this address book. 
     *
     *  @param  addressQuery the address query 
     *  @throws org.osid.NullArgumentException <code> addressQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> addressQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAddressQuery(org.osid.contact.AddressQuery addressQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an address query inspector for this address book. 
     *
     *  @return the address query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressQueryInspector inspectAddressQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an address search order to this address book. 
     *
     *  @param  addressSearchOrder the address search order 
     *  @throws org.osid.NullArgumentException <code> addressSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> addressSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyAddressSequencing(org.osid.contact.AddressSearchOrder addressSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an address query from an inspector. 
     *
     *  @param  addressQueryInspector a query inspector 
     *  @return the address query 
     *  @throws org.osid.NullArgumentException <code> addressQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> addressQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressQuery getAddressQueryFromInspector(org.osid.contact.AddressQueryInspector addressQueryInspector);
}
