//
// org.osid.contact.Contact
//
//     The OSID Java specification for org.osid.contact.Contact.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>A <code> Contact </code> relates a reference <code> Id </code> to an 
 *  address and addresse. The contact addressee is expressed as a <code> 
 *  Resource. </code> For example, a contact for a <code> Repository </code> 
 *  would have the repository <code> Id </code> as the reference, and the 
 *  person to contact as the addressee. When specifying <code> Contacts 
 *  </code> for external <code> Resources, </code> the reference <code> Id 
 *  </code> and the addressee may be the same. </p> 
 *  
 *  <p> Multiple contacts may be related to an <code> Id </code> sorted by 
 *  priority. A <code> Contact </code> is available for use on the specified 
 *  weekdays and within a time of day. The genus <code> Type </code> of the 
 *  <code> Contact </code> may be used to provide further detail on how the 
 *  context or usage of this <code> Contact. </code> </p>
 */

public interface Contact
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the reference. 
     *
     *  @return the reference <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReferenceId();


    /**
     *  Gets the <code> Id </code> of the addressee. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddresseeId();


    /**
     *  Gets the addressee. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getAddressee()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the subscriber's address. 
     *
     *  @return the subscriber <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressId();


    /**
     *  Gets the subscriber's address. 
     *
     *  @return the subscriber's address. 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.Address getAddress()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the contact record corresponding to the given <code> Contact 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> contactRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(contactRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  contactRecordType the type of contact record to retrieve 
     *  @return the contact record 
     *  @throws org.osid.NullArgumentException <code> contactRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(contactRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.records.ContactRecord getContactRecord(org.osid.type.Type contactRecordType)
        throws org.osid.OperationFailedException;
}
