//
// org.osid.contact.ContactAdminSession
//
//     The OSID Java specification for org.osid.contact.ContactAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>This session creates, updates, and deletes <code> Contacts. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Contact, </code> a <code> ContactForm </code> is requested using <code> 
 *  getContactFormForCreate() </code> specifying the desired relationship 
 *  peers and record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> ContactForm </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> ContactForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ContactForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ContactForms </code> are requested to the <code> 
 *  Contact </code> <code> Id </code> that is to be updated using <code> 
 *  getContactFormForUpdate(). </code> Similarly, the <code> ContactForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> ContactForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Addresses. </code> To unmap a 
 *  <code> Contact </code> from the current <code> AddressBook, </code> the 
 *  <code> ContactAddressBookAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Address </code> itself thus 
 *  removing it from all known <code> ContactForm </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ContactAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> AddressBook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> AddressBook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAddressBookId();


    /**
     *  Gets the <code> AddressBook </code> associated with this session. 
     *
     *  @return the address book 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.AddressBook getAddressBook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create contacts. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Contact </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Contact </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateContacts();


    /**
     *  Tests if this user can create a single <code> Contact </code> using 
     *  the desired record types. While <code> 
     *  ContactManager.getContactRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Contact. </code> Providing an 
     *  empty array tests if a <code> Contact </code> can be created with no 
     *  records. 
     *
     *  @param  contactRecordTypes array of contact record types 
     *  @return <code> true </code> if <code> Contact </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> contactRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateContactWithRecordTypes(org.osid.type.Type[] contactRecordTypes);


    /**
     *  Gets the contact form for creating new contacts. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  addressId the <code> Id </code> for the address 
     *  @param  referenceId the <code> Id </code> for the reference 
     *  @param  contactRecordTypes array of contact record types 
     *  @return the contact form 
     *  @throws org.osid.NotFoundException <code> addressId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> addressId, referenceId, 
     *          </code> or <code> contactRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactForm getContactFormForCreate(org.osid.id.Id addressId, 
                                                                org.osid.id.Id referenceId, 
                                                                org.osid.type.Type[] contactRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Contact. </code> 
     *
     *  @param  contactForm the form for this <code> Contact </code> 
     *  @return the new <code> Contact </code> 
     *  @throws org.osid.IllegalStateException <code> contactForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> contactForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> contactForm </code> did 
     *          not originate from <code> getContactFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.Contact createContact(org.osid.contact.ContactForm contactForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update contacts. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Contact </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Contact </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateContacts();


    /**
     *  Gets the contact form for updating an existing contact. A new contact 
     *  form should be requested for each update transaction. 
     *
     *  @param  contactId the <code> Id </code> of the <code> Contact </code> 
     *  @return the contact form 
     *  @throws org.osid.NotFoundException <code> contactId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> contactId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.ContactForm getContactFormForUpdate(org.osid.id.Id contactId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing contact. 
     *
     *  @param  contactForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> contactForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> contactForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> contactForm </code> did 
     *          not originate from <code> getContactFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateContact(org.osid.contact.ContactForm contactForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete contacts. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Contact </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Contact </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteContacts();


    /**
     *  Deletes a <code> Contact. </code> 
     *
     *  @param  contactId the <code> Id </code> of the <code> Contact </code> 
     *          to remove 
     *  @throws org.osid.NotFoundException <code> contactId </code> not found 
     *  @throws org.osid.NullArgumentException <code> contactId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteContact(org.osid.id.Id contactId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Contacts. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Contact </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageContactAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Contact </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Contact </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another contact, it is reassigned to the given 
     *  contact <code> Id. </code> 
     *
     *  @param  contactId the <code> Id </code> of a <code> Contact </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> contactId </code> not found 
     *  @throws org.osid.NullArgumentException <code> contactId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasContact(org.osid.id.Id contactId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
