//
// org.osid.contact.ContactProfile
//
//     The OSID Java specification for org.osid.contact.ContactProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>The contact profile describes the interoperability among contact 
 *  services. </p>
 */

public interface ContactProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any address federation is exposed. Federation is exposed when 
     *  a specific address may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  addresses appears as a single address. 
     *
     *  @return <code> true </code> if visible federation is supproted, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a contact service for getting available 
     *  contacts for a resource. 
     *
     *  @return <code> true </code> if contact is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContact();


    /**
     *  Tests for the availability of a contact lookup service. 
     *
     *  @return <code> true </code> if contact lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactLookup();


    /**
     *  Tests if querying contacts is available. 
     *
     *  @return <code> true </code> if contact query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactQuery();


    /**
     *  Tests if searching for contacts is available. 
     *
     *  @return <code> true </code> if contact search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactSearch();


    /**
     *  Tests if managing contacts is available. 
     *
     *  @return <code> true </code> if contact admin is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactAdmin();


    /**
     *  Tests if contact notification is available. 
     *
     *  @return <code> true </code> if contact notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactNotification();


    /**
     *  Tests if a contact to address book lookup session is available. 
     *
     *  @return <code> true </code> if contact address book lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactAddressBook();


    /**
     *  Tests if a contact to address book assignment session is available. 
     *
     *  @return <code> true </code> if contact address book assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactAddressBookAssignment();


    /**
     *  Tests if a contact smart address book session is available. 
     *
     *  @return <code> true </code> if contact smart address book is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactSmartAddressBook();


    /**
     *  Tests for the availability of an address lookup service. 
     *
     *  @return <code> true </code> if address lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressLookup();


    /**
     *  Tests if querying addresses is available. 
     *
     *  @return <code> true </code> if address query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressQuery();


    /**
     *  Tests if searching for addresses is available. 
     *
     *  @return <code> true </code> if address search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressSearch();


    /**
     *  Tests for the availability of an address administrative service for 
     *  creating and deleting addresses. 
     *
     *  @return <code> true </code> if address administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressAdmin();


    /**
     *  Tests for the availability of an address notification service. 
     *
     *  @return <code> true </code> if address notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAddressNotification();


    /**
     *  Tests if an address to address book lookup session is available. 
     *
     *  @return <code> true </code> if address address book lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressAddressBook();


    /**
     *  Tests if an address to address book assignment session is available. 
     *
     *  @return <code> true </code> if address address book assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressAddressBookAssignment();


    /**
     *  Tests if an address smart address book session is available. 
     *
     *  @return <code> true </code> if address smart address book is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressSmartAddressBook();


    /**
     *  Tests for the availability of an address book lookup service. 
     *
     *  @return <code> true </code> if address book lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookLookup();


    /**
     *  Tests if querying address books is available. 
     *
     *  @return <code> true </code> if address book query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookQuery();


    /**
     *  Tests if searching for address books is available. 
     *
     *  @return <code> true </code> if address book search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookSearch();


    /**
     *  Tests for the availability of an address book administrative service 
     *  for creating and deleting address books. 
     *
     *  @return <code> true </code> if address book administration is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookAdmin();


    /**
     *  Tests for the availability of an address book notification service. 
     *
     *  @return <code> true </code> if address book notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAddressBookNotification();


    /**
     *  Tests for the availability of an address book hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if address book hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookHierarchy();


    /**
     *  Tests for the availability of an address book hierarchy design 
     *  service. 
     *
     *  @return <code> true </code> if address book hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAddressBookHierarchyDesign();


    /**
     *  Tests for the availability of a contact batch service. 
     *
     *  @return <code> true </code> if a contact batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactBatch();


    /**
     *  Tests for the availability of a contact rules service. 
     *
     *  @return <code> true </code> if a contact rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactRules();


    /**
     *  Gets the supported <code> Contact </code> record types. 
     *
     *  @return a list containing the supported contact record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getContactRecordTypes();


    /**
     *  Tests if the given <code> Contact </code> record type is supported. 
     *
     *  @param  contactRecordType a <code> Type </code> indicating a <code> 
     *          Contact </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> contactRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactRecordType(org.osid.type.Type contactRecordType);


    /**
     *  Gets the supported contact search record types. 
     *
     *  @return a list containing the supported contact search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getContactSearchRecordTypes();


    /**
     *  Tests if the given contact search record type is supported. 
     *
     *  @param  contactSearchRecordType a <code> Type </code> indicating a 
     *          contact record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> contactSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactSearchRecordType(org.osid.type.Type contactSearchRecordType);


    /**
     *  Gets the supported <code> Address </code> record types. 
     *
     *  @return a list containing the supported address record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAddressRecordTypes();


    /**
     *  Tests if the given <code> Address </code> record type is supported. 
     *
     *  @param  addressRecordType a <code> Type </code> indicating a <code> 
     *          Address </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> addressRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressRecordType(org.osid.type.Type addressRecordType);


    /**
     *  Gets the supported address search record types. 
     *
     *  @return a list containing the supported address search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAddressSearchRecordTypes();


    /**
     *  Tests if the given address search record type is supported. 
     *
     *  @param  addressSearchRecordType a <code> Type </code> indicating an 
     *          address record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> addressSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressSearchRecordType(org.osid.type.Type addressSearchRecordType);


    /**
     *  Gets the supported <code> AddressBook </code> record types. 
     *
     *  @return a list containing the supported address book record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAddressBookRecordTypes();


    /**
     *  Tests if the given <code> AddressBook </code> record type is 
     *  supported. 
     *
     *  @param  addressBookRecordType a <code> Type </code> indicating a 
     *          <code> AddressBook </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> addressBookRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookRecordType(org.osid.type.Type addressBookRecordType);


    /**
     *  Gets the supported address book search record types. 
     *
     *  @return a list containing the supported address book search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAddressBookSearchRecordTypes();


    /**
     *  Tests if the given address book search record type is supported. 
     *
     *  @param  addressBookSearchRecordType a <code> Type </code> indicating 
     *          an address book record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          addressBookSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressBookSearchRecordType(org.osid.type.Type addressBookSearchRecordType);
}
