//
// org.osid.contact.ContactProxyManager
//
//     The OSID Java specification for org.osid.contact.ContactProxyManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact;


/**
 *  <p>The contact manager provides access to contact sessions and provides 
 *  interoperability tests for various aspects of this service. Methods in 
 *  this manager accept a <code> Proxy </code> for passing information from a 
 *  server environment. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ContactSession </code> : a session to get available 
 *      contacts for a resource </li> 
 *      <li> <code> ContactLookupSession: </code> a session to lookup contacts 
 *      </li> 
 *      <li> <code> ContactQuerySession: </code> a session to query contacts 
 *      </li> 
 *      <li> <code> ContactSearchSession: </code> a session to search contacts 
 *      </li> 
 *      <li> <code> ContactAdminSession: </code> a session to manage contacts 
 *      </li> 
 *      <li> <code> ContactNotificationSession: </code> a session to subscribe 
 *      to notifications of contact changes </li> 
 *      <li> <code> ContactAddressBookSession: </code> a session to lookup 
 *      contact address book mappings </li> 
 *      <li> <code> ContactAddressBookAssignmentSession: </code> a session to 
 *      manage contact address book mappings </li> 
 *      <li> <code> ContactSmartAddressBookSession: </code> a session to 
 *      manage smart address books of contacts </li> 
 *      <li> <code> AddressLookupSession: </code> a session to retrieve 
 *      addresses </li> 
 *      <li> <code> AddressQuerySession: </code> a session to query addresses 
 *      </li> 
 *      <li> <code> AddressSearchSession: </code> a session to search for 
 *      addresses </li> 
 *      <li> <code> AddressAdminSession: </code> a session to create, update 
 *      and delete addresses </li> 
 *      <li> <code> AddressNotificationSession: </code> a session to receive 
 *      notifications for changes in addresses </li> 
 *      <li> <code> AddressAddressBookSession: </code> a session to lookup 
 *      address address book mappings </li> 
 *      <li> <code> AddressAddressBookAssignmentSession: </code> a session to 
 *      manage address address book mappings </li> 
 *      <li> <code> AddressSmartAddressBookSession: </code> a session to 
 *      manage smart address books of addresses </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AddressBookLookupSession: </code> a session to retrieve 
 *      address books </li> 
 *      <li> <code> AddressBookQuerySession: </code> a session to query 
 *      address books </li> 
 *      <li> <code> AddressBookSearchSession: </code> a session to search for 
 *      address books </li> 
 *      <li> <code> AddressBookAdminSession: </code> a session to create, 
 *      update and delete address books </li> 
 *      <li> <code> AddressBookNotificationSession: </code> a session to 
 *      receive notifications for changes in address books </li> 
 *      <li> <code> AddressBookHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of address books </li> 
 *      <li> <code> AddressBookHierarchyDesignSession: </code> a session to 
 *      manage hierarchies of address books </li> 
 *  </ul>
 *  
 *  
 *  <p> The contact manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface ContactProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.contact.ContactProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the contact 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ContactSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContact() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContact() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactSession getContactSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact 
     *  service for the given address book. 
     *
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ContactLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Address </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContact() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContact() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.ContactSession getContactSessionForAddressBook(org.osid.id.Id addressId, 
                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ContactLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactLookup() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactLookupSession getContactLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact lookup 
     *  service for the given address book. 
     *
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ContactLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Address </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.ContactLookupSession getContactLookupSessionForAddressBook(org.osid.id.Id addressId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ContactQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactQuerySession getContactQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact query 
     *  service for the given address book. 
     *
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ContactQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Contact </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.ContactQuerySession getContactQuerySessionForAddressBook(org.osid.id.Id addressId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ContactSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactSearch() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactSearchSession getContactSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact search 
     *  service for the given address book. 
     *
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ContactSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Contact </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.ContactSearchSession getContactSearchSessionForAddressBook(org.osid.id.Id addressId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ContactAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactAdmin() </code> is <code> true. </code> 
     */

    public org.osid.contact.ContactAdminSession getContactAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact 
     *  administration service for the given address book. 
     *
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ContactAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Contact </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.ContactAdminSession getContactAdminSessionForAddressBook(org.osid.id.Id addressId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact 
     *  notification service. 
     *
     *  @param  contactReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> ContactNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> contactReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContactNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.ContactNotificationSession getContactNotificationSession(org.osid.contact.ContactReceiver contactReceiver, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the contact 
     *  notification service for the given address book. 
     *
     *  @param  contactReceiver the receiver 
     *  @param  addressId the <code> Id </code> of the <code> Address </code> 
     *  @param  proxy a proxy 
     *  @return a <code> ContactNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Contact </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> contactReceiver, 
     *          addressId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContactNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.ContactNotificationSession getContactNotificationSessionForAddressBook(org.osid.contact.ContactReceiver contactReceiver, 
                                                                                                   org.osid.id.Id addressId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving contact to address book mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ContactAddressBookSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContactAddressBook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactAddressBook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.ContactAddressBookSession getContactAddressBookSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning contact to address book mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ContactAddressBookAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContactAddressBookAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactAddressBookAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.contact.ContactAddressBookAssignmentSession getContactAddressBookAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the contact smart address book for 
     *  the given address book. 
     *
     *  @param  addressBookId the <code> Id </code> of the contact book 
     *  @param  proxy a proxy 
     *  @return a <code> ContactSmartAddressBookSession </code> 
     *  @throws org.osid.NotFoundException <code> contactBookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> contactBookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContactSmartAddressBook() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactSmartAddressBook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.ContactSmartAddressBookSession getContactSmartAddressBookSession(org.osid.id.Id addressBookId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressLookup() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressLookupSession getAddressLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address lookup 
     *  service for the given address book. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AddressLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> AddressBook </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.AddressLookupSession getAddressLookupSessionForAddressBook(org.osid.id.Id addressBookId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressQuerySession getAddressQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address query 
     *  service for the given address book. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AddressQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Address </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.AddressQuerySession getAddressQuerySessionForAddressBook(org.osid.id.Id addressBookId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressSearch() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressSearchSession getAddressSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address search 
     *  service for the given address book. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AddressSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Address </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.AddressSearchSession getAddressSearchSessionForAddressBook(org.osid.id.Id addressBookId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressAdmin() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressAdminSession getAddressAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address 
     *  administration service for the given address book. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AddressAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Address </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAddressAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.AddressAdminSession getAddressAdminSessionForAddressBook(org.osid.id.Id addressBookId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address 
     *  notification service. 
     *
     *  @param  addressReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return an <code> AddressNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> addressReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressNotificationSession getAddressNotificationSession(org.osid.contact.AddressReceiver addressReceiver, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address 
     *  notification service for the given address book. 
     *
     *  @param  addressReceiver the receiver 
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AddressNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Address </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> addressReceiver, 
     *          addressBookId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.contact.AddressNotificationSession getAddressNotificationSessionForAddressBook(org.osid.contact.AddressReceiver addressReceiver, 
                                                                                                   org.osid.id.Id addressBookId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving address to address book mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressAddressBookSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressAddressBook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressAddressBook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressAddressBookSession getAddressAddressBookSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning address to address book mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressAddressBookAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressAddressBookAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressAddressBookAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.contact.AddressAddressBookAssignmentSession getAddressAddressBookAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic address address books for the 
     *  given address book. 
     *
     *  @param  addressBookId the <code> Id </code> of an address book 
     *  @param  proxy a proxy 
     *  @return an <code> AddressSmartAddressBookSession </code> 
     *  @throws org.osid.NotFoundException <code> addressBookId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressSmartAddressBook() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressSmartAddressBook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressSmartAddressBookSession getAddressSmartAddressBookSession(org.osid.id.Id addressBookId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address book 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressBookLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressBookLookupSession getAddressBookLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address book 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressBookQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressBookQuerySession getAddressBookQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address book 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressBookSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressBookSearchSession getAddressBookSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address book 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressBookAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookAdmin() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressBookAdminSession getAddressBookAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address book 
     *  notification service. 
     *
     *  @param  addressBookReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return an <code> AddressBookNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> addressBookReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressBookNotificationSession getAddressBookNotificationSession(org.osid.contact.AddressBookReceiver addressBookReceiver, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address book 
     *  hierarchy service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressBookHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressBookHierarchySession getAddressBookHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the address book 
     *  hierarchy design service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AddressBookHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressBookHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressBookHierarchyDesign() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.contact.AddressBookHierarchyDesignSession getAddressBookHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ContactBatchProxyManager. </code> 
     *
     *  @return a <code> ContactBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactBatch() </code> is <code> true. </code> 
     */

    public org.osid.contact.batch.ContactBatchProxyManager getContactBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ContactRulesProxyManager. </code> 
     *
     *  @return a <code> ContactRulesProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsContactRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContactRules() </code> is <code> true. </code> 
     */

    public org.osid.contact.rules.ContactRulesProxyManager getContactRulesProxyManager()
        throws org.osid.OperationFailedException;
}
