//
// org.osid.contact.rules.ContactEnablerAddressBookAssignmentSession
//
//     The OSID Java specification for org.osid.contact.rules.ContactEnablerAddressBookAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact.rules;


/**
 *  <p>This session provides methods to re-assign <code> ContactEnabler 
 *  </code> to <code> AddressBook </code> mappings. A <code> ContactEnabler 
 *  </code> may appear in multiple <code> AddressBook </code> objects and 
 *  removing the last reference to a <code> ContactEnabler </code> is the 
 *  equivalent of deleting it. Each <code> AddressBook </code> may have its 
 *  own authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> ContactEnabler </code> to another 
 *  <code> AddressBook </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface ContactEnablerAddressBookAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter contact enabler/address book mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignContactEnablers();


    /**
     *  Tests if this user can alter contact enabler/address book mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignContactEnablersToAddressBook(org.osid.id.Id addressBookId);


    /**
     *  Gets a list of address books including and under the given address 
     *  book node in which any contact enabler can be assigned. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @return list of assignable address book <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAddressBookIds(org.osid.id.Id addressBookId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of address books including and under the given address 
     *  book node in which a specific contact enabler can be assigned. 
     *
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> 
     *  @return list of assignable address book <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> addressBookId </code> or 
     *          <code> contactEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableAddressBookIdsForContactEnabler(org.osid.id.Id addressBookId, 
                                                                           org.osid.id.Id contactEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ContactEnabler </code> to an <code> 
     *  AddressBook. </code> 
     *
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> 
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> contactEnablerId 
     *          </code> is already assigned to <code> addressBookId </code> 
     *  @throws org.osid.NotFoundException <code> contactEnablerId </code> or 
     *          <code> addressBookId </code> not found 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          or <code> addressBookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignContactEnablerToAddressBook(org.osid.id.Id contactEnablerId, 
                                                  org.osid.id.Id addressBookId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ContactEnabler </code> from an <code> AddressBook. 
     *  </code> 
     *
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> 
     *  @param  addressBookId the <code> Id </code> of the <code> AddressBook 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> contactEnablerId </code> or 
     *          <code> addressBookId </code> not found or <code> 
     *          contactEnablerId </code> is not assigned to <code> 
     *          addressBookId </code> 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId </code> 
     *          or <code> addressBookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignContactEnablerFromAddressBook(org.osid.id.Id contactEnablerId, 
                                                      org.osid.id.Id addressBookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> ContactEnabler </code> from one <code> AddressBook 
     *  </code> to another. Mappings to other <code> AddressBooks </code> are 
     *  unaffected. 
     *
     *  @param  contactEnablerId the <code> Id </code> of the <code> 
     *          ContactEnabler </code> 
     *  @param  fromAddressBookId the <code> Id </code> of the current <code> 
     *          AddressBook </code> 
     *  @param  toAddressBookId the <code> Id </code> of the destination 
     *          <code> AddressBook </code> 
     *  @throws org.osid.NotFoundException <code> contactEnablerId, 
     *          fromAddressBookId, </code> or <code> toAddressBookId </code> 
     *          not found or <code> contactEnablerId </code> not mapped to 
     *          <code> fromAddressBookId </code> 
     *  @throws org.osid.NullArgumentException <code> contactEnablerId, 
     *          fromAddressBookId, </code> or <code> toAddressBookId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignContactEnablerToAddressBook(org.osid.id.Id contactEnablerId, 
                                                    org.osid.id.Id fromAddressBookId, 
                                                    org.osid.id.Id toAddressBookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
