//
// org.osid.contact.rules.ContactEnablerSearchSession
//
//     The OSID Java specification for org.osid.contact.rules.ContactEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.contact.rules;


/**
 *  <p>This session provides methods for searching among <code> ContactEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  ContactEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getContactEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> ContactEnablers. </code> A more advanced 
 *  search may be performed with <code> getContactEnablersBySearch(). </code> 
 *  It accepts a <code> ContactEnablerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getContactEnablersBySearch() </code> 
 *  returns a <code> ContactEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> ContactEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  ContactEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated address book view: searches include contact enablers in 
 *      address books of which this address book is an ancestor in the address 
 *      book hierarchy </li> 
 *      <li> isolated address book view: searches are restricted to contact 
 *      enablers in this address book </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> ContactEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  ContactEnablerQuery. </code> </p>
 */

public interface ContactEnablerSearchSession
    extends org.osid.contact.rules.ContactEnablerQuerySession {


    /**
     *  Gets a contact enabler search. 
     *
     *  @return the contact enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.rules.ContactEnablerSearch getContactEnablerSearch();


    /**
     *  Gets a contact enabler search order. The <code> 
     *  ContactEnablerSearchOrder </code> is supplied to a <code> 
     *  ContactEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the contact enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.rules.ContactEnablerSearchOrder getContactEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  contactEnablerQuery the contact enabler query 
     *  @param  contactEnablerSearch the contact enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> contactEnablerQuery 
     *          </code> or <code> contactEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> contactEnablerQuery 
     *          </code> or <code> contactEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.rules.ContactEnablerSearchResults getContactEnablersBySearch(org.osid.contact.rules.ContactEnablerQuery contactEnablerQuery, 
                                                                                         org.osid.contact.rules.ContactEnablerSearch contactEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a contact enabler query from an inspector. The inspector is 
     *  available from a <code> ContactEnablerSearchResults. </code> 
     *
     *  @param  contactEnablerQueryInspector a contact enabler query inspector 
     *  @return the contact enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          contactEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          contactEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.contact.rules.ContactEnablerQuery getContactEnablerQueryFromInspector(org.osid.contact.rules.ContactEnablerQueryInspector contactEnablerQueryInspector);
}
