//
// org.osid.control.ActionGroupAdminSession
//
//     The OSID Java specification for org.osid.control.ActionGroupAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session creates, updates, and deletes <code> ActionGroups. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> ActionGroup, </code> an <code> ActionGroupForm </code> is requested 
 *  using <code> getActionGroupFormForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> ActionGroupForm </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once the <code> ActionGroupForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ActionGroupForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> ActionGroupForms </code> are requested to the 
 *  <code> ActionGroup </code> <code> Id </code> that is to be updated using 
 *  <code> getActionGroupFormForUpdate(). </code> Similarly, the <code> 
 *  ActionGroupForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ActionGroupForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ActionGroups. </code> To unmap an 
 *  <code> ActionGroup </code> from the current <code> System, </code> the 
 *  <code> ActionGroupSystemAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> ActionGroup </code> itself 
 *  thus removing it from all known <code> System </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ActionGroupAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ActionGroups. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> ActionGroup </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActionGroup </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActionGroups();


    /**
     *  Tests if this user can create a single <code> ActionGroup </code> 
     *  using the desired record types. While <code> 
     *  ControlManager.getActionGroupRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> ActionGroup. </code> 
     *  Providing an empty array tests if an <code> ActionGroup </code> can be 
     *  created with no records. 
     *
     *  @param  actionGroupRecordTypes array of action group record types 
     *  @return <code> true </code> if <code> ActionGroup </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> actionGroupRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActionGroupWithRecordTypes(org.osid.type.Type[] actionGroupRecordTypes);


    /**
     *  Gets the action group form for creating new action groups. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  actionGroupRecordTypes array of action group record types 
     *  @return the action group form 
     *  @throws org.osid.NullArgumentException <code> actionGroupRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupForm getActionGroupFormForCreate(org.osid.type.Type[] actionGroupRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ActionGroup. </code> 
     *
     *  @param  actionGroupForm the form for this <code> ActionGroup </code> 
     *  @return the new <code> ActionGroup </code> 
     *  @throws org.osid.IllegalStateException <code> actionGroupForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> actionGroupForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> actionGroupForm </code> 
     *          did not originate from <code> getActionGroupFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroup createActionGroup(org.osid.control.ActionGroupForm actionGroupForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ActionGroups. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> ActionGroup </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActionGroup </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateActionGroups();


    /**
     *  Gets the action group form for updating an existing action group. A 
     *  new action group form should be requested for each update transaction. 
     *
     *  @param  actionGroupId the <code> Id </code> of the <code> ActionGroup 
     *          </code> 
     *  @return the action group form 
     *  @throws org.osid.NotFoundException <code> actionGroupId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupForm getActionGroupFormForUpdate(org.osid.id.Id actionGroupId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing action group. 
     *
     *  @param  actionGroupForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> actionGroupForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> actionGroupForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> actionGroupForm </code> 
     *          did not originate from <code> getActionGroupFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateActionGroup(org.osid.control.ActionGroupForm actionGroupForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ActionGroups. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> ActionGroup </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActionGroup </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteActionGroups();


    /**
     *  Deletes an <code> ActionGroup. </code> 
     *
     *  @param  actionGroupId the <code> Id </code> of the <code> ActionGroup 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> actionGroupId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteActionGroup(org.osid.id.Id actionGroupId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ActionGroups. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActionGroup </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageActionGroupAliases();


    /**
     *  Adds an <code> Id </code> to an <code> ActionGroup </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ActionGroup </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another action group, it is 
     *  reassigned to the given action group <code> Id. </code> 
     *
     *  @param  actionGroupId the <code> Id </code> of an <code> ActionGroup 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> actionGroupId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasActionGroup(org.osid.id.Id actionGroupId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create a single <code> Action </code> using the 
     *  desired record types. While <code> 
     *  ControlManager.getActionRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Action. </code> Providing an 
     *  empty array tests if an <code> Action </code> can be created with no 
     *  records. 
     *
     *  @param  actionRecordTypes array of action record types 
     *  @return <code> true </code> if <code> Action </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> actionRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActionWithRecordTypes(org.osid.type.Type[] actionRecordTypes);


    /**
     *  Gets the action form for creating new actions. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  actionGroupId an action group <code> Id </code> 
     *  @param  actionRecordTypes array of action record types 
     *  @return the action form 
     *  @throws org.osid.NotFoundException <code> actionGroupId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> or 
     *          <code> actionRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionForm getActionFormForCreate(org.osid.id.Id actionGroupId, 
                                                              org.osid.type.Type[] actionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Action. </code> 
     *
     *  @param  actionForm the form for this <code> Action </code> 
     *  @return the new <code> Action </code> 
     *  @throws org.osid.IllegalStateException <code> actionForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> actionForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> actionForm </code> did 
     *          not originate from <code> getActionFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.Action createAction(org.osid.control.ActionForm actionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Actions. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Action </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Action </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateActions();


    /**
     *  Gets the action form for updating an existing action. A new action 
     *  form should be requested for each update transaction. 
     *
     *  @param  actionId the <code> Id </code> of the <code> Action </code> 
     *  @return the action form 
     *  @throws org.osid.NotFoundException <code> actionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> actionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionForm getActionFormForUpdate(org.osid.id.Id actionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing action. 
     *
     *  @param  actionForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> actionForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> actionForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> actionForm </code> did 
     *          not originate from <code> getActionFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAction(org.osid.control.ActionForm actionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Actions. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Action </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Action </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteActions();


    /**
     *  Deletes an <code> Action. </code> 
     *
     *  @param  actionId the <code> Id </code> of the <code> Action </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> actionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> actionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAction(org.osid.id.Id actionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Actions. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Action </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageActionAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Action </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Action </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another action, it is reassigned to the given 
     *  action <code> Id. </code> 
     *
     *  @param  actionId the <code> Id </code> of an <code> Action </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> actionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> actionId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAction(org.osid.id.Id actionId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> Actions. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Action </code> ordering is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceActions();


    /**
     *  Reorders actions in an action grpup by moving the specified action in 
     *  front of a reference action. 
     *
     *  @param  actionId the <code> Id </code> of an <code> Action </code> 
     *  @param  actionGroupId the <code> Id </code> of an <code> ActionGroup 
     *          </code> 
     *  @param  referenceId the reference action <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> actionId, actionGroupId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          actionId </code> or <code> referenceId </code> not related to 
     *          <code> actionGroupId </code> 
     *  @throws org.osid.NullArgumentException <code> actionId, actionGroupId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveActionAhead(org.osid.id.Id actionId, 
                                org.osid.id.Id actionGroupId, 
                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders actions in an action group by moving the specified action 
     *  behind a reference action. 
     *
     *  @param  actionId the <code> Id </code> of an <code> Action </code> 
     *  @param  actionGroupId the <code> Id </code> of an <code> ActionGroup 
     *          </code> 
     *  @param  referenceId the reference action <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> actionId, actionGroupId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          actionId </code> or <code> referenceId </code> not related to 
     *          <code> actionGroupId </code> 
     *  @throws org.osid.NullArgumentException <code> actionId, actionGroupId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveActionBehind(org.osid.id.Id actionId, 
                                 org.osid.id.Id actionGroupId, 
                                 org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of actions in an action group. 
     *
     *  @param  actionIds the <code> Ids </code> for a set of <code> Actiond 
     *          </code> 
     *  @param  actionGroupId the <code> Id </code> of an <code> ActionGroup 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> actionGroupId </code> not 
     *          found or, an <code> actionId </code> not related to <code> 
     *          actionGroupId </code> 
     *  @throws org.osid.NullArgumentException <code> actionIds </code> or 
     *          <code> actionGroupId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderActions(org.osid.id.Id[] actionIds, 
                             org.osid.id.Id actionGroupId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
