//
// org.osid.control.ActionGroupQuery
//
//     The OSID Java specification for org.osid.control.ActionGroupQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the query for searching action groups. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface ActionGroupQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidAggregateableQuery {


    /**
     *  Sets the action <code> Id </code> for this query. 
     *
     *  @param  actionId the action <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> actionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActionId(org.osid.id.Id actionId, boolean match);


    /**
     *  Clears the action <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionIdTerms();


    /**
     *  Tests if an <code> ActionQuery </code> is available. 
     *
     *  @return <code> true </code> if an action query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionQuery();


    /**
     *  Gets the query for an action. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the action query 
     *  @throws org.osid.UnimplementedException <code> supportsActionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ActionQuery getActionQuery();


    /**
     *  Matches action groups with any action. 
     *
     *  @param  match <code> true </code> to match action groups with any 
     *          action, <code> false </code> to match action groups with no 
     *          actions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAction(boolean match);


    /**
     *  Clears the action query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionTerms();


    /**
     *  Sets the action group <code> Id </code> for this query to match 
     *  controllers assigned to action groups. 
     *
     *  @param  actionGroupId the action group <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSystemId(org.osid.id.Id actionGroupId, boolean match);


    /**
     *  Clears the system <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemIdTerms();


    /**
     *  Tests if a <code> SystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a system query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemQuery();


    /**
     *  Gets the query for a system. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the system query 
     *  @throws org.osid.UnimplementedException <code> supportsSystemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemQuery getSystemQuery();


    /**
     *  Clears the system query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemTerms();


    /**
     *  Gets the action group query record corresponding to the given <code> 
     *  ActionGroup </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  actionGroupRecordType an action group record type 
     *  @return the action group query record 
     *  @throws org.osid.NullArgumentException <code> actionGroupRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(actionGroupRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ActionGroupQueryRecord getActionGroupQueryRecord(org.osid.type.Type actionGroupRecordType)
        throws org.osid.OperationFailedException;
}
