//
// org.osid.control.ActionGroupSmartSystemSession
//
//     The OSID Java specification for org.osid.control.ActionGroupSmartSystemSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> ActionGroupQuery </code> can be retrieved from this 
 *  session and mapped to this <code> System </code> to create a virtual 
 *  collection of <code> ActionGroups. </code> The action groups may be 
 *  sequenced using the <code> ActionGroupSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> System </code> has a default query that matches any action 
 *  group and a default search order that specifies no sequencing. The queries 
 *  may be examined using an <code> ActionGroupQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to an <code> 
 *  ActionGroupQuery. </code> </p>
 */

public interface ActionGroupSmartSystemSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart systems. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart system management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartSystems();


    /**
     *  Gets an action group query. 
     *
     *  @return the action group query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupQuery getActionGroupQuery();


    /**
     *  Gets an action group search order. 
     *
     *  @return the action group search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupSearchOrder getActionGroupSearchOrder();


    /**
     *  Applies an action group query to this system. 
     *
     *  @param  actuionGroupQuery the action group query 
     *  @throws org.osid.NullArgumentException <code> actuionGroupQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> actuionGroupQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyActionGroupQuery(org.osid.control.ActionGroupQuery actuionGroupQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an action group query inspector for this system. 
     *
     *  @return the action group query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupQueryInspector inspectActionGroupQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an action group search order to this system. 
     *
     *  @param  actionGroupSearchOrder the action group search order 
     *  @throws org.osid.NullArgumentException <code> actionGroupSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> actionGroupSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyActionGroupSequencing(org.osid.control.ActionGroupSearchOrder actionGroupSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an action group query from an inspector. 
     *
     *  @param  actuionGroupQueryInspector an action group query inspector 
     *  @return the action group query 
     *  @throws org.osid.NullArgumentException <code> 
     *          actuionGroupQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          actuionGroupQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupQuery getActionGroupQueryFromInspector(org.osid.control.ActionGroupQueryInspector actuionGroupQueryInspector);
}
