//
// org.osid.control.ActionQuery
//
//     The OSID Java specification for org.osid.control.ActionQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the query for searching actions. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ActionQuery
    extends org.osid.OsidRuleQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the action group <code> Id </code> for this query. 
     *
     *  @param  actionGroupId an action group <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActionGroupId(org.osid.id.Id actionGroupId, boolean match);


    /**
     *  Clears the action group <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionGroupIdTerms();


    /**
     *  Tests if an <code> ActionGroupQuery </code> is available. 
     *
     *  @return <code> true </code> if an action group query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupQuery();


    /**
     *  Gets the query for an action group. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the action group query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ActionGroupQuery getActionGroupQuery();


    /**
     *  Clears the action group query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionGroupTerms();


    /**
     *  Matches delays between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start or end </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDelay(org.osid.calendaring.Duration start, 
                           org.osid.calendaring.Duration end, boolean match);


    /**
     *  Matches any delay. 
     *
     *  @param  match <code> true </code> to match actions with delays, <code> 
     *          false </code> to match actions with no delays 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDelay(boolean match);


    /**
     *  Clears the delay query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDelayTerms();


    /**
     *  Matches blocking actions. 
     *
     *  @param  match <code> true </code> to match blocking actions, <code> 
     *          false </code> to match unblocking actions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBlocking(boolean match);


    /**
     *  Clears the blocking query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBlockingTerms();


    /**
     *  Sets the executed action group <code> Id </code> for this query. 
     *
     *  @param  actionGroupId an action group <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNextActionGroupId(org.osid.id.Id actionGroupId, 
                                       boolean match);


    /**
     *  Clears the executed action group <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNextActionGroupIdTerms();


    /**
     *  Tests if an <code> ActionGroupQuery </code> is available. 
     *
     *  @return <code> true </code> if an action group query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNextActionGroupQuery();


    /**
     *  Gets the query for the action group to execute. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the action group query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNextActionGroupQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNextActionGroupQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ActionGroupQuery getNextActionGroupQuery();


    /**
     *  Matches actions with any executable action group. 
     *
     *  @param  match <code> true </code> to match actions with any action 
     *          group, <code> false </code> to match actions with no action 
     *          groups 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNextActionGroup(boolean match);


    /**
     *  Clears the action group query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNextActionGroupTerms();


    /**
     *  Sets the scene <code> Id </code> for this query. 
     *
     *  @param  sceneId a scene <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sceneId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSceneId(org.osid.id.Id sceneId, boolean match);


    /**
     *  Clears the scene <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSceneIdTerms();


    /**
     *  Tests if a <code> SceneQuery </code> is available. 
     *
     *  @return <code> true </code> if a scene query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneQuery();


    /**
     *  Gets the query for a scene. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the scene query 
     *  @throws org.osid.UnimplementedException <code> supportsSceneQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneQuery getSceneQuery();


    /**
     *  Matches actions with any scene. 
     *
     *  @param  match <code> true </code> to match actions with any scene, 
     *          <code> false </code> to match actions with no scene 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScene(boolean match);


    /**
     *  Clears the scene query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSceneTerms();


    /**
     *  Sets the setting <code> Id </code> for this query. 
     *
     *  @param  settingId a setting <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> settingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSettingId(org.osid.id.Id settingId, boolean match);


    /**
     *  Clears the setting <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSettingIdTerms();


    /**
     *  Tests if a <code> SettingQuery </code> is available. 
     *
     *  @return <code> true </code> if a setting query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingQuery();


    /**
     *  Gets the query for a setting. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the setting query 
     *  @throws org.osid.UnimplementedException <code> supportsSettingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingQuery getSettingQuery();


    /**
     *  Matches actions with any setting. 
     *
     *  @param  match <code> true </code> to match actions with any setting, 
     *          <code> false </code> to match actions with no setting 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySetting(boolean match);


    /**
     *  Clears the setting query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSettingTerms();


    /**
     *  Gets the action query record corresponding to the given <code> Action 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  actionRecordType an action record type 
     *  @return the action query record 
     *  @throws org.osid.NullArgumentException <code> actionRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(actionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ActionQueryRecord getActionQueryRecord(org.osid.type.Type actionRecordType)
        throws org.osid.OperationFailedException;
}
