//
// org.osid.control.ControlManager
//
//     The OSID Java specification for org.osid.control.ControlManager.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>The control manager provides access to control sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> DeviceLookupSession: </code> a session to retrieve devices 
 *      </li> 
 *      <li> <code> DeviceQuerySession: </code> a session to query for 
 *      devicess </li> 
 *      <li> <code> DeviceSearchSession: </code> a session to search for 
 *      devices </li> 
 *      <li> <code> DeviceAdminSession: </code> a session to create and delete 
 *      devices </li> 
 *      <li> <code> DeviceNotificationSession: </code> a session to receive 
 *      notifications pertaining to device changes </li> 
 *      <li> <code> DeviceSystemSession: </code> a session to look up device 
 *      system mappings </li> 
 *      <li> <code> DeviceSystemAssignmentSession: </code> a session to manage 
 *      device to system mappings </li> 
 *      <li> <code> DeviceSmartSystemSession: </code> a session to manage 
 *      dynamic systems of devices </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ControllerLookupSession: </code> a session to retrieve 
 *      controllers </li> 
 *      <li> <code> ControllerQuerySession: </code> a session to query for 
 *      controllers </li> 
 *      <li> <code> ControllerSearchSession: </code> a session to search for 
 *      controllers </li> 
 *      <li> <code> ControllerAdminSession: </code> a session to create and 
 *      delete controllers </li> 
 *      <li> <code> ControllerNotificationSession: </code> a session to 
 *      receive notifications pertaining to controller changes </li> 
 *      <li> <code> ControllerSystemSession: </code> a session to look up 
 *      controller system mappings </li> 
 *      <li> <code> ControllerSystemAssignmentSession: </code> a session to 
 *      manage controller to system mappings </li> 
 *      <li> <code> ControllerSmartSystemSession: </code> a session to manage 
 *      dynamic systems of controllers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> InputLookupSession: </code> a session to retrieve inputs 
 *      </li> 
 *      <li> <code> InputQuerySession: </code> a session to query for inputs 
 *      </li> 
 *      <li> <code> InputSearchSession: </code> a session to search for inputs 
 *      </li> 
 *      <li> <code> InputAdminSession: </code> a session to create and delete 
 *      inputs </li> 
 *      <li> <code> InputNotificationSession: </code> a session to receive 
 *      notifications pertaining to input changes </li> 
 *      <li> <code> InputSystemSession: </code> a session to look up input 
 *      system mappings </li> 
 *      <li> <code> InputSystemAssignmentSession: </code> a session to manage 
 *      inputs to system mappings </li> 
 *      <li> <code> InputSmartSystemSession: </code> a session to manage 
 *      dynamic systems of inputs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SettingLookupSession: </code> a session to retrieve 
 *      settings </li> 
 *      <li> <code> SettingQuerySession: </code> a session to query for 
 *      settings </li> 
 *      <li> <code> SettingSearchSession: </code> a session to search for 
 *      settings </li> 
 *      <li> <code> SettingAdminSession: </code> a session to create and 
 *      delete settings </li> 
 *      <li> <code> SettingNotificationSession: </code> a session to receive 
 *      notifications pertaining to setting changes </li> 
 *      <li> <code> SettingSystemsSession: </code> a session to look up 
 *      setting systems mappings </li> 
 *      <li> <code> SettingSystemAssignmentSession: </code> a session to 
 *      manage setting to system mappings </li> 
 *      <li> <code> SettingSmartSystemSession: </code> a session to manage 
 *      dynamic systems of settings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SceneLookupSession: </code> a session to retrieve scenes 
 *      </li> 
 *      <li> <code> SceneQuerySession: </code> a session to query for scenes 
 *      </li> 
 *      <li> <code> SceneSearchSession: </code> a session to search for scenes 
 *      </li> 
 *      <li> <code> SceneAdminSession: </code> a session to create and delete 
 *      scenes </li> 
 *      <li> <code> SceneNotificationSession: </code> a session to receive 
 *      notifications pertaining to scene changes </li> 
 *      <li> <code> SceneSystemsSession: </code> a session to look up scene 
 *      systems mappings </li> 
 *      <li> <code> SceneSystemAssignmentSession: </code> a session to manage 
 *      scene to system mappings </li> 
 *      <li> <code> SceneSmartSystemSession: </code> a session to manage 
 *      dynamic systems of scenes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> TriggerLookupSession: </code> a session to retrieve 
 *      triggers </li> 
 *      <li> <code> TriggerQuerySession: </code> a session to query for 
 *      triggers </li> 
 *      <li> <code> TriggerSearchSession: </code> a session to search for 
 *      triggers </li> 
 *      <li> <code> TriggerAdminSession: </code> a session to create and 
 *      delete triggers </li> 
 *      <li> <code> TriggerNotificationSession: </code> a session to receive 
 *      notifications pertaining to trigger changes </li> 
 *      <li> <code> TriggerSystemSession: </code> a session to look up 
 *      mappings of triggers to systems </li> 
 *      <li> <code> TriggerSystemAssignmentSession: </code> a session to 
 *      manage trigger to system mappings </li> 
 *      <li> <code> TriggerSmartSystemSession: </code> a session to manage 
 *      dynamic systems of triggers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ActionGroupLookupSession: </code> a session to retrieve 
 *      action groups </li> 
 *      <li> <code> ActionGroupQuerySession: </code> a session to query for 
 *      action groups </li> 
 *      <li> <code> ActionGroupSearchSession: </code> a session to search for 
 *      action groups </li> 
 *      <li> <code> ActionGroupAdminSession: </code> a session to create and 
 *      delete action groups </li> 
 *      <li> <code> ActionGroupNotificationSession: </code> a session to 
 *      receive notifications pertaining to action group changes </li> 
 *      <li> <code> ActionGroupSystemSession: </code> a session to look up 
 *      mappings of action groups to systems </li> 
 *      <li> <code> ActionGroupSystemAssignmentSession: </code> a session to 
 *      manage action group to system mappings </li> 
 *      <li> <code> ActionGroupSmartSystemSession: </code> a session to manage 
 *      dynamic systems of action groups </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SystemLookupSession: </code> a session to retrieve systems 
 *      </li> 
 *      <li> <code> SystemQuerySession: </code> a session to search for 
 *      systems </li> 
 *      <li> <code> SystemSearchSession: </code> a session to search for 
 *      systems </li> 
 *      <li> <code> SystemAdminSession: </code> a session to create and delete 
 *      systems </li> 
 *      <li> <code> SystemNotificationSession: </code> a session to receive 
 *      notifications pertaining to system changes </li> 
 *      <li> <code> SystemHierarchySession: </code> a session to traverse a 
 *      hierarchy of system </li> 
 *      <li> <code> SystemHierarchyDesignSession: </code> a session to manage 
 *      a system hierarchy </li> 
 *  </ul>
 *  
 */

public interface ControlManager
    extends org.osid.OsidManager,
            org.osid.control.ControlProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the device lookup 
     *  service. 
     *
     *  @return a <code> DeviceLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceLookup() </code> is <code> true. </code> 
     */

    public org.osid.control.DeviceLookupSession getDeviceLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device lookup 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> DeviceLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.DeviceLookupSession getDeviceLookupSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device query 
     *  service. 
     *
     *  @return a <code> DeviceQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.DeviceQuerySession getDeviceQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device query 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> DeviceQuerySession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.DeviceQuerySession getDeviceQuerySessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device search 
     *  service. 
     *
     *  @return a <code> DeviceSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceSearch() </code> is <code> true. </code> 
     */

    public org.osid.control.DeviceSearchSession getDeviceSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device search 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> DeviceSearchSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.DeviceSearchSession getDeviceSearchSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device 
     *  administration service. 
     *
     *  @return a <code> DeviceAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.DeviceAdminSession getDeviceAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> DeviceAdminSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.DeviceAdminSession getDeviceAdminSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device 
     *  notification service. 
     *
     *  @param  deviceReceiver the notification callback 
     *  @return a <code> DeviceNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> deviceReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.DeviceNotificationSession getDeviceNotificationSession(org.osid.control.DeviceReceiver deviceReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the device 
     *  notification service for the given system. 
     *
     *  @param  deviceReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> DeviceNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> deviceReceiver </code> 
     *          or <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.DeviceNotificationSession getDeviceNotificationSessionForSystem(org.osid.control.DeviceReceiver deviceReceiver, 
                                                                                            org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup device/system mappings. 
     *
     *  @return a <code> DeviceSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDeviceSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.DeviceSystemSession getDeviceSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning devices 
     *  to systems. 
     *
     *  @return a <code> DeviceSystemAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceSystemAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.DeviceSystemAssignmentSession getDeviceSystemAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage device smart systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> DeviceSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDeviceSmartSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDeviceSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.DeviceSmartSystemSession getDeviceSmartSystemSession(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  lookup service. 
     *
     *  @return a <code> ControllerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerLookup() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerLookupSession getControllerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> ControllerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ControllerLookupSession getControllerLookupSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  query service. 
     *
     *  @return a <code> ControllerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerQuerySession getControllerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  query service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> ControllerQuerySession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ControllerQuerySession getControllerQuerySessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  search service. 
     *
     *  @return a <code> ControllerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerSearch() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerSearchSession getControllerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  search service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> ControllerSearchSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ControllerSearchSession getControllerSearchSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  administration service. 
     *
     *  @return a <code> ControllerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerAdminSession getControllerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> ControllerAdminSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ControllerAdminSession getControllerAdminSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  notification service. 
     *
     *  @param  controllerReceiver the notification callback 
     *  @return a <code> ControllerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> controllerReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ControllerNotificationSession getControllerNotificationSession(org.osid.control.ControllerReceiver controllerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the controller 
     *  notification service for the given system. 
     *
     *  @param  controllerReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> ControllerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> controllerReceiver 
     *          </code> or <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ControllerNotificationSession getControllerNotificationSessionForSystem(org.osid.control.ControllerReceiver controllerReceiver, 
                                                                                                    org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup controller/system 
     *  mappings. 
     *
     *  @return a <code> ControllerSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerSystemSession getControllerSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  controllers to systems. 
     *
     *  @return a <code> ControllerSystemAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerSystemAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.ControllerSystemAssignmentSession getControllerSystemAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage controller smart 
     *  systems. 
     *
     *  @param  systemId the <code> Id </code> of the system 
     *  @return a <code> ControllerSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerSmartSystem() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ControllerSmartSystemSession getControllerSmartSystemSession(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input lookup 
     *  service. 
     *
     *  @return an <code> InputLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputLookup() </code> is <code> true. </code> 
     */

    public org.osid.control.InputLookupSession getInputLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input lookup 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> InputLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.InputLookupSession getInputLookupSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input query 
     *  service. 
     *
     *  @return an <code> InputQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.InputQuerySession getInputQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input query 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> InputQuerySession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.InputQuerySession getInputQuerySessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input search 
     *  service. 
     *
     *  @return an <code> InputSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputSearch() </code> is <code> true. </code> 
     */

    public org.osid.control.InputSearchSession getInputSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input search 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> InputSearchSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.InputSearchSession getInputSearchSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input 
     *  administration service. 
     *
     *  @return an <code> InputAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.InputAdminSession getInputAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> InputAdminSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.InputAdminSession getInputAdminSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input 
     *  notification service. 
     *
     *  @param  inputReceiver the notification callback 
     *  @return an <code> InputNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> inputReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.InputNotificationSession getInputNotificationSession(org.osid.control.InputReceiver inputReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the input 
     *  notification service for the given system. 
     *
     *  @param  inputReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> InputNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> inputReceiver </code> or 
     *          <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.InputNotificationSession getInputNotificationSessionForSystem(org.osid.control.InputReceiver inputReceiver, 
                                                                                          org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup input/system mappings. 
     *
     *  @return an <code> InputSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInputSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.InputSystemSession getInputSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning inputs 
     *  to systems. 
     *
     *  @return an <code> InputSystemAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputSystemAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.InputSystemAssignmentSession getInputSystemAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage input smart systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> InputSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputSmartSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputSmartSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.InputSmartSystemSession getInputSmartSystemSession(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting lookup 
     *  service. 
     *
     *  @return a <code> SettingLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingLookup() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingLookupSession getSettingLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting lookup 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the system 
     *  @return a <code> SettingLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SettingLookupSession getSettingLookupSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting query 
     *  service. 
     *
     *  @return a <code> SettingQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingQuerySession getSettingQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting query 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SettingQuerySession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SettingQuerySession getSettingQuerySessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting search 
     *  service. 
     *
     *  @return a <code> SettingSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingSearch() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingSearchSession getSettingSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting search 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SettingSearchSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SettingSearchSession getSettingSearchSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting 
     *  administration service. 
     *
     *  @return a <code> SettingAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingAdminSession getSettingAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> Dostributor 
     *          </code> 
     *  @return a <code> SettingAdminSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SettingAdminSession getSettingAdminSessionForInput(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting 
     *  notification service. 
     *
     *  @param  settingReceiver the notification callback 
     *  @return a <code> SettingNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> settingReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSettingNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SettingNotificationSession getSettingNotificationSession(org.osid.control.SettingReceiver settingReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the setting 
     *  notification service for the given system. 
     *
     *  @param  settingReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SettingNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> settingReceiver </code> 
     *          or <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSettingNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SettingNotificationSession getSettingNotificationSessionForSystem(org.osid.control.SettingReceiver settingReceiver, 
                                                                                              org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup setting/system mappings. 
     *
     *  @return a <code> SettingSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSettingSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingSystemSession getSettingSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning settings 
     *  to systems. 
     *
     *  @return a <code> SettingSystemAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSettingSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingSystemAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SettingSystemAssignmentSession getSettingSystemAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SettingSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSettingSmartSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SettingSmartSystemSession getSettingSmartSystemSession(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene lookup 
     *  service. 
     *
     *  @return a <code> SceneLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneLookup() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneLookupSession getSceneLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene lookup 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the system 
     *  @return a <code> SceneLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SceneLookupSession getSceneLookupSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene query 
     *  service. 
     *
     *  @return a <code> SceneQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneQuerySession getSceneQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene query 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SceneQuerySession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SceneQuerySession getSceneQuerySessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene search 
     *  service. 
     *
     *  @return a <code> SceneSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneSearch() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneSearchSession getSceneSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene search 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SceneSearchSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SceneSearchSession getSceneSearchSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene 
     *  administration service. 
     *
     *  @return a <code> SceneAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneAdminSession getSceneAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> Dostributor 
     *          </code> 
     *  @return a <code> SceneAdminSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SceneAdminSession getSceneAdminSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene 
     *  notification service. 
     *
     *  @param  sceneReceiver the notification callback 
     *  @return a <code> SceneNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> sceneReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSceneNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SceneNotificationSession getSceneNotificationSession(org.osid.control.SceneReceiver sceneReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the scene 
     *  notification service for the given system. 
     *
     *  @param  sceneReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SceneNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> sceneReceiver </code> or 
     *          <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSceneNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.SceneNotificationSession getSceneNotificationSessionForSystem(org.osid.control.SceneReceiver sceneReceiver, 
                                                                                          org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup scene/system mappings. 
     *
     *  @return a <code> SceneSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSceneSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneSystemSession getSceneSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning scenes 
     *  to systems. 
     *
     *  @return a <code> SceneSystemAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSceneSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneSystemAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SceneSystemAssignmentSession getSceneSystemAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> SceneSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSceneSmartSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneSmartSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneSmartSystemSession getSceneSmartSystemSession(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger lookup 
     *  service. 
     *
     *  @return a <code> TriggerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerLookup() </code> is <code> true. </code> 
     */

    public org.osid.control.TriggerLookupSession getTriggerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger lookup 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> TriggerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.TriggerLookupSession getTriggerLookupSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger query 
     *  service. 
     *
     *  @return a <code> TriggerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.TriggerQuerySession getTriggerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger query 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> TriggerQuerySession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.TriggerQuerySession getTriggerQuerySessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger search 
     *  service. 
     *
     *  @return a <code> TriggerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerSearch() </code> is <code> true. </code> 
     */

    public org.osid.control.TriggerSearchSession getTriggerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger search 
     *  service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> TriggerSearchSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.TriggerSearchSession getTriggerSearchSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  administration service. 
     *
     *  @return a <code> TriggerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.TriggerAdminSession getTriggerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> TriggerAdminSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.TriggerAdminSession getTriggerAdminSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  notification service. 
     *
     *  @param  triggerReceiver the notification callback 
     *  @return a <code> TriggerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> triggerReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.TriggerNotificationSession getTriggerNotificationSession(org.osid.control.TriggerReceiver triggerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the trigger 
     *  notification service for the given system. 
     *
     *  @param  triggerReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> TriggerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> triggerReceiver </code> 
     *          or <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.TriggerNotificationSession getTriggerNotificationSessionForSystem(org.osid.control.TriggerReceiver triggerReceiver, 
                                                                                              org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup trigger/system mappings. 
     *
     *  @return a <code> TriggerSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTriggerSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerSystem() </code> is <code> true. </code> 
     */

    public org.osid.control.TriggerSystemSession getTriggerSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning triggers 
     *  to systems. 
     *
     *  @return a <code> TriggerSystemAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerSystemAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.TriggerSystemAssignmentSession getTriggerSystemAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage trigger smart systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return a <code> TriggerSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTriggerSmartSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTriggerSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.TriggerSmartSystemSession getTriggerSmartSystemSession(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  lookup service. 
     *
     *  @return an <code> ActionGroupLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ActionGroupLookupSession getActionGroupLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  lookup service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> ActionGroupLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ActionGroupLookupSession getActionGroupLookupSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  query service. 
     *
     *  @return an <code> ActionGroupQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ActionGroupQuerySession getActionGroupQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  query service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> ActionGroupQuerySession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ActionGroupQuerySession getActionGroupQuerySessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  search service. 
     *
     *  @return an <code> ActionGroupSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ActionGroupSearchSession getActionGroupSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  search service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> ActionGroupSearchSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ActionGroupSearchSession getActionGroupSearchSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  administration service. 
     *
     *  @return an <code> ActionGroupAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.ActionGroupAdminSession getActionGroupAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  administration service for the given system. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> ActionGroupAdminSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ActionGroupAdminSession getActionGroupAdminSessionForSystem(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  notification service. 
     *
     *  @param  actionGroupReceiver the notification callback 
     *  @return an <code> ActionGroupNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> actionGroupReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ActionGroupNotificationSession getActionGroupNotificationSession(org.osid.control.ActionGroupReceiver actionGroupReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the action group 
     *  notification service for the given system. 
     *
     *  @param  actionGroupReceiver the notification callback 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> ActionGroupNotificationSession </code> 
     *  @throws org.osid.NotFoundException no system found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> actionGroupReceiver 
     *          </code> or <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.control.ActionGroupNotificationSession getActionGroupNotificationSessionForSystem(org.osid.control.ActionGroupReceiver actionGroupReceiver, 
                                                                                                      org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup action group/system 
     *  mappings. 
     *
     *  @return an <code> ActionGroupSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupSystem() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ActionGroupSystemSession getActionGroupSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning action 
     *  groups to systems. 
     *
     *  @return an <code> ActionGroupSystemAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupSystemAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupSystemAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.control.ActionGroupSystemAssignmentSession getActionGroupSystemAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage action group smart 
     *  systems. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return an <code> ActionGroupSmartSystemSession </code> 
     *  @throws org.osid.NotFoundException no <code> System </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupSmartSystem() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupSmartSystem() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.ActionGroupSmartSystemSession getActionGroupSmartSystemSession(org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the system lookup 
     *  service. 
     *
     *  @return a <code> SystemLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSystemLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemLookup() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemLookupSession getSystemLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the system query 
     *  service. 
     *
     *  @return a <code> SystemQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSystemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemQuerySession getSystemQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the system search 
     *  service. 
     *
     *  @return a <code> SystemSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSystemSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemSearch() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemSearchSession getSystemSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the system 
     *  administrative service. 
     *
     *  @return a <code> SystemAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSystemAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemAdmin() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemAdminSession getSystemAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the system 
     *  notification service. 
     *
     *  @param  systemReceiver the notification callback 
     *  @return a <code> SystemNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> systemReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSystemNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SystemNotificationSession getSystemNotificationSession(org.osid.control.SystemReceiver systemReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the system 
     *  hierarchy service. 
     *
     *  @return a <code> SystemHierarchySession </code> for systems 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSystemHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemHierarchySession getSystemHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the system 
     *  hierarchy design service. 
     *
     *  @return a <code> HierarchyDesignSession </code> for systems 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSystemHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.control.SystemHierarchyDesignSession getSystemHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ControlBatchManager. </code> 
     *
     *  @return a <code> ControlBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsControlBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControlBatch() </code> is <code> true. </code> 
     */

    public org.osid.control.batch.ControlBatchManager getControlBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ControlRulesManager. </code> 
     *
     *  @return a <code> ControlRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsControlRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControlRules() </code> is <code> true. </code> 
     */

    public org.osid.control.rules.ControlRulesManager getControlRulesManager()
        throws org.osid.OperationFailedException;
}
