//
// org.osid.control.Controller
//
//     The OSID Java specification for org.osid.control.Controller.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>A <code> Controller </code> is an addressable <code> Operable </code> 
 *  that executes an action. <code> Controllers </code> are related to <code> 
 *  Devices </code> through <code> Inputs. </code> A few typical controller 
 *  modes are defined such as a toggle, a variable amount, and a set of 
 *  discreet states. Other kinds of controllers may be defined in a <code> 
 *  ControllerRecord. </code> </p>
 */

public interface Controller
    extends org.osid.OsidObject,
            org.osid.Operable {


    /**
     *  Gets the controller address. 
     *
     *  @return the address 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getAddress();


    /**
     *  Gets the controller model <code> Id. </code> 
     *
     *  @return the model <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getModelId();


    /**
     *  Gets the controller model. 
     *
     *  @return the model 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Model getModel()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the controller version. 
     *
     *  @return the version 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Version getVersion();


    /**
     *  Tests if this controller can be turned on and off. A controller that 
     *  may also be variable if the minimum and maximum settings correspond to 
     *  ON and OFF. A controller that defines discreet states may also presnet 
     *  itself as toggleable if there are ON and OFF states. 
     *
     *  @return <code> true </code> if this controller can be toggled, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isToggleable();


    /**
     *  Tests if this controller supports levels between on and off. A 
     *  variable controller may also be toggleable but does not define 
     *  discreet states. 
     *
     *  @return <code> true </code> if this controller has levels, false 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isVariable();


    /**
     *  Tests if the levels represent a percentage. 
     *
     *  @return <code> true </code> if this controller has levels as a 
     *          percentage, false otherwise 
     *  @throws org.osid.IllegalStateException <code> isVariable() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isVariableByPercentage();


    /**
     *  Gets the minimum level. 
     *
     *  @return the minimum level 
     *  @throws org.osid.IllegalStateException <code> isVariable() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getVariableMinimum();


    /**
     *  Gets the maximum level. 
     *
     *  @return the maximum level 
     *  @throws org.osid.IllegalStateException <code> isVariable() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getVariableMaximum();


    /**
     *  Gets the increments in the level. 
     *
     *  @return the increment 
     *  @throws org.osid.IllegalStateException <code> isVariable() </code> is 
     *          <code> false </code> or <code> isVariableByPercentage() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getVariableIncrement();


    /**
     *  Tests if this controller supports discreet states. A state controller 
     *  may also be toggleable but not variable. 
     *
     *  @return <code> true </code> if this controller has discreet states, 
     *          false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDiscreetStates();


    /**
     *  Gets the discreet <code> State </code> <code> Ids. </code> 
     *
     *  @return a list of state <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasDiscreetStates() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getDiscreetStateIds();


    /**
     *  Gets the discreet <code> States. </code> 
     *
     *  @return a list of states 
     *  @throws org.osid.IllegalStateException <code> hasDiscreetStates() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getDiscreetStates()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this controller supports a ramp rate for a transition from 
     *  off to on. 
     *
     *  @return <code> true </code> if this controller supports ramp rates, 
     *          false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isRampable();


    /**
     *  Gets the controller record corresponding to the given <code> 
     *  Controller </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  controllerRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(controllerRecordType) </code> is <code> true </code> . 
     *
     *  @param  controllerRecordType the type of controller record to retrieve 
     *  @return the controller record 
     *  @throws org.osid.NullArgumentException <code> controllerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(controllerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ControllerRecord getControllerRecord(org.osid.type.Type controllerRecordType)
        throws org.osid.OperationFailedException;
}
