//
// org.osid.control.ControllerQuery
//
//     The OSID Java specification for org.osid.control.ControllerQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the query for searching controllers. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface ControllerQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidOperableQuery {


    /**
     *  Mathes an address. 
     *
     *  @param  address an address 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> address </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAddress(String address, 
                             org.osid.type.Type stringMatchType, boolean match);


    /**
     *  Clears the address query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressTerms();


    /**
     *  Sets the model <code> Id </code> for this query. 
     *
     *  @param  modelId the model <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> modelId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchModelId(org.osid.id.Id modelId, boolean match);


    /**
     *  Clears the model <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelIdTerms();


    /**
     *  Tests if a <code> ModelQuery </code> is available. 
     *
     *  @return <code> true </code> if a model query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelQuery();


    /**
     *  Gets the query for a <code> Model. </code> Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the model query 
     *  @throws org.osid.UnimplementedException <code> supportsModelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelQuery getModelQuery();


    /**
     *  Matches any models. 
     *
     *  @param  match <code> true </code> to match controllers with models, 
     *          <code> false </code> to match controllers with no model 
     *          defined 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyModel(boolean match);


    /**
     *  Clears the model query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelTerms();


    /**
     *  Sets the version for this query. 
     *
     *  @param  version the version 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> version </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVersion(org.osid.installation.Version version, 
                             boolean match);


    /**
     *  Matches controllers with any version. 
     *
     *  @param  match <code> true </code> to match controllers with versions, 
     *          <code> false </code> to match controllers with no version 
     *          defined 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyVersion(boolean match);


    /**
     *  Clears the version query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersionTerms();


    /**
     *  Matches controllers with versions including and more recent than the 
     *  given version. 
     *
     *  @param  version the version 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> version </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVersionSince(org.osid.installation.Version version, 
                                  boolean match);


    /**
     *  Clears the version since query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersionSinceTerms();


    /**
     *  Matches toggleable controllers. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchToggleable(boolean match);


    /**
     *  Clears the toggleable query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearToggleableTerms();


    /**
     *  Matches variable controllers. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVariable(boolean match);


    /**
     *  Clears the variable query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableTerms();


    /**
     *  Matches variable by percentage controllers. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVariableByPercentage(boolean match);


    /**
     *  Clears the variable query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableByPercentageTerms();


    /**
     *  Matches variable minimums between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start or end </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVariableMinimum(java.math.BigDecimal start, 
                                     java.math.BigDecimal end, boolean match);


    /**
     *  Matches any variable minimums. 
     *
     *  @param  match <code> true </code> to match controllers with variable 
     *          minimums, <code> false </code> to match controllers with no 
     *          variable minimums 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyVariableMinimum(boolean match);


    /**
     *  Clears the variable minimum query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableMinimumTerms();


    /**
     *  Matches variable maximums between the given range inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start or end </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVariableMaximum(java.math.BigDecimal start, 
                                     java.math.BigDecimal end, boolean match);


    /**
     *  Matches any variable maximums. 
     *
     *  @param  match <code> true </code> to match controllers with variable 
     *          maximums, <code> false </code> to match controllers with no 
     *          variable maximums 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyVariableMaximum(boolean match);


    /**
     *  Clears the variable maximum query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableMaximumTerms();


    /**
     *  Matches discreet states controllers. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDiscreetStates(boolean match);


    /**
     *  Clears the discreet states query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStatesTerms();


    /**
     *  Sets the state <code> Id </code> for this query. 
     *
     *  @param  stateId the state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDiscreetStateId(org.osid.id.Id stateId, boolean match);


    /**
     *  Clears the state <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStateIdTerms();


    /**
     *  Tests if a <code> StateQuery </code> is available. 
     *
     *  @return <code> true </code> if a state query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDiscreetStateQuery();


    /**
     *  Gets the query for a <code> State. </code> Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the state query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDiscreetStateQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDiscreetStateQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.StateQuery getDiscreetStateQuery();


    /**
     *  Matches any discreet states. 
     *
     *  @param  match <code> true </code> to match controllers with discreet 
     *          states, <code> false </code> to match controllers with no 
     *          discreet states 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDiscreetState(boolean match);


    /**
     *  Clears the state query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStateTerms();


    /**
     *  Sets the system <code> Id </code> for this query. 
     *
     *  @param  systemId the system <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSystemId(org.osid.id.Id systemId, boolean match);


    /**
     *  Clears the system <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemIdTerms();


    /**
     *  Tests if a <code> SystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a system query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemQuery();


    /**
     *  Gets the query for a system. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the system query 
     *  @throws org.osid.UnimplementedException <code> supportsSystemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemQuery getSystemQuery();


    /**
     *  Clears the system query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemTerms();


    /**
     *  Gets the controller query record corresponding to the given <code> 
     *  Controller </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  controllerRecordType a controller record type 
     *  @return the controller query record 
     *  @throws org.osid.NullArgumentException <code> controllerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(controllerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.ControllerQueryRecord getControllerQueryRecord(org.osid.type.Type controllerRecordType)
        throws org.osid.OperationFailedException;
}
