//
// org.osid.control.InputSearchSession
//
//     The OSID Java specification for org.osid.control.InputSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session provides methods for searching among <code> Input </code> 
 *  objects. The search query is constructed using the <code> InputQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getInputsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Inputs. </code> A more advanced search may be 
 *  performed with <code> getInputsBySearch(). </code> It accepts a <code> 
 *  InputSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getInputsBySearch() </code> returns a <code> InputSearchResults </code> 
 *  that can be used to access the resulting <code> InputList </code> or be 
 *  used to perform a search within the result set through <code> InputSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated trigger view: searches include inputs in triggers of 
 *      which this trigger is an ancestor in the trigger hierarchy </li> 
 *      <li> isolated trigger view: searches are restricted to inputs in this 
 *      trigger </li> 
 *  </ul>
 *  
 *  
 *  <p> Inputs may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> InputQuery. </code> 
 *  </p>
 */

public interface InputSearchSession
    extends org.osid.control.InputQuerySession {


    /**
     *  Gets an input search. 
     *
     *  @return the input search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.InputSearch getInputSearch();


    /**
     *  Gets an input search order. The <code> InputSearchOrder </code> is 
     *  supplied to a <code> InputSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the input search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.InputSearchOrder getInputSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  inputQuery the input query 
     *  @param  inputSearch the input search 
     *  @return the input search results 
     *  @throws org.osid.NullArgumentException <code> inputQuery </code> or 
     *          <code> inputSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inputQuery </code> or 
     *          <code> inputSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.InputSearchResults getInputsBySearch(org.osid.control.InputQuery inputQuery, 
                                                                 org.osid.control.InputSearch inputSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an input query from an inspector. The inspector is available from 
     *  a <code> InputSearchResults. </code> 
     *
     *  @param  inputQueryInspector an input query inspector 
     *  @return the input query 
     *  @throws org.osid.NullArgumentException <code> inputQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> inputQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.InputQuery getInputQueryFromInspector(org.osid.control.InputQueryInspector inputQueryInspector);
}
