//
// org.osid.control.Setting
//
//     The OSID Java specification for org.osid.control.Setting.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>An <code> Setting </code> is a preset value for a <code> Controller. 
 *  </code> </p>
 */

public interface Setting
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the controller <code> Id. </code> 
     *
     *  @return the controller <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getControllerId();


    /**
     *  Gets the controller. 
     *
     *  @return the controller 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.Controller getController()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the toggleable controller is on. 
     *
     *  @return <code> true </code> if the controller is on, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          Controller.isToggleable() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOn();


    /**
     *  Tests if the toggleable controller is off. 
     *
     *  @return <code> true </code> if the controller is iff, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> 
     *          Controller.isToggleable() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOff();


    /**
     *  Gets the level amount on a fixed scale. 
     *
     *  @return the level amount 
     *  @throws org.osid.IllegalStateException <code> Controller.isVariable() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getVariableAmount();


    /**
     *  Gets the discreet <code> State </code> <code> Id. </code> 
     *
     *  @return the state <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          Controller.hasDiscreetStates() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDiscreetStateId();


    /**
     *  Gets the discreet <code> State. </code> 
     *
     *  @return the state 
     *  @throws org.osid.IllegalStateException <code> 
     *          Controller.hasDiscreetStates() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.State getDiscreetState()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the ramp rate from off to on to use for the transition for this 
     *  setting. If the ramp rate is 10 seconds and the variable percentage is 
     *  50%, then the actual transition duration from off would be 5 seconds 
     *  for a linear controller. 
     *
     *  @return the ramp rate 
     *  @throws org.osid.IllegalStateException <code> Controller.isRampable() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getRampRate();


    /**
     *  Gets the setting record corresponding to the given <code> Setting 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> settingRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(settingRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  settingRecordType the type of setting record to retrieve 
     *  @return the setting record 
     *  @throws org.osid.NullArgumentException <code> settingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(settingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.SettingRecord getSettingRecord(org.osid.type.Type settingRecordType)
        throws org.osid.OperationFailedException;
}
