//
// org.osid.control.SettingForm
//
//     The OSID Java specification for org.osid.control.SettingForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the form for creating and updating settings. <code> </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  SettingAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface SettingForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the on status. 
     *
     *  @return metadata for the on status 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOnMetadata();


    /**
     *  Sets the on status. 
     *
     *  @param  on the new on status 
     *  @throws org.osid.InvalidArgumentException <code> on </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOn(boolean on);


    /**
     *  Removes the on status. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOn();


    /**
     *  Gets the metadata for the off status. 
     *
     *  @return metadata for the off status 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOffMetadata();


    /**
     *  Sets the off status. 
     *
     *  @param  off the new off status 
     *  @throws org.osid.InvalidArgumentException <code> off </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOff(boolean off);


    /**
     *  Removes the off status. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOff();


    /**
     *  Gets the metadata for the percentage amount. 
     *
     *  @return metadata for the percentage amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVariablePercentageMetadata();


    /**
     *  Sets the percentage amount. 
     *
     *  @param  amount the new percentage amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> amount </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVariablePercentage(java.math.BigDecimal amount);


    /**
     *  Removes the percentage amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariablePercentage();


    /**
     *  Gets the metadata for the variable amount. 
     *
     *  @return metadata for the variable amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVariableAmountMetadata();


    /**
     *  Sets the variable amount. 
     *
     *  @param  amount the new variable amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> amount </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVariableAmount(java.math.BigDecimal amount);


    /**
     *  Removes the variable amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVariableAmount();


    /**
     *  Gets the metadata for the state. 
     *
     *  @return metadata for the state 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDiscreetMetadata();


    /**
     *  Sets the state. 
     *
     *  @param  stateId the new state 
     *  @throws org.osid.InvalidArgumentException <code> stateId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDiscreetState(org.osid.id.Id stateId);


    /**
     *  Removes the discreet state. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetState();


    /**
     *  Gets the metadata for the ramp rate. 
     *
     *  @return metadata for the ramp rate 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRampRateMetadata();


    /**
     *  Sets the ramp rate. 
     *
     *  @param  rate the new ramp rate 
     *  @throws org.osid.InvalidArgumentException <code> rate </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> rate </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRampRate(org.osid.calendaring.Duration rate);


    /**
     *  Removes the ramp rate. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRampRate();


    /**
     *  Gets the <code> SettingFormRecord </code> corresponding to the given 
     *  setting record <code> Type. </code> 
     *
     *  @param  settingRecordType a setting record type 
     *  @return the setting form record 
     *  @throws org.osid.NullArgumentException <code> settingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(settingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.SettingFormRecord getSettingFormRecord(org.osid.type.Type settingRecordType)
        throws org.osid.OperationFailedException;
}
