//
// org.osid.control.SettingSearchSession
//
//     The OSID Java specification for org.osid.control.SettingSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This session provides methods for searching among <code> Setting 
 *  </code> objects. The search query is constructed using the <code> 
 *  SettingQuery. </code> </p> 
 *  
 *  <p> <code> getSettingsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Settings. </code> A more advanced search may be 
 *  performed with <code> getSettingsBySearch(). </code> It accepts an <code> 
 *  SettingSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getSettingsBySearch() </code> returns an <code> 
 *  SettingSearchResults </code> that can be used to access the resulting 
 *  <code> SettingList </code> or be used to perform a search within the 
 *  result set through <code> SettingSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated system view: searches include settings in systems of 
 *      which this system is an ancestor in the system hierarchy </li> 
 *      <li> isolated system view: searches are restricted to settings in this 
 *      system </li> 
 *  </ul>
 *  
 *  
 *  <p> Settings may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> SettingQuery. </code> 
 *  </p>
 */

public interface SettingSearchSession
    extends org.osid.control.SettingQuerySession {


    /**
     *  Gets a setting search. 
     *
     *  @return the setting search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SettingSearch getSettingSearch();


    /**
     *  Gets a setting search order. The <code> SettingSearchOrder </code> is 
     *  supplied to a <code> SettingSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the setting search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SettingSearchOrder getSettingSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  settingQuery the setting query 
     *  @param  settingSearch the setting search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> settingQuery </code> or 
     *          <code> settingSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> settingQuery </code> or 
     *          <code> settingSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SettingSearchResults getSettingsBySearch(org.osid.control.SettingQuery settingQuery, 
                                                                     org.osid.control.SettingSearch settingSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a setting query from an inspector. The inspector is available 
     *  from a <code> SettingSearchResults. </code> 
     *
     *  @param  settingQueryInspector a setting query inspector 
     *  @return the setting query 
     *  @throws org.osid.NullArgumentException <code> settingQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> settingQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SettingQuery getSettingQueryFromInspector(org.osid.control.SettingQueryInspector settingQueryInspector);
}
