//
// org.osid.control.Trigger
//
//     The OSID Java specification for org.osid.control.Trigger.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>A <code> Trigger </code> is an <code> OsidRule </code> that listens to 
 *  events from a <code> Controller. </code> The <code> ActionGroups </code> , 
 *  <code> Scenes </code> and <code> Settings </code> are executed based on 
 *  the event criteria of the <code> Trigger. </code> </p>
 */

public interface Trigger
    extends org.osid.OsidRule,
            org.osid.Subjugateable {


    /**
     *  Gets the controller <code> Id. </code> 
     *
     *  @return the controller <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getControllerId();


    /**
     *  Gets the controller. 
     *
     *  @return the controller 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.Controller getController()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this trigger listens to controller ON events. 
     *
     *  @return <code> true </code> if this is an ON event listener, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean turnedOn();


    /**
     *  Tests if this trigger listens to controller OFF events. 
     *
     *  @return <code> true </code> if this is an OFF event listener, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean turnedOff();


    /**
     *  Tests if this trigger listens to changed variable amount controller 
     *  events. 
     *
     *  @return <code> true </code> if this is a change event listener, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean changedVariableAmount();


    /**
     *  Tests if this trigger listens to events where the variable amount or 
     *  percentage increased to the same or above this value. 
     *
     *  @return the max threshold 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal changedExceedsVariableAmount();


    /**
     *  Tests if this trigger listens to events where the variable amount or 
     *  percentage decreased to the same or below this value. 
     *
     *  @return the max threshold 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal changedDeceedsVariableAmount();


    /**
     *  Tests if this trigger listens to controller state changes. 
     *
     *  @return <code> true </code> if this is a state change event listener, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean changedDiscreetState();


    /**
     *  Tests if this trigger listens to controller events where a state has 
     *  changed to a specific state. 
     *
     *  @return <code> true </code> if this is a state change event, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean changedToDiscreetState();


    /**
     *  Gets the discreet <code> State </code> <code> Id </code> for a changed 
     *  state event. 
     *
     *  @return the state <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> changedToDiscreetState() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDiscreetStateId();


    /**
     *  Gets the discreet <code> State </code> for a changed state event. 
     *
     *  @return the state 
     *  @throws org.osid.IllegalStateException <code> changedToDiscreetState() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.State getDiscreetState()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ActionGroup </code> <code> Ids </code> to execute in 
     *  this trigger. Multiple action groups can be executed in the order of 
     *  this list. 
     *
     *  @return the action group <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getActionGroupIds();


    /**
     *  Gets the <code> ActionGroups </code> to execute in this trigger. 
     *  Multiple action groups can be executed in the order of this list. 
     *
     *  @return the action group 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.ActionGroupList getActionGroups()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Scene </code> <code> Ids </code> to execute in this 
     *  trigger. Multiple scenes can be executed in the order of this list. 
     *  This is a shortcut to defining <code> Actions </code> and <code> 
     *  ActionGroups </code> which offer more control in scene execution. 
     *
     *  @return the scene <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSceneIds();


    /**
     *  Gets the <code> Scenes </code> to execute in this trigger. Multiple 
     *  scenes can be executed in the order of this list. This is a shortcut 
     *  to defining <code> Actions </code> and <code> ActionGroups </code> 
     *  which offer more control in scene execution. 
     *
     *  @return the action group 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SceneList getScenes()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Setting </code> <code> Ids </code> to execute in this 
     *  trigger. Multiple settings can be executed in the order of this list. 
     *  This is a shortcut to defining <code> Settings, </code> <code> Actions 
     *  </code> and <code> ActionGroups </code> which offer more control in 
     *  scene and setting execution. 
     *
     *  @return the setting <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSettingIds();


    /**
     *  Gets the <code> Settings </code> to execute in this trigger. Multiple 
     *  settings can be executed in the order of this list. This is a shortcut 
     *  to defining <code> Settings, </code> <code> Actions </code> and <code> 
     *  ActionGroups </code> which offer more control in scene and setting 
     *  execution. 
     *
     *  @return the action group 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.SettingList getSettings()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the trigger record corresponding to the given <code> Trigger 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> triggerRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(triggerRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  triggerRecordType the type of trigger record to retrieve 
     *  @return the trigger record 
     *  @throws org.osid.NullArgumentException <code> triggerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(triggerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.TriggerRecord getTriggerRecord(org.osid.type.Type triggerRecordType)
        throws org.osid.OperationFailedException;
}
