//
// org.osid.control.TriggerForm
//
//     The OSID Java specification for org.osid.control.TriggerForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the form for creating and updating triggers. <code> </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  TriggerAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface TriggerForm
    extends org.osid.OsidRuleForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the ON event listener. 
     *
     *  @return metadata for the ON event listener 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTurnedOnMetadata();


    /**
     *  Sets the ON event listener. 
     *
     *  @param  listen true to listen for ON events, false to not listen to ON 
     *          events 
     *  @throws org.osid.InvalidArgumentException <code> listen </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTurnedOn(boolean listen);


    /**
     *  Removes the ON event listener. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTurnedOn();


    /**
     *  Gets the metadata for the OFF event listener. 
     *
     *  @return metadata for the OFF event listener 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTurnedOffMetadata();


    /**
     *  Sets the OFF event listener. 
     *
     *  @param  listen true to listen for OFF events, false to not listen to 
     *          OFF events 
     *  @throws org.osid.InvalidArgumentException <code> listen </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTurnedOff(boolean listen);


    /**
     *  Removes the OFF event listener. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTurnedOff();


    /**
     *  Gets the metadata for the changed variable amount event listener. 
     *
     *  @return metadata for the changed variable amount event listener 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getChangedVariableAmountMetadata();


    /**
     *  Sets the changed variable amount event listener. 
     *
     *  @param  listen true to listen for changed variable amount events, 
     *          false to not listen to changed variable amount events 
     *  @throws org.osid.InvalidArgumentException <code> listen </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setChangedVariableAmount(boolean listen);


    /**
     *  Removes the changed variable amount event listener. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChangedVariableAmount();


    /**
     *  Gets the metadata for the exceeds variable amount event listener. 
     *
     *  @return metadata for the exceeds variable amount event listener 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getExceedsVariableAmountMetadata();


    /**
     *  Sets the exceeds variable amount event listener. 
     *
     *  @param  threshold the threshold amount 
     *  @throws org.osid.InvalidArgumentException <code> threshold </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> threshold </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setExceedsVariableAmount(java.math.BigDecimal threshold);


    /**
     *  Removes the exceeds variable amount event listener. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExceedsVariableAmount();


    /**
     *  Gets the metadata for the deceeds variable amount event listener. 
     *
     *  @return metadata for the deceeds variable amount event listener 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDeceedsVariableAmountMetadata();


    /**
     *  Sets the deceeds variable amount event listener. 
     *
     *  @param  threshold the threshold amount 
     *  @throws org.osid.InvalidArgumentException <code> threshold </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> threshold </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDeceedsVariableAmount(java.math.BigDecimal threshold);


    /**
     *  Removes the deceeds variable amount event listener. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeceedsVariableAmount();


    /**
     *  Gets the metadata for the changed state event listener. 
     *
     *  @return metadata for the changed state event listener 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getChangedDiscreetStateMetadata();


    /**
     *  Sets the changed state event listener. 
     *
     *  @param  listen true to listen for changed state events, false to not 
     *          listen to changed state events 
     *  @throws org.osid.InvalidArgumentException <code> listen </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setChangedDiscreetState(boolean listen);


    /**
     *  Removes the changed state event listener. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChangedDiscreetState();


    /**
     *  Gets the metadata for the discreet state event listener. 
     *
     *  @return metadata for the discreet state event listener 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDiscreetStateMetadata();


    /**
     *  Sets the discreet state event listener. 
     *
     *  @param  stateId a state <code> Id </code> 
     *  @throws org.osid.InvalidArgumentException <code> stateId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDiscreetState(org.osid.id.Id stateId);


    /**
     *  Removes the discreet state. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetState();


    /**
     *  Gets the metadata for the action groups. 
     *
     *  @return metadata for the action groups 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getActionGroupsMetadata();


    /**
     *  Sets the action groups. 
     *
     *  @param  actionGroupIds action group <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> actionGroupIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> actionGroupIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setActionGroups(org.osid.id.Id[] actionGroupIds);


    /**
     *  Removes the action groups. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionGroup();


    /**
     *  Gets the metadata for the scenes. 
     *
     *  @return metadata for the scenes 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getScenesMetadata();


    /**
     *  Sets the scenes. 
     *
     *  @param  sceneIds the scene <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> sceneIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> sceneIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScenes(org.osid.id.Id[] sceneIds);


    /**
     *  Removes the scenes. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScenes();


    /**
     *  Gets the metadata for the settings. 
     *
     *  @return metadata for the settings 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSettingsMetadata();


    /**
     *  Sets the settings. 
     *
     *  @param  settingIds the setting <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> settingIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> settingIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSettings(org.osid.id.Id[] settingIds);


    /**
     *  Removes the settings. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSettings();


    /**
     *  Gets the <code> TriggerFormRecord </code> corresponding to the given 
     *  trigger record <code> Type. </code> 
     *
     *  @param  triggerRecordType a trigger record type 
     *  @return the trigger form record 
     *  @throws org.osid.NullArgumentException <code> triggerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(triggerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.TriggerFormRecord getTriggerFormRecord(org.osid.type.Type triggerRecordType)
        throws org.osid.OperationFailedException;
}
