//
// org.osid.control.TriggerQuery
//
//     The OSID Java specification for org.osid.control.TriggerQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control;


/**
 *  <p>This is the query for searching triggers. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface TriggerQuery
    extends org.osid.OsidRuleQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the controller <code> Id </code> for this query. 
     *
     *  @param  controllerId a controller <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> controllerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchControllerId(org.osid.id.Id controllerId, boolean match);


    /**
     *  Clears the controller <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearControllerIdTerms();


    /**
     *  Tests if a <code> ControllerQuery </code> is available. 
     *
     *  @return <code> true </code> if a controller query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControllerQuery();


    /**
     *  Gets the query for a controller. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the controller query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsControllerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsControllerQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ControllerQuery getControllerQuery();


    /**
     *  Clears the controller query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearControllerTerms();


    /**
     *  Matches triggers listening for ON events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTurnedOn(boolean match);


    /**
     *  Clears the ON event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTurnedOnTerms();


    /**
     *  Matches triggers listening for OFF events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTurnedOff(boolean match);


    /**
     *  Clears the OFF event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTurnedOffTerms();


    /**
     *  Matches triggers listening for changed amount events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchChangedVariableAmount(boolean match);


    /**
     *  Clears the changed amount event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChangedVariableAmountTerms();


    /**
     *  Matches triggers listening for exceeds amount events between the given 
     *  values inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExceedsVariableAmount(java.math.BigDecimal start, 
                                           java.math.BigDecimal end, 
                                           boolean match);


    /**
     *  Matches triggers with any exceeds variable amount. 
     *
     *  @param  match <code> true </code> to match triggers with any exceeds 
     *          amount, <code> false </code> to match triggers with no exceeds 
     *          amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyExceedsVariableAmount(boolean match);


    /**
     *  Clears the exceeds amount event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExceedsVariableAmountTerms();


    /**
     *  Matches triggers listening for deceeds amount events between the given 
     *  values inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDeceedsVariableAmount(java.math.BigDecimal start, 
                                           java.math.BigDecimal end, 
                                           boolean match);


    /**
     *  Matches triggers with any deceeds variable amount. 
     *
     *  @param  match <code> true </code> to match triggers with any deceeds 
     *          amount, <code> false </code> to match triggers with no deceeds 
     *          amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDeceedsVariableAmount(boolean match);


    /**
     *  Clears the deceeds amount event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeceedsVariableAmountTerms();


    /**
     *  Matches triggers listening for changed state events. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchChangedDiscreetState(boolean match);


    /**
     *  Clears the changed state event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChangedDiscreetStateTerms();


    /**
     *  Sets the state <code> Id </code> for this query. 
     *
     *  @param  stateId a state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDiscreetStateId(org.osid.id.Id stateId, boolean match);


    /**
     *  Clears the discreet state <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStateIdTerms();


    /**
     *  Tests if a <code> StateQuery </code> is available. 
     *
     *  @return <code> true </code> if a discreet state query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDiscreetStateQuery();


    /**
     *  Gets the query for a discreet state. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the discreet state query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDiscreetStateQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDiscreetStateQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.StateQuery getDiscreetStateQuery();


    /**
     *  Matches triggers with any discreet state. 
     *
     *  @param  match <code> true </code> to match triggers with any discreet 
     *          state, <code> false </code> to match triggers with no discreet 
     *          states 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDiscreetState(boolean match);


    /**
     *  Clears the discreet state query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDiscreetStateTerms();


    /**
     *  Sets the action group <code> Id </code> for this query. 
     *
     *  @param  actionGroupId an action group <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActionGroupId(org.osid.id.Id actionGroupId, boolean match);


    /**
     *  Clears the action group <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionGroupIdTerms();


    /**
     *  Tests if an <code> ActionGroupQuery </code> is available. 
     *
     *  @return <code> true </code> if a action group query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActionGroupQuery();


    /**
     *  Gets the query for an action group. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the action group query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActionGroupQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActionGroupQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.ActionGroupQuery getActionGroupQuery();


    /**
     *  Matches triggers with any action group. 
     *
     *  @param  match <code> true </code> to match triggers with any action 
     *          group,, <code> false </code> to match triggers with no action 
     *          groups 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActionGroup(boolean match);


    /**
     *  Clears the action group query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActionGroupTerms();


    /**
     *  Sets the scene <code> Id </code> for this query. 
     *
     *  @param  sceneId a scene <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sceneId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSceneId(org.osid.id.Id sceneId, boolean match);


    /**
     *  Clears the scene <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSceneIdTerms();


    /**
     *  Tests if a <code> SceneQuery </code> is available. 
     *
     *  @return <code> true </code> if a scene query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSceneQuery();


    /**
     *  Gets the query for a scene. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the scene query 
     *  @throws org.osid.UnimplementedException <code> supportsSceneQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSceneQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SceneQuery getSceneQuery();


    /**
     *  Matches triggers with any scene. 
     *
     *  @param  match <code> true </code> to match triggers with any scene, 
     *          <code> false </code> to match triggers with no scenes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScene(boolean match);


    /**
     *  Clears the scene query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSceneTerms();


    /**
     *  Sets the setting <code> Id </code> for this query. 
     *
     *  @param  settingId a setting <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> settingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSettingId(org.osid.id.Id settingId, boolean match);


    /**
     *  Clears the setting <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSettingIdTerms();


    /**
     *  Tests if a <code> SettingQuery </code> is available. 
     *
     *  @return <code> true </code> if a setting query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSettingQuery();


    /**
     *  Gets the query for a setting. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the setting query 
     *  @throws org.osid.UnimplementedException <code> supportsSettingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSettingQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SettingQuery getSettingQuery();


    /**
     *  Matches triggers with any setting. 
     *
     *  @param  match <code> true </code> to match triggers with any setting, 
     *          <code> false </code> to match triggers with no settings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySetting(boolean match);


    /**
     *  Clears the setting query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSettingTerms();


    /**
     *  Sets the system <code> Id </code> for this query to match triggers 
     *  assigned to systems. 
     *
     *  @param  triggerId the trigger <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> triggerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSystemId(org.osid.id.Id triggerId, boolean match);


    /**
     *  Clears the system <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemIdTerms();


    /**
     *  Tests if a <code> SystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a system query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSystemQuery();


    /**
     *  Gets the query for a system. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the system query 
     *  @throws org.osid.UnimplementedException <code> supportsSystemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.control.SystemQuery getSystemQuery();


    /**
     *  Clears the system query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSystemTerms();


    /**
     *  Gets the trigger query record corresponding to the given <code> 
     *  Trigger </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  triggerRecordType a trigger record type 
     *  @return the trigger query record 
     *  @throws org.osid.NullArgumentException <code> triggerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(triggerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.records.TriggerQueryRecord getTriggerQueryRecord(org.osid.type.Type triggerRecordType)
        throws org.osid.OperationFailedException;
}
