//
// org.osid.control.batch.ControllerBatchAdminSession
//
//     The OSID Java specification for org.osid.control.batch.ControllerBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Controllers </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Controller, </code> a <code> ControllerForm </code> is requested using 
 *  <code> getControllerFormsForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> ControllerForms </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once a <code> ControllerForm </code> 
 *  is submiited to a create operation, it cannot be reused with another 
 *  create operation unless the first operation was unsuccessful. Each <code> 
 *  ControllerForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ControllerForms </code> returned from <code> 
 *  getControllerFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> ControllerForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  ControllerForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ControllerForm </code> are submitted for 
 *  create, a <code> CreateController </code> is returned for each <code> 
 *  ControllerForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createControllers(), </code> errors specific to an individual <code> 
 *  ControllerForm </code> are indicated in the corresponding <code> 
 *  CreateController. </code> <code> CreateControllers </code> may be linked 
 *  to the originating <code> ControllerForm </code> through the <code> 
 *  ControllerForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ControllerForms </code> are requested to the 
 *  <code> Controller </code> <code> Id </code> that is to be updated using 
 *  <code> getControllerFormsForUpdate() </code> where the reference <code> Id 
 *  </code> in the <code> ControllerForm </code> may be used to link the 
 *  request. Similarly, the <code> ControllerForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ControllerForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ControllerForms </code> are submitted for 
 *  update, an <code> UpdateController </code> is returned for each <code> 
 *  ControllerForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateControllers(), </code> errors specific to an individual <code> 
 *  ControllerForm </code> are indicated in the corresponding <code> 
 *  UpdateController. </code> <code> UpdateControllers </code> may be linked 
 *  to the originating <code> ControllerForm </code> through the <code> 
 *  ControllerForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Controllers </code> in bulk. To 
 *  unmap a <code> Controller </code> from the current <code> System, </code> 
 *  the <code> ControllerSystemAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Controller </code> itself 
 *  thus removing it from all known <code> System </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteControllers. </code> 
 *  </p>
 */

public interface ControllerBatchAdminSession
    extends org.osid.control.ControllerAdminSession {


    /**
     *  Gets the controller forms for creating a bunch of new controllers. 
     *
     *  @param  n the number of forms to retrieve 
     *  @param  controllerRecordTypes array of controller record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the controller forms 
     *  @throws org.osid.NullArgumentException <code> controllerRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.ControllerBatchFormList getControllerFormsForCreate(long n, 
                                                                                      org.osid.type.Type[] controllerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Controllers. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateController </code> . 
     *
     *  @param  controllerForms the controller forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> controllerForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createControllers(org.osid.control.batch.ControllerBatchFormList controllerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the controller forms for updating an existing set of controllers. 
     *  A new controller form should be requested for each update transaction. 
     *
     *  @param  controllerIds the <code> Ids </code> of the <code> Controller 
     *          </code> 
     *  @return the controller form 
     *  @throws org.osid.NotFoundException a <code> controllerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> controllerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.ControllerBatchFormList getControllerFormsForUpdate(org.osid.id.IdList controllerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing controllers. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateController </code> . 
     *
     *  @param  controllerForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> controllerForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateControllers(org.osid.control.batch.ControllerBatchFormList controllerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Controllers </code> in this <code> System. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllControllers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes controllers for the given <code> Ids. </code> 
     *
     *  @param  controllerIds the <code> Ids </code> of the controllers to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> controllerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteControllers(org.osid.id.IdList controllerIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Controller </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Controller </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another controller, it is reassigned to the 
     *  given controller <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasControllers(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
