//
// org.osid.control.batch.SettingBatchAdminSession
//
//     The OSID Java specification for org.osid.control.batch.SettingBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Settings </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Setting, </code> a <code> SettingForm </code> is requested using <code> 
 *  getSettingFormsForCreate() </code> specifying the desired controller and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> SettingForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> SettingForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> SettingForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> SettingForms </code> returned from <code> 
 *  getSettingFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> SettingForm. 
 *  </code> In the case where there may be duplicates, any <code> SettingForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> SettingForm </code> are submitted for create, a 
 *  <code> CreateSetting </code> is returned for each <code> SettingForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createSettings(), 
 *  </code> errors specific to an individual <code> SettingForm </code> are 
 *  indicated in the corresponding <code> CreateSetting. </code> <code> 
 *  CreateSettings </code> may be linked to the originating <code> SettingForm 
 *  </code> through the <code> SettingForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> SettingForms </code> are requested to the <code> 
 *  Setting </code> <code> Id </code> that is to be updated using <code> 
 *  getSettingFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> SettingForm </code> may be used to link the request. 
 *  Similarly, the <code> SettingForm </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> SettingForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> SettingForms </code> are submitted for update, 
 *  an <code> UpdateSetting </code> is returned for each <code> SettingForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateSettings(), 
 *  </code> errors specific to an individual <code> SettingForm </code> are 
 *  indicated in the corresponding <code> UpdateSetting. </code> <code> 
 *  UpdateSettings </code> may be linked to the originating <code> SettingForm 
 *  </code> through the <code> SettingForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Settings </code> in bulk. To unmap 
 *  a <code> Setting </code> from the current <code> System, </code> the 
 *  <code> SettingSystemAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Setting </code> itself thus 
 *  removing it from all known <code> System </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteSettings. </code> </p>
 */

public interface SettingBatchAdminSession
    extends org.osid.control.SettingAdminSession {


    /**
     *  Gets the setting forms for creating a bunch of new settings. A form is 
     *  retrieved for each controller. 
     *
     *  @param  controllerIds list of controller <code> Ids </code> 
     *  @param  settingRecordTypes array of setting record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the setting forms 
     *  @throws org.osid.NotFoundException a <code> controllerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> controllerIds </code> or 
     *          <code> settingRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.SettingBatchFormList getSettingFormsForCreate(org.osid.id.IdList controllerIds, 
                                                                                org.osid.type.Type[] settingRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Settings. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateSetting </code> . 
     *
     *  @param  settingForms the setting forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> settingForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createSettings(org.osid.control.batch.SettingBatchFormList settingForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the setting forms for updating an existing set of settings. A new 
     *  setting form should be requested for each update transaction. 
     *
     *  @param  settingIds the <code> Ids </code> of the <code> Setting 
     *          </code> 
     *  @return the setting form 
     *  @throws org.osid.NotFoundException a <code> settingId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> settingIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.SettingBatchFormList getSettingFormsForUpdate(org.osid.id.IdList settingIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing settings. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateSetting </code> . 
     *
     *  @param  settingForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> settingForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateSettings(org.osid.control.batch.SettingBatchFormList settingForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Settings </code> in this <code> System. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllSettings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes settings for the given <code> Ids. </code> 
     *
     *  @param  settingIds the <code> Ids </code> of the settings to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> settingIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteSettings(org.osid.id.IdList settingIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes settings for the given <code> Controller. </code> 
     *
     *  @param  controllerId a controller <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> controllerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteSettingsForController(org.osid.id.Id controllerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Setting </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Setting </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another setting, it is reassigned to the given setting 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasSettings(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
