//
// org.osid.control.batch.TriggerBatchAdminSession
//
//     The OSID Java specification for org.osid.control.batch.TriggerBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Triggers </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Trigger, </code> a <code> TriggerForm </code> is requested using <code> 
 *  getTriggerFormsForCreate() </code> specifying the desired controller and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> TriggerForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> TriggerForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> TriggerForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> TriggerForms </code> returned from <code> 
 *  getTriggerFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> TriggerForm. 
 *  </code> In the case where there may be duplicates, any <code> TriggerForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> TriggerForm </code> are submitted for create, a 
 *  <code> CreateTrigger </code> is returned for each <code> TriggerForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createTriggers(), 
 *  </code> errors specific to an individual <code> TriggerForm </code> are 
 *  indicated in the corresponding <code> CreateTrigger. </code> <code> 
 *  CreateTriggers </code> may be linked to the originating <code> TriggerForm 
 *  </code> through the <code> TriggerForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> TriggerForms </code> are requested to the <code> 
 *  Trigger </code> <code> Id </code> that is to be updated using <code> 
 *  getTriggerFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> TriggerForm </code> may be used to link the request. 
 *  Similarly, the <code> TriggerForm </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> TriggerForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> TriggerForms </code> are submitted for update, 
 *  an <code> UpdateTrigger </code> is returned for each <code> TriggerForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateTriggers(), 
 *  </code> errors specific to an individual <code> TriggerForm </code> are 
 *  indicated in the corresponding <code> UpdateTrigger. </code> <code> 
 *  UpdateTriggers </code> may be linked to the originating <code> TriggerForm 
 *  </code> through the <code> TriggerForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Triggers </code> in bulk. To unmap 
 *  a <code> Trigger </code> from the current <code> System, </code> the 
 *  <code> TriggerSystemAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Trigger </code> itself thus 
 *  removing it from all known <code> System </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteTriggers. </code> </p>
 */

public interface TriggerBatchAdminSession
    extends org.osid.control.TriggerAdminSession {


    /**
     *  Gets the trigger forms for creating a bunch of new triggers. A form is 
     *  retrieved for each controller. 
     *
     *  @param  controllerIds list of controller <code> Ids </code> 
     *  @param  triggerRecordTypes array of trigger record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the trigger forms 
     *  @throws org.osid.NotFoundException a <code> controllerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> controllerIds </code> or 
     *          <code> triggerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.TriggerBatchFormList getTriggerFormsForCreate(org.osid.id.IdList controllerIds, 
                                                                                org.osid.type.Type[] triggerRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Triggers. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateTrigger </code> . 
     *
     *  @param  triggerForms the trigger forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> triggerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createTriggers(org.osid.control.batch.TriggerBatchFormList triggerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the trigger forms for updating an existing set of triggers. A new 
     *  trigger form should be requested for each update transaction. 
     *
     *  @param  triggerIds the <code> Ids </code> of the <code> Trigger 
     *          </code> 
     *  @return the trigger form 
     *  @throws org.osid.NotFoundException a <code> triggerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> triggerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.batch.TriggerBatchFormList getTriggerFormsForUpdate(org.osid.id.IdList triggerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing triggers. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateTrigger </code> . 
     *
     *  @param  triggerForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> triggerForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateTriggers(org.osid.control.batch.TriggerBatchFormList triggerForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Triggers </code> in this <code> System. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllTriggers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes triggers for the given <code> Ids. </code> 
     *
     *  @param  triggerIds the <code> Ids </code> of the triggers to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> triggerIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteTriggers(org.osid.id.IdList triggerIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes triggers for the given <code> Controller. </code> 
     *
     *  @param  controllerId a controller <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> controllerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteTriggersForController(org.osid.id.Id controllerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Trigger </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Trigger </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another trigger, it is reassigned to the given trigger 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasTriggers(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
