//
// org.osid.control.rules.ActionEnablerSearchSession
//
//     The OSID Java specification for org.osid.control.rules.ActionEnablerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session provides methods for searching among <code> ActionEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  ActionEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getActionEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> ActionEnablers. </code> An more advanced 
 *  search may be performed with <code> getActionEnablersBySearch(). </code> 
 *  It accepts an <code> ActionEnablerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as control. <code> getActionEnablersBySearch() </code> 
 *  returns an <code> ActionEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> ActionEnablerList </code> or be used to 
 *  perform a search within the result set through <code> ActionEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated system view: searches include action enablers in 
 *      systems of which this system is an ancestor in the system hierarchy 
 *      </li> 
 *      <li> isolated system view: searches are restricted to action enablers 
 *      in this system </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> ActionEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  ActionEnablerQuery. </code> </p>
 */

public interface ActionEnablerSearchSession
    extends org.osid.control.rules.ActionEnablerQuerySession {


    /**
     *  Gets an action enabler search. 
     *
     *  @return the action enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.ActionEnablerSearch getActionEnablerSearch();


    /**
     *  Gets an action enabler search order. The <code> 
     *  ActionEnablerSearchOrder </code> is supplied to an <code> 
     *  ActionEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the action enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.ActionEnablerSearchOrder getActionEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  actionEnablerQuery the action enabler query 
     *  @param  actionEnablerSearch the action enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> actionEnablerQuery 
     *          </code> or <code> actionEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> actionEnablerQuery 
     *          </code> or <code> actionEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.ActionEnablerSearchResults getActionEnablersBySearch(org.osid.control.rules.ActionEnablerQuery actionEnablerQuery, 
                                                                                       org.osid.control.rules.ActionEnablerSearch actionEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an action enabler query from an inspector. The inspector is 
     *  available from an <code> ActionEnablerSearchResults. </code> 
     *
     *  @param  actionEnablerQueryInspector an action enabler query inspector 
     *  @return the action enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          actionEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          actionEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.ActionEnablerQuery getActionEnablerQueryFromInspector(org.osid.control.rules.ActionEnablerQueryInspector actionEnablerQueryInspector);
}
