//
// org.osid.control.rules.ActionEnablerSystemAssignmentSession
//
//     The OSID Java specification for org.osid.control.rules.ActionEnablerSystemAssignmentSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session provides methods to re-assign <code> ActionEnabler </code> 
 *  to <code> System </code> mappings. An <code> ActionEnabler </code> may 
 *  appear in multiple <code> System </code> objects and removing the last 
 *  reference to an <code> ActionEnabler </code> is the equivalent of deleting 
 *  it. Each <code> System </code> may have its own authorizations governing 
 *  who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> ActionEnabler </code> to another 
 *  <code> System </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface ActionEnablerSystemAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter action enabler/system mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignActionEnablers();


    /**
     *  Tests if this user can alter action enabler/system mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignActionEnablersToSystem(org.osid.id.Id systemId);


    /**
     *  Gets a list of systems including and under the given system node in 
     *  which any action enabler can be assigned. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @return list of assignable system <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableSystemIds(org.osid.id.Id systemId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of systems including and under the given system node in 
     *  which a specific action enabler can be assigned. 
     *
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @param  actionEnablerId the <code> Id </code> of the <code> 
     *          ActionEnabler </code> 
     *  @return list of assignable system <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> systemId </code> or 
     *          <code> actionEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableSystemIdsForActionEnabler(org.osid.id.Id systemId, 
                                                                     org.osid.id.Id actionEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ActionEnabler </code> to a <code> System. 
     *  </code> 
     *
     *  @param  actionEnablerId the <code> Id </code> of the <code> 
     *          ActionEnabler </code> 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @throws org.osid.AlreadyExistsException <code> actionEnablerId </code> 
     *          already assigned to <code> systemId </code> 
     *  @throws org.osid.NotFoundException <code> actionEnablerId </code> or 
     *          <code> systemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> actionEnablerId </code> 
     *          or <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignActionEnablerToSystem(org.osid.id.Id actionEnablerId, 
                                            org.osid.id.Id systemId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> ActionEnabler </code> from a <code> System. </code> 
     *
     *  @param  actionEnablerId the <code> Id </code> of the <code> 
     *          ActionEnabler </code> 
     *  @param  systemId the <code> Id </code> of the <code> System </code> 
     *  @throws org.osid.NotFoundException <code> actionEnablerId </code> or 
     *          <code> systemId </code> not found or <code> actionEnablerId 
     *          </code> already assigned to <code> systemId </code> 
     *  @throws org.osid.NullArgumentException <code> actionEnablerId </code> 
     *          or <code> systemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignActionEnablerFromSystem(org.osid.id.Id actionEnablerId, 
                                                org.osid.id.Id systemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> ActionEnabler </code> from one <code> System </code> 
     *  to another. Mappings to other <code> Systems </code> are unaffected. 
     *
     *  @param  actionEnablerId the <code> Id </code> of the <code> 
     *          ActionEnabler </code> 
     *  @param  fromSystemId the <code> Id </code> of the current <code> 
     *          System </code> 
     *  @param  toSystemId the <code> Id </code> of the destination <code> 
     *          System </code> 
     *  @throws org.osid.NotFoundException <code> actionEnablerId, 
     *          fromSystemId, </code> or <code> toSystemId </code> not found 
     *          or <code> actionEnablerId </code> not mapped to <code> 
     *          fromSystemId </code> 
     *  @throws org.osid.NullArgumentException <code> actionEnablerId, 
     *          fromSystemId, </code> or <code> toSystemId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignActionEnablerToSystem(org.osid.id.Id actionEnablerId, 
                                              org.osid.id.Id fromSystemId, 
                                              org.osid.id.Id toSystemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
