//
// org.osid.control.rules.DeviceEnablerAdminSession
//
//     The OSID Java specification for org.osid.control.rules.DeviceEnablerAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session creates and removes device enablers. The data for create 
 *  and update is provided via the <code> DeviceEnablerForm. </code> </p>
 */

public interface DeviceEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create device enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> DeviceEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> DeviceEnabler </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDeviceEnabler();


    /**
     *  Tests if this user can create a single <code> DeviceEnabler </code> 
     *  using the desired record types. While <code> 
     *  OfferingRulesManager.getDeviceEnablerRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> DeviceEnabler. 
     *  </code> Providing an empty array tests if a <code> DeviceEnabler 
     *  </code> can be created with no records. 
     *
     *  @param  deviceEnablerRecordTypes array of device enabler record types 
     *  @return <code> true </code> if <code> DeviceEnabler </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDeviceEnablerWithRecordTypes(org.osid.type.Type[] deviceEnablerRecordTypes);


    /**
     *  Gets the device enabler form for creating new device enablers. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  deviceEnablerRecordTypes array of device enabler record types 
     *  @return the device enabler form 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.DeviceEnablerForm getDeviceEnablerFormForCreate(org.osid.type.Type[] deviceEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> DeviceEnabler. </code> 
     *
     *  @param  deviceEnablerForm the form for this <code> DeviceEnabler 
     *          </code> 
     *  @return the new <code> DeviceEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> deviceEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> deviceEnablerForm did not 
     *          originate from getDeviceEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.DeviceEnabler createDeviceEnabler(org.osid.control.rules.DeviceEnablerForm deviceEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update device enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> DeviceEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> DeviceEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateDeviceEnablers();


    /**
     *  Gets the device enabler form for updating an existing device enabler. 
     *  A new device enabler form should be requested for each update 
     *  transaction. 
     *
     *  @param  deviceEnablerId the <code> Id </code> of the <code> 
     *          DeviceEnabler </code> 
     *  @return the device enabler form 
     *  @throws org.osid.NotFoundException <code> deviceEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.DeviceEnablerForm getDeviceEnablerFormForUpdate(org.osid.id.Id deviceEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing device enabler. 
     *
     *  @param  deviceEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> deviceEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> deviceEnablerForm </code> 
     *          did not originate from <code> getDeviceEnablerFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDeviceEnabler(org.osid.control.rules.DeviceEnablerForm deviceEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete device enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> DeviceEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> DeviceEnabler </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteDeviceEnablers();


    /**
     *  Deletes a <code> DeviceEnabler. </code> 
     *
     *  @param  deviceEnablerId the <code> Id </code> of the <code> 
     *          DeviceEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> deviceEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDeviceEnabler(org.osid.id.Id deviceEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for device 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> DeviceEnabler </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDeviceEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> DeviceEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> DeviceEnabler </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another device enabler. it is 
     *  reassigned to the given device enabler <code> Id. </code> 
     *
     *  @param  deviceEnablerId the <code> Id </code> of a <code> 
     *          DeviceEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> deviceEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> deviceEnablerId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasDeviceEnabler(org.osid.id.Id deviceEnablerId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
