//
// org.osid.control.rules.InputEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.control.rules.InputEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session provides methods to apply <code> InputEnablers </code> to 
 *  <code> Inputs. </code> An <code> Input </code> with multiple <code> 
 *  InputEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Input. </code> </p>
 */

public interface InputEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter input enabler/input mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignInputEnablers();


    /**
     *  Adds an existing <code> InputEnabler </code> to an <code> Input. 
     *  </code> 
     *
     *  @param  inputEnablerId the <code> Id </code> of the <code> 
     *          InputEnabler </code> 
     *  @param  inputId the <code> Id </code> of the <code> Input </code> 
     *  @throws org.osid.AlreadyExistsException <code> inputEnablerId </code> 
     *          already applied to <code> inputId </code> 
     *  @throws org.osid.NotFoundException <code> inputEnablerId </code> or 
     *          <code> inputId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inputEnablerId </code> 
     *          or <code> inputId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignInputEnablerToInput(org.osid.id.Id inputEnablerId, 
                                          org.osid.id.Id inputId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> InputEnabler </code> from an <code> Input. </code> 
     *
     *  @param  inputEnablerId the <code> Id </code> of the <code> 
     *          InputEnabler </code> 
     *  @param  inputId the <code> Id </code> of the <code> Input </code> 
     *  @throws org.osid.NotFoundException <code> inputEnablerId </code> or 
     *          <code> inputId </code> not found or not mapped 
     *  @throws org.osid.NullArgumentException <code> inputEnablerId </code> 
     *          or <code> inputId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignInputEnablerFromInput(org.osid.id.Id inputEnablerId, 
                                              org.osid.id.Id inputId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> Inputs. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> InputEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceInputEnablers();


    /**
     *  Reorders input enablers for an input by moving the specified input 
     *  enabler in front of a reference input enabler. 
     *
     *  @param  inputEnablerId the <code> Id </code> of an <code> InputEnabler 
     *          </code> 
     *  @param  inputId the <code> Id </code> of an <code> Input </code> 
     *  @param  referenceId the reference input <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> inputEnablerId, 
     *          deviceProcesorId, </code> or <code> referenceId </code> not 
     *          found or, <code> inputEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> inputId </code> 
     *  @throws org.osid.NullArgumentException <code> inputEnablerId, inputId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveInputEnablerAhead(org.osid.id.Id inputEnablerId, 
                                      org.osid.id.Id inputId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders input enablers for an input by moving the specified input 
     *  enabler behind a reference input enabler. 
     *
     *  @param  inputEnablerId the <code> Id </code> of an <code> InputEnabler 
     *          </code> 
     *  @param  inputId the <code> Id </code> of an <code> Input </code> 
     *  @param  referenceId the reference input <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> inputEnablerId, 
     *          deviceProcesorId, </code> or <code> referenceId </code> not 
     *          found or, <code> inputEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> inputId </code> 
     *  @throws org.osid.NullArgumentException <code> inputEnablerId, inputId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveInputEnablerBehind(org.osid.id.Id inputEnablerId, 
                                       org.osid.id.Id inputId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of input enablers for an input. 
     *
     *  @param  inputEnablerIds the <code> Ids </code> for a set of <code> 
     *          InputEnablers </code> 
     *  @param  inputId the <code> Id </code> of an <code> Input </code> 
     *  @throws org.osid.NotFoundException <code> inputId </code> not found 
     *          or, an <code> inputEnablerId </code> not related to <code> 
     *          inputId </code> 
     *  @throws org.osid.NullArgumentException <code> inputEnablerIds </code> 
     *          or <code> inputId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderInputEnablers(org.osid.id.Id[] inputEnablerIds, 
                                   org.osid.id.Id inputId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
