//
// org.osid.control.rules.InputEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.control.rules.InputEnablerRuleLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session provides methods to retrieve <code> InputEnabler </code> 
 *  to <code> Input </code> mappings. An <code> Input </code> with multiple 
 *  <code> InputEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Input. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated system view: All methods in this session operate, 
 *      retrieve and pertain input enablers defined explicitly in the current 
 *      system </li> 
 *      <li> federated system view: All methods in this session operate, 
 *      retrieve and pertain to all input enablers defined in this system and 
 *      any other input enablers implicitly available in this system through 
 *      system inheritence. </li> 
 *  </ul>
 *  
 */

public interface InputEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> System </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> System Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSystemId();


    /**
     *  Gets the <code> System </code> associated with this session. 
     *
     *  @return the system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.System getSystem()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of input enabler/input 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupInputEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInputEnablerRuleView();


    /**
     *  A complete view of the <code> InputEnabler </code> and <code> Input 
     *  </code> returns is desired. Methods will return what is requested or 
     *  result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInputEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include input enablers in systems which are children of this system in 
     *  the system hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedSystemView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this system only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedSystemView();


    /**
     *  Gets the <code> InputEnabler Id </code> associated with an <code> 
     *  Input. </code> 
     *
     *  @param  inputId <code> Id </code> of the <code> Input </code> 
     *  @return the input enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> inputId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> inputId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInputEnablerIdsForInput(org.osid.id.Id inputId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> InputEnabler </code> associated with an <code> Input. 
     *  </code> 
     *
     *  @param  inputId <code> Id </code> of the <code> Input </code> 
     *  @return the input enablers 
     *  @throws org.osid.NotFoundException <code> inputId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> inputId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.InputEnablerList getInputEnablersForInput(org.osid.id.Id inputId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Input </code> <code> Ids </code> mapped to an <code> 
     *  InputEnabler. </code> 
     *
     *  @param  inputEnablerId <code> Id </code> of an <code> InputEnabler 
     *          </code> 
     *  @return list of input <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> inputEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> inputEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInputIdsForInputEnabler(org.osid.id.Id inputEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Inputs </code> mapped to an <code> InputEnabler. 
     *  </code> 
     *
     *  @param  inputEnablerId <code> Id </code> of an <code> InputEnabler 
     *          </code> 
     *  @return list of inputs 
     *  @throws org.osid.NotFoundException <code> inputEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> inputEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.InputList getInputsForInputEnabler(org.osid.id.Id inputEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
