//
// org.osid.control.rules.TriggerEnablerSearchSession
//
//     The OSID Java specification for org.osid.control.rules.TriggerEnablerSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.control.rules;


/**
 *  <p>This session provides methods for searching among <code> TriggerEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  TriggerEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getTriggerEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> TriggerEnablers. </code> A more advanced 
 *  search may be performed with <code> getTriggerEnablersBySearch(). </code> 
 *  It accepts a <code> TriggerEnablerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as offering. <code> getTriggerEnablersBySearch() </code> 
 *  returns a <code> TriggerEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> TriggerEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  TriggerEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated system view: searches include trigger enablers in 
 *      systems of which this system is an ancestor in the system hierarchy 
 *      </li> 
 *      <li> isolated system view: searches are restricted to trigger enablers 
 *      in this system </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> TriggerEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  TriggerEnablerQuery. </code> </p>
 */

public interface TriggerEnablerSearchSession
    extends org.osid.control.rules.TriggerEnablerQuerySession {


    /**
     *  Gets a trigger enabler search. 
     *
     *  @return the trigger enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerSearch getTriggerEnablerSearch();


    /**
     *  Gets a trigger enabler search order. The <code> 
     *  TriggerEnablerSearchOrder </code> is supplied to a <code> 
     *  TriggerEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the trigger enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerSearchOrder getTriggerEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  triggerEnablerQuery the trigger enabler query 
     *  @param  triggerEnablerSearch the trigger enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> triggerEnablerQuery 
     *          </code> or <code> triggerEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> triggerEnablerQuery 
     *          </code> or <code> triggerEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerSearchResults getTriggerEnablersBySearch(org.osid.control.rules.TriggerEnablerQuery triggerEnablerQuery, 
                                                                                         org.osid.control.rules.TriggerEnablerSearch triggerEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a trigger enabler query from an inspector. The inspector is 
     *  available from a <code> TriggerEnablerSearchResults. </code> 
     *
     *  @param  triggerEnablerQueryInspector a trigger enabler query inspector 
     *  @return the trigger enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          triggerEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          triggerEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.control.rules.TriggerEnablerQuery getTriggerEnablerQueryFromInspector(org.osid.control.rules.TriggerEnablerQueryInspector triggerEnablerQueryInspector);
}
