//
// org.osid.course.ActivityQueryInspector
//
//     The OSID Java specification for org.osid.course.ActivityQueryInspector.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface ActivityQueryInspector
    extends org.osid.OsidRelationshipQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the implicit terms. 
     *
     *  @return the implicit terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getImplicitTerms();


    /**
     *  Gets the activity unit <code> Id </code> query terms. 
     *
     *  @return the activity unit <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityUnitIdTerms();


    /**
     *  Gets the activity unit query terms. 
     *
     *  @return the activity unit query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitQueryInspector[] getActivityUnitTerms();


    /**
     *  Gets the course offering <code> Id </code> query terms. 
     *
     *  @return the course offering <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseOfferingIdTerms();


    /**
     *  Gets the course offering query terms. 
     *
     *  @return the course offering query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingQueryInspector[] getCourseOfferingTerms();


    /**
     *  Gets the term <code> Id </code> query terms. 
     *
     *  @return the term <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTermIdTerms();


    /**
     *  Gets the term query terms. 
     *
     *  @return the term query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.TermQueryInspector[] getTermTerms();


    /**
     *  Gets the meeting time query terms. 
     *
     *  @return the date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeTerm[] getMeetingTimeTerms();


    /**
     *  Gets the meeting time query terms. 
     *
     *  @return the date range query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getMeetingTimeInclusiveTerms();


    /**
     *  Gets the location <code> Id </code> query terms. 
     *
     *  @return the location <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getMeetingLocationIdTerms();


    /**
     *  Gets the location query terms. 
     *
     *  @return the location query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationQueryInspector[] getMeetingLocationTerms();


    /**
     *  Gets the schedule <code> Id </code> query terms. 
     *
     *  @return the schedule <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getScheduleIdTerms();


    /**
     *  Gets the schedule query terms. 
     *
     *  @return the schedule query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleQueryInspector[] getScheduleTerms();


    /**
     *  Gets the superseding activity <code> Id </code> query terms. 
     *
     *  @return the activity <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSupersedingActivityIdTerms();


    /**
     *  Gets the superseding activity query terms. 
     *
     *  @return the activity query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityQueryInspector[] getSupersedingActivityTerms();


    /**
     *  Gets the specific meeting time query terms. 
     *
     *  @return the date range query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getSpecificMeetingTimeTerms();


    /**
     *  Gets the blackout query terms. 
     *
     *  @return the blackout query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeTerm[] getBlackoutTerms();


    /**
     *  Gets the inclusive blackout query terms. 
     *
     *  @return the blackout query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getBlackoutInclusiveTerms();


    /**
     *  Gets the instructor <code> Id </code> query terms. 
     *
     *  @return the instructor <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getInstructorIdTerms();


    /**
     *  Gets the instructor query terms. 
     *
     *  @return the instructor query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getInstructorTerms();


    /**
     *  Gets the minimum seating terms. 
     *
     *  @return the minimum seat query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getMinimumSeatsTerms();


    /**
     *  Gets the maximum seating terms. 
     *
     *  @return the maximum seat query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getMaximumSeatsTerms();


    /**
     *  Gets the total effort query terms. 
     *
     *  @return the total effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getTotalTargetEffortTerms();


    /**
     *  Gets the contact query terms. 
     *
     *  @return the contact query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getContactTerms();


    /**
     *  Gets the total contact time query terms. 
     *
     *  @return the total contact time query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getTotalTargetContactTimeTerms();


    /**
     *  Gets the total individual effort query terms. 
     *
     *  @return the total individual effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getTotalTargetIndividualEffortTerms();


    /**
     *  Gets the recurring weekly query terms. 
     *
     *  @return the recurring weekly query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getRecurringWeeklyTerms();


    /**
     *  Gets the weekly effort query terms. 
     *
     *  @return the weekly effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getWeeklyEffortTerms();


    /**
     *  Gets the weekly contact time query terms. 
     *
     *  @return the weekly contact time query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getWeeklyContactTimeTerms();


    /**
     *  Gets the weekly individual effort query terms. 
     *
     *  @return the weekly individual effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getWeeklyIndividualEffortTerms();


    /**
     *  Gets the course catalog <code> Id </code> query terms. 
     *
     *  @return the course catalog <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog query terms. 
     *
     *  @return the course catalog query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the activity query inspector record corresponding to the given 
     *  <code> Activity </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the activity query inspector record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivityQueryInspectorRecord getActivityQueryInspectorRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
