//
// org.osid.course.ActivitySearchOrder
//
//     The OSID Java specification for org.osid.course.ActivitySearchOrder.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface ActivitySearchOrder
    extends org.osid.OsidRelationshipSearchOrder,
            org.osid.OsidSubjugateableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by activity unit. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByActivityUnit(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an activity unit search order is available. 
     *
     *  @return <code> true </code> if an activity unit search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitSearchOrder();


    /**
     *  Gets the activity unit search order. 
     *
     *  @return the activity unit search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityUnitSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityUnitSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseSearchOrder getActivityUnitSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by course offering. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCourseOffering(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a course offering search is available. 
     *
     *  @return <code> true </code> if a course offering search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingSearchOrder();


    /**
     *  Gets the course offering search order. 
     *
     *  @return the course offering search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseOfferingSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityUnitSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseOfferingSearchOrder getCourseOfferingSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by term. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTerm(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a term search order is available. 
     *
     *  @return <code> true </code> if a term search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermSearchOrder();


    /**
     *  Gets the term order. 
     *
     *  @return the term search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTermSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTermSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.course.TermSearchOrder getTermSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the implicit 
     *  status. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByImplicit(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the minimum 
     *  seats. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMinimumSeats(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the maximum 
     *  seats. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMaximumSeats(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the total 
     *  effort. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTotalTargetEffort(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the total 
     *  contact. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTotalTargetContactTime(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by total individual 
     *  effort. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTotalTargetIndividualEffort(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by weekly 
     *  recurring. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByRecurringWeekly(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the weekly 
     *  effort. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByWeeklyEffort(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the weekly 
     *  contact. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByWeeklyContactTime(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by weekly 
     *  individual effort. 
     *
     *  @param  style a search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByWeeklyIndividualEffort(org.osid.SearchOrderStyle style);


    /**
     *  Gets the activity search order record corresponding to the given 
     *  activity record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the activity search order record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivitySearchOrderRecord getActivitySearchOrderRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
