//
// org.osid.course.ActivityUnit
//
//     The OSID Java specification for org.osid.course.ActivityUnit.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>An <code> ActivityUnit </code> represents a canonical learning unit. A 
 *  canonical learning unit describes a kind of activity that will be offered 
 *  and is used for curriculum planning. </p>
 */

public interface ActivityUnit
    extends org.osid.OsidObject,
            org.osid.Operable,
            org.osid.Subjugateable {


    /**
     *  Gets the canonical course <code> Id </code> associated with this 
     *  activity. 
     *
     *  @return the course <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseId();


    /**
     *  Gets the canonical course associated with this activity. 
     *
     *  @return the course 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Course getCourse()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the total time required for this activity. 
     *
     *  @return the total effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalTargetEffort();


    /**
     *  Tests if this is a contact activity. 
     *
     *  @return <code> true </code> if this is a contact activity, <code> 
     *          false </code> if an independent activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isContact();


    /**
     *  Gets the total contact time for this activity. 
     *
     *  @return the total effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalTargetContactTime();


    /**
     *  Gets the total indivudal time required for this activity. 
     *
     *  @return the total individual effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTotalTargetIndividualEffort();


    /**
     *  Tests if this activity is recurring. 
     *
     *  @return <code> true </code> if this activity is recurring, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isRecurringWeekly();


    /**
     *  Gets the time required for this recurring effort on a weekly basis. 
     *
     *  @return the weekly time 
     *  @throws org.osid.IllegalStateException <code> isRecurringWeekly() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getWeeklyEffort();


    /**
     *  Gets the weekly contact time for ths activity. 
     *
     *  @return the weekly time 
     *  @throws org.osid.IllegalStateException <code> isRecurringWeekly() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getWeeklyContactTime();


    /**
     *  Gets the weekly individual time for ths activity. 
     *
     *  @return the weekly time 
     *  @throws org.osid.IllegalStateException <code> isRecurringWeekly() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getWeeklyIndividualEffort();


    /**
     *  Tests if this activity unit has associated learning objectives. 
     *
     *  @return <code> true </code> if this activity unit has a learning 
     *          objective, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLearningObjectives();


    /**
     *  Gets the overall learning objective <code> Ids </code> for this 
     *  activity unit. 
     *
     *  @return <code> Ids </code> of the <code> l </code> earning objectives 
     *  @throws org.osid.IllegalStateException <code> hasLearningObjectives() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.id.IdList getLearningObjectiveIds();


    /**
     *  Gets the overall learning objectives for this activity unit. 
     *
     *  @return the learning objectives 
     *  @throws org.osid.IllegalStateException <code> hasLearningObjectives() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getLearningObjectives()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the activity unit record corresponding to the given <code> 
     *  ActivityUnit </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  activityUnitRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(activityUnitRecordType) </code> is <code> true </code> . 
     *
     *  @param  activityUnitRecordType the type of activity unit record to 
     *          retrieve 
     *  @return the activity unit record 
     *  @throws org.osid.NullArgumentException <code> activityUnitRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityUnitRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivityUnitRecord getActivityUnitRecord(org.osid.type.Type activityUnitRecordType)
        throws org.osid.OperationFailedException;
}
