//
// org.osid.course.ActivityUnitAdminSession
//
//     The OSID Java specification for org.osid.course.ActivityUnitAdminSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session creates, updates, and deletes <code> ActivityUnit. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> ActivityUnit, </code> an <code> ActivityUnitForm </code> is 
 *  requested using <code> getActivityUnitFormForCreate() </code> specifying 
 *  the desired course and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> ActivityUnitForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> ActivityUnitForm </code> is submiited to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> ActivityUnitForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ActivityUnitForms </code> are requested to the 
 *  <code> ActivityUnit </code> <code> Id </code> that is to be updated using 
 *  <code> getActivityUnitFormForUpdate(). </code> Similarly, the <code> 
 *  ActivityUnitForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ActivityUnitForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ActivityUnits. </code> To unmap an 
 *  <code> ActivityUnit </code> from the current <code> CourseCatalog, </code> 
 *  the <code> ActivityUnitCourseCatalogAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> ActivityUnit 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ActivityUnitAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ActivityUnits. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> ActivityUnit </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityUnit </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityUnits();


    /**
     *  Tests if this user can create a single <code> ActivityUnit </code> 
     *  using the desired record types. While <code> 
     *  CourseManager.getActivityUnitRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> ActivityUnit. </code> 
     *  Providing an empty array tests if an <code> ActivityUnit </code> can 
     *  be created with no records. 
     *
     *  @param  activityUnitRecordTypes array of activity unit record types 
     *  @return <code> true </code> if <code> ActivityUnit </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activityUnitRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityUnitWithRecordTypes(org.osid.type.Type[] activityUnitRecordTypes);


    /**
     *  Gets the activity unit form for creating new activity units. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  courseId the course <code> Id </code> 
     *  @param  activityUnitRecordTypes array of activity unit record types 
     *  @return the activity unit form 
     *  @throws org.osid.NotFoundException <code> courseId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseId </code> or 
     *          <code> activityUnitRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitForm getActivityUnitFormForCreate(org.osid.id.Id courseId, 
                                                                         org.osid.type.Type[] activityUnitRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ActivityUnit. </code> 
     *
     *  @param  activityUnitForm the form for this <code> ActivityUnit </code> 
     *  @return the new <code> ActivityUnit </code> 
     *  @throws org.osid.IllegalStateException <code> activityForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> activityUnitForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityUnitForm did not 
     *          originate from getActivityUnitFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnit createActivityUnit(org.osid.course.CourseForm activityUnitForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ActivityUnits. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> ActivityUnit </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityUnit </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateActivityUnits();


    /**
     *  Gets the activity unit form for updating an existing activity unit. A 
     *  new activity unit form should be requested for each update 
     *  transaction. 
     *
     *  @param  activityUnitId the <code> Id </code> of the <code> 
     *          ActivityUnit </code> 
     *  @return the activity unit form 
     *  @throws org.osid.NotFoundException <code> activityUnitId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitForm getActivityUnitFormForUpdate(org.osid.id.Id activityUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing activity unit. 
     *
     *  @param  activityUnitForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> activityForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> courseForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityUnitForm did not 
     *          originate from getActivityUnitFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateActivityUnit(org.osid.course.ActivityUnitForm activityUnitForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ActivityUnits. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> ActivityUnit </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityUnit </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteActivityUnits();


    /**
     *  Deletes an <code> ActivityUnit. </code> 
     *
     *  @param  activityUnitId the <code> Id </code> of the <code> 
     *          ActivityUnit </code> to remove 
     *  @throws org.osid.NotFoundException <code> activityUnitId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteActivityUnit(org.osid.id.Id activityUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ActivityUnits. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityUnit </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageActivityUnitAliases();


    /**
     *  Adds an <code> Id </code> to an <code> ActivityUnit </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ActivityUnit </code> is deactivityined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another activity unit, it is 
     *  reassigned to the given activity unit <code> Id. </code> 
     *
     *  @param  activityUnitId the <code> Id </code> of an <code> ActivityUnit 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> activityUnitId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasActivityUnit(org.osid.id.Id activityUnitId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
