//
// org.osid.course.ActivityUnitQueryInspector
//
//     The OSID Java specification for org.osid.course.ActivityUnitQueryInspector.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface ActivityUnitQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidOperableQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the course <code> Id </code> query terms. 
     *
     *  @return the course <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseIdTerms();


    /**
     *  Gets the course query terms. 
     *
     *  @return the course query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseQueryInspector[] getCourseTerms();


    /**
     *  Gets the total effort query terms. 
     *
     *  @return the total effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getTotalTargetEffortTerms();


    /**
     *  Gets the contact query terms. 
     *
     *  @return the contact query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getContactTerms();


    /**
     *  Gets the total contact time query terms. 
     *
     *  @return the total contact time query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getTotalTargetContactTimeTerms();


    /**
     *  Gets the total individual effort query terms. 
     *
     *  @return the total individual effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getTotalTargetIndividualEffortTerms();


    /**
     *  Gets the recurring weekly query terms. 
     *
     *  @return the recurring weekly query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getRecurringWeeklyTerms();


    /**
     *  Gets the weekly effort query terms. 
     *
     *  @return the weekly effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getWeeklyEffortTerms();


    /**
     *  Gets the weekly contact time query terms. 
     *
     *  @return the weekly contact time query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getWeeklyContactTimeTerms();


    /**
     *  Gets the weekly individual effort query terms. 
     *
     *  @return the weekly individual effort query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getWeeklyIndividualEffortTerms();


    /**
     *  Gets the objective <code> Id </code> query terms. 
     *
     *  @return the objective <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLearningObjectiveIdTerms();


    /**
     *  Gets the objective query terms. 
     *
     *  @return the objective query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getLearningObjectiveTerms();


    /**
     *  Gets the activity <code> Id </code> query terms. 
     *
     *  @return the activity <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityIdTerms();


    /**
     *  Gets the activity query terms. 
     *
     *  @return the activity query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityQueryInspector[] getActivityTerms();


    /**
     *  Gets the course catalog <code> Id </code> query terms. 
     *
     *  @return the course catalog <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog query terms. 
     *
     *  @return the course catalog query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the activity unit query inspector record corresponding to the 
     *  given <code> ActivityUnit </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  activityUnitRecordType an activity unit record type 
     *  @return the activity unit query inspector record 
     *  @throws org.osid.NullArgumentException <code> activityUnitRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityUnitRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.ActivityUnitQueryInspectorRecord getActivityUnitQueryInspectorRecord(org.osid.type.Type activityUnitRecordType)
        throws org.osid.OperationFailedException;
}
