//
// org.osid.course.ActivityUnravellingSession
//
//     The OSID Java specification for org.osid.course.ActivityUnravellingSession.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This session provides methods for retrieving and expanding activities. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated course catalog view: All activity methods in this 
 *      session operate, retrieve and pertain to activities defined explicitly 
 *      in the current course catalog. </li> 
 *      <li> federated course catalog view: All activity event in this session 
 *      operate, retrieve and pertain to all activities defined in this course 
 *      catalog and any other cours ecatalogs implicitly available in this 
 *      course catalog through course catalog inheritence. </li> 
 *  </ul>
 *  
 */

public interface ActivityUnravellingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Activity </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUnravelActviities();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeActivityView();


    /**
     *  A complete view of the <code> Activity </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryActivityView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include activities in course catalogs which are children of this 
     *  course catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Gets the activity where the given activity <code> Id </code> was 
     *  issued as part of a recurring series. 
     *
     *  @param  activityId <code> an activity Id </code> 
     *  @return the returned <code> Activity </code> 
     *  @throws org.osid.NotFoundException <code> activityId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Activity getExplicitActivityByActivity(org.osid.id.Id activityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityList </code> corresponding to the given event 
     *  <code> IdList </code> where the activities were implcitly created from 
     *  the recurring series. In plenary mode, the returned list contains all 
     *  of the activities corresponding to the events in the <code> Id </code> 
     *  list, in the order of the list, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible activities may be omitted from 
     *  the list and may present the elements in any order including returning 
     *  a unique set. 
     *
     *  @param  activityIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Activity </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> eventIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList getExplicitActivitiesByActivities(org.osid.id.IdList activityIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given activity into a series of single-date activities In 
     *  plenary mode, the returned list contains all of the activities in the 
     *  series, including duplicates, or an error results. In comparative 
     *  mode, activities may be omitted from the list and may present the 
     *  elements in any order, including providing a unique set. 
     *
     *  @param  activityId <code> Id </code> of the <code> Activity </code> 
     *  @return the returned <code> Activity list </code> 
     *  @throws org.osid.NotFoundException <code> activityId was </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.course.ActivityList expandActivity(org.osid.id.Id activityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given activity into a series of single-date activities 
     *  that fall within the given date range inclusive. In plenary mode, the 
     *  returned list contains all of the activities in the series, including 
     *  duplicates, or an error results. In comparative mode, activities may 
     *  be omitted from the list and may present the elements in any order, 
     *  including providing a unique set. 
     *
     *  @param  activityId <code> Id </code> of the <code> Activity </code> 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Activity list </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException <code> activityId was </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.course.ActivityList expandActivityInDateRange(org.osid.id.Id activityId, 
                                                                  org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given recurring activities into a series of single-date 
     *  activities. In plenary mode, the returned list contains all of the 
     *  activities in the series, including duplicates, or an error results. 
     *  In comparative mode, activities may be omitted from the list and may 
     *  present the elements in any order, including providing a unique set. 
     *
     *  @param  activityIds the list of <code> Ids </code> to expand 
     *  @return the returned <code> Activity list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList expandActivities(org.osid.id.IdList activityIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Expands the given recurring activities into a series of single-date 
     *  activities that fall within the given date range inclusive. In plenary 
     *  mode, the returned list contains all of the activities in the series, 
     *  including duplicates, or an error results. In comparative mode, 
     *  activities may be omitted from the list and may present the elements 
     *  in any order, including providing a unique set. 
     *
     *  @param  activityIds the list of <code> Ids </code> to expand 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Activity list </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.course.ActivityList expandActivitiesInDateRange(org.osid.id.Id activityIds, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of normalized unexpanded activities where the given date 
     *  falls within the span of a single activity meeting time. <code> 
     *  </code> In plenary mode, the returned list contains all known 
     *  activities or an error results. Otherwise, the returned list may 
     *  contain only those activities that are accessible through this 
     *  session. 
     *
     *  @param  datetime a date 
     *  @return the returned <code> Activity </code> list 
     *  @throws org.osid.NullArgumentException <code> datetime </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList getActivitiesByDate(org.osid.calendaring.DateTime datetime)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a normalized list of unexpanded activities whose series falls 
     *  entirely within the given range inclusive <code> . </code> In plenary 
     *  mode, the returned list contains all known activities or an error 
     *  results. Otherwise, the returned list may contain only those 
     *  activities that are accessible through this session. 
     *
     *  @param  from start date 
     *  @param  to end date 
     *  @return the returned <code> Activity </code> list 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList getActivtiesInDateRange(org.osid.calendaring.DateTime from, 
                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the number of activity meeting times in the recurring series. 
     *
     *  @param  activityId <code> Id </code> of the recurring <code> Activity 
     *          </code> 
     *  @return the number of meeting times 
     *  @throws org.osid.NotFoundException <code> activityId was </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public long getNumberOfActivities(org.osid.id.Id activityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the number of activity meeting times in the recurring series 
     *  between the given dates inclusive. 
     *
     *  @param  activityId <code> Id </code> of the recurring <code> Activity 
     *          </code> 
     *  @param  from start date 
     *  @param  to end date 
     *  @return the number of meeting times 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NotFoundException <code> activityId was </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public long getNumberOfActivitiesInDateRange(org.osid.id.Id activityId, 
                                                 org.osid.calendaring.DateTime from, 
                                                 org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
