//
// org.osid.course.CourseCatalogQuery
//
//     The OSID Java specification for org.osid.course.CourseCatalogQuery.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the query for searching course catalogs. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface CourseCatalogQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the course <code> Id </code> for this query to match courses that 
     *  have a related course. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseId(org.osid.id.Id courseId, boolean match);


    /**
     *  Clears the course <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseIdTerms();


    /**
     *  Tests if a <code> CourseQuery </code> is available. 
     *
     *  @return <code> true </code> if a course query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseQuery();


    /**
     *  Gets the query for a course. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the course query 
     *  @throws org.osid.UnimplementedException <code> supportsCourseQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.CourseQuery getCourseQuery();


    /**
     *  Matches course catalogs that have any course. 
     *
     *  @param  match <code> true </code> to match courses with any course, 
     *          <code> false </code> to match courses with no course 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCourse(boolean match);


    /**
     *  Clears the course query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseTerms();


    /**
     *  Sets the activity unit <code> Id </code> for this query. 
     *
     *  @param  activityUnitId an activity unit <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityUnitId(org.osid.id.Id activityUnitId, 
                                    boolean match);


    /**
     *  Clears the activity unit <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityUnitIdTerms();


    /**
     *  Tests if an <code> ActivityUnitQuery </code> is available. 
     *
     *  @return <code> true </code> if an activity unit query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityUnitQuery();


    /**
     *  Gets the query for an activity unit. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the activity unit query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActivityUnitQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityUnitQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.ActivityUnitQuery getActivityUnitQuery();


    /**
     *  Matches course catalogs that have any activity unit. 
     *
     *  @param  match <code> true </code> to match course catalogs with any 
     *          activity unit, <code> false </code> to match course catalogs 
     *          with no activity units 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivityUnit(boolean match);


    /**
     *  Clears the activity unit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityUnitTerms();


    /**
     *  Sets the catalog <code> Id </code> for this query. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseOfferingId(org.osid.id.Id courseOfferingId, 
                                      boolean match);


    /**
     *  Clears the course offering <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingIdTerms();


    /**
     *  Tests if a <code> CourseOfferingQuery </code> is available. 
     *
     *  @return <code> true </code> if a course offering query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseOfferingQuery();


    /**
     *  Gets the query for a course offering. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course offering query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseOfferingQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseOfferingQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseOfferingQuery getCourseOfferingQuery();


    /**
     *  Matches course catalogs that have any course offering. 
     *
     *  @param  match <code> true </code> to match courses with any course 
     *          offering, <code> false </code> to match courses with no course 
     *          offering 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCourseOffering(boolean match);


    /**
     *  Clears the course offering query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseOfferingTerms();


    /**
     *  Sets the activity <code> Id </code> for this query. 
     *
     *  @param  activityUnitId an activity <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityId(org.osid.id.Id activityUnitId, boolean match);


    /**
     *  Clears the activity <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityIdTerms();


    /**
     *  Tests if an <code> ActivityQuery </code> is available. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Gets the query for an activity. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.ActivityQuery getActivityQuery();


    /**
     *  Matches course catalogs that have any activity. 
     *
     *  @param  match <code> true </code> to match course catalogs with any 
     *          activity, <code> false </code> to match course catalogs with 
     *          no activities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivity(boolean match);


    /**
     *  Clears the activity query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityTerms();


    /**
     *  Sets the term <code> Id </code> for this query to match catalogs 
     *  containing terms. 
     *
     *  @param  termId the term <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTermId(org.osid.id.Id termId, boolean match);


    /**
     *  Clears the term <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermIdTerms();


    /**
     *  Tests if a <code> TermQuery </code> is available. 
     *
     *  @return <code> true </code> if a term query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTermQuery();


    /**
     *  Gets the query for a term Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the term query 
     *  @throws org.osid.UnimplementedException <code> supportsTermQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTermQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.TermQuery getTermQuery();


    /**
     *  Matches course catalogs that have any term. 
     *
     *  @param  match <code> true </code> to match course catalogs with any 
     *          term, <code> false </code> to match courses with no term 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTerm(boolean match);


    /**
     *  Clears the term query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTermTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  course catalogs that have the specified course catalog as an ancestor. 
     *
     *  @param  courseCatalogId a course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                             boolean match);


    /**
     *  Clears the ancestor course catalog <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorCourseCatalogQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorCourseCatalogQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.CourseCatalogQuery getAncestorCourseCatalogQuery();


    /**
     *  Matches course catalogs with any course catalog ancestor. 
     *
     *  @param  match <code> true </code> to match course catalogs with any 
     *          ancestor, <code> false </code> to match root course catalogs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorCourseCatalog(boolean match);


    /**
     *  Clears the ancestor course catalog query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCourseCatalogTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  course catalogs that have the specified course catalog as an 
     *  descendant. 
     *
     *  @param  courseCatalogId a course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                               boolean match);


    /**
     *  Clears the descendant course catalog <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantCourseCatalogQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantCourseCatalogQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.CourseCatalogQuery getDescendantCourseCatalogQuery();


    /**
     *  Matches course catalogs with any descendant course catalog. 
     *
     *  @param  match <code> true </code> to match course catalogs with any 
     *          descendant, <code> false </code> to match leaf course catalogs 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantCourseCatalog(boolean match);


    /**
     *  Clears the descendant course catalog query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCourseCatalogTerms();


    /**
     *  Gets the course catalog query record corresponding to the given <code> 
     *  CourseCatalog </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  courseCatalogRecordType a course catalog record type 
     *  @return the course catalog query record 
     *  @throws org.osid.NullArgumentException <code> courseCatalogRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseCatalogRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseCatalogQueryRecord getCourseCatalogQueryRecord(org.osid.type.Type courseCatalogRecordType)
        throws org.osid.OperationFailedException;
}
