//
// org.osid.course.CourseCatalogQueryInspector
//
//     The OSID Java specification for org.osid.course.CourseCatalogQueryInspector.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface CourseCatalogQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the course <code> Id </code> query terms. 
     *
     *  @return the course <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseIdTerms();


    /**
     *  Gets the course query terms. 
     *
     *  @return the course query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseQueryInspector[] getCourseTerms();


    /**
     *  Gets the activity unit <code> Id </code> query terms. 
     *
     *  @return the activity unit <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityUnitIdTerms();


    /**
     *  Gets the activity unit query terms. 
     *
     *  @return the activity unit query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnitQueryInspector[] getActivityUnitTerms();


    /**
     *  Gets the course offering <code> Id </code> query terms. 
     *
     *  @return the course offering <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseOfferingIdTerms();


    /**
     *  Gets the course offering query terms. 
     *
     *  @return the course offering query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOfferingQueryInspector[] getCourseOfferingTerms();


    /**
     *  Gets the activity <code> Id </code> query terms. 
     *
     *  @return the activity <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityIdTerms();


    /**
     *  Gets the activity query terms. 
     *
     *  @return the activity query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityQueryInspector[] getActivityTerms();


    /**
     *  Gets the term <code> Id </code> query terms. 
     *
     *  @return the term <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTermIdTerms();


    /**
     *  Gets the term query terms. 
     *
     *  @return the term query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.TermQueryInspector[] getTermTerms();


    /**
     *  Gets the ancestor course catalog <code> Id </code> query terms. 
     *
     *  @return the ancestor course catalog <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorCourseCatalogIdTerms();


    /**
     *  Gets the ancestor course catalog query terms. 
     *
     *  @return the ancestor course catalog terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getAncestorCourseCatalogTerms();


    /**
     *  Gets the descendant course catalog <code> Id </code> query terms. 
     *
     *  @return the descendant course catalog <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantCourseCatalogIdTerms();


    /**
     *  Gets the descendant course catalog query terms. 
     *
     *  @return the descendant course catalog terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getDescendantCourseCatalogTerms();


    /**
     *  Gets the course catalog query inspector record corresponding to the 
     *  given <code> CourseCatalog </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  courseCatalogRecordType a course catalog record type 
     *  @return the course catalog query inspector record 
     *  @throws org.osid.NullArgumentException <code> courseCatalogRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseCatalogRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseCatalogQueryInspectorRecord getCourseCatalogQueryInspectorRecord(org.osid.type.Type courseCatalogRecordType)
        throws org.osid.OperationFailedException;
}
