//
// org.osid.course.CourseForm
//
//     The OSID Java specification for org.osid.course.CourseForm.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the form for creating and updating <code> Courses. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> CourseAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface CourseForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidOperableForm {


    /**
     *  Gets the metadata for a course title. 
     *
     *  @return metadata for the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTitleMetadata();


    /**
     *  Sets the title. 
     *
     *  @param  title the new title 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTitle(String title);


    /**
     *  Removes the title. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitle();


    /**
     *  Gets the metadata for a course number. 
     *
     *  @return metadata for the course number 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNumberMetadata();


    /**
     *  Sets the course number. 
     *
     *  @param  number the new course number 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNumber(String number);


    /**
     *  Removes the course number. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumber();


    /**
     *  Gets the metadata for a set of sponsors. 
     *
     *  @return metadata for the sponsors 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSponsorsMetadata();


    /**
     *  Sets the sponsors. 
     *
     *  @param  resourceIds the new sponsors 
     *  @throws org.osid.InvalidArgumentException <code> resourceIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSponsors(org.osid.id.Id[] resourceIds);


    /**
     *  Removes the sponsors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsors();


    /**
     *  Gets the metadata for the credits. 
     *
     *  @return metadata for the credit scale 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditsMetadata();


    /**
     *  Sets the credits. 
     *
     *  @param  gradeIds the new credit levels 
     *  @throws org.osid.InvalidArgumentException <code> gradeIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCredits(org.osid.id.Id[] gradeIds);


    /**
     *  Removes the credits. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredits();


    /**
     *  Gets the metadata for a course prerequisite informational string. 
     *
     *  @return metadata for the prerequisite information 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPrerequisitesInfoMetadata();


    /**
     *  Sets the prerequisitie information. 
     *
     *  @param  prereqInfo the new prerequsite information 
     *  @throws org.osid.InvalidArgumentException <code> prereqInfo </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> prereqInfo </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPrerequisitesInfo(String prereqInfo);


    /**
     *  Removes the prerequisite information. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPrerequisitesInfo();


    /**
     *  Gets the metadata for a prerequisites. 
     *
     *  @return metadata for the requisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPrerequisitesMetadata();


    /**
     *  Sets the prerequisites. 
     *
     *  @param  requisiteIds the new requisites 
     *  @throws org.osid.InvalidArgumentException <code> requisiteIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPrerequisites(org.osid.id.Id[] requisiteIds);


    /**
     *  Removes the prerequisites. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPrerequisites();


    /**
     *  Gets the metadata for a set of grade levels. 
     *
     *  @return metadata for the levels 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLevelsMetadata();


    /**
     *  Sets the levels. 
     *
     *  @param  gradeIds the new grade levels 
     *  @throws org.osid.InvalidArgumentException <code> gradeIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLevels(org.osid.id.Id[] gradeIds);


    /**
     *  Removes the grade levels. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevels();


    /**
     *  Gets the metadata for a set of grading options. 
     *
     *  @return metadata for the grading options 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGradingOptionsMetadata();


    /**
     *  Sets the grading options. 
     *
     *  @param  gradeSystemIds the new grade systems 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGradingOptions(org.osid.id.Id[] gradeSystemIds);


    /**
     *  Removes the grading options. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradingOptions();


    /**
     *  Gets the metadata for a set of learning objectives. 
     *
     *  @return metadata for the obecjtives 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLearningObjectiveMetadata();


    /**
     *  Sets the learning objectives. 
     *
     *  @param  objectiveIds the new obejctives 
     *  @throws org.osid.InvalidArgumentException <code> objectiveIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLearningObjectives(org.osid.id.Id[] objectiveIds);


    /**
     *  Removes the learning objectives. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectives();


    /**
     *  Gets the <code> CourseFormRecord </code> corresponding to the given 
     *  course record <code> Type. </code> 
     *
     *  @param  courseRecordType a course record type 
     *  @return the course form record 
     *  @throws org.osid.NullArgumentException <code> courseRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.CourseFormRecord getCourseFormRecord(org.osid.type.Type courseRecordType)
        throws org.osid.OperationFailedException;
}
