//
// org.osid.course.Term
//
//     The OSID Java specification for org.osid.course.Term.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>A <code> Term </code> represents a period of time in which a course is 
 *  offered. This <code> Term </code> contains information on severel 
 *  milestones that may drive the behavior of schedules and registration. 
 *  These periods of time may be linked to the <code> Term </code> in the 
 *  Calendaring OSID to effect the behavior of the <code> RecurringEvents. 
 *  </code> </p>
 */

public interface Term
    extends org.osid.OsidObject,
            org.osid.Federateable {


    /**
     *  Gets a display label for this term which may be less formal than the 
     *  display name. 
     *
     *  @return the term label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayLabel();


    /**
     *  Tests if this term has an open date when published offerings are 
     *  finalized. 
     *
     *  @return <code> true </code> if there is an open date associated with 
     *          this term, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasOpenDate();


    /**
     *  Gets the open date when published offerings are finalized. 
     *
     *  @return the open date 
     *  @throws org.osid.IllegalStateException <code> hasOpenDate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getOpenDate();


    /**
     *  Tests if this term has a registration period. 
     *
     *  @return <code> true </code> if there is a registration period 
     *          associated with this term, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRegistrationPeriod();


    /**
     *  Gets the start of the registration period. 
     *
     *  @return the start date 
     *  @throws org.osid.IllegalStateException <code> hasRegistrationPeriod() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getRegistrationStart();


    /**
     *  Gets the end of the registration period. 
     *
     *  @return the end date 
     *  @throws org.osid.IllegalStateException <code> hasRegistrationPeriod() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getRegistrationEnd();


    /**
     *  Gets the start of classes. 
     *
     *  @return the start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getClassesStart();


    /**
     *  Gets the end of classes. 
     *
     *  @return the end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getClassesEnd();


    /**
     *  Tests if this term has an add/drop date. 
     *
     *  @return <code> true </code> if there is an add/drop date associated 
     *          with this term, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAddDropDate();


    /**
     *  Gets the add/drop date. 
     *
     *  @return the add/drop date 
     *  @throws org.osid.IllegalStateException <code> hasAddDropDate() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getAddDate();


    /**
     *  Gets the add/drop date. 
     *
     *  @return the add/drop date 
     *  @throws org.osid.IllegalStateException <code> hasAddDropDate() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDropDate();


    /**
     *  Tests if this term has a final eam period. 
     *
     *  @return <code> true </code> if there is a final exam period associated 
     *          with this term, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasFinalExamPeriod();


    /**
     *  Gets the start of the final exam period. 
     *
     *  @return the start date 
     *  @throws org.osid.IllegalStateException <code> hasFinalExamPeriod() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getFinalExamStart();


    /**
     *  Gets the end of the final exam period. 
     *
     *  @return the end date 
     *  @throws org.osid.IllegalStateException <code> hasFinalExamPeriod() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getFinalExamEnd();


    /**
     *  Tests if this term has a close date when results from course offerings 
     *  are finalized. 
     *
     *  @return <code> true </code> if there is a close date associated with 
     *          this term, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCloseDate();


    /**
     *  Gets the close date when results of course offerings are finalized. 
     *
     *  @return the close date 
     *  @throws org.osid.IllegalStateException <code> hasCloseDate() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCloseDate();


    /**
     *  Gets the term record corresponding to the given <code> Term </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> termRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(termRecordType) </code> is <code> true </code> . 
     *
     *  @param  termRecordType the type of term record to retrieve 
     *  @return the term record 
     *  @throws org.osid.NullArgumentException <code> termRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(termRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.TermRecord getTermRecord(org.osid.type.Type termRecordType)
        throws org.osid.OperationFailedException;
}
