//
// org.osid.course.TermForm
//
//     The OSID Java specification for org.osid.course.TermForm.
//
// Copyright (C) 2002-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course;


/**
 *  <p>This is the form for creating and updating <code> Terms. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> TermAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface TermForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidFederateableForm {


    /**
     *  Gets the metadata for a display label title. 
     *
     *  @return metadata for the display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDisplayLabelMetadata();


    /**
     *  Sets the display label. 
     *
     *  @param  displayLabel the new display label 
     *  @throws org.osid.InvalidArgumentException <code> displayLabel </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> displayLabel </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDisplayLabel(String displayLabel);


    /**
     *  Removes the display label. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabel();


    /**
     *  Gets the metadata for an open date. 
     *
     *  @return metadata for the open date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOpenDateMetadata();


    /**
     *  Sets the open date. 
     *
     *  @param  date the new open date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOpenDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the open date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOpenDate();


    /**
     *  Gets the metadata for the registration start date. 
     *
     *  @return metadata for the registration start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRegistrationStartMetadata();


    /**
     *  Sets the registration start date. 
     *
     *  @param  date the new registration start date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRegistrationStart(org.osid.calendaring.DateTime date);


    /**
     *  Clears the registration start date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationStart();


    /**
     *  Gets the metadata for the registration end date. 
     *
     *  @return metadata for the registration end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRegistrationEndMetadata();


    /**
     *  Sets the registration end date. 
     *
     *  @param  date the new registration end date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRegistrationEnd(org.osid.calendaring.DateTime date);


    /**
     *  Clears the registration end date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRegistrationEnd();


    /**
     *  Gets the metadata for the classes start date. 
     *
     *  @return metadata for the classes start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getClassesStartMetadata();


    /**
     *  Sets the classes start date. 
     *
     *  @param  date the new classes start date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setClassesStart(org.osid.calendaring.DateTime date);


    /**
     *  Clears the classes start date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClassesStart();


    /**
     *  Gets the metadata for the classes end date. 
     *
     *  @return metadata for the classes end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getClassesEndMetadata();


    /**
     *  Sets the classes end date. 
     *
     *  @param  date the new classes end date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setClassesEnd(org.osid.calendaring.DateTime date);


    /**
     *  Clears the classes end date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClassesEnd();


    /**
     *  Gets the metadata for the add date. 
     *
     *  @return metadata for the add date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAddDateMetadata();


    /**
     *  Sets the add date. 
     *
     *  @param  date the new add date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAddDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the add date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddDate();


    /**
     *  Gets the metadata for the drop date. 
     *
     *  @return metadata for the drop date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDropDateMetadata();


    /**
     *  Sets the drop date. 
     *
     *  @param  date the new drop date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDropDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the drop date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDropDate();


    /**
     *  Gets the metadata for the classes start date. 
     *
     *  @return metadata for the classes start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFinalExamStartMetadata();


    /**
     *  Sets the final exam start date. 
     *
     *  @param  date the new final exam start date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFinalExamStart(org.osid.calendaring.DateTime date);


    /**
     *  Clears the final exam start date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFinalExamStart();


    /**
     *  Gets the metadata for the final exam end date. 
     *
     *  @return metadata for the final exam end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFinalExamEndMetadata();


    /**
     *  Sets the final exam end date. 
     *
     *  @param  date the new final exam end date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFinalExamEnd(org.osid.calendaring.DateTime date);


    /**
     *  Clears the final exam end date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFinalExamEnd();


    /**
     *  Gets the metadata for the close date. 
     *
     *  @return metadata for the close date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCloseDateMetadata();


    /**
     *  Sets the close date. 
     *
     *  @param  date the new close date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> date </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCloseDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the close date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloseDate();


    /**
     *  Gets the <code> TermFormRecord </code> corresponding to the given term 
     *  record <code> Type. </code> 
     *
     *  @param  termRecordType a term record type 
     *  @return the term form record 
     *  @throws org.osid.NullArgumentException <code> termRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(termRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.records.TermFormRecord getTermFormRecord(org.osid.type.Type termRecordType)
        throws org.osid.OperationFailedException;
}
