//
// org.osid.course.batch.ActivityUnitBatchAdminSession
//
//     The OSID Java specification for org.osid.course.batch.ActivityUnitBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.batch;


/**
 *  <p>This session creates, updates, and deletes <code> ActivityUnits </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> ActivityUnit, </code> an <code> ActivityUnitForm </code> is 
 *  requested using <code> getActivityUnitFormsForCreate() </code> specifying 
 *  the desired course and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  ActivityUnitForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once an <code> ActivityUnitForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ActivityUnitForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ActivityUnitForms </code> returned from <code> 
 *  getActivityUnitFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  ActivityUnitForm. </code> In the case where there may be duplicates, any 
 *  <code> ActivityUnitForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ActivityUnitForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ActivityUnitForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createActivityUnits(), </code> errors specific to an individual 
 *  <code> ActivityUnitForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> ActivityUnitForm </code> through the <code> 
 *  ActivityUnitForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ActivityUnitForms </code> are requested to the 
 *  <code> ActivityUnit </code> <code> Id </code> that is to be updated using 
 *  <code> getActivityUnitFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> ActivityUnitForm </code> may be used to link the 
 *  request. Similarly, the <code> ActivityUnitForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ActivityUnitForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ActivityUnitForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ActivityUnitForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateActivityUnits(), </code> errors specific to an individual 
 *  <code> ActivityUnitForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> ActivityUnitForm </code> through the <code> 
 *  ActivityUnitForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> ActivityUnits </code> in bulk. To 
 *  unmap an <code> ActivityUnit </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  ActivityUnitCourseCatalogAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> ActivityUnit </code> itself 
 *  thus removing it from all known <code> CourseCatalog </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface ActivityUnitBatchAdminSession
    extends org.osid.course.ActivityUnitAdminSession {


    /**
     *  Gets the activity unitforms for creating a bunch of new activity 
     *  units. A new activity form is returned for each supplied course. 
     *
     *  @param  courseIds a list of course <code> Ids </code> 
     *  @param  activityUnitRecordTypes array of activity unit record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the activity unitforms 
     *  @throws org.osid.NotFoundException a <code> courseId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseIds </code> or 
     *          <code> activityUnitRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.batch.ActivityUnitBatchFormList getActivityUnitFormsForCreate(org.osid.id.IdList courseIds, 
                                                                                         org.osid.type.Type[] activityUnitRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> ActivityUnits. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  activityUnitForms the activity unit forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> activityUnitForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createActivityUnits(org.osid.course.batch.ActivityUnitBatchFormList activityUnitForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the activity unit forms for updating an existing set of activity 
     *  units. A new activity unitform should be requested for each update 
     *  transaction. 
     *
     *  @param  activityUnitIds the <code> Ids </code> of the <code> 
     *          ActivityUnit </code> 
     *  @return the activity unit form 
     *  @throws org.osid.NotFoundException an <code> activityUnitId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> activityUnitIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.batch.ActivityUnitBatchFormList getActivityUnitFormsForUpdate(org.osid.id.IdList activityUnitIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing activity units. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  activityUnitForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> activityUnitForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateActivityUnits(org.osid.course.batch.ActivityUnitBatchFormList activityUnitForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> ActivityUnits </code> in this <code> CourseCatalog 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllActivityUnits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes activity units for the given <code> Ids. </code> 
     *
     *  @param  activityUnitIds the <code> Ids </code> of the activity units 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> activityUnitIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActivityUnits(org.osid.id.IdList activityUnitIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all activity units mapped to the given course. 
     *
     *  @param  courseId an <code> Id </code> of a course 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteActivityUnitsForCourse(org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> ActivityUnit </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ActivityUnit </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another activity unit, it is reassigned to the 
     *  given activity unit <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasActivityUnits(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
