//
// org.osid.course.batch.CourseCatalogBatchAdminSession
//
//     The OSID Java specification for org.osid.course.batch.CourseCatalogBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.batch;


/**
 *  <p>This session creates, updates, and deletes <code> CourseCatalogs 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CourseCatalog, </code> a <code> CourseCatalogForm </code> is requested 
 *  using <code> getCourseCatalogFormsForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. Each of the returned <code> CourseCatalogForms </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once a <code> 
 *  CourseCatalogForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> CourseCatalogForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> CourseCatalogForms </code> returned from <code> 
 *  getCourseCatalogFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  CourseCatalogForm. </code> In the case where there may be duplicates, any 
 *  <code> CourseCatalogForm </code> of the same peer <code> Ids </code> may 
 *  be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> CourseCatalogForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  CourseCatalogForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createCourseCatalogs(), </code> errors specific to an individual 
 *  <code> CourseCatalogForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> CourseCatalogForm </code> through the <code> 
 *  CourseCatalogForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> CourseCatalogForms </code> are requested to the 
 *  <code> CourseCatalog </code> <code> Id </code> that is to be updated using 
 *  <code> getCourseCatalogFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> CourseCatalogForm </code> may be used to link the 
 *  request. Similarly, the <code> CourseCatalogForm </code> has metadata 
 *  about the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> CourseCatalogForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> CourseCatalogForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  CourseCatalogForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateCourseCatalogs(), </code> errors specific to an individual 
 *  <code> CourseCatalogForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> CourseCatalogForm </code> through the <code> 
 *  CourseCatalogForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> CourseCatalogs </code> in bulk. To 
 *  unmap a <code> CourseCatalog </code> from the current <code> Calendar, 
 *  </code> the <code> CourseCatalogCalendarAssignmentSession </code> should 
 *  be used. These delete operations attempt to remove the <code> 
 *  CourseCatalog </code> itself thus removing it from all known <code> 
 *  Calendar </code> catalogs. Bulk delete operations return the results in 
 *  <code> DeleteResponses. </code> </p>
 */

public interface CourseCatalogBatchAdminSession
    extends org.osid.course.CourseCatalogAdminSession {


    /**
     *  Gets the course catalog forms for creating a bunch of new course 
     *  catalogs. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  courseCatalogRecordTypes array of course catalog record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the course catalog forms 
     *  @throws org.osid.NullArgumentException <code> courseCatalogRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.batch.CourseCatalogBatchFormList getCourseCatalogFormsForCreate(long number, 
                                                                                           org.osid.type.Type[] courseCatalogRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> CourseCatalogs. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  courseCatalogForms the course catalog forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> courseCatalogForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCourseCatalogs(org.osid.course.batch.CourseCatalogBatchFormList courseCatalogForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the course catalog forms for updating an existing set of course 
     *  catalogs. A new course catalog form should be requested for each 
     *  update transaction. 
     *
     *  @param  courseCatalogIds the <code> Ids </code> of the <code> 
     *          CourseCatalog </code> 
     *  @return the course catalog form 
     *  @throws org.osid.NotFoundException a <code> courseCatalogId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseCatalogIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.batch.CourseCatalogBatchFormList getCourseCatalogFormsForUpdate(org.osid.id.IdList courseCatalogIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing course catalogs. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  courseCatalogForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> courseCatalogForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCourseCatalogs(org.osid.course.batch.CourseCatalogBatchFormList courseCatalogForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> CourseCatalogs </code> in this <code> Calendar 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCourseCatalogs()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes course catalogs for the given <code> Ids. </code> 
     *
     *  @param  courseCatalogIds the <code> Ids </code> of the course catalogs 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseCatalogIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCourseCatalogs(org.osid.id.IdList courseCatalogIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> CourseCatalog </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CourseCatalog </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another course catalog, it is reassigned to 
     *  the given course catalog <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCourseCatalogs(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
