//
// org.osid.course.batch.CourseOfferingBatchAdminSession
//
//     The OSID Java specification for org.osid.course.batch.CourseOfferingBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.batch;


/**
 *  <p>This session creates, updates, and deletes <code> CourseOfferings 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CourseOffering, </code> a <code> CourseOfferingForm </code> is requested 
 *  using <code> getCourseOfferingFormsForCreate() </code> specifying the 
 *  desired canonical course, term, and record <code> Types </code> or none if 
 *  no record <code> Types </code> are needed. Each of the returned <code> 
 *  CourseOfferingForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> CourseOfferingForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> CourseOfferingForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> CourseOfferingForms </code> returned from <code> 
 *  getCourseOfferingFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  CourseOfferingForm. </code> In the case where there may be duplicates, any 
 *  <code> CourseOfferingForm </code> of the same peer <code> Ids </code> may 
 *  be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> CourseOfferingForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  CourseOfferingForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createCourseOfferings(), </code> errors specific to an individual 
 *  <code> CourseOfferingForm </code> are indicated in the corresponding 
 *  <code> CreateResponse. </code> <code> CreateResponses </code> may be 
 *  linked to the originating <code> CourseOfferingForm </code> through the 
 *  <code> CourseOfferingForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> CourseOfferingForms </code> are requested to the 
 *  <code> CourseOffering </code> <code> Id </code> that is to be updated 
 *  using <code> getCourseOfferingFormsForUpdate() </code> where the reference 
 *  <code> Id </code> in the <code> CourseOfferingForm </code> may be used to 
 *  link the request. Similarly, the <code> CourseOfferingForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> CourseOfferingForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> CourseOfferingForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  CourseOfferingForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateCourseOfferings(), </code> errors specific to an individual 
 *  <code> CourseOfferingForm </code> are indicated in the corresponding 
 *  <code> UpdateResponse. </code> <code> UpdateResponses </code> may be 
 *  linked to the originating <code> CourseOfferingForm </code> through the 
 *  <code> CourseOfferingForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> CourseOfferings </code> in bulk. 
 *  To unmap a <code> CourseOffering </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  CourseOfferingCourseCatalogAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> CourseOffering </code> 
 *  itself thus removing it from all known <code> CourseCatalog </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface CourseOfferingBatchAdminSession
    extends org.osid.course.CourseOfferingAdminSession {


    /**
     *  Gets the course offering forms for creating a bunch of new course 
     *  offerings. A form is returned for each canonical course and term pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  courseOfferingRecordTypes array of course offering record 
     *          types to be included in each create operation or an empty list 
     *          if none 
     *  @return the course offering forms 
     *  @throws org.osid.NotFoundException a <code> courseId </code> or <code> 
     *          termId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          courseOfferingRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.batch.CourseOfferingBatchFormList getCourseOfferingFormsForCreate(org.osid.course.batch.CourseOfferingPeerList peers, 
                                                                                             org.osid.type.Type[] courseOfferingRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> CourseOfferings. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  courseOfferingForms the course offering forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> courseOfferingForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCourseOfferings(org.osid.course.batch.CourseOfferingBatchFormList courseOfferingForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the course offering forms for updating an existing set of course 
     *  offerings. A new course offering form should be requested for each 
     *  update transaction. 
     *
     *  @param  courseOfferingIds the <code> Ids </code> of the <code> 
     *          CourseOffering </code> 
     *  @return the course offering form 
     *  @throws org.osid.NotFoundException a <code> courseOfferingId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> courseOfferingIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.batch.CourseOfferingBatchFormList getCourseOfferingFormsForUpdate(org.osid.id.IdList courseOfferingIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing course offerings. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  courseOfferingForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> courseOfferingForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCourseOfferings(org.osid.course.batch.CourseOfferingBatchFormList courseOfferingForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> CourseOfferings </code> in this <code> 
     *  CourseCatalog </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCourseOfferings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes course offerings for the given <code> Ids. </code> 
     *
     *  @param  courseOfferingIds the <code> Ids </code> of the course 
     *          offerings to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseOfferingIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCourseOfferings(org.osid.id.IdList courseOfferingIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes course offerings for the given course. 
     *
     *  @param  courseId the <code> Id </code> of a course 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCourseOfferingsForCourse(org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes course offerings for the given term. 
     *
     *  @param  termId the <code> Id </code> of a term 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCourseOfferingsForTerm(org.osid.id.Id termId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes course offerings for the given course and term. 
     *
     *  @param  courseId the <code> Id </code> of a course 
     *  @param  termId the <code> Id </code> of a term 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> courseId </code> or 
     *          <code> termId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCourseOfferingsForCourseAndTerm(org.osid.id.Id courseId, 
                                                                                               org.osid.id.Id termId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes course offerings ineffective before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveCourseOfferingsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> CourseOffering </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CourseOffering </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another course offering, it is reassigned to 
     *  the given course offering <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCourseOfferings(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
