//
// org.osid.course.chronicle.AcademicRecordSession
//
//     The OSID Java specification for org.osid.course.chronicle.AcademicRecordSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session defines methods for retrieving an acedmic record for a 
 *  student. Lookup methods assume a only effective entries are returned. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> isolated course catalog view: All program entry methods in this 
 *      session operate, retrieve and pertain to program entries defined 
 *      explicitly in the current course catalog. Using an isolated view is 
 *      useful for managing <code> ProgramEntries </code> with the 
 *      ProgramEntry <code> AdminSession. </code> </li> 
 *      <li> federated course catalog view: All program entry lookup methods 
 *      in this session operate, retrieve and pertain to all program entries 
 *      defined in this course catalog and any other program entries 
 *      implicitly available in this course catalog through course catalog 
 *      inheritence. </li> 
 *  </ul>
 *  
 */

public interface AcademicRecordSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform academic record lookups. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAcademicRecord();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in catalogs which are children of this catalog in the 
     *  course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Gets completed program entries for a student with summary results. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return the returned <code> ProgramEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntryList getCompletedProgramEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets program entries for a student in which the student is currently 
     *  enrolled. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return the returned <code> ProgramEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntryList getEnrolledProgramEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective program entries for a student in the given term. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @param  termId the <code> Id </code> of a <code> Term </code> 
     *  @return the returned <code> ProgramEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> termId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntryList getProgramEntriesByTermForStudent(org.osid.id.Id resourceId, 
                                                                                        org.osid.id.Id termId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective course entries for a student in the given term. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @param  termId the <code> Id </code> of a <code> Term </code> 
     *  @return the returned <code> CourseEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> termId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesByTermForStudent(org.osid.id.Id resourceId, 
                                                                                      org.osid.id.Id termId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all completed course entries for a student. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return the returned <code> CourseEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCompletedCourseEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective credential entries for a student. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return the returned <code> CredentialEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CredentialEntryList getCredentialEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective credential entries for a student awarded within the 
     *  given date range inclusive. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> CredentialEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          , or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CredentialEntryList getCredentialEntriesByDateForStudent(org.osid.id.Id resourceId, 
                                                                                              org.osid.calendaring.DateTime from, 
                                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective assessment entries for a student. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return the returned <code> AssessmentEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntryList getAssessmentEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective assessment entries for a student completed within 
     *  the given date range inclusive. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> AssessmentEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          , or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AssessmentEntryList getAssessmentEntriesByDateForStudent(org.osid.id.Id resourceId, 
                                                                                              org.osid.calendaring.DateTime from, 
                                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective award entries for a student. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @return the returned <code> AwardEntryList </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AwardEntryList getAwardEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all effective award entries for a student completed within the 
     *  given date range inclusive. 
     *
     *  @param  resourceId the <code> Id </code> of a <code> Resource </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> AwardEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          , or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AwardEntryList getAwardEntriesByDateForStudent(org.osid.id.Id resourceId, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
