//
// org.osid.course.chronicle.AwardEntrySearchSession
//
//     The OSID Java specification for org.osid.course.chronicle.AwardEntrySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session provides methods for searching among <code> AwardEntries. 
 *  </code> The search query is constructed using the <code> AwardEntryQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getAwardEntriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> AwardEntries. </code> A more advanced search may 
 *  be performed with <code> getAwardEntriesBySearch(). </code> It accepts an 
 *  <code> AwardEntrySearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getAwardEntriesBySearch() </code> returns an <code> 
 *  AwardEntrySearchResults </code> that can be used to access the resulting 
 *  <code> AwardEntryList </code> or be used to perform a search within the 
 *  result set through <code> AwardEntrySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include award entries in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to courses 
 *      in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> AwardEntries may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> AwardEntryQuery. 
 *  </code> </p>
 */

public interface AwardEntrySearchSession
    extends org.osid.course.chronicle.AwardEntryQuerySession {


    /**
     *  Gets an award entry search. 
     *
     *  @return the award entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AwardEntrySearch getAwardEntrySearch();


    /**
     *  Gets an award entry search order. The <code> AwardEntrySearchOrder 
     *  </code> is supplied to an <code> AwardEntrySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the award entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AwardEntrySearchOrder getAwardEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  awardEntryQuery the award entry query 
     *  @param  awardEntrySearch the award entry search 
     *  @return the award entry search results 
     *  @throws org.osid.NullArgumentException <code> awardEntryQuery </code> 
     *          or <code> awardEntrySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> awardEntryQuery </code> 
     *          or <code> AwardEntrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AwardEntrySearchResults getAwardEntriesBySearch(org.osid.course.chronicle.AwardEntryQuery awardEntryQuery, 
                                                                                     org.osid.course.chronicle.AwardEntrySearch awardEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an award entry query from an inspector. The inspector is 
     *  available from an <code> AwardEntrySearchResults. </code> 
     *
     *  @param  awardEntryQueryInspector an award entry query inspector 
     *  @return the award entry query 
     *  @throws org.osid.NullArgumentException <code> awardEntryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> awardEntryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.AwardEntryQuery getAwardEntryQueryFromInspector(org.osid.course.chronicle.AwardEntryQueryInspector awardEntryQueryInspector);
}
