//
// org.osid.course.chronicle.CourseChronicleProfile
//
//     The OSID Java specification for org.osid.course.chronicle.CourseChronicleProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>The course chronicle profile describes the interoperability among 
 *  course chronicle services. </p>
 */

public interface CourseChronicleProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any course catalog federation is exposed. Federation is 
     *  exposed when a specific course catalog may be identified, selected and 
     *  used to create a lookup or admin session. Federation is not exposed 
     *  when a set of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if retrieving an academic record is supported. 
     *
     *  @return <code> true </code> if academic record is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademicRecord();


    /**
     *  Tests if looking up program entries is supported. 
     *
     *  @return <code> true </code> if program entry lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntryLookup();


    /**
     *  Tests if querying program entries is supported. 
     *
     *  @return <code> true </code> if program entry query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntryQuery();


    /**
     *  Tests if searching program entries is supported. 
     *
     *  @return <code> true </code> if program entry search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntrySearch();


    /**
     *  Tests if program entry administrative service is supported. 
     *
     *  @return <code> true </code> if program entry administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntryAdmin();


    /**
     *  Tests if a program entry notification service is supported. 
     *
     *  @return <code> true </code> if program entry notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntryNotification();


    /**
     *  Tests if a program entry cataloging service is supported. 
     *
     *  @return <code> true </code> if program entry cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntryCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps program entries to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntryCourseCatalogAssignment();


    /**
     *  Tests if a program entry smart course catalog session is available. 
     *
     *  @return <code> true </code> if a program entry smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntrySmartCourseCatalog();


    /**
     *  Tests if looking up course entries is supported. 
     *
     *  @return <code> true </code> if course entry lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntryLookup();


    /**
     *  Tests if querying course entries is supported. 
     *
     *  @return <code> true </code> if course entry query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntryQuery();


    /**
     *  Tests if searching course entries is supported. 
     *
     *  @return <code> true </code> if course entry search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntrySearch();


    /**
     *  Tests if course entry administrative service is supported. 
     *
     *  @return <code> true </code> if course entry administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntryAdmin();


    /**
     *  Tests if a course entry notification service is supported. 
     *
     *  @return <code> true </code> if course entry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntryNotification();


    /**
     *  Tests if a course entry cataloging service is supported. 
     *
     *  @return <code> true </code> if course entry cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntryCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps course entries to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntryCourseCatalogAssignment();


    /**
     *  Tests if a course entry smart course catalog session is available. 
     *
     *  @return <code> true </code> if a course entry smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntrySmartCourseCatalog();


    /**
     *  Tests if looking up credential entries is supported. 
     *
     *  @return <code> true </code> if credential entry lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntryLookup();


    /**
     *  Tests if querying credential entries is supported. 
     *
     *  @return <code> true </code> if credential entry query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntryQuery();


    /**
     *  Tests if searching credential entries is supported. 
     *
     *  @return <code> true </code> if credential entry search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntrySearch();


    /**
     *  Tests if credential entry administrative service is supported. 
     *
     *  @return <code> true </code> if credential entry administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntryAdmin();


    /**
     *  Tests if a credential entry notification service is supported. 
     *
     *  @return <code> true </code> if credential entry notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntryNotification();


    /**
     *  Tests if a credential entry cataloging service is supported. 
     *
     *  @return <code> true </code> if credential entry cataloging is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntryCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps credential entries to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntryCourseCatalogAssignment();


    /**
     *  Tests if a credential entry smart course catalog session is available. 
     *
     *  @return <code> true </code> if a credential entry smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntrySmartCourseCatalog();


    /**
     *  Tests if looking up assessment entries is supported. 
     *
     *  @return <code> true </code> if assessment entry lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntryLookup();


    /**
     *  Tests if querying assessment entries is supported. 
     *
     *  @return <code> true </code> if assessment entry query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntryQuery();


    /**
     *  Tests if searching assessment entries is supported. 
     *
     *  @return <code> true </code> if assessment entry search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntrySearch();


    /**
     *  Tests if assessment entry administrative service is supported. 
     *
     *  @return <code> true </code> if assessment entry administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntryAdmin();


    /**
     *  Tests if an assessment entry notification service is supported. 
     *
     *  @return <code> true </code> if assessment entry notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntryNotification();


    /**
     *  Tests if an assessment entry cataloging service is supported. 
     *
     *  @return <code> true </code> if assessment entry cataloging is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntryCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps assessment entries to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntryCourseCatalogAssignment();


    /**
     *  Tests if an assessment entry smart course catalog session is 
     *  available. 
     *
     *  @return <code> true </code> if an assessment entry smart course 
     *          catalog session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntrySmartCourseCatalog();


    /**
     *  Tests if looking up award entries is supported. 
     *
     *  @return <code> true </code> if award entry lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntryLookup();


    /**
     *  Tests if querying award entries is supported. 
     *
     *  @return <code> true </code> if award entry query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntryQuery();


    /**
     *  Tests if searching award entries is supported. 
     *
     *  @return <code> true </code> if award entry search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntrySearch();


    /**
     *  Tests if award entry administrative service is supported. 
     *
     *  @return <code> true </code> if award entry administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntryAdmin();


    /**
     *  Tests if an award entry notification service is supported. 
     *
     *  @return <code> true </code> if award entry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntryNotification();


    /**
     *  Tests if an award entry cataloging service is supported. 
     *
     *  @return <code> true </code> if award entry cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntryCourseCatalog();


    /**
     *  Tests if a course cataloging service is supported. A course cataloging 
     *  service maps award entries to catalogs. 
     *
     *  @return <code> true </code> if course cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntryCourseCatalogAssignment();


    /**
     *  Tests if an award entry smart course catalog session is available. 
     *
     *  @return <code> true </code> if an award entry smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntrySmartCourseCatalog();


    /**
     *  Tests if a course chronicle batch service is available. 
     *
     *  @return <code> true </code> if a course chronicle batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseChronicalBatch();


    /**
     *  Gets the supported <code> ProgramEntry </code> record types. 
     *
     *  @return a list containing the supported <code> ProgramEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProgramEntryRecordTypes();


    /**
     *  Tests if the given <code> ProgramEntry </code> record type is 
     *  supported. 
     *
     *  @param  programEntryRecordType a <code> Type </code> indicating a 
     *          <code> ProgramEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> programEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntryRecordType(org.osid.type.Type programEntryRecordType);


    /**
     *  Gets the supported <code> ProgramEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> ProgramEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProgramEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> ProgramEntry </code> search record type is 
     *  supported. 
     *
     *  @param  programEntrySearchRecordType a <code> Type </code> indicating 
     *          a <code> ProgramEntry </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          programEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramEntrySearchRecordType(org.osid.type.Type programEntrySearchRecordType);


    /**
     *  Gets the supported <code> CourseEntry </code> record types. 
     *
     *  @return a list containing the supported <code> CourseEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseEntryRecordTypes();


    /**
     *  Tests if the given <code> CourseEntry </code> record type is 
     *  supported. 
     *
     *  @param  courseEntryRecordType a <code> Type </code> indicating a 
     *          <code> CourseEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntryRecordType(org.osid.type.Type courseEntryRecordType);


    /**
     *  Gets the supported <code> CourseEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> CourseEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCourseEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> CourseEntry </code> search record type is 
     *  supported. 
     *
     *  @param  courseEntrySearchRecordType a <code> Type </code> indicating a 
     *          <code> CourseEntry </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseEntrySearchRecordType(org.osid.type.Type courseEntrySearchRecordType);


    /**
     *  Gets the supported <code> CredentialEntry </code> record types. 
     *
     *  @return a list containing the supported <code> CredentialEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCredentialEntryRecordTypes();


    /**
     *  Tests if the given <code> CredentialEntry </code> record type is 
     *  supported. 
     *
     *  @param  credentialEntryRecordType a <code> Type </code> indicating a 
     *          <code> CredentialEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialEntryRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntryRecordType(org.osid.type.Type credentialEntryRecordType);


    /**
     *  Gets the supported <code> CredentialEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> CredentialEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCredentialEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> CredentialEntry </code> search record type 
     *  is supported. 
     *
     *  @param  credentialEntrySearchRecordType a <code> Type </code> 
     *          indicating a <code> CredentialEntry </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialEntrySearchRecordType(org.osid.type.Type credentialEntrySearchRecordType);


    /**
     *  Gets the supported <code> AssessmentEntry </code> record types. 
     *
     *  @return a list containing the supported <code> AssessmentEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentEntryRecordTypes();


    /**
     *  Tests if the given <code> AssessmentEntry </code> record type is 
     *  supported. 
     *
     *  @param  assessmentEntryRecordType an <code> Type </code> indicating an 
     *          <code> AssessmentEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentEntryRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntryRecordType(org.osid.type.Type assessmentEntryRecordType);


    /**
     *  Gets the supported <code> AssessmentEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> AssessmentEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAssessmentEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> AssessmentEntry </code> search record type 
     *  is supported. 
     *
     *  @param  assessmentEntrySearchRecordType an <code> Type </code> 
     *          indicating an <code> AssessmentEntry </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentEntrySearchRecordType(org.osid.type.Type assessmentEntrySearchRecordType);


    /**
     *  Gets the supported <code> AwardEntry </code> record types. 
     *
     *  @return a list containing the supported <code> AwardEntry </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAwardEntryRecordTypes();


    /**
     *  Tests if the given <code> AwardEntry </code> record type is supported. 
     *
     *  @param  awardEntryRecordType an <code> Type </code> indicating an 
     *          <code> AwardEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> awardEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntryRecordType(org.osid.type.Type awardEntryRecordType);


    /**
     *  Gets the supported <code> AwardEntry </code> search record types. 
     *
     *  @return a list containing the supported <code> AwardEntry </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAwardEntrySearchRecordTypes();


    /**
     *  Tests if the given <code> AwardEntry </code> search record type is 
     *  supported. 
     *
     *  @param  awardEntrySearchRecordType an <code> Type </code> indicating 
     *          an <code> AwardEntry </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          awardEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardEntrySearchRecordType(org.osid.type.Type awardEntrySearchRecordType);
}
