//
// org.osid.course.chronicle.CourseEntry
//
//     The OSID Java specification for org.osid.course.chronicle.CourseEntry.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>A <code> CourseEntry </code> represents an academic record entry for a 
 *  course. The fields in the <code> CourseEntry </code> are specific to a 
 *  <code> Term. </code> </p>
 */

public interface CourseEntry
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the <code> Student. </code> 
     *
     *  @return the student <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStudentId();


    /**
     *  Gets the <code> Student. </code> 
     *
     *  @return the student 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getStudent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Course. </code> 
     *
     *  @return the course <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseId();


    /**
     *  Gets the <code> Course. </code> 
     *
     *  @return the course 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Course getCourse()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Term. </code> 
     *
     *  @return the term <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTermId();


    /**
     *  Gets the <code> Term. </code> 
     *
     *  @return the term 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Term getTerm()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the course has been completed. 
     *
     *  @return <code> true </code> if the course has been completed, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isComplete();


    /**
     *  Gets the <code> Id </code> of the <code> GradeSystem. </code> 
     *
     *  @return the grade system <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCreditScaleId();


    /**
     *  Gets the <code> GradeSystem. </code> 
     *
     *  @return the grade system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getCreditScale()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the number of credits earned in this course. 
     *
     *  @return the credits earned 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getCreditsEarned();


    /**
     *  Tests if a grade is available. 
     *
     *  @return <code> true </code> if a grade is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasGrade();


    /**
     *  Gets the <code> Id </code> of the <code> Grade. </code> 
     *
     *  @return the grade <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasGrade() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradeId();


    /**
     *  Gets the <code> Grade. </code> 
     *
     *  @return the grade 
     *  @throws org.osid.IllegalStateException <code> hasGrade() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getGrade()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a score is available. 
     *
     *  @return <code> true </code> if a score is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasScore();


    /**
     *  Gets the <code> Id </code> of the <code> GradeSystem. </code> 
     *
     *  @return the grade system <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasScore() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getScoreScaleId();


    /**
     *  Gets the <code> GradeSystem. </code> 
     *
     *  @return the grade system 
     *  @throws org.osid.IllegalStateException <code> hasScore() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getScoreScale()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the cumulative score. 
     *
     *  @return the score 
     *  @throws org.osid.IllegalStateException <code> hasScore() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getScore();


    /**
     *  Tests if <code> Registrations </code> are available. 
     *
     *  @return <code> true </code> if registrations are available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasRegistrations();


    /**
     *  Gets the <code> Ids </code> of the <code> Registrations. </code> 
     *
     *  @return the registrations <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasRegistrations() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRegistrationIds();


    /**
     *  Gets the <code> Registrations. </code> 
     *
     *  @return the registrations 
     *  @throws org.osid.IllegalStateException <code> hasRegistrations() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationList getRegistrations()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the course entry record corresponding to the given <code> 
     *  CourseEntry </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  courseEntryRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(courseEntryRecordType) </code> is <code> true </code> . 
     *
     *  @param  courseEntryRecordType the type of course entry record to 
     *          retrieve 
     *  @return the course entry record 
     *  @throws org.osid.NullArgumentException <code> courseEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(courseEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.records.CourseEntryRecord getCourseEntryRecord(org.osid.type.Type courseEntryRecordType)
        throws org.osid.OperationFailedException;
}
