//
// org.osid.course.chronicle.CourseEntryLookupSession
//
//     The OSID Java specification for org.osid.course.chronicle.CourseEntryLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session defines methods for retrieving course entries. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All course entry methods in this 
 *      session operate, retrieve and pertain to course entries defined 
 *      explicitly in the current course catalog. Using an isolated view is 
 *      useful for managing <code> CourseEntries </code> with the CourseEntry 
 *      <code> AdminSession. </code> </li> 
 *      <li> federated course catalog view: All course entry lookup methods in 
 *      this session operate, retrieve and pertain to all course entries 
 *      defined in this course catalog and any other course entries implicitly 
 *      available in this course catalog through course catalog inheritence. 
 *      </li> 
 *      <li> effective course entry view: All course entry lookup methods 
 *      return course entry where the current date falls in between the 
 *      effective dates inclusive. </li> 
 *      <li> any course entry view: Course entries of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Course entries may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> CourseEntry. </code> </p>
 */

public interface CourseEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> CourseEntry </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCourseEntries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCourseEntryView();


    /**
     *  A complete view of the <code> CourseEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCourseEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include course entries in catalogs which are children of this catalog 
     *  in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only course entries whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveCourseEntryView();


    /**
     *  All course entries of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveCourseEntryView();


    /**
     *  Gets the <code> CourseEntry </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CourseEntry </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> CourseEntry </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  courseEntryId the <code> Id </code> of the <code> CourseEntry 
     *          </code> to retrieve 
     *  @return the returned <code> CourseEntry </code> 
     *  @throws org.osid.NotFoundException no <code> CourseEntry </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntry getCourseEntry(org.osid.id.Id courseEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  course entries specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> CourseEntries </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  courseEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> CourseEntryList </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> courseEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesByIds(org.osid.id.IdList courseEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> corresponding to the given 
     *  course entry genus <code> Type </code> which does not include course 
     *  entries of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course entries or an error results. Otherwise, the returned list may 
     *  contain only those course entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  courseEntryGenusType a course entry genus type 
     *  @return the returned <code> CourseEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> courseEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesByGenusType(org.osid.type.Type courseEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> corresponding to the given 
     *  course entry genus <code> Type </code> and include any additional 
     *  course entries with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course entries or an error results. Otherwise, the returned list may 
     *  contain only those course entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  courseEntryGenusType a course entry genus type 
     *  @return the returned <code> CourseEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> courseEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesByParentGenusType(org.osid.type.Type courseEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> containing the given course 
     *  entry record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course entries or an error results. Otherwise, the returned list may 
     *  contain only those course entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  courseEntryRecordType a course entry record type 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.NullArgumentException <code> courseEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesByRecordType(org.osid.type.Type courseEntryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. This 
     *  method return sthe same results in either effective status mode. 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesOnDate(org.osid.calendaring.DateTime from, 
                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> for the given student <code> . 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> for the given student effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. This method return sthe same results in either effective 
     *  status mode. 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          , or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesForStudentOnDate(org.osid.id.Id resourceId, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> for the given course. 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesForCourse(org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> for the given course effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseId, from </code> , 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesForCourseOnDate(org.osid.id.Id courseId, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> for the given student and course 
     *  <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  courseId a course <code> Id </code> 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> courseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesForStudentAndCourse(org.osid.id.Id resourceId, 
                                                                                         org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseEntryList </code> for the given student and course 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  courseId a course <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> CourseEntryList </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, courseId, 
     *          from </code> , or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntriesForStudentAndCourseOnDate(org.osid.id.Id resourceId, 
                                                                                               org.osid.id.Id courseId, 
                                                                                               org.osid.calendaring.DateTime from, 
                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseEntries. </code> 
     *  
     *  In plenary mode, the returned list contains all known course entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those course entries that are accessible through this session. 
     *  
     *  In effective mode, course entries are returned that are currently 
     *  effective. In any effective mode, effective course entries and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> CourseEntries </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryList getCourseEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
