//
// org.osid.course.chronicle.CourseEntrySearchSession
//
//     The OSID Java specification for org.osid.course.chronicle.CourseEntrySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session provides methods for searching among <code> CourseEntries. 
 *  </code> The search query is constructed using the <code> CourseEntryQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getCourseEntriesByQuery() </code> is the basic search method 
 *  and returns a list of <code> CourseEntries. </code> A more advanced search 
 *  may be performed with <code> getCourseEntriesBySearch(). </code> It 
 *  accepts a <code> CourseEntrySearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getCourseEntriesBySearch() </code> returns a 
 *  <code> CourseEntrySearchResults </code> that can be used to access the 
 *  resulting <code> CourseEntryList </code> or be used to perform a search 
 *  within the result set through <code> CourseEntrySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include course entries in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to courses 
 *      in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> CourseEntries may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  CourseEntryQuery. </code> </p>
 */

public interface CourseEntrySearchSession
    extends org.osid.course.chronicle.CourseEntryQuerySession {


    /**
     *  Gets a course entry search. 
     *
     *  @return the course entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntrySearch getCourseEntrySearch();


    /**
     *  Gets a course entry search order. The <code> CourseEntrySearchOrder 
     *  </code> is supplied to a <code> CourseEntrySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the course entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntrySearchOrder getCourseEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  courseEntryQuery the course entry query 
     *  @param  courseEntrySearch the course entry search 
     *  @return the course entry search results 
     *  @throws org.osid.NullArgumentException <code> courseEntryQuery </code> 
     *          or <code> courseEntrySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> courseEntryQuery </code> 
     *          or <code> CourseEntrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntrySearchResults getCourseEntriesBySearch(org.osid.course.chronicle.CourseEntryQuery courseEntryQuery, 
                                                                                       org.osid.course.chronicle.CourseEntrySearch courseEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a course entry query from an inspector. The inspector is 
     *  available from a <code> CourseEntrySearchResults. </code> 
     *
     *  @param  courseEntryQueryInspector a course entry query inspector 
     *  @return the course entry query 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseEntryQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> courseEntryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CourseEntryQuery getCourseEntryQueryFromInspector(org.osid.course.chronicle.CourseEntryQueryInspector courseEntryQueryInspector);
}
