//
// org.osid.course.chronicle.CredentialEntryAdminSession
//
//     The OSID Java specification for org.osid.course.chronicle.CredentialEntryAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session creates, updates, and deletes <code> CredentialEntries. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  CredentialEntry, </code> a <code> CredentialEntryForm </code> is requested 
 *  using <code> getCredentialEntryFormForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> CredentialEntryForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  CredentialEntryForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> CredentialEntryForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CredentialEntryForms </code> are requested to the 
 *  <code> CredentialEntry </code> <code> Id </code> that is to be updated 
 *  using <code> getCredentialEntryFormForUpdate(). </code> Similarly, the 
 *  <code> CredentialEntryForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> CredentialEntryForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> CredentialEntries. </code> To 
 *  unmap a <code> CredentialEntry </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  CredentialEntryCourseCatalogAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> CredentialEntry 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CredentialEntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> CredentialEntries. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> CredentialEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialEntry </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCredentialEntries();


    /**
     *  Tests if this user can create a single <code> Porgram </code> using 
     *  the desired record types. While <code> 
     *  CourseChronicleManager.getCredentialEntryRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> CredentialEntry. 
     *  </code> Providing an empty array tests if a <code> CredentialEntry 
     *  </code> can be created with no records. 
     *
     *  @param  credentialEntryRecordTypes array of credential entry record 
     *          types 
     *  @return <code> true </code> if <code> CredentialEntry </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialEntryRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCredentialEntryWithRecordTypes(org.osid.type.Type[] credentialEntryRecordTypes);


    /**
     *  Gets the credential entry form for creating new credential entries. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  credentialId a credential <code> Id </code> 
     *  @param  resourceId a student <code> Id </code> 
     *  @param  credentialEntryRecordTypes array of credential entry record 
     *          types 
     *  @return the credential entry form 
     *  @throws org.osid.NotFoundException <code> credentialId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> credentialId, resourceId 
     *          </code> , or <code> credentialEntryRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CredentialEntryForm getCredentialEntryFormForCreate(org.osid.id.Id credentialId, 
                                                                                         org.osid.id.Id resourceId, 
                                                                                         org.osid.type.Type[] credentialEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CredentialEntry. </code> 
     *
     *  @param  credentialEntryForm the form for this <code> CredentialEntry 
     *          </code> 
     *  @return the new <code> CredentialEntry </code> 
     *  @throws org.osid.IllegalStateException <code> credentialEntryForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> credentialEntryForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> credentialEntryForm 
     *          </code> did not originate from <code> 
     *          getCredentialEntryFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CredentialEntry createCredentialEntry(org.osid.course.chronicle.CredentialEntryForm credentialEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> CredentialEntries. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> CredentialEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialEntry </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCredentialEntries();


    /**
     *  Gets the credential entry form for updating an existing credential 
     *  entry. A new credential entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  credentialEntryId the <code> Id </code> of the <code> 
     *          CredentialEntry </code> 
     *  @return the credential entry form 
     *  @throws org.osid.NotFoundException <code> credentialEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> credentialEntryId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.CredentialEntryForm getCredentialEntryFormForUpdate(org.osid.id.Id credentialEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing credential entry. 
     *
     *  @param  credentialEntryForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> credentialEntryForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> credentialEntryForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> credentialEntryForm 
     *          </code> did not originate from <code> 
     *          getCredentialEntryFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCredentialEntry(org.osid.course.chronicle.CredentialEntryForm credentialEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> CredentialEntries. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> CredentialEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialEntry </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCredentialEntries();


    /**
     *  Deletes a <code> CredentialEntry. </code> 
     *
     *  @param  credentialEntryId the <code> Id </code> of the <code> 
     *          CredentialEntry </code> to remove 
     *  @throws org.osid.NotFoundException <code> credentialEntryId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> credentialEntryId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCredentialEntry(org.osid.id.Id credentialEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  CredentialEntries. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialEntry </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCredentialEntryAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CredentialEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> CredentialEntry </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another credential entry, it is 
     *  reassigned to the given credential entry <code> Id. </code> 
     *
     *  @param  credentialEntryId the <code> Id </code> of a <code> 
     *          CredentialEntry </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> credentialEntryId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> credentialEntryId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCredentialEntry(org.osid.id.Id credentialEntryId, 
                                     org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
