//
// org.osid.course.chronicle.ProgramEntrySearchSession
//
//     The OSID Java specification for org.osid.course.chronicle.ProgramEntrySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle;


/**
 *  <p>This session provides methods for searching among <code> 
 *  ProgramEntries. </code> The search query is constructed using the <code> 
 *  ProgramEntryQuery. </code> </p> 
 *  
 *  <p> <code> getProgramEntriesByQuery() </code> is the basic search method 
 *  and returns a list of <code> ProgramEntries. </code> A more advanced 
 *  search may be performed with <code> getProgramEntriesBySearch(). </code> 
 *  It accepts a <code> ProgramEntrySearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getProgramEntriesBySearch() </code> 
 *  returns a <code> ProgramEntrySearchResults </code> that can be used to 
 *  access the resulting <code> ProgramEntryList </code> or be used to perform 
 *  a search within the result set through <code> ProgramEntrySearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include program entries 
 *      in course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to courses 
 *      in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> ProgramEntries may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ProgramEntryQuery. </code> </p>
 */

public interface ProgramEntrySearchSession
    extends org.osid.course.chronicle.ProgramEntryQuerySession {


    /**
     *  Gets a program entry search. 
     *
     *  @return the program entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntrySearch getProgramEntrySearch();


    /**
     *  Gets a program entry search order. The <code> ProgramEntrySearchOrder 
     *  </code> is supplied to a <code> ProgramEntrySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the program entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntrySearchOrder getProgramEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  programEntryQuery the program entry query 
     *  @param  programEntrySearch the program entry search 
     *  @return the program entry search results 
     *  @throws org.osid.NullArgumentException <code> programEntryQuery 
     *          </code> or <code> programEntrySearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> programEntryQuery </code> 
     *          or <code> ProgramEntrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntrySearchResults getProgramEntriesBySearch(org.osid.course.chronicle.ProgramEntryQuery programEntryQuery, 
                                                                                         org.osid.course.chronicle.ProgramEntrySearch programEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a program entry query from an inspector. The inspector is 
     *  available from a <code> ProgramEntrySearchResults. </code> 
     *
     *  @param  programEntryQueryInspector a program entry query inspector 
     *  @return the program entry query 
     *  @throws org.osid.NullArgumentException <code> 
     *          programEntryQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          programEntryQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.ProgramEntryQuery getProgramEntryQueryFromInspector(org.osid.course.chronicle.ProgramEntryQueryInspector programEntryQueryInspector);
}
