//
// org.osid.course.chronicle.batch.AssessmentEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.course.chronicle.batch.AssessmentEntryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle.batch;


/**
 *  <p>This session creates, updates, and deletes <code> AssessmentEntries 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AssessmentEntry, </code> an <code> AssessmentEntryForm </code> is 
 *  requested using <code> getAssessmentEntryFormsForCreate() </code> 
 *  specifying the desired assessment, student, and record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. Each of the 
 *  returned <code> AssessmentEntryForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once an <code> AssessmentEntryForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> AssessmentEntryForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> The <code> AssessmentEntryForms </code> returned from <code> 
 *  getAssessmentEntryFormsForCreate() </code> may be linked to the 
 *  originating request through the peer <code> Ids </code> of the <code> 
 *  AssessmentEntryForm. </code> In the case where there may be duplicates, 
 *  any <code> AssessmentEntryForm </code> of the same peer <code> Ids </code> 
 *  may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> AssessmentEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  AssessmentEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createAssessmentEntries(), </code> errors specific to an individual 
 *  <code> AssessmentEntryForm </code> are indicated in the corresponding 
 *  <code> CreateResponse. </code> <code> CreateResponses </code> may be 
 *  linked to the originating <code> AssessmentEntryForm </code> through the 
 *  <code> AssessmentEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> AssessmentEntryForms </code> are requested to the 
 *  <code> AssessmentEntry </code> <code> Id </code> that is to be updated 
 *  using <code> getAssessmentEntryFormsForUpdate() </code> where the 
 *  reference <code> Id </code> in the <code> AssessmentEntryForm </code> may 
 *  be used to link the request. Similarly, the <code> AssessmentEntryForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> AssessmentEntryForm 
 *  </code> can only be used once for a successful update and cannot be 
 *  reused. </p> 
 *  
 *  <p> Once a batch of <code> AssessmentEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  AssessmentEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateAssessmentEntries(), </code> errors specific to an individual 
 *  <code> AssessmentEntryForm </code> are indicated in the corresponding 
 *  <code> UpdateResponse. </code> <code> UpdateResponses </code> may be 
 *  linked to the originating <code> AssessmentEntryForm </code> through the 
 *  <code> AssessmentEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> AssessmentEntries </code> in bulk. 
 *  To unmap an <code> AssessmentEntry </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  AssessmentEntryCourseCatalogAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> AssessmentEntry 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface AssessmentEntryBatchAdminSession
    extends org.osid.course.chronicle.AssessmentEntryAdminSession {


    /**
     *  Gets the assessment entry forms for creating a bunch of new 
     *  cressmentedential entries. An <code> AssessmentEntryForm </code> is 
     *  returned for each assessment and student pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  assessmentEntryRecordTypes array of assessment entry record 
     *          types to be included in each create operation or an empty list 
     *          if none 
     *  @return the assessment entry forms 
     *  @throws org.osid.NotFoundException an <code> assessmentId </code> or 
     *          <code> stuidentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          assessmentEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.AssessmentEntryBatchFormList getAssessmentEntryFormsForCreate(org.osid.course.chronicle.batch.AssessmentEntryPeerList peers, 
                                                                                                         org.osid.type.Type[] assessmentEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> AssessmentEntries. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  assessmentEntryForms the assessment entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAssessmentEntries(org.osid.course.chronicle.batch.AssessmentEntryBatchFormList assessmentEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the assessment entry forms for updating an existing set of 
     *  assessment entries. A new assessment entry form should be requested 
     *  for each update transaction. 
     *
     *  @param  assessmentEntryIds the <code> Ids </code> of the <code> 
     *          AssessmentEntry </code> 
     *  @return the assessment entry form 
     *  @throws org.osid.NotFoundException anassessment <code> EntryId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.AssessmentEntryBatchFormList getAssessmentEntryFormsForUpdate(org.osid.id.IdList assessmentEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing assessment entries. This method returns an error if 
     *  the entire operation fails. Otherwise, the status of an individual 
     *  update operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  assessmentEntryForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAssessmentEntries(org.osid.course.chronicle.batch.AssessmentEntryBatchFormList assessmentEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> AssessmentEntries </code> in this <code> 
     *  CourseCatalog </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAssessmentEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes assessment entries for the given <code> Ids. </code> 
     *
     *  @param  assessmentEntryIds the <code> Ids </code> of the assessment 
     *          entries to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> assessmentEntryIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentEntries(org.osid.id.IdList assessmentEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all assessment entries for the given assessment. 
     *
     *  @param  assessmentId an <code> Id </code> of an assessment 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentEntriesForAssessment(org.osid.id.Id assessmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all assessment entries for the given student. 
     *
     *  @param  resourceId an <code> Id </code> of a student 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAssessmentEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes assessment entries expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveAssessmentEntriesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AssessmentEntry </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another sessment entry, it is reassigned to 
     *  the given assessment entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAssessmentEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
