//
// org.osid.course.chronicle.batch.AwardEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.course.chronicle.batch.AwardEntryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle.batch;


/**
 *  <p>This session creates, updates, and deletes <code> AwardEntries </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> AwardEntry, </code> an <code> AwardEntryForm </code> is requested 
 *  using <code> getAwardEntryFormsForCreate() </code> specifying the desired 
 *  award, student, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  AwardEntryForms </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once an <code> AwardEntryForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> AwardEntryForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> AwardEntryForms </code> returned from <code> 
 *  getAwardEntryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> AwardEntryForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  AwardEntryForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> AwardEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  AwardEntryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createAwardEntries(), </code> errors specific to an individual <code> 
 *  AwardEntryForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> AwardEntryForm </code> through the <code> 
 *  AwardEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> AwardEntryForms </code> are requested to the 
 *  <code> AwardEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getAwardEntryFormsForUpdate() </code> where the reference <code> Id 
 *  </code> in the <code> AwardEntryForm </code> may be used to link the 
 *  request. Similarly, the <code> AwardEntryForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> AwardEntryForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> AwardEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  AwardEntryForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateAwardEntries(), </code> errors specific to an individual <code> 
 *  AwardEntryForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> AwardEntryForm </code> through the <code> 
 *  AwardEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> AwardEntries </code> in bulk. To 
 *  unmap an <code> AwardEntry </code> from the current <code> CourseCatalog, 
 *  </code> the <code> AwardEntryCourseCatalogAssignmentSession </code> should 
 *  be used. These delete operations attempt to remove the <code> AwardEntry 
 *  </code> itself thus removing it from all known <code> CourseCatalog 
 *  </code> catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface AwardEntryBatchAdminSession
    extends org.osid.course.chronicle.AwardEntryAdminSession {


    /**
     *  Gets the award entry forms for creating a bunch of new award entries. 
     *  A form is returned for each award and student pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  awardEntryRecordTypes array of award entry record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the award entry forms 
     *  @throws org.osid.NotFoundException an <code> awardId </code> or <code> 
     *          studentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          awardEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.AwardEntryBatchFormList getAwardEntryFormsForCreate(org.osid.course.chronicle.batch.AwardEntryPeerList peers, 
                                                                                               org.osid.type.Type[] awardEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> AwardEntries. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  awardEntryForms the award entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> awardEntryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createAwardEntries(org.osid.course.chronicle.batch.AwardEntryBatchFormList awardEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the award entry forms for updating an existing set of award 
     *  entries. A new award entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  awardEntryIds the <code> Ids </code> of the <code> AwardEntry 
     *          </code> 
     *  @return the award entry form 
     *  @throws org.osid.NotFoundException an <code> awardEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> awardEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.AwardEntryBatchFormList getAwardEntryFormsForUpdate(org.osid.id.IdList awardEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing award entries. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  awardEntryForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> awardEntryForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateAwardEntries(org.osid.course.chronicle.batch.AwardEntryBatchFormList awardEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> AwardEntries </code> in this <code> CourseCatalog 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllAwardEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes award entries for the given <code> Ids. </code> 
     *
     *  @param  awardEntryIds the <code> Ids </code> of the award entries to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> awardEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAwardEntries(org.osid.id.IdList awardEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes award entries for the given award. 
     *
     *  @param  awardId an <code> Id </code> of an award 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAwardEntriesForAward(org.osid.id.IdList awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes award entries for the given student. 
     *
     *  @param  resourceId an <code> Id </code> of a student 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAwardEntriesForStudent(org.osid.id.IdList resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes award entries expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveAwardEntriesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> AwardEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> AwardEntry </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another award entry, it is reassigned to the 
     *  given award entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasAwardEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
