//
// org.osid.course.chronicle.batch.ProgramEntryBatchAdminSession
//
//     The OSID Java specification for org.osid.course.chronicle.batch.ProgramEntryBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.chronicle.batch;


/**
 *  <p>This session creates, updates, and deletes <code> ProgramEntries 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ProgramEntry, </code> a <code> ProgramEntryForm </code> is requested using 
 *  <code> getProgramEntryFormsForCreate() </code> specifying the desired 
 *  program, student, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  ProgramEntryForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> ProgramEntryForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ProgramEntryForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ProgramEntryForms </code> returned from <code> 
 *  getProgramEntryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  ProgramEntryForm. </code> In the case where there may be duplicates, any 
 *  <code> ProgramEntryForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ProgramEntryForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ProgramEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createProgramEntries(), </code> errors specific to an individual 
 *  <code> ProgramEntryForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> ProgramEntryForm </code> through the <code> 
 *  ProgramEntryForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ProgramEntryForms </code> are requested to the 
 *  <code> ProgramEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getProgramEntryFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> ProgramEntryForm </code> may be used to link the 
 *  request. Similarly, the <code> ProgramEntryForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ProgramEntryForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ProgramEntryForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ProgramEntryForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateProgramEntries(), </code> errors specific to an individual 
 *  <code> ProgramEntryForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> ProgramEntryForm </code> through the <code> 
 *  ProgramEntryForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> ProgramEntries </code> in bulk. To 
 *  unmap a <code> ProgramEntry </code> from the current <code> CourseCatalog, 
 *  </code> the <code> ProgramEntryCourseCatalogAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  ProgramEntry </code> itself thus removing it from all known <code> 
 *  CourseCatalog </code> catalogs. Bulk delete operations return the results 
 *  in <code> DeleteResponses. </code> </p>
 */

public interface ProgramEntryBatchAdminSession
    extends org.osid.course.chronicle.ProgramEntryAdminSession {


    /**
     *  Gets the program entry forms for creating a bunch of new program 
     *  entries. A <code> ProgramEntryForm </code> is returned for each 
     *  program and student pair. 
     *
     *  @param  peers a list of program entry peers 
     *  @param  programEntryRecordTypes array of program entry record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the program entry forms 
     *  @throws org.osid.NotFoundException a <code> programId </code> or 
     *          <code> studentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          programEntryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.ProgramEntryBatchFormList getProgramEntryFormsForCreate(org.osid.course.chronicle.batch.ProgramEntryPeerList peers, 
                                                                                                   org.osid.type.Type[] programEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> ProgramEntries. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  programEntryForms the program entry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> programEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createProgramEntries(org.osid.course.chronicle.batch.ProgramEntryBatchFormList programEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the program entry forms for updating an existing set of program 
     *  entries. A new program entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  programEntryIds the <code> Ids </code> of the <code> 
     *          ProgramEntry </code> 
     *  @return the program entry form 
     *  @throws org.osid.NotFoundException a <code> programEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> programEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.chronicle.batch.ProgramEntryBatchFormList getProgramEntryFormsForUpdate(org.osid.id.IdList programEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing program entries. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  programEntryForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> programEntryForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateProgramEntries(org.osid.course.chronicle.batch.ProgramEntryBatchFormList programEntryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> ProgramEntries </code> in this <code> CourseCatalog 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllProgramEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes program entries for the given <code> Ids. </code> 
     *
     *  @param  programEntryIds the <code> Ids </code> of the program entries 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> programEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProgramEntries(org.osid.id.IdList programEntryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes program entries for the given program. 
     *
     *  @param  programId the <code> Id </code> of a program 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProgramEntriesForProgram(org.osid.id.Id programId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes program entries for the given student 
     *
     *  @param  resourceId the <code> Id </code> of a student 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProgramEntriesForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes program entries expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveProgramEntriesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> ProgramEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ProgramEntry </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another program entry, it is reassigned to the 
     *  given program entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasProgramEntries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
