/**
 * <p>The Open Service Interface Definitions for the org.osid.course
 * service.</p>
 * 
 * <p>The Course OSID provides course management services for educational 
 * offerings or other learning units related to an event or curriculum. <code> 
 * Courses </code> may be used to model a class, conference tutorial session, 
 * or even a meetup group. </p> 
 * 
 * <p> The Course OSID defines two sets of interfaces. <code> Courses </code> 
 * and <code> ActivityUnits </code> represent canonical curriculum. Canonical 
 * <code> Courses </code> and <code> ActivityUnits </code> includes the 
 * description of the curriculum, requirements, and learning objectives 
 * independent of any offering. <code> CourseOfferings </code> and <code> 
 * Activities </code> are offerings of a canonical unit in a <code> Term. 
 * </code> </p> 
 * <h4> Courses </h4> 
 * 
 * <p> The <code> Course </code> is a canonical learning unit describing the 
 * overall content of a course, related learning <code> Objectives, </code> 
 * and any credit or grading options available that serve to constrain related 
 * offerings. The content of a canonical <code> Course </code> can be managed 
 * through a set of <code> ActivityUnits </code> . </p> 
 * <h4> ActivityUnits </h4> 
 * 
 * <p> An <code> ActivityUnit </code> is a component of a canonical <code> 
 * Course </code> that describes in more detail a learning activity. An <code> 
 * ActivityUnit </code> relates to a set of learning <code> Objectives. 
 * </code> Learning <code> Objectives </code> managed at the <code> 
 * ActivityUnit </code> level can be rolled up to the canonical Course. </p> 
 * 
 * <p> An <code> ActivityUnit </code> also describes target efforts split 
 * between contact and individual durations, and whether the an offering of an 
 * <code> ActivityUnit </code> is intended to repeat on a weekly basis. The 
 * <code> ActivityUnit </code> maintains the high level data to which 
 * offerings are scheduled. </p> 
 * <h4> Example </h4> 
 * 
 * <p> Course 6.111 Digital Systems Laboratory has a prerequisite of 6.002 and 
 * offered at 12 credits. It as three associated activity units. One activity 
 * unit is the lecture recurring weekly at 3 hours per week. The second 
 * activity unit is the lab recurring weekly at 7 hours per week. The third 
 * activity is preparation recurring weekly at 2 hours per week. MIT 
 * calculates the credits ("units" as they would call them) as the sum of the 
 * weekly effort hours; 12 credits (transformable to 4 semester hours in the 
 * Grading OSID). The total target effort for all three activity units is 168 
 * hours. When an offering is scheduled during a Term, the actual effort can 
 * be compared to the target effort based in the weekly effort estimates. </p> 
 * <h4> CourseOfferings </h4> 
 * 
 * <p> A <code> CourseOffering </code> is a canonical <code> Course </code> 
 * offered during a <code> Term. </code> <code> CourseOffering </code> 
 * replicates some of the data managed in the <code> Course </code> in the 
 * case it is refined or tweaked. <code> CourseOffering </code> adds some 
 * logistical information such as requiring registration, instructors, and 
 * overall constraints on seating count. Like its canonical counterpart, a 
 * <code> CourseOffering </code> is made up of <code> Activities </code> . 
 * </p> 
 * <h4> Activities </h4> 
 * 
 * <p> An <code> Activity </code> is an offering of an <code> ActivityUnit. 
 * </code> The <code> Activity </code> allows for some information, such as 
 * seating constraints and instructors, to be managed at this level instead of 
 * the <code> CourseOffering </code> level. The <code> Activity </code> also 
 * allows for the effort numbers to be refined fromits canonical counterpart. 
 * </p> 
 * 
 * <p> The <code> Activity </code> also manages scheduling information. <code> 
 * Schedules, </code> as managed by the Calendaring OSID, can be related to an 
 * <code> Activity. </code> When the <code> Schedule </code> is applied to a 
 * <code> Term, </code> a series of meeting times can be visible as either a 
 * series of implicit <code> Activities </code> in the Course OSID or as a 
 * <code> RecurringEvent </code> in the Calendaring OSID. </p> 
 * 
 * <p> The interplay between the Calendaring OSID and the Course OSID for 
 * scheduling is apparent by the similarity between the <code> Activity 
 * </code> and the <code> RecurringEvent. </code> At a conceptual level, the 
 * <code> Activity </code> is an <code> ActivityUnit </code> offered on a 
 * recurring <code> Schedule </code> duing a <code> Term </code> while a 
 * <code> RecuringEvent </code> is an event offered on a recurring <code> 
 * Schedule </code> during a <code> Term. </code> </p> 
 * 
 * <p> Like a <code> RecurringEvent, </code> an <code> Activity </code> may be 
 * "unravelled" as in expanded to a set of <code> Activities </code> where 
 * each <code> Activity </code> represents a single meeting time. This 
 * unravelling allows for a single meeting time to be identified and 
 * potentially modified to add or change information for one occurrence. An 
 * eample would be to implement a rotating instructor for each class in a 
 * series. </p> 
 * 
 * <p> A "superseding" <code> Activity </code> be be applied to an <code> 
 * Activity </code> to replace individual occurrences. The <code> Schedules 
 * </code> for each the <code> Activity </code> and the superseding <code> 
 * Activity </code> are expanded into individual meeting times. If any 
 * individual times overlap with any individual times of the superseding 
 * <code> Activity, </code> the superseding <code> Activity </code> session 
 * replaces the original one. </p> 
 * <h4> Terms </h4> 
 * 
 * <p> A <code> Term </code> is a time period in which <code> Courses </code> 
 * can be offered. The <code> Term </code> includes a set of course related 
 * milestones included a date range in which classes occur. This class date 
 * range drives the expansion of the <code> Schedules </code> in the Activity. 
 * </p> 
 * 
 * <p> The <code> Term </code> in the Course OSID is analogous to the <code> 
 * Term </code> in the Calendaring OSID but has extra course-related 
 * information. The <code> Schedule </code> expansion in the Course OSID is 
 * based on the class date range while the expandion of the <code> Schedule 
 * </code> in the Calendaring OSID is based on the date range of the <code> 
 * Term </code> itself. </p> 
 * <h4> Course Catalog Cataloging </h4> 
 * 
 * <p> <code> Courses, </code> <code> ActivityUnits, </code> <code> 
 * CourseOfferings, </code> <code> Activities, </code> and <code> Terms 
 * </code> can be organized into federateble <code> OsidCatalogs. </code> 
 * <code> CourseCatalogs </code> can be used to represent a set of <code> 
 * CourseOfferings </code> offered in a specific <code> Term, </code> year, or 
 * by subject area or sponsor. </p> 
 * <h4> Orchestration </h4> 
 * 
 * <p> The Course OSID is orchestrated with a Calendaring OSID to manage 
 * <code> Schedules </code> or to offer a calendar view of offerings. The 
 * Course OSID may also be orchestrated a Resource OSID to manage instructors 
 * and students, with an Ontology OSID to organize Courses by subject matter 
 * or with a Learning OSID to manage related learning <code> Objectives. 
 * </code> The Resourcing OSID may be used to manage the instructor pools and 
 * apply their expertise to course offerings. The Grading OSID serves to 
 * manage <code> GradeSystems </code> for the grading options available for an 
 * offering. The Commenting OSID may be used to gather feedback and ratings 
 * for course offerings. The Course OSID provides the slice that includes 
 * curriculum and offering management around a suite of other services. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Course OSID includes a Course Program OSID to manage Programs, a 
 * Course Registration OSID to register students in CourseOfferings, a Course 
 * Requisite OSID to manage course and program requirements, a Course Syllabus 
 * OSID to manage the content of an Activity, and a Course Chronicle OSID to 
 * provide an academic record, and a Course Batch OSID to manage <code> 
 * Courses, </code> <code> ActivityUnits, </code> <code> Terms, </code> <code> 
 * CourseOfferings, </code> and <code> Activities </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004, 2007 Massachusetts Institute of Technology. 
 * </p> 
 * 
 * <p> Copyright &copy; 2010-2011 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.course;
