//
// org.osid.course.plan.Lesson
//
//     The OSID Java specification for org.osid.course.plan.Lesson.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>A <code> Lesson </code> is the application of a <code> Docet </code> to 
 *  a <code> Plan </code> . The effectiveness of the lesson determines the 
 *  applicability of the lesson. The lesson includes additional times for the 
 *  starting and completion of the lesson. </p>
 */

public interface Lesson
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the plan. 
     *
     *  @return the plan <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPlanId();


    /**
     *  Gets the plan. 
     *
     *  @return the plan 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.Plan getPlan()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the docet. 
     *
     *  @return the lesson <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDocetId();


    /**
     *  Gets the docet. 
     *
     *  @return the docet 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.Docet getDocet()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the activities to which this lesson 
     *  applies. 
     *
     *  @return the activity <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getActivityIds();


    /**
     *  Gets the activities to which this lesson applies. A Lesson may span 
     *  multiple scheduled activities. 
     *
     *  @return the activities 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList getActivities()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the planned start time within the first activity as deteremined 
     *  by the <code> Lesson </code> scheduling. The time expressed as a 
     *  duration relative to the starting time of the first activity. 
     *
     *  @return the starting time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getPlannedStartTime();


    /**
     *  Tests if this lesson has begun. <code> hasBegun() </code> is <code> 
     *  true </code> for completed lessons. A lesson in progress is one where 
     *  <code> hasBegun() </code> is <code> true </code> and <code> 
     *  isComplete() </code> or <code> isSkipped() </code> is <code> false. 
     *  </code> 
     *
     *  @return <code> true </code> if this lesson has begun, <code> false 
     *          </code> if not yet begun 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasBegun();


    /**
     *  Gets the actual start time. The time expressed as a duration relative 
     *  to the starting time of the actual starting activity. 
     *
     *  @return the actual starting time 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getActualStartTime();


    /**
     *  Gets the <code> Id </code> of the activity when this lesson actually 
     *  began. 
     *
     *  @return the starting activity <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActualStartingActivityId();


    /**
     *  Gets the activity when this lesson actually began. 
     *
     *  @return the starting activity 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Activity getActualStartingActivity()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this lesson has been marked as completed. 
     *
     *  @return <code> true </code> if this lesson is complete, <code> false 
     *          </code> if not completed 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isComplete();


    /**
     *  Tests if this lesson has been marked as skipped. A skipped lesson may 
     *  have been partially undertaken but <code> isComplete() </code> remains 
     *  <code> false. </code> 
     *
     *  @return <code> true </code> if this lesson is skipped, <code> false 
     *          </code> if not completed 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSkipped();


    /**
     *  Gets the actual completion time. The time expressed as a duration 
     *  relative to the starting time of the ending activity. 
     *
     *  @return the actual end time 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> and 
     *          <code> isSkipped() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getActualEndTime();


    /**
     *  Gets the <code> Id </code> of the activity when this lesson was 
     *  completed or skipped. 
     *
     *  @return the ending activity <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> and 
     *          <code> isSkipped() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActualEndingActivityId();


    /**
     *  Gets the activity when this lesson was completed or skipped. 
     *
     *  @return the ending activity 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.IllegalStateException <code> isComplete() </code> and 
     *          <code> isSkipped() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Activity getActualEndingActivity()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the actual duration of this lesson if it has completed, in 
     *  progress, or skipped. 
     *
     *  @return the actual time spent 
     *  @throws org.osid.IllegalStateException <code> hasBegun() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getActualTimeSpent();


    /**
     *  Gets the lesson record corresponding to the given <code> Lesson 
     *  </code> record <code> Type. </code> This method must be used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  lessonRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(lessonRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  lessonRecordType the type of lesson record to retrieve 
     *  @return the lesson record 
     *  @throws org.osid.NullArgumentException <code> lessonRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(planRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.records.LessonRecord getLessonRecord(org.osid.type.Type lessonRecordType)
        throws org.osid.OperationFailedException;
}
