//
// org.osid.course.plan.LessonConflictSession
//
//     The OSID Java specification for org.osid.course.plan.LessonConflictSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This session provides a way of "anchoring" lessons with a plan. <code> 
 *  Lessons </code> correspond to their corresponding <code> Docents </code> 
 *  laid out along the related <code> Activities. </code> The <code> 
 *  LessonAnchor </code> ties a <code> Lesson </code> to a specific <code> 
 *  Activity </code> or at a specific time offet within the specific <code> 
 *  Activity. </code> </p> 
 *  
 *  <p> Automatic generation of <code> Lessons </code> should be constrained 
 *  around the <code> LessonAnchors. </code> </p>
 */

public interface LessonConflictSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can anchor lessons. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if plan anchoring methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAnchorLessons();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include plans in course catalogs which are children of this course 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Gets all lessons for a plan. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of lessons 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsForPlan(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of overlapping lessons. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of lesson <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getOverlappingLessonIds(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of overlapping lessons. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of lessons 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getOverlappingLessons(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of lesson <code> Ids </code> that do not begin at the 
     *  start of an activity. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of lesson <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getStartingOffsetLessonIds(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of lessons that do not begin at the start of an activity. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of lessons 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getStartingOffsetLessons(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of lesson <code> Ids </code> that do not end at the end of 
     *  an activity. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of lesson <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getEndingOffsetLessonIds(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of lessons that do not end at the end of an activity. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of lessons 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getEndingOffsetLessons(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of activity <code> Ids </code> with lesson gaps or missing 
     *  lessons. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of activity <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getActivityIdsWithLessonGaps(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of activities with lesson gaps. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return a list of activities 
     *  @throws org.osid.NotFoundException <code> planId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityList getActivitiesWithLessonGaps(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
