//
// org.osid.course.plan.LessonForm
//
//     The OSID Java specification for org.osid.course.plan.LessonForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This is the form for creating and updating <code> Lessons. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> LessonAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface LessonForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for the activities. 
     *
     *  @return metadata for the activities 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getActivitiesMetadata();


    /**
     *  Sets the activities. 
     *
     *  @param  activityIds the new activities 
     *  @throws org.osid.InvalidArgumentException <code> activityIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> activityIds </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> activityIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setActivities(org.osid.id.IdList activityIds);


    /**
     *  Clears the activities. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivities();


    /**
     *  Gets the metadata for the planned start time. 
     *
     *  @return metadata for the planned start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPlannedStartTimeMetadata();


    /**
     *  Sets the planned start time. The time is expressed as a time relative 
     *  to the starting time of the first activity. 
     *
     *  @param  time the new planned start time 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> time </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPlannedStartTime(org.osid.calendaring.Duration time);


    /**
     *  Clears the planned start time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPlannedStartTime();


    /**
     *  Gets the metadata for the begun flag. 
     *
     *  @return metadata for the begun flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBegunMetadata();


    /**
     *  Sets the begun flag. 
     *
     *  @param  begun the new begun flag 
     *  @throws org.osid.InvalidArgumentException <code> begun </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> begun </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBegun(boolean begun);


    /**
     *  Clears the begun flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBegun();


    /**
     *  Gets the metadata for the actual start time. The time is expressed as 
     *  a time relative to the starting time of the actual starting activity. 
     *
     *  @return metadata for the actual start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getActualStartTimeMetadata();


    /**
     *  Sets the actual start time. 
     *
     *  @param  time the new actual start time 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> time </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setActualStartTime(org.osid.calendaring.Duration time);


    /**
     *  Clears the actual start time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualStartTime();


    /**
     *  Gets the metadata for the actual starting activity. 
     *
     *  @return metadata for the actual starting activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getActualStartingActivityMetadata();


    /**
     *  Sets the actual starting activity. 
     *
     *  @param  activityId the new actual starting activity 
     *  @throws org.osid.InvalidArgumentException <code> activityId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> activityId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setActualStartingActivity(org.osid.id.Id activityId);


    /**
     *  Clears the actual starting activity. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualStartingActivity();


    /**
     *  Gets the metadata for the complete flag. 
     *
     *  @return metadata for the complete flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCompleteMetadata();


    /**
     *  Sets the complete flag. 
     *
     *  @param  complete the new complete flag 
     *  @throws org.osid.InvalidArgumentException <code> complete </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> complete </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setComplete(boolean complete);


    /**
     *  Clears the complete flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearComplete();


    /**
     *  Gets the metadata for the skipped flag. 
     *
     *  @return metadata for the skipped flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSkippedMetadata();


    /**
     *  Sets the skipped flag. 
     *
     *  @param  skipped the new skipped flag 
     *  @throws org.osid.InvalidArgumentException <code> skipped </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> skipped </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSkipped(boolean skipped);


    /**
     *  Clears the skipped flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSkipped();


    /**
     *  Gets the metadata for the actual end time. 
     *
     *  @return metadata for the actual end time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getActualEndTimeMetadata();


    /**
     *  Sets the actual end time. The time is expressed as a time relative to 
     *  the starting time of the ending activity. 
     *
     *  @param  time the new actual end time 
     *  @throws org.osid.InvalidArgumentException <code> time </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> time </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> time </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setActualEndTime(org.osid.calendaring.Duration time);


    /**
     *  Clears the actual end time. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualEndTme();


    /**
     *  Gets the metadata for the actual ending activity. 
     *
     *  @return metadata for the actual ending activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getActualEndingActivityMetadata();


    /**
     *  Sets the actual ending activity. 
     *
     *  @param  activityId the new actual ending activity 
     *  @throws org.osid.InvalidArgumentException <code> activityId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> activityId </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setActualEndingActivity(org.osid.id.Id activityId);


    /**
     *  Clears the actual ending activity. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualEndingActivity();


    /**
     *  Gets the metadata for the actual time spent. 
     *
     *  @return metadata for the actual time spent 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getActualTimeSpentMetadata();


    /**
     *  Sets the actual time spent. 
     *
     *  @param  duration the new duration 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> duration </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setActualTimeSpent(org.osid.calendaring.Duration duration);


    /**
     *  Clears the actual time spent. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualTimeSpent();


    /**
     *  Gets the <code> LessonFormRecord </code> corresponding to the given 
     *  lesson record <code> Type. </code> 
     *
     *  @param  lessonRecordType the lesson record type 
     *  @return the lesson form record 
     *  @throws org.osid.NullArgumentException <code> lessonRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(lessonRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.records.LessonFormRecord getLessonFormRecord(org.osid.type.Type lessonRecordType)
        throws org.osid.OperationFailedException;
}
