//
// org.osid.course.plan.LessonLookupSession
//
//     The OSID Java specification for org.osid.course.plan.LessonLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This session provides methods for retrieving <code> Lesson </code> 
 *  objects. The <code> Lesson </code> represents a collection of syllabi. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete view or is an error condition 
 *      </li> 
 *      <li> isolated course catalog view: All lesson methods in this session 
 *      operate, retrieve and pertain to lessonsdefined explicitly in the 
 *      current course catalog. Using an isolated view is useful for managing 
 *      lessonswith the <code> LessonAdminSession. </code> </li> 
 *      <li> federated course catalog view: All lesson lookup methods in this 
 *      session operate, retrieve and pertain to all lessonsdefined in this 
 *      course catalog and any other course catalogs implicitly available in 
 *      this course catalog through course catalog inheritence. </li> 
 *      <li> effective lesson view: All lesson lookup methods return lessons 
 *      where the current date falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any lesson view: Lessons of any effective date are returned from 
 *      methods. </li> 
 *  </ul>
 *  
 */

public interface LessonLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Lesson </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupLessons();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeLessonView();


    /**
     *  A complete view of the <code> Lesson </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryLessonView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include lessonsin course catalogs which are children of this course 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only lessons whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveLessonView();


    /**
     *  All lessons of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveLessonView();


    /**
     *  Gets the <code> Lesson </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Lesson </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Lesson </code> and retained for compatibility. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  lessonId <code> Id </code> of the <code> Lesson </code> 
     *  @return the lesson 
     *  @throws org.osid.NotFoundException <code> lessonId </code> not found 
     *  @throws org.osid.NullArgumentException <code> lessonId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.course.plan.Lesson getLesson(org.osid.id.Id lessonId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  lessonsspecified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Lessons </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  lessonIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> lessonIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsByIds(org.osid.id.IdList lessonIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> corresponding to the given lesson 
     *  genus <code> Type </code> which does not include lessonsof genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  lessonsor an error results. Otherwise, the returned list may contain 
     *  only those lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  lessonGenusType a lesson genus type 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.NullArgumentException <code> lessonGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsByGenusType(org.osid.type.Type lessonGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> corresponding to the given lesson 
     *  genus <code> Type </code> and include any additional lessonswith genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  lessonsor an error results. Otherwise, the returned list may contain 
     *  only those lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  lessonGenusType a lesson genus type 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.NullArgumentException <code> lessonGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsByParentGenusType(org.osid.type.Type lessonGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> containing the given lesson record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  lessonsor an error results. Otherwise, the returned list may contain 
     *  only those lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  lessonRecordType a lesson record type 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.NullArgumentException <code> lessonRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsByRecordType(org.osid.type.Type lessonRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> effective sduring the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known lessonsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsOnDate(org.osid.calendaring.DateTime from, 
                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> for the given plan <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  lessons or an error results. Otherwise, the returned list may contain 
     *  only those lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsForPlan(org.osid.id.Id planId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> for a plan effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known lessonsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> planId, from, </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsForPlanOnDate(org.osid.id.Id planId, 
                                                                   org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> for the given docet <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  lessonsor an error results. Otherwise, the returned list may contain 
     *  only those lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  docetId a docet <code> Id </code> 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.NullArgumentException <code> docetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsForDocet(org.osid.id.Id docetId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> for a docet effective sduring the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known lessonsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  docetId a docet <code> Id </code> 
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> docetId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsForDocetOnDate(org.osid.id.Id docetId, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> for the given plan and docet. 
     *  
     *  In plenary mode, the returned list contains all known lessonsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @param  docetId a docet <code> Id </code> 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.NullArgumentException <code> planId </code> or <code> 
     *          docetId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsForPlanAndDocet(org.osid.id.Id planId, 
                                                                     org.osid.id.Id docetId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LessonList </code> for a plan and docet effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. 
     *  
     *  In plenary mode, the returned list contains all known lessonsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @param  docetId a docet <code> Id </code> 
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Lesson </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> planId, docetId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessonsForPlanAndDocetOnDate(org.osid.id.Id planId, 
                                                                           org.osid.id.Id docetId, 
                                                                           org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Lessons. </code> 
     *  
     *  In plenary mode, the returned list contains all known lessonsor an 
     *  error results. Otherwise, the returned list may contain only those 
     *  lessonsthat are accessible through this session. 
     *  
     *  In effective mode, lessons are returned that are currently effective. 
     *  In any effective mode, effective lessons and those currently expired 
     *  are returned. 
     *
     *  @return a list of <code> Lessons </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.LessonList getLessons()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
