//
// org.osid.course.plan.LessonQuery
//
//     The OSID Java specification for org.osid.course.plan.LessonQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This is the query for searching for lessons. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface LessonQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the plan <code> Id </code> for this query. 
     *
     *  @param  planId a plan <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPlanId(org.osid.id.Id planId, boolean match);


    /**
     *  Clears the plan <code> Id </code> tems. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPlanIdTerms();


    /**
     *  Tests if a plan query is available. 
     *
     *  @return <code> true </code> if a plan query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPlanQuery();


    /**
     *  Gets the query for a plan. 
     *
     *  @return the plan query 
     *  @throws org.osid.UnimplementedException <code> supportsPlanQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPlanQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.plan.PlanQuery getPlanQuery();


    /**
     *  Clears the plan terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPlanTerms();


    /**
     *  Sets the docet <code> Id </code> for this query. 
     *
     *  @param  docetId a docet <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> docetId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDocetId(org.osid.id.Id docetId, boolean match);


    /**
     *  Clears the docet <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDocetIdTerms();


    /**
     *  Tests if a docet query is available. 
     *
     *  @return <code> true </code> if a docet query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetQuery();


    /**
     *  Gets the query for a docet. 
     *
     *  @return the docet query 
     *  @throws org.osid.UnimplementedException <code> supportsDocetQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDocetQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.syllabus.DocetQuery getDocetQuery();


    /**
     *  Matches a lesson that has any docet. 
     *
     *  @param  match <code> true </code> to match lessons with any docet, 
     *          <code> false </code> to match lessons with no docet 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDocet(boolean match);


    /**
     *  Clears the docet terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDocetTerms();


    /**
     *  Sets the activity <code> Id </code> for this query. 
     *
     *  @param  activitytId an activity <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActivityId(org.osid.id.Id activitytId, boolean match);


    /**
     *  Clears the activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityIdTerms();


    /**
     *  Tests if an activity query is available. 
     *
     *  @return <code> true </code> if an activity query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Gets the query for an activity. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> supportsActivityQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActivityQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.ActivityQuery getActivityQuery();


    /**
     *  Matches a lesson that has any activity. 
     *
     *  @param  match <code> true </code> to match lessons with any activity, 
     *          <code> false </code> to match lessons with no activities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActivity(boolean match);


    /**
     *  Clears the activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActivityTerms();


    /**
     *  Matches a planned start time within the given duration range 
     *  inclusive. 
     *
     *  @param  from a starting date 
     *  @param  to a ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPlannedStartTime(org.osid.calendaring.Duration from, 
                                      org.osid.calendaring.Duration to, 
                                      boolean match);


    /**
     *  Matches a lesson that has any planned start time. 
     *
     *  @param  match <code> true </code> to match lessons with any planned 
     *          start time, <code> false </code> to match lessons with no 
     *          planned start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPlannedStartTime(boolean match);


    /**
     *  Clears the planned start time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPlannedStartTimeTerms();


    /**
     *  Matches an actual start time within the given date range inclusive. 
     *
     *  @param  from a starting date 
     *  @param  to a ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActualStartTime(org.osid.calendaring.Duration from, 
                                     org.osid.calendaring.Duration to, 
                                     boolean match);


    /**
     *  Matches a lesson that has begun. 
     *
     *  @param  match <code> true </code> to match lessons with any actual 
     *          start time, <code> false </code> to match lessons with no 
     *          actual start time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActualStartTime(boolean match);


    /**
     *  Clears the actual start time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualStartTimeTerms();


    /**
     *  Sets the starting activity <code> Id </code> for this query. 
     *
     *  @param  activitytId an activity <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActualStartingActivityId(org.osid.id.Id activitytId, 
                                              boolean match);


    /**
     *  Clears the starting activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualStartingActivityIdTerms();


    /**
     *  Tests if a starting activity query is available. 
     *
     *  @return <code> true </code> if a starting activity query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActualStartingActivityQuery();


    /**
     *  Gets the query for a starting activity. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsActualStartingActivityQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsActualStartingActivityQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.course.ActivityQuery getActualStartingActivityQuery();


    /**
     *  Matches a lesson that has any starting activity. 
     *
     *  @param  match <code> true </code> to match lessons with any starting 
     *          activity, <code> false </code> to match lessons with no 
     *          starting activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActualStartingActivity(boolean match);


    /**
     *  Clears the starting activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualStartingActivityTerms();


    /**
     *  Matches a lesson that has been completed. 
     *
     *  @param  match <code> true </code> to match lessons that have been 
     *          completed, <code> false </code> to match lessons that have not 
     *          been completed 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchComplete(boolean match);


    /**
     *  Clears the complete terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompleteTerms();


    /**
     *  Matches a lesson that has been skipped. 
     *
     *  @param  match <code> true </code> to match lessons that have been 
     *          skipped, <code> false </code> to match lessons that have not 
     *          been skipped 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSkipped(boolean match);


    /**
     *  Clears the skipped terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSkippedTerms();


    /**
     *  Matches an actual ending time within the given date range inclusive. 
     *
     *  @param  from a starting date 
     *  @param  to a ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActualEndTime(org.osid.calendaring.Duration from, 
                                   org.osid.calendaring.Duration to, 
                                   boolean match);


    /**
     *  Matches a lesson that has any actual end time. 
     *
     *  @param  match <code> true </code> to match lessons with any actual end 
     *          time, <code> false </code> to match lessons with no actual end 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActualEndTime(boolean match);


    /**
     *  Clears the actual end time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualEndTimeTerms();


    /**
     *  Sets the ending activity <code> Id </code> for this query. 
     *
     *  @param  activitytId an activity <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActualEndingActivityId(org.osid.id.Id activitytId, 
                                            boolean match);


    /**
     *  Clears the ending activity <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualEndingActivityIdTerms();


    /**
     *  Tests if an ending activity query is available. 
     *
     *  @return <code> true </code> if an ending activity query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActualEndingActivityQuery();


    /**
     *  Gets the query for an ending activity. 
     *
     *  @return the activity query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEndingActivityQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEndingActivityQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.ActivityQuery getActualEndingActivityQuery();


    /**
     *  Matches a lesson that has any ending activity. 
     *
     *  @param  match <code> true </code> to match lessons with any ending 
     *          activity, <code> false </code> to match lessons with no ending 
     *          activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActualEndingActivity(boolean match);


    /**
     *  Clears the ending activity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualEndingActivityTerms();


    /**
     *  Matches an actual time spent within the given duration range 
     *  inclusive. 
     *
     *  @param  from a starting date 
     *  @param  to a ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchActualTimeSpent(org.osid.calendaring.Duration from, 
                                     org.osid.calendaring.Duration to, 
                                     boolean match);


    /**
     *  Matches a lesson that has any actual time spent. 
     *
     *  @param  match <code> true </code> to match lessons with any actual 
     *          time spent, <code> false </code> to match lessons with no time 
     *          spent 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyActualTimeSpent(boolean match);


    /**
     *  Clears the actual time spent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearActualTimeSpentTerms();


    /**
     *  Sets the lesson <code> Id </code> for this query to match syllabi 
     *  assigned to course catalogs. 
     *
     *  @param  courseCatalogId a course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if an <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog query. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the lesson query record corresponding to the given <code> Lesson 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  lessonRecordType a lesson record type 
     *  @return the lesson query record 
     *  @throws org.osid.NullArgumentException <code> lessonRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(lessonRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.records.LessonQueryRecord getLessonQueryRecord(org.osid.type.Type lessonRecordType)
        throws org.osid.OperationFailedException;
}
