//
// org.osid.course.plan.Plan
//
//     The OSID Java specification for org.osid.course.plan.Plan.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>A <code> Plan </code> is an <code> OsidRelationship </code> to apply a 
 *  <code> Syllabus </code> to a <code> CourseOffering. </code> The <code> 
 *  Plans </code> within a <code> Plan </code> must be to the same <code> 
 *  Syllabus </code> indicated by the <code> Plan </code> and the <code> 
 *  CourseOffering </code> must be to the same <code> Course </code> as the 
 *  <code> Syllabus. </code> </p>
 */

public interface Plan
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the syllabus. 
     *
     *  @return the syllabus <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSyllabusId();


    /**
     *  Gets the syllabus. 
     *
     *  @return the syllabus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.Syllabus getSyllabus()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the course offering. 
     *
     *  @return the course offering <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseOfferingId();


    /**
     *  Gets the course offering. 
     *
     *  @return the course offering 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseOffering getCourseOffering()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the modules to apply to this plan. 
     *
     *  @return the module <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getModuleIds();


    /**
     *  Gets the modules to apply to this plan. 
     *
     *  @return the module 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleList getModules()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the plan record corresponding to the given <code> Plan </code> 
     *  record <code> Type. </code> This method must be used to retrieve an 
     *  object implementing the requested record. The <code> planRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(planRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  planRecordType the type of plan record to retrieve 
     *  @return the plan record 
     *  @throws org.osid.NullArgumentException <code> planRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(planRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.records.PlanRecord getPlanRecord(org.osid.type.Type planRecordType)
        throws org.osid.OperationFailedException;
}
