//
// org.osid.course.plan.PlanForm
//
//     The OSID Java specification for org.osid.course.plan.PlanForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This is the form for creating and updating <code> Plan </code> objects. 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  PlanAdminSession. </code> For each data element that may be set, metadata 
 *  may be examined to provide display hints or data constraints. </p>
 */

public interface PlanForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for the modules. 
     *
     *  @return metadata for the modules 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getModulesMetadata();


    /**
     *  Sets the modules to which this plan applies. 
     *
     *  @param  moduleIds the new modules 
     *  @throws org.osid.InvalidArgumentException <code> moduleIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> moduleIds </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> moduleIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setModules(org.osid.id.IdList moduleIds);


    /**
     *  Clears the modules. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModules();


    /**
     *  Gets the <code> PlanFormRecord </code> corresponding to the given plan 
     *  record <code> Type. </code> 
     *
     *  @param  planRecordType the plan record type 
     *  @return the plan form record 
     *  @throws org.osid.NullArgumentException <code> planRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(planRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.records.PlanFormRecord getPlanFormRecord(org.osid.type.Type planRecordType)
        throws org.osid.OperationFailedException;
}
