//
// org.osid.course.plan.PlanLookupSession
//
//     The OSID Java specification for org.osid.course.plan.PlanLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.plan;


/**
 *  <p>This session defines methods for retrieving plans. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All plan methods in this session 
 *      operate, retrieve and pertain to plans defined explicitly in the 
 *      current course catalog. Using an isolated view is useful for managing 
 *      plans with the <code> PlanAdminSession. </code> </li> 
 *      <li> federated course catalog view: All plan lookup methods in this 
 *      session operate, retrieve and pertain to all plans defined in this 
 *      course catalog and any other course catalogs implicitly available in 
 *      this course catalog through course catalog inheritence. </li> 
 *      <li> effective plan view: All plan lookup methods return plans where 
 *      the current date falls in between the effective dates inclusive. </li> 
 *      <li> any plan view: Plans of any effective date are returned from 
 *      methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface PlanLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup plans. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if plan lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPlans();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePlanView();


    /**
     *  A complete view of the <code> Plan </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPlanView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include plans in course catalogs which are children of this course 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only plans whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectivePlanView();


    /**
     *  All plans of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectivePlanView();


    /**
     *  Gets the <code> Plan </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Plan </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Plan </code> and retained for compatibility. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  planId the <code> Id </code> of the <code> Plan </code> to 
     *          retrieve 
     *  @return the returned <code> Plan </code> 
     *  @throws org.osid.NotFoundException no <code> Plan </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> planId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.Plan getPlan(org.osid.id.Id planId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  plans specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible plans may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  planIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Plan list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> planIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansByIds(org.osid.id.IdList planIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> corresponding to the given plan genus 
     *  <code> Type </code> which does not include plans of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  plans or an error results. Otherwise, the returned list may contain 
     *  only those plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  planGenusType a plan genus type 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.NullArgumentException <code> planGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansByGenusType(org.osid.type.Type planGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> corresponding to the given plan genus 
     *  <code> Type </code> and include any additional plans with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known plans or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  planGenusType a plan genus type 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.NullArgumentException <code> planGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansByParentGenusType(org.osid.type.Type planGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> containing the given plan record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  plans or an error results. Otherwise, the returned list may contain 
     *  only those plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  planRecordType a plan record type 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.NullArgumentException <code> planRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansByRecordType(org.osid.type.Type planRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  plans or an error results. Otherwise, the returned list may contain 
     *  only those plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from or to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansOnDate(org.osid.calendaring.DateTime from, 
                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> for the given syllabus <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  plans or an error results. Otherwise, the returned list may contain 
     *  only those plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  syllabusId a syllabus <code> Id </code> 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.NullArgumentException <code> syllabusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansForSyllabus(org.osid.id.Id syllabusId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> for a syllabus effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known plans or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  syllabusId a syllabus <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> syllabusId, from, or to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansForSyllabusOnDate(org.osid.id.Id syllabusId, 
                                                                   org.osid.calendaring.DateTime from, 
                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> for the given course offering <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  plans or an error results. Otherwise, the returned list may contain 
     *  only those plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansForCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> for a course offering effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. 
     *  
     *  In plenary mode, the returned list contains all known plans or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId, from, 
     *          or to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansForCourseOfferingOnDate(org.osid.id.Id courseOfferingId, 
                                                                         org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> for the given syllabus <code> and 
     *  course offering. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  plans or an error results. Otherwise, the returned list may contain 
     *  only those plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  syllabusId a syllabus <code> Id </code> 
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.NullArgumentException <code> syllabusId </code> or 
     *          <code> courseOfferingId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansForSyllabusAndCourseOffering(org.osid.id.Id syllabusId, 
                                                                              org.osid.id.Id courseOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PlanList </code> for a syllabus and course offering 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known plans or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @param  syllabusId a syllabus <code> Id </code> 
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Plan </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> syllabusId, 
     *          courseOfferingId, from, or to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlansForSyllabusAndCourseOfferingOnDate(org.osid.id.Id syllabusId, 
                                                                                    org.osid.id.Id courseOfferingId, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all plans. 
     *  
     *  In plenary mode, the returned list contains all known plans or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  plans that are accessible through this session. 
     *  
     *  In effective mode, plans are returned that are currently effective. In 
     *  any effective mode, effective plans and those currently expired are 
     *  returned. 
     *
     *  @return a list of plans 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.plan.PlanList getPlans()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
