/**
 * <p>The Open Service Interface Definitions for the org.osid.course.plan
 * service.</p>
 * 
 * <p>The Course Plan OSID is a service that maps syllabi defined in the 
 * Course Syllabus OSID to scheduled <code> Activities </code> to manage the 
 * logistics of following a lesson plan during an offering of a course. </p> 
 * <h4> Plans </h4> 
 * 
 * <p> A <code> Plan </code> is an <code> OsidRelationship </code> that 
 * relates a <code> Syllabus </code> to a <code> CourseOffering </code> to 
 * form a lesson plan. All or a selected set of <code> Modules </code> within 
 * a <code> Syllabus </code> may be included in the <code> Plan </code> . </p> 
 * <h4> Lessons </h4> 
 * 
 * <p> A <code> Lesson </code> is an <code> OsidRelationship </code> mapping a 
 * <code> Plan </code> to a <code> Docet </code> in a <code> Syllabus. </code> 
 * A <code> Lesson </code> has a time duration covering one or more <code> 
 * Activities </code> and may be checked off or skipped during the execution 
 * of the course. </p> 
 * 
 * <p> The <code> Activities </code> relating to <code> Lessons </code> are 
 * instances of an <code> Activity </code> as determined by the <code> 
 * Activity </code> schedule. Each instance of an <code> Activity, </code> 
 * such as the 10/31 lecture of a lecture <code> ActivityUnit </code> during 
 * fall semester, has its own <code> Id </code> that is referenced from a 
 * <code> Lesson. </code> </p> 
 * 
 * <p> <code> Lessons </code> may appear autoamtically from the creation of a 
 * <code> Plan </code> that is the result of an overlay of the <code> Syllabus 
 * </code> on to the set of <code> Activity </code> instances as determined by 
 * the <code> Activity </code> schedule. The <code> Lessons </code> can be 
 * examined or marked as skipped. Changes to the <code> Lesson </code> 
 * duration occur in its related <code> Docet. </code> </p> 
 * 
 * <p> <code> Lessons </code> may be anchored to begin at designated <code> 
 * Activity </code> instances using the <code> LessonAnchoringSession. </code> 
 * Overlaps or gaps in the overall lesson <code> Plan </code> can be examined 
 * in the <code> LessonConflictSession </code> . </p> 
 * <h4> CourseCatalog Cataloging </h4> 
 * 
 * <p> <code> Plans </code> and <code> Lessons </code> can be organized into 
 * federateable <code> CourseCatalog </code> catalogs. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.course.plan;
