//
// org.osid.course.program.EnrollmentLookupSession
//
//     The OSID Java specification for org.osid.course.program.EnrollmentLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session defines methods for retrieving enrollments. An <code> 
 *  Enrollment </code> is a relationship between a student and an <code> 
 *  ProgramOffering. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All enrollment methods in this 
 *      session operate, retrieve and pertain to enrollments defined 
 *      explicitly in the current course catalog. Using an isolated view is 
 *      useful for managing <code> Enrollments </code> with the <code> 
 *      EnrollmentAdminSession. </code> </li> 
 *      <li> federated course catalog view: All enrollment lookup methods in 
 *      this session operate, retrieve and pertain to all enrollments defined 
 *      in this course catalog and any other enrollments implicitly available 
 *      in this course catalog through course catalog inheritence. </li> 
 *      <li> effective vote view: All enrollment lookup methods return 
 *      enrollments where the current date falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective vote view: enrollments of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Enrollments may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Enrollment. </code> </p>
 */

public interface EnrollmentLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Enrollment </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupEnrollments();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeEnrollmentView();


    /**
     *  A complete view of the <code> Enrollment </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryEnrollmentView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include enrollments in catalogs which are children of this catalog in 
     *  the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only enrollments whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveEnrollmentView();


    /**
     *  All enrollments of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveEnrollmentView();


    /**
     *  Gets the <code> Enrollment </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Enrollment </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Enrollment </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  enrollmentId the <code> Id </code> of the <code> Enrollment 
     *          </code> to retrieve 
     *  @return the returned <code> Enrollment </code> 
     *  @throws org.osid.NotFoundException no <code> Enrollment </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> enrollmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Enrollment getEnrollment(org.osid.id.Id enrollmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EnrollmentList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  enrollments specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Enrollments </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  enrollmentIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Enrollment </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> enrollmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsByIds(org.osid.id.IdList enrollmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EnrollmentList </code> corresponding to the given 
     *  enrollment genus <code> Type </code> which does not include 
     *  enrollments of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  enrollments or an error results. Otherwise, the returned list may 
     *  contain only those enrollments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  enrollmentGenusType an enrollment genus type 
     *  @return the returned <code> Enrollment </code> list 
     *  @throws org.osid.NullArgumentException <code> enrollmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsByGenusType(org.osid.type.Type enrollmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EnrollmentList </code> corresponding to the given 
     *  course genus <code> Type </code> and include any additional 
     *  enrollments with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  enrollments or an error results. Otherwise, the returned list may 
     *  contain only those enrollments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  enrollmentGenusType an enrollment genus type 
     *  @return the returned <code> Enrollment </code> list 
     *  @throws org.osid.NullArgumentException <code> enrollmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsByParentGenusType(org.osid.type.Type enrollmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> EnrollmentList </code> containing the given enrollment 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  enrollmentRecordType an enrollment record type 
     *  @return the returned <code> Enrollment </code> list 
     *  @throws org.osid.NullArgumentException <code> enrollmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsByRecordType(org.osid.type.Type enrollmentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsOnDate(org.osid.calendaring.DateTime from, 
                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> associated with a given <code> 
     *  ProgramOffering. </code> 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programOfferingId a program offering <code> Id </code> 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.NullArgumentException <code> programOfferingId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgramOffering(org.osid.id.Id programOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programOfferingId a program offering <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> programOfferingId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgramOfferingOnDate(org.osid.id.Id programOfferingId, 
                                                                                         org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> for a given student. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> for a student during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForStudentOnDate(org.osid.id.Id resourceId, 
                                                                                 org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> for a given program offering and 
     *  student. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programOfferingId a program offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.NullArgumentException <code> programOfferingId 
     *          </code> or <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgramOfferingAndStudent(org.osid.id.Id programOfferingId, 
                                                                                             org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> for a program offering and student 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programOfferingId a program offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> programOfferingId, 
     *          resourceId, from </code> or <code> to </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgramOfferingAndStudentOnDate(org.osid.id.Id programOfferingId, 
                                                                                                   org.osid.id.Id resourceId, 
                                                                                                   org.osid.calendaring.DateTime from, 
                                                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> related to a program. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgram(org.osid.id.Id programId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> for a program effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> programId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgramOnDate(org.osid.id.Id programId, 
                                                                                 org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> for a given program and student. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.NullArgumentException <code> programId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgramAndStudent(org.osid.id.Id programId, 
                                                                                     org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments </code> for a program and student 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> programId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollmentsForProgramAndStudentOnDate(org.osid.id.Id programId, 
                                                                                           org.osid.id.Id resourceId, 
                                                                                           org.osid.calendaring.DateTime from, 
                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Enrollments. </code> 
     *  
     *  In plenary mode, the returned list contains all known enrollments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  enrollments that are accessible through this session. 
     *  
     *  In effective mode, enrollments are returned that are currently 
     *  effective. In any effective mode, effective enrollments and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Enrollments </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentList getEnrollments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
