//
// org.osid.course.program.EnrollmentNotificationSession
//
//     The OSID Java specification for org.osid.course.program.EnrollmentNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Enrollment </code> objects in this <code> CourseCatalog. </code> 
 *  This also includes existing enrollments that may appear or disappear due 
 *  to changes in the <code> CourseCatalog </code> hierarchy, This session is 
 *  intended for consumers needing to synchronize their state with this 
 *  service without the use of polling. Notifications are cancelled when this 
 *  session is closed. </p> 
 *  
 *  <p> The views defined in this session correspond to the views in the 
 *  <code> EnrollmentLookupSession. </code> </p>
 */

public interface EnrollmentNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Enrollment </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForEnrollmentNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include enrollments in catalogs which are children of this catalog in 
     *  the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeEnrollmentNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableEnrollmentNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableEnrollmentNotifications();


    /**
     *  Acknowledge an enrollment notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeEnrollmentNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new enrollments. <code> 
     *  EnrollmentReceiver.newEnrollments() </code> is invoked when a new 
     *  <code> Enrollment </code> appears in this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewEnrollments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new enrollments for the given program 
     *  offering. <code> EnrollmentReceiver.newEnrollments() </code> is 
     *  invoked when a new <code> Enrollment </code> appears in this course 
     *  catalog. 
     *
     *  @param  programOfferingId the <code> Id </code> of the <code> 
     *          ProgramOffering </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> programOfferingId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewEnrollmentsForProgramOffering(org.osid.id.Id programOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new enrollments for the given student. 
     *  <code> EnrollmentReceiver.newEnrollments() </code> is invoked when a 
     *  new <code> Enrollment </code> appears in this course catalog. 
     *
     *  @param  studentId the <code> Id </code> of the <code> Resource </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> studentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewEnrollmentsForStudent(org.osid.id.Id studentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated enrollments. <code> 
     *  EnrollmentReceiver.changedEnrollments() </code> is invoked when an 
     *  enrollment in this course catalog is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedEnrollments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated enrollments for the given 
     *  program offering. <code> EnrollmentReceiver.changedEnrollments() 
     *  </code> is invoked when an enrollment in this course catalog is 
     *  changed. 
     *
     *  @param  programOfferingId the <code> Id </code> of the <code> 
     *          ProgramOffering </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> programOfferingId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedEnrollmentsForProgramOffering(org.osid.id.Id programOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated enrollments for the given 
     *  student. <code> EnrollmentReceiver.changedEnrollments() </code> is 
     *  invoked when a course in this course catalog is changed. 
     *
     *  @param  studentId the <code> Id </code> of the <code> Resource </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> studentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedEnrollmentsForStudent(org.osid.id.Id studentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated enrollment. <code> 
     *  EnrollmentReceiver.changedEnrollments() </code> is invoked when the 
     *  specified enrollment in this course catalog is changed. 
     *
     *  @param  enrollmentId the <code> Id </code> of the <code> Enrollment 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> enrollmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedEnrollment(org.osid.id.Id enrollmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted enrollments. <code> 
     *  EnrollmentReceiver.deletedEnrollments() </code> is invoked when an 
     *  enrollment is deleted or removed from this course catalog. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedEnrollments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted enrollments for the given 
     *  program offering. <code> EnrollmentReceiver.deletedEnrollments() 
     *  </code> is invoked when an enrollment is deleted or removed from this 
     *  course catalog. 
     *
     *  @param  programOfferingId the <code> Id </code> of the <code> 
     *          ProgramOffering </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> programOfferingId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedEnrollmentsForProgramOffering(org.osid.id.Id programOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted enrollments for the given 
     *  student. <code> EnrollmentReceiver.deletedEnrollments() </code> is 
     *  invoked when an enrollment is deleted or removed from this course 
     *  catalog. 
     *
     *  @param  studentId the <code> Id </code> of the <code> Resource </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> studentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedEnrollmentsForStudent(org.osid.id.Id studentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted enrollment. <code> 
     *  EnrollmentReceiver.deletedEnrollments() </code> is invoked when the 
     *  specified enrollment is deleted or removed from this course catalog. 
     *
     *  @param  enrollmentId the <code> Id </code> of the <code> Enrollment 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> enrollmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedEnrollment(org.osid.id.Id enrollmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
