//
// org.osid.course.program.EnrollmentSearchSession
//
//     The OSID Java specification for org.osid.course.program.EnrollmentSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session provides methods for searching among <code> Enrollment 
 *  </code> objects. The search query is constructed using the <code> 
 *  EnrollmentQuery. </code> </p> 
 *  
 *  <p> <code> getEnrollmentsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Enrollments. </code> A more advanced search may 
 *  be performed with <code> getEnrollmentsBySearch(). </code> It accepts an 
 *  <code> EnrollmentSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getEnrollmentsBySearch() </code> returns an <code> 
 *  EnrollmentSearchResults </code> that can be used to access the resulting 
 *  <code> EnrollmentList </code> or be used to perform a search within the 
 *  result set through <code> EnrollmentSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include enrollments in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to 
 *      enrollments in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Enrollments may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> EnrollmentQuery. 
 *  </code> </p>
 */

public interface EnrollmentSearchSession
    extends org.osid.course.program.EnrollmentQuerySession {


    /**
     *  Gets an enrollment search. 
     *
     *  @return the enrollment search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentSearch getEnrollmentSearch();


    /**
     *  Gets an enrollment search order. The <code> EnrollmentSearchOrder 
     *  </code> is supplied to an <code> EnrollmentSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the enrollment search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentSearchOrder getEnrollmentSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  enrollmentQuery the enrollment query 
     *  @param  enrollmentSearch the enrollment search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> enrollmentQuery </code> 
     *          or <code> enrollmentSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> enrollmentQuery </code> 
     *          or <code> enrollmentSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentSearchResults getEnrollmentsBySearch(org.osid.course.program.EnrollmentQuery enrollmentQuery, 
                                                                                  org.osid.course.program.EnrollmentSearch enrollmentSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an enrollment query from an inspector. The inspector is available 
     *  from an <code> EnrollmentSearchResults. </code> 
     *
     *  @param  enrollmentQueryInspector an enrollment query inspector 
     *  @return the enrollment query 
     *  @throws org.osid.NullArgumentException <code> enrollmentQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> enrollmentQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.EnrollmentQuery getEnrollmentQueryFromInspector(org.osid.assessment.ItemQueryInspector enrollmentQueryInspector);
}
