//
// org.osid.course.program.Program
//
//     The OSID Java specification for org.osid.course.program.Program.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>A <code> Program </code> represents a canonical program and 
 *  instantiated for offering through the creation of a <code> 
 *  ProgramOffering. </code> </p>
 */

public interface Program
    extends org.osid.OsidObject,
            org.osid.Operable {


    /**
     *  Gets the formal title of this program. It may be the same as the 
     *  display name or it may be used to more formally label the program. It 
     *  may be the same as the display name or it may be used to more formally 
     *  label the program. A display name might be Course 16 where the title 
     *  is Aeronautics &amp; Astronautics. 
     *
     *  @return the program title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getTitle();


    /**
     *  Gets the program number which is a label generally used to index the 
     *  program in a catalog, such as "16c." 
     *
     *  @return the program number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getNumber();


    /**
     *  Tests if this program has sponsors. 
     *
     *  @return <code> true </code> if this program has sponsors, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSponsors();


    /**
     *  Gets the sponsor <code> Ids. </code> 
     *
     *  @return the sponsor <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSponsorIds();


    /**
     *  Gets the sponsors. 
     *
     *  @return the sponsors 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getSponsors()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the an informational string for the program completion. 
     *
     *  @return the program completion 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getCompletionRequirementsInfo();


    /**
     *  Tests if this program has a rule for the program completion. 
     *
     *  @return <code> true </code> if this program has a completion rule, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCompletionRequirements();


    /**
     *  Gets the <code> Requisite </code> <code> Ids </code> for the program 
     *  completion. 
     *
     *  @return the completion requisite <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasCompletionRequirements() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCompletionRequirementIds();


    /**
     *  Gets the requisites for the program completion. Each <code> Requisite 
     *  </code> is an <code> AND </code> term and must be true for the 
     *  requirements to be satisifed. 
     *
     *  @return the completion requisites 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasCompletionRequirements() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getCompletionRequirements()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if completion of this program results in credentials awarded. 
     *
     *  @return <code> true </code> if this program earns credentials, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean earnsCredentials();


    /**
     *  Gets the awarded credential <code> Ids. </code> 
     *
     *  @return the returned list of credential <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> earnsCredentials() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCredentialIds();


    /**
     *  Gets the awarded credentials. 
     *
     *  @return the returned list of credentials 
     *  @throws org.osid.IllegalStateException <code> earnsCredentials() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialList getCredentials()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the program record corresponding to the given <code> Program 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> programRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(programRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  programRecordType the type of program record to retrieve 
     *  @return the program record 
     *  @throws org.osid.NullArgumentException <code> programRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(programRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.records.ProgramRecord getProgramRecord(org.osid.type.Type programRecordType)
        throws org.osid.OperationFailedException;
}
