//
// org.osid.course.program.ProgramOffering
//
//     The OSID Java specification for org.osid.course.program.ProgramOffering.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>A <code> ProgramOffering </code> represents a learning unit offered 
 *  duing a <code> Term. </code> Scheduling information of a <code> 
 *  ProgramOffering </code> is maintained at the <code> Activity </code> level 
 *  resulting in a composite <code> RecurringEvent. </code> A separate <code> 
 *  Calendar </code> of activities can be made available through orchestration 
 *  of the Calendaring OSID. </p>
 */

public interface ProgramOffering
    extends org.osid.OsidRelationship {


    /**
     *  Gets the canonical program <code> Id </code> associated with this 
     *  program offering. 
     *
     *  @return the program <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProgramId();


    /**
     *  Gets the canonical program associated with this program offering. 
     *
     *  @return the program 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Program getProgram()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Term </code> of this 
     *  offering. 
     *
     *  @return the <code> Term </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTermId();


    /**
     *  Gets the <code> Term </code> of this offering. 
     *
     *  @return the term 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.Term getTerm()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the formal title of this program offering. It may be the same as 
     *  the display name or it may be used to more formally label the program. 
     *  A display name might be Course 16 where the title is Aeronautics &amp; 
     *  Astronautics. 
     *
     *  @return the program title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getTitle();


    /**
     *  Gets the program number which is a label generally used to index the 
     *  program offering in a catalog, such as 16. 
     *
     *  @return the program number 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getNumber();


    /**
     *  Tests if this program offering has sponsors. 
     *
     *  @return <code> true </code> if this program offering has sponsors, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSponsors();


    /**
     *  Gets the sponsor <code> Ids. </code> 
     *
     *  @return the sponsor <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSponsorIds();


    /**
     *  Gets the sponsors. 
     *
     *  @return the sponsors 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getSponsors()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the an informational string for the program completion. 
     *
     *  @return the program completion 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getCompletionRequirementsInfo();


    /**
     *  Tests if this program has a rule for the program completion. 
     *
     *  @return <code> true </code> if this program has a completion rule, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCompletionRequirements();


    /**
     *  Gets the <code> Requisite </code> <code> Ids </code> for the program 
     *  completion. 
     *
     *  @return the completion requisite <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasCompletionRequirements() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCompletionRequirementIds();


    /**
     *  Gets the requisites for the program completion. Each <code> Requisite 
     *  </code> is an <code> AND </code> term and must be true for the 
     *  requirements to be satisifed. 
     *
     *  @return the completion requisites 
     *  @throws org.osid.IllegalStateException <code> 
     *          hasCompletionRequirements() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getCompletionRequirements()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if completion of this program results in credentials awarded. 
     *
     *  @return <code> true </code> if this program earns credentials, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean earnsCredentials();


    /**
     *  Gets the awarded credential <code> Ids. </code> 
     *
     *  @return the returned list of credential <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> earnsCredentials() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCredentialIds();


    /**
     *  Gets the awarded credentials. 
     *
     *  @return the returned list of credentials 
     *  @throws org.osid.IllegalStateException <code> earnsCredentials() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialList getCredentials()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this program offering requires advanced registration. 
     *
     *  @return <code> true </code> if this progranm offering requires advance 
     *          registration, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresRegistration();


    /**
     *  Gets the minimum number of students this offering can have. 
     *
     *  @return the minimum seats 
     *  @throws org.osid.IllegalStateException <code> requiresRegistration() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMinimumSeats();


    /**
     *  Gets the maximum number of students this offering can have. 
     *
     *  @return the maximum seats 
     *  @throws org.osid.IllegalStateException <code> requiresRegistration() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getMaximumSeats();


    /**
     *  Gets an external resource, such as a class web site, associated with 
     *  this offering. 
     *
     *  @return a URL string 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getURL();


    /**
     *  Gets the program offering record corresponding to the given <code> 
     *  ProgramOffering </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> programOfferingRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(programOfferingRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  programOfferingRecordType the type of program offering record 
     *          to retrieve 
     *  @return the program offering record 
     *  @throws org.osid.NullArgumentException <code> 
     *          programOfferingRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(programOfferingRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.records.ProgramOfferingRecord getProgramOfferingRecord(org.osid.type.Type programOfferingRecordType)
        throws org.osid.OperationFailedException;
}
