//
// org.osid.course.program.ProgramOfferingLookupSession
//
//     The OSID Java specification for org.osid.course.program.ProgramOfferingLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session defines methods for retrieving program offerings. A <code> 
 *  ProgramOffering </code> is an offering of a <code> Program </code> in 
 *  which a student can enroll. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All program offering methods in 
 *      this session operate, retrieve and pertain to program offerings 
 *      defined explicitly in the current course catalog. Using an isolated 
 *      view is useful for managing <code> ProgramOfferings </code> with the 
 *      <code> ProgramOfferingAdminSession. </code> </li> 
 *      <li> federated course catalog view: All program offering lookup 
 *      methods in this session operate, retrieve and pertain to all program 
 *      offerings defined in this course catalog and any other courses 
 *      implicitly available in this course catalog through course catalog 
 *      inheritence. </li> 
 *      <li> effective program offering view: All program offering lookup 
 *      methods return program offerings where the current date falls within 
 *      the effective dates inclusive. </li> 
 *      <li> any effective program offering view: Program offerings of any 
 *      effective or expired status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Courses may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Course. </code> </p>
 */

public interface ProgramOfferingLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ProgramOffering </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProgramOfferings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProgramOfferingView();


    /**
     *  A complete view of the <code> ProgramOffering </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProgramOfferingView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include program offerings in catalogs which are children of this 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  All program offering methods return program offerings where the 
     *  current date falls within the effective dates inclusive. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveProgramOfferingView();


    /**
     *  All methods return program offerings of any effective or expired 
     *  status. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveProgramOfferingView();


    /**
     *  Gets the <code> ProgramOffering </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ProgramOffering </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> program </code> and retained for compatibility. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programOfferingId the <code> Id </code> of the <code> 
     *          ProgramOffering </code> to retrieve 
     *  @return the returned <code> ProgramOffering </code> 
     *  @throws org.osid.NotFoundException no <code> ProgramOffering </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> programOfferingId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOffering getProgramOffering(org.osid.id.Id programOfferingId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  program offerings specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> ProgramOfferings </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programOfferingIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> programOfferingIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsByIds(org.osid.id.IdList programOfferingIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> corresponding to the given 
     *  program offering genus <code> Type </code> which does not include 
     *  program offerings of types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  program offerings or an error results. Otherwise, the returned list 
     *  may contain only those program offerings that are accessible through 
     *  this session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programOfferingGenusType a program offering genus type 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.NullArgumentException <code> programOfferingGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsByGenusType(org.osid.type.Type programOfferingGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> corresponding to the given 
     *  porgram offering genus <code> Type </code> and include any additional 
     *  program offerings with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  program offerings or an error results. Otherwise, the returned list 
     *  may contain only those program offerings that are accessible through 
     *  this session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programOfferingGenusType a program offering genus type 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.NullArgumentException <code> programOfferingGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsByParentGenusType(org.osid.type.Type programOfferingGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> containing the given program 
     *  offering record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programOfferingRecordType a program offering record type 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          programOfferingRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsByRecordType(org.osid.type.Type programOfferingRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> effective within the given 
     *  date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsOnDate(org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ProgramOfferings </code> associated with a given 
     *  <code> Program. </code> In plenary mode, the returned list contains 
     *  all known program offerings or an error results. Otherwise, the 
     *  returned list may contain only those program offerings that are 
     *  accessible through this session. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @return a list of <code> ProgramOfferings </code> 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsForProgram(org.osid.id.Id programId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> for the given program and 
     *  effective within the given date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> programId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsForProgramOnDate(org.osid.id.Id programId, 
                                                                                           org.osid.calendaring.DateTime from, 
                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ProgramOfferings </code> associated with a given 
     *  <code> Term. </code> 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @return a list of <code> ProgramOfferings </code> 
     *  @throws org.osid.NullArgumentException <code> termId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsForTerm(org.osid.id.Id termId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> for the given term and 
     *  effective within the given date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  termId a term <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> termId, from, </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsForTermOnDate(org.osid.id.Id termId, 
                                                                                        org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ProgramOfferings </code> associated with a given 
     *  <code> Term </code> and <code> Program. </code> 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programId a programId <code> Id </code> 
     *  @param  termId a term <code> Id </code> 
     *  @return a list of <code> ProgramOfferings </code> 
     *  @throws org.osid.NullArgumentException <code> programId </code> or 
     *          <code> termId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsForProgramAndTerm(org.osid.id.Id programId, 
                                                                                            org.osid.id.Id termId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramOfferingList </code> for the given program, term, 
     *  and effective within the given date range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  termId a term <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> ProgramOffering </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> programId, termId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferingsForProgramAndTermOnDate(org.osid.id.Id programId, 
                                                                                                  org.osid.id.Id termId, 
                                                                                                  org.osid.calendaring.DateTime from, 
                                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ProgramOfferings. </code> 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  offerings or an error results. Otherwise, the returned list may 
     *  contain only those program offerings that are accessible through this 
     *  session. 
     *  
     *  In effective mode, program offerings are returned where the current 
     *  date falls within the effective dates inclusive. In any effective 
     *  mode, effective and expired program offerings are returned. 
     *
     *  @return a list of <code> ProgramOfferings </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramOfferingList getProgramOfferings()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
