//
// org.osid.course.program.ProgramSearchSession
//
//     The OSID Java specification for org.osid.course.program.ProgramSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.program;


/**
 *  <p>This session provides methods for searching among <code> Programs. 
 *  </code> The search query is constructed using the <code> ProgramQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getProgramsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Programs. </code> A more advanced search may be 
 *  performed with <code> getProgramsBySearch(). </code> It accepts a <code> 
 *  ProgramSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProgramsBySearch() </code> returns a <code> 
 *  ProgramSearchResults </code> that can be used to access the resulting 
 *  <code> ProgramList </code> or be used to perform a search within the 
 *  result set through <code> ProgramSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include programs in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to courses 
 *      in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Programs may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ProgramQuery. </code> 
 *  </p>
 */

public interface ProgramSearchSession
    extends org.osid.course.program.ProgramQuerySession {


    /**
     *  Gets a program search. 
     *
     *  @return the program search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramSearch getProgramSearch();


    /**
     *  Gets a program search order. The <code> ProgramSearchOrder </code> is 
     *  supplied to a <code> ProgramSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the program search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramSearchOrder getProgramSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  programQuery the program query 
     *  @param  programSearch the program search 
     *  @return the program search results 
     *  @throws org.osid.NullArgumentException <code> programQuery </code> or 
     *          <code> programSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> programQuery </code> or 
     *          <code> programSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramSearchResults getProgramsBySearch(org.osid.course.program.ProgramQuery programQuery, 
                                                                            org.osid.course.program.ProgramSearch programSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a program query from an inspector. The inspector is available 
     *  from a <code> ProgramSearchResults. </code> 
     *
     *  @param  programQueryInspector a program query inspector 
     *  @return the program query 
     *  @throws org.osid.NullArgumentException <code> programQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> programQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramQuery getProgramQueryFromInspector(org.osid.course.program.ProgramQueryInspector programQueryInspector);
}
