//
// org.osid.course.registration.ActivityBundleForm
//
//     The OSID Java specification for org.osid.course.registration.ActivityBundleForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This is the form for creating and updating <code> ActivityBundles. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  ActivityBundleAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ActivityBundleForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for credits. 
     *
     *  @return metadata for the credits 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreditsMetadata();


    /**
     *  Sets the activity bundle credits. 
     *
     *  @param  credits the new credits 
     *  @throws org.osid.InvalidArgumentException <code> credits </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> credits </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCredits(java.math.BigDecimal[] credits);


    /**
     *  Removes the credits. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredits();


    /**
     *  Gets the metadata for a set of grading options. 
     *
     *  @return metadata for the grading options 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGradingOptionsMetadata();


    /**
     *  Sets the grading options. 
     *
     *  @param  gradeSystemIds the new grade systems 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGradingOptions(org.osid.id.Id[] gradeSystemIds);


    /**
     *  Removes the grading options. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradingOptions();


    /**
     *  Gets the <code> ActivityBundleFormRecord </code> corresponding to the 
     *  given activity bundle record <code> Type. </code> 
     *
     *  @param  activityBundleRecordType an activity bundle record type 
     *  @return the activity bundle form record 
     *  @throws org.osid.NullArgumentException <code> activityBundleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityBundleRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.records.ActivityBundleFormRecord getActivityBundleFormRecord(org.osid.type.Type activityBundleRecordType)
        throws org.osid.OperationFailedException;
}
