//
// org.osid.course.registration.ActivityBundleSearchSession
//
//     The OSID Java specification for org.osid.course.registration.ActivityBundleSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session provides methods for searching among <code> ActivityBundle 
 *  </code> objects. The search query is constructed using the <code> 
 *  ActivityBundleQuery. </code> </p> 
 *  
 *  <p> <code> getActivityBundlesByQuery() </code> is the basic search method 
 *  and returns a list of <code> ActivityBundles. </code> A more advanced 
 *  search may be performed with <code> getActivityBundlesBySearch(). </code> 
 *  It accepts an <code> ActivityBundleSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getActivityBundlesBySearch() </code> 
 *  returns an <code> ActivityBundleSearchResults </code> that can be used to 
 *  access the resulting <code> ActivityBundleList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  ActivityBundleSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include activity bundles 
 *      in course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to activity 
 *      bundles in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Activity Bundles may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ActivityBundleQuery. </code> </p>
 */

public interface ActivityBundleSearchSession
    extends org.osid.course.registration.ActivityBundleQuerySession {


    /**
     *  Gets an activity bundle search. 
     *
     *  @return the activity bundle search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleSearch getActivityBundleSearch();


    /**
     *  Gets an activity search order. The <code> ActivityBundleSearchOrder 
     *  </code> is supplied to an <code> ActivityBundleSearch </code> to 
     *  specify the ordering of results. 
     *
     *  @return the activity bundle search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleSearchOrder getActivityBundleSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  activityBundleQuery the activity bundle query 
     *  @param  activityBundleSearch the activity bundle search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> activityBundleQuery 
     *          </code> or <code> activityBundleSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityBundleQuery 
     *          </code> or <code> activityBundleSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleSearchResults getActivityBundlesBySearch(org.osid.course.registration.ActivityBundleQuery activityBundleQuery, 
                                                                                               org.osid.course.registration.ActivityBundleSearch activityBundleSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an activity bundle query from an inspector. The inspector is 
     *  available from an <code> ActivityBundleSearchResults. </code> 
     *
     *  @param  activityBundleQueryInspector a query inspector 
     *  @return the activity bundle query 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityBundleQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          activityBundleQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityBundleQuery getActivityBundleQueryFromInspector(org.osid.assessment.ItemQueryInspector activityBundleQueryInspector);
}
