//
// org.osid.course.registration.ActivityRegistrationAdminSession
//
//     The OSID Java specification for org.osid.course.registration.ActivityRegistrationAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session creates, updates, and deletes <code> 
 *  ActivityRegistrations. </code> The data for create and update is provided 
 *  by the consumer via the form object. <code> OsidForms </code> are 
 *  requested for each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> ActivityRegistration, </code> an <code> ActivityRegistrationForm 
 *  </code> is requested using <code> getRegistrationFormForCreate() </code> 
 *  specifying the registration, activity, student, and desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> ActivityRegistrationForm </code> will indicate that it is 
 *  to be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> ActivityRegistrationForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ActivityRegistrationForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> For updates, <code> ActivityRegistrationForms </code> are requested to 
 *  the <code> ActivityRegistrationForm </code> <code> Id </code> that is to 
 *  be updated using <code> getActivityRegistrationFormForUpdate(). </code> 
 *  Similarly, the <code> ActivityRegistrationForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ActivityRegistrationForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ActivityRegistrations. </code> To 
 *  unmap an <code> ActivityRegistration </code> from the current <code> 
 *  CourseCatalog, </code> the <code> 
 *  ActivityRegistrationCourseCatalogAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> 
 *  ActivityRegistrationForm </code> itself thus removing it from all known 
 *  <code> CourseCatalog </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ActivityRegistrationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ActivityRegistrations. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating an <code> 
     *  ActivityRegistration </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityRegistration </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityRegistrations();


    /**
     *  Tests if this user can create a single <code> ActivityRegistration 
     *  </code> using the desired record types. While <code> 
     *  CourseRegistrationManager.getActivityRegistrationRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  ActivityRegistration. </code> Providing an empty array tests if an 
     *  <code> ActivityRegistration </code> can be created with no records. 
     *
     *  @param  activityRegistrationRecordTypes array of activity registration 
     *          record types 
     *  @return <code> true </code> if <code> ActivityRegistration </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateActivityRegistrationWithRecordTypes(org.osid.type.Type[] activityRegistrationRecordTypes);


    /**
     *  Gets the course form for creating new activity registrations. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  registrationId the <code> Id </code> for a <code> Registration 
     *          </code> 
     *  @param  activityId the <code> Id </code> for an <code> Activity 
     *          </code> 
     *  @param  resourceId the <code> Id </code> for a <code> Resource </code> 
     *  @param  activityRegistrationRecordTypes array of activity registration 
     *          record types 
     *  @return the activity registration form 
     *  @throws org.osid.NotFoundException <code> activityId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> activityId, resourceId, 
     *          </code> or <code> activityRegistrationRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          recod types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationForm getActivityRegistrationFormForCreate(org.osid.id.Id registrationId, 
                                                                                                      org.osid.id.Id activityId, 
                                                                                                      org.osid.id.Id resourceId, 
                                                                                                      org.osid.type.Type[] activityRegistrationRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ActivityRegistration. </code> 
     *
     *  @param  activityRegistrationForm the form for this <code> 
     *          ActivityRegistration </code> 
     *  @return the new <code> ActivityRegistration </code> 
     *  @throws org.osid.IllegalStateException <code> activityRegistrationForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityRegistrationForm 
     *          </code> did not originate from <code> 
     *          getActivityRegistrationFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistration createActivityRegistration(org.osid.course.registration.ActivityRegistrationForm activityRegistrationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ActivityRegistrations. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating an <code> 
     *  ActivityRegistration </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityRegistration </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateActivityRegistrations();


    /**
     *  Gets the activity registration form for updating an existing activity 
     *  registration. A new activity registration form should be requested for 
     *  each update transaction. 
     *
     *  @param  activityRegistrationId the <code> Id </code> of the <code> 
     *          ActivityRegistration </code> 
     *  @return the activity registration form 
     *  @throws org.osid.NotFoundException <code> activityRegistrationId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationForm getActivityRegistrationFormForUpdate(org.osid.id.Id activityRegistrationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing activity registration. 
     *
     *  @param  activityRegistrationId the <code> Id </code> of the <code> 
     *          ActivityRegistration </code> 
     *  @param  activityRegistrationForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> activityRegistrationForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> activityRegistrationForm 
     *          </code> did not originate from <code> 
     *          getActivityRegistrationFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateActivityRegistration(org.osid.id.Id activityRegistrationId, 
                                           org.osid.course.registration.ActivityRegistrationForm activityRegistrationForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ActivityRegistrations. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting an <code> 
     *  ActivityRegistration </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityRegistration </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteActivityRegistrations();


    /**
     *  Deletes an <code> ActivityRegistration. </code> 
     *
     *  @param  activityRegistrationId the <code> Id </code> of the <code> 
     *          ActivityRegistration </code> to remove 
     *  @throws org.osid.NotFoundException <code> activityRegistrationId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteActivityRegistration(org.osid.id.Id activityRegistrationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ActivityRegistrations. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ActivityRegistration </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageActivityRegistrationAliases();


    /**
     *  Adds an <code> Id </code> to an <code> ActivityRegistration </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> ActivityRegistration </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id. </code> If the alias is a pointer to another 
     *  activity registration, it is reassigned to the given activity 
     *  registration <code> Id. </code> 
     *
     *  @param  activityRegistrationId the <code> Id </code> of an <code> 
     *          ActivityRegistration </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> activityRegistrationId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasActivityRegistration(org.osid.id.Id activityRegistrationId, 
                                          org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
