//
// org.osid.course.registration.ActivityRegistrationLookupSession
//
//     The OSID Java specification for org.osid.course.registration.ActivityRegistrationLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session defines methods for retrieving activity registrations. An 
 *  <code> ActivityRegistration </code> is a relationship between a student 
 *  and an <code> Activity. </code> <code> ActivityRegistrations </code> may 
 *  be implied from a <code> Registration. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All activity registration methods 
 *      in this session operate, retrieve and pertain to activity 
 *      registrations defined explicitly in the current course catalog. Using 
 *      an isolated view is useful for managing <code> ActivityRegistrations 
 *      </code> with the <code> ActivityRegistrationAdminSession. </code> 
 *      </li> 
 *      <li> federated course catalog view: All activity registration lookup 
 *      methods in this session operate, retrieve and pertain to all activity 
 *      registrations defined in this course catalog and any other activity 
 *      registrations implicitly available in this course catalog through 
 *      course catalog inheritence. </li> 
 *      <li> effective vote view: All activity registration lookup methods 
 *      return registrations where the current date falls in between the 
 *      effective dates inclusive. </li> 
 *      <li> any effective vote view: Activity registrations of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Activity registrations may have an additional records indicated by 
 *  their respective record types. The record may not be accessed through a 
 *  cast of the <code> ActivityRegistration. </code> </p>
 */

public interface ActivityRegistrationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ActivityRegistration </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupActivityRegistrations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeActivityRegistrationView();


    /**
     *  A complete view of the <code> ActivityRegistration </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryActivityRegistrationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include activity registrations in catalogs which are children of this 
     *  catalog in the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only activity registrations whose effective dates are current are 
     *  returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveActivityRegistrationView();


    /**
     *  All activity registrations of any effective dates are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveActivityRegistrationView();


    /**
     *  Gets the <code> ActivityRegistration </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ActivityRegistration </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> Course </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityRegistrationId the <code> Id </code> of the <code> 
     *          ActivityRegistration </code> to retrieve 
     *  @return the returned <code> ActivityRegistration </code> 
     *  @throws org.osid.NotFoundException no <code> ActivityRegistration 
     *          </code> found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistration getActivityRegistration(org.osid.id.Id activityRegistrationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityRegistrationList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  activity registrations specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> ActivityRegistrations </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityRegistrationIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> ActivityRegistration </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityRegistrationIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsByIds(org.osid.id.IdList activityRegistrationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityRegistrationList </code> corresponding to the 
     *  given activity registration genus <code> Type </code> which does not 
     *  include activity registrations of types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  activity registrations or an error results. Otherwise, the returned 
     *  list may contain only those activity registrations that are accessible 
     *  through this session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityRegistrationGenusType an activity registration genus 
     *          type 
     *  @return the returned <code> ActivityRegistration </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsByGenusType(org.osid.type.Type activityRegistrationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityRegistrationList </code> corresponding to the 
     *  given course genus <code> Type </code> and include any additional 
     *  activity registrations with genus types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  activity registrations or an error results. Otherwise, the returned 
     *  list may contain only those activity registrations that are accessible 
     *  through this session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityRegistrationGenusType an activity registration genus 
     *          type 
     *  @return the returned <code> ActivityRegistration </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsByParentGenusType(org.osid.type.Type activityRegistrationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityRegistrationList </code> containing the given 
     *  activity registration record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those activity registrations that are accessible through 
     *  this session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityRegistrationRecordType an activity registration record 
     *          type 
     *  @return the returned <code> ActivityRegistration </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsByRecordType(org.osid.type.Type activityRegistrationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsOnDate(org.osid.calendaring.DateTime from, 
                                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a registration. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  registrationId a registration <code> Id </code> 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.NullArgumentException <code> registrationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForRegistration(org.osid.id.Id registrationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a registration and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  registrationId a registration <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> registrationId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForRegistrationOnDate(org.osid.id.Id registrationId, 
                                                                                                               org.osid.calendaring.DateTime from, 
                                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> associated with a given 
     *  <code> Activity. </code> 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for the given activity 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> activityId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForActivityOnDate(org.osid.id.Id activityId, 
                                                                                                           org.osid.calendaring.DateTime from, 
                                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a given student. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForStudent(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a student during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForStudentOnDate(org.osid.id.Id resourceId, 
                                                                                                          org.osid.calendaring.DateTime from, 
                                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a given activity and 
     *  student. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.NullArgumentException <code> activityId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForActivityAndStudent(org.osid.id.Id activityId, 
                                                                                                               org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for an activity and 
     *  student during the entire given date range inclusive but not confined 
     *  to the date range. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> activityId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForActivityAndStudentOnDate(org.osid.id.Id activityId, 
                                                                                                                     org.osid.id.Id resourceId, 
                                                                                                                     org.osid.calendaring.DateTime from, 
                                                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> related to a course 
     *  offering. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForCourseOffering(org.osid.id.Id courseOfferingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a course offering 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForCourseOfferingOnDate(org.osid.id.Id courseOfferingId, 
                                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a given course 
     *  offering and student. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId </code> 
     *          or <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForCourseOfferingAndStudent(org.osid.id.Id courseOfferingId, 
                                                                                                                     org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations </code> for a course offering 
     *  and student effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those registrations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @param  courseOfferingId a course offering <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> courseOfferingId, 
     *          resourceId, from, </code> or <code> to </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrationsForCourseOfferingAndStudentOnDate(org.osid.id.Id courseOfferingId, 
                                                                                                                           org.osid.id.Id resourceId, 
                                                                                                                           org.osid.calendaring.DateTime from, 
                                                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ActivityRegistrations. </code> 
     *  
     *  In plenary mode, the returned list contains all known activity 
     *  registrations or an error results. Otherwise, the returned list may 
     *  contain only those activity registrations that are accessible through 
     *  this session. 
     *  
     *  In effective mode, activity registrations are returned that are 
     *  currently effective. In any effective mode, effective activity 
     *  registrations and those currently expired are returned. 
     *
     *  @return a list of <code> ActivityRegistrations </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.ActivityRegistrationList getActivityRegistrations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
