//
// org.osid.course.registration.CourseRegistrationProfile
//
//     The OSID Java specification for org.osid.course.registration.CourseRegistrationProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>The course registration profile describes the interoperability among 
 *  course registration services. </p>
 */

public interface CourseRegistrationProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any course catalog federation is exposed. Federation is 
     *  exposed when a specific course catalog may be identified, selected and 
     *  used to create a lookup or admin session. Federation is not exposed 
     *  when a set of catalogs appears as a single catalog. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up activity bundles is supported. 
     *
     *  @return <code> true </code> if activity bundle lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleLookup();


    /**
     *  Tests if querying activity bundles is supported. 
     *
     *  @return <code> true </code> if activity bundle query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleQuery();


    /**
     *  Tests if searching activity bundles is supported. 
     *
     *  @return <code> true </code> if activity bundle search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleSearch();


    /**
     *  Tests if an activity bundle <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if activity bundle administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleAdmin();


    /**
     *  Tests if an activity bundle <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if activity bundle notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleNotification();


    /**
     *  Tests if an activity bundle cataloging service is supported. 
     *
     *  @return <code> true </code> if activity bundle catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleCourseCatalog();


    /**
     *  Tests if an activity bundle cataloging service is supported. A 
     *  cataloging service maps activity bundles to catalogs. 
     *
     *  @return <code> true </code> if activity bundle cataloging is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleCourseCatalogAssignment();


    /**
     *  Tests if an activity bundle smart course catalog session is available. 
     *
     *  @return <code> true </code> if an activity bundle smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleSmartCourseCatalog();


    /**
     *  Tests if looking up registrations is supported. 
     *
     *  @return <code> true </code> if registration lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationLookup();


    /**
     *  Tests if querying registrations is supported. 
     *
     *  @return <code> true </code> if registration query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationQuery();


    /**
     *  Tests if searching registrations is supported. 
     *
     *  @return <code> true </code> if registration search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationSearch();


    /**
     *  Tests if course <code> </code> offering <code> </code> administrative 
     *  service is supported. 
     *
     *  @return <code> true </code> if registration administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationAdmin();


    /**
     *  Tests if a registration <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if registration notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationNotification();


    /**
     *  Tests if a registration cataloging service is supported. 
     *
     *  @return <code> true </code> if registration catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationCourseCatalog();


    /**
     *  Tests if a registration cataloging service is supported. A cataloging 
     *  service maps registrations to catalogs. 
     *
     *  @return <code> true </code> if registration cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationCourseCatalogAssignment();


    /**
     *  Tests if a registration smart course catalog session is available. 
     *
     *  @return <code> true </code> if a registration smart course catalog 
     *          session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationSmartCourseCatalog();


    /**
     *  Tests if looking up activity registrations is supported. 
     *
     *  @return <code> true </code> if activity registration lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationLookup();


    /**
     *  Tests if querying activity registrations is supported. 
     *
     *  @return <code> true </code> if activity registration query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationQuery();


    /**
     *  Tests if searching activity registrations is supported. 
     *
     *  @return <code> true </code> if activity registration search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationSearch();


    /**
     *  Tests if an activity registration <code> </code> administrative 
     *  service is supported. 
     *
     *  @return <code> true </code> if activity registration administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationAdmin();


    /**
     *  Tests if an activity registration <code> </code> notification service 
     *  is supported. 
     *
     *  @return <code> true </code> if activity registration notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationNotification();


    /**
     *  Tests if an activity registration cataloging service is supported. 
     *
     *  @return <code> true </code> if activity registration catalog is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationCourseCatalog();


    /**
     *  Tests if an activity registration cataloging service is supported. A 
     *  cataloging service maps activity registrations to catalogs. 
     *
     *  @return <code> true </code> if activity registration cataloging is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationCourseCatalogAssignment();


    /**
     *  Tests if an activity registration smart course catalog session is 
     *  available. 
     *
     *  @return <code> true </code> if an activity registration smart course 
     *          catalog session is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationSmartCourseCatalog();


    /**
     *  Tests if a course registration batch service is available. 
     *
     *  @return <code> true </code> if a course registration service session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseRegistrationBatch();


    /**
     *  Gets the supported <code> ActivityBundle </code> record types. 
     *
     *  @return a list containing the supported <code> ActivityBundle </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityBundleRecordTypes();


    /**
     *  Tests if the given <code> ActivityBundle </code> record type is 
     *  supported. 
     *
     *  @param  activityBundleRecordType a <code> Type </code> indicating an 
     *          <code> ActivityBundle </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activityBundleRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleRecordType(org.osid.type.Type activityBundleRecordType);


    /**
     *  Gets the supported <code> ActivityBundle </code> search record types. 
     *
     *  @return a list containing the supported <code> ActivityBundle </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityBundleSearchRecordTypes();


    /**
     *  Tests if the given <code> ActivityBundle </code> search record type is 
     *  supported. 
     *
     *  @param  activityBundleSearchRecordType a <code> Type </code> 
     *          indicating an <code> ActivityBundle </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityBundleSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBundleSearchRecordType(org.osid.type.Type activityBundleSearchRecordType);


    /**
     *  Gets the supported <code> Registration </code> record types. 
     *
     *  @return a list containing the supported <code> Registration </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRegistrationRecordTypes();


    /**
     *  Tests if the given <code> Registration </code> record type is 
     *  supported. 
     *
     *  @param  registrationRecordType a <code> Type </code> indicating an 
     *          <code> Registration </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> registrationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationRecordType(org.osid.type.Type registrationRecordType);


    /**
     *  Gets the supported <code> Registration </code> search record types. 
     *
     *  @return a list containing the supported <code> Registration </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRegistrationSearchRecordTypes();


    /**
     *  Tests if the given <code> Registration </code> search record type is 
     *  supported. 
     *
     *  @param  registrationSearchRecordType a <code> Type </code> indicating 
     *          an <code> Registration </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          registrationSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRegistrationSearchRecordType(org.osid.type.Type registrationSearchRecordType);


    /**
     *  Gets the supported <code> ActivityRegistration </code> record types. 
     *
     *  @return a list containing the supported <code> ActivityRegistration 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityRegistrationRecordTypes();


    /**
     *  Tests if the given <code> ActivityRegistration </code> record type is 
     *  supported. 
     *
     *  @param  activityRegistrationRecordType a <code> Type </code> 
     *          indicating an <code> ActivityRegistration </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationRecordType(org.osid.type.Type activityRegistrationRecordType);


    /**
     *  Gets the supported <code> ActivityRegistration </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> ActivityRegistration 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityRegistrationSearchRecordTypes();


    /**
     *  Tests if the given <code> ActivityRegistration </code> search record 
     *  type is supported. 
     *
     *  @param  activityRegistrationSearchRecordType a <code> Type </code> 
     *          indicating an <code> ActivityRegistration </code> search 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          activityRegistrationSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRegistrationSearchRecordType(org.osid.type.Type activityRegistrationSearchRecordType);
}
