//
// org.osid.course.registration.RegistrationSearchSession
//
//     The OSID Java specification for org.osid.course.registration.RegistrationSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.registration;


/**
 *  <p>This session provides methods for searching among <code> Registration 
 *  </code> objects. The search query is constructed using the <code> 
 *  RegistrationQuery. </code> </p> 
 *  
 *  <p> <code> getRegistrationsByQuery() </code> is the basic search method 
 *  and returns a list of <code> Registrations. </code> A more advanced search 
 *  may be performed with <code> getRegistrationsBySearch(). </code> It 
 *  accepts a <code> RegistrationSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getRegistrationsBySearch() </code> returns a 
 *  <code> RegistrationSearchResults </code> that can be used to access the 
 *  resulting <code> RegistrationList </code> or be used to perform a search 
 *  within the result set through <code> RegistrationSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated course catalog view: searches include registrations in 
 *      course catalogs of which this course catalog is an ancestor in the 
 *      course catalog hierarchy </li> 
 *      <li> isolated course catalog view: searches are restricted to 
 *      registrations in this course catalog </li> 
 *  </ul>
 *  
 *  
 *  <p> Registrations may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  RegistrationQuery. </code> </p>
 */

public interface RegistrationSearchSession
    extends org.osid.course.registration.RegistrationQuerySession {


    /**
     *  Gets a registration search. 
     *
     *  @return the registration search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationSearch getRegistrationSearch();


    /**
     *  Gets a registration search order. The <code> RegistrationSearchOrder 
     *  </code> is supplied to a <code> RegistrationSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the registration search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationSearchOrder getRegistrationSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  registrationQuery the registration query 
     *  @param  registrationSearch the registration search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> registrationQuery 
     *          </code> or <code> registrationSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> registrationQuery </code> 
     *          or <code> registrationSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationSearchResults getRegistrationsBySearch(org.osid.course.registration.RegistrationQuery registrationQuery, 
                                                                                           org.osid.course.registration.RegistrationSearch registrationSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a registration query from an inspector. The inspector is 
     *  available from a <code> RegistrationSearchResults. </code> 
     *
     *  @param  registrationQueryInspector a registration query inspector 
     *  @return the registration query 
     *  @throws org.osid.NullArgumentException <code> 
     *          registrationQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          registrationQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.registration.RegistrationQuery getRegistrationQueryFromInspector(org.osid.assessment.ItemQueryInspector registrationQueryInspector);
}
