//
// org.osid.course.requisite.AssessmentRequirementForm
//
//     The OSID Java specification for org.osid.course.requisite.AssessmentRequirementForm.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>This is the form for creating and updating <code> 
 *  AssessmentRequirements. </code> Like all <code> OsidForm </code> objects, 
 *  various data elements may be set here for use in the create and update 
 *  methods in the <code> RequisiteAdminSession. </code> For each data element 
 *  that may be set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface AssessmentRequirementForm
    extends org.osid.OsidRuleForm,
            org.osid.OsidAggregateableForm {


    /**
     *  Gets the metadata for the timeframe. 
     *
     *  @return metadata for the timeframe 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimeframeMetadata();


    /**
     *  Sets the timeframe. 
     *
     *  @param  duration the new duration 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeframe(org.osid.calendaring.Duration duration);


    /**
     *  Clears the timeframe. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeframe();


    /**
     *  Gets the metadata for the minimum grade. 
     *
     *  @return metadata for the minimum grade 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumGradeMetadata();


    /**
     *  Sets the minimum grade. 
     *
     *  @param  gradeId the new grade 
     *  @throws org.osid.InvalidArgumentException <code> gradeId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumGrade(org.osid.id.Id gradeId);


    /**
     *  Clears the minimum grade. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumGrade();


    /**
     *  Gets the metadata for the minimum score system. 
     *
     *  @return metadata for the minimum score system 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumScoreSystemMetadata();


    /**
     *  Sets the minimum score system. 
     *
     *  @param  gradeSystemId the new grade system 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemId </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumScoreSystem(org.osid.id.Id gradeSystemId);


    /**
     *  Clears the minimum score system. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumScoreSystem();


    /**
     *  Gets the metadata for the minimum score. 
     *
     *  @return metadata for the minimum score 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumScoreMetadata();


    /**
     *  Sets the minimum score. 
     *
     *  @param  score the new minimum score 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumScore(java.math.BigDecimal score);


    /**
     *  Clears the minimum score. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumScore();


    /**
     *  Gets the <code> AssessmentRequirementFormRecord </code> corresponding 
     *  to the given assessmentl requirement record <code> Type. </code> 
     *
     *  @param  assessmentRequirementRecordType an assessment requirement 
     *          record type 
     *  @return the assessment requirement form record 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assessmentRequirementRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.records.AssessmentRequirementFormRecord getAssessmentlRequirementFormRecord(org.osid.type.Type assessmentRequirementRecordType)
        throws org.osid.OperationFailedException;
}
