//
// org.osid.course.requisite.CredentialRequirement
//
//     The OSID Java specification for org.osid.course.requisite.CredentialRequirement.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>A <code> CredentialRequirement </code> is an <code> OsidRule </code> 
 *  and represents a requirement based on a <code> Credential. </code> </p>
 */

public interface CredentialRequirement
    extends org.osid.OsidRule,
            org.osid.Aggregateable {


    /**
     *  Gets any <code> Requisites </code> that may be substituted in place of 
     *  this <code> CredentialRequirement. </code> All <code> Requisites 
     *  </code> must be satisifed to be a substitute for this credential 
     *  requirement. Inactive <code> Requisites </code> are not evaluated but 
     *  if no applicable requisite exists, then the alternate requisite is not 
     *  satisifed. 
     *
     *  @return the alternate requisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.Requisite[] getAltRequisites();


    /**
     *  Gets the <code> Id </code> of the <code> Credential. </code> 
     *
     *  @return the credential <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCredentialId();


    /**
     *  Gets the <code> Credential. </code> 
     *
     *  @return the credential 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.Credential getCredential()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the credential has to be earned within the required duration. 
     *
     *  @return <code> true </code> if the credential must be earned within a 
     *          required time, <code> false </code> if it could have been 
     *          earned at any time in the past 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasTimeframe();


    /**
     *  Gets the timeframe in which the credential has to be earned. A 
     *  negative duration indicates the credential had to be earned within the 
     *  specified amount of time in the past. A posiitive duration indicates 
     *  the credential must be earned within the specified amount of time in 
     *  the future. A zero duration indicates the credential must be earned in 
     *  the current term. 
     *
     *  @return the time frame 
     *  @throws org.osid.IllegalStateException <code> hasTimeframe() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getTimeframe();


    /**
     *  Gets the credential requirement record corresponding to the given 
     *  <code> CredentialRequirement </code> record <code> Type. </code> This 
     *  method is used to retrieve an object implementing the requested 
     *  record. The <code> credentialRequirementRecordType </code> may be the 
     *  <code> Type </code> returned in <code> getRecordTypes() </code> or any 
     *  of its parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(credentialRequirementRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  credentialRequirementRecordType the type of credential 
     *          requirement record to retrieve 
     *  @return the credential requirement record 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(credentialRequirementRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.records.CredentialRequirementRecord getCredentialRequirementRecord(org.osid.type.Type credentialRequirementRecordType)
        throws org.osid.OperationFailedException;
}
