//
// org.osid.course.requisite.LearningObjectiveRequirement
//
//     The OSID Java specification for org.osid.course.requisite.LearningObjectiveRequirement.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>A <code> LearningObjectiveRequirement </code> is an <code> OsidRule 
 *  </code> and represents a requirement based on a learning <code> Objective. 
 *  </code> </p>
 */

public interface LearningObjectiveRequirement
    extends org.osid.OsidRule,
            org.osid.Aggregateable {


    /**
     *  Gets any <code> Requisites </code> that may be substituted in place of 
     *  this <code> LearningObjectiveRequirement. </code> All <code> 
     *  Requisites </code> must be satisifed to be a substitute for this 
     *  learning objective requirement. Inactive <code> Requisites </code> are 
     *  not evaluated but if no applicable requisite exists, then the 
     *  alternate requisite is not satisifed. 
     *
     *  @return the alternate requisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.Requisite[] getAltRequisites();


    /**
     *  Gets the <code> Id </code> of the <code> LearningObjective. </code> 
     *
     *  @return the learning objective <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLearningObjectiveId();


    /**
     *  Gets the <code> LearningObjective. </code> 
     *
     *  @return the learning objective 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.Objective getLearningObjective()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a minimum grade in proficency is required for this learning 
     *  objective. 
     *
     *  @return <code> true </code> if a minimum proficiency is required, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasMinimumProficiency();


    /**
     *  Gets the minimum proficiency expressed as a <code> Grade. </code> 
     *
     *  @return the minimum proficiency 
     *  @throws org.osid.IllegalStateException <code> hasMinimumProficiency() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMinimumProficiencyId();


    /**
     *  Gets the minimum proficiency expressed as a <code> Grade. </code> 
     *
     *  @return the minimum proficiency 
     *  @throws org.osid.IllegalStateException <code> hasMinimumProficiency() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getMinimumProficiency()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the learning objective requirement record corresponding to the 
     *  given <code> LearningObjectiveRequirement </code> record <code> Type. 
     *  </code> This method is used to retrieve an object implementing the 
     *  requested record. The <code> learningObjectiveRequirementRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> 
     *  hasRecordType(learningObjectiveRequirementRecordType) </code> is 
     *  <code> true </code> . 
     *
     *  @param  learningObjectiveRequirementRecordType the type of learning 
     *          objective requirement record to retrieve 
     *  @return the learning objective requirement record 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(learningObjectiveRequirementRecordType) </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.records.LearningObjectiveRequirementRecord getLearningObjectiveRequirementRecord(org.osid.type.Type learningObjectiveRequirementRecordType)
        throws org.osid.OperationFailedException;
}
