//
// org.osid.course.requisite.RequisiteAdminSession
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteAdminSession.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>This session creates and removes requisites and their requirement 
 *  components. The data for create and update is provided via their 
 *  respective forms. </p> 
 *  
 *  <p> The view of the administrative methods defined in this session is 
 *  determined by the provider. For an instance of this session where no 
 *  course catalog has been specified, it may not be parallel to the <code> 
 *  RequisiteLookupSession. </code> For example, a default <code> 
 *  RequisiteLookupSession </code> may view the entire course catalog 
 *  hierarchy while the default <code> RequisiteAdminSession </code> uses an 
 *  isolated <code> CourseCatalog </code> to create new <code> Requisites 
 *  </code> or <code> </code> a specific course catalog to operate on a 
 *  predetermined set of <code> Requisites. </code> Another scenario is a 
 *  federated provider who does not wish to permit administrative operations 
 *  for the federation unaware. </p>
 */

public interface RequisiteAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Requisites. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Requisite </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Requisite </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRequisites();


    /**
     *  Tests if this user can create a single <code> Porgram </code> using 
     *  the desired record types. While <code> 
     *  CourseRequisiteManager.getRequisiteRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Requisite. 
     *  </code> Providing an empty array tests if a <code> Requisite </code> 
     *  can be created with no records. 
     *
     *  @param  requisiteRecordTypes array of requisite record types 
     *  @return <code> true </code> if <code> Requisite </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> requisiteRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRequisiteWithRecordTypes(org.osid.type.Type[] requisiteRecordTypes);


    /**
     *  Gets the requisite form for creating new requisites. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  requisiteRecordTypes array of requisite record types 
     *  @return the requisite form 
     *  @throws org.osid.NullArgumentException <code> requisiteRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteForm getRequisiteFormForCreate(org.osid.type.Type[] requisiteRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Requisite. </code> 
     *
     *  @param  requisiteForm the form for this <code> Requisite </code> 
     *  @return the new <code> Requisite </code> 
     *  @throws org.osid.IllegalStateException <code> requisiteForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> requisiteForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> requisiteForm </code> did 
     *          not originate from <code> getRequisiteFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.Requisite createRequisite(org.osid.course.requisite.RequisiteForm requisiteForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Requisites. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> requisite </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> requisite </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRequisites();


    /**
     *  Gets the requisite form for updating an existing requisite. A new 
     *  requisite form should be requested for each update transaction. 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> 
     *  @return the requisite form 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteForm getRequisiteFormForUpdate(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing requisite. 
     *
     *  @param  requisiteForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> requisiteForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> requisiteForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> requisiteForm </code> did 
     *          not originate from <code> getRequisiteFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRequisite(org.osid.course.requisite.RequisiteForm requisiteForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Requisites. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Requisite </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Requisite </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRequisites();


    /**
     *  Tests if this user can delete a specified <code> Requisite. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting the <code> Requisite 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer a 
     *  delete operation to an unauthorized user for this requisite. 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> 
     *  @return <code> false </code> if deletion of this <code> Requisite 
     *          </code> is not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> requisiteId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of a delete 
     *          available. 
     */

    public boolean canDeleteRequisite(org.osid.id.Id requisiteId);


    /**
     *  Deletes a <code> Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRequisite(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Requisites. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Requisite </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRequisiteAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Requisite </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Requisite </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another requisite, it is 
     *  reassigned to the given requisite <code> Id. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRequisite(org.osid.id.Id requisiteId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a <code> Requisite </code> as an option to a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  requisiteOptionId the <code> Id </code> of a <code> Requisite 
     *          </code> option 
     *  @throws org.osid.AlreadyExistsException <code> requisiteOptionId 
     *          </code> is already part of <code> requisiteId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> requisiteOptionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> requisiteOptionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addRequsiteOption(org.osid.id.Id requisiteId, 
                                  org.osid.id.Id requisiteOptionId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Requisite </code> as an option from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  requisiteOptionId the <code> Id </code> of a <code> Requisite 
     *          </code> option 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> requisiteOptionId </code> not found or <code> 
     *          requisiteOptionId </code> not part of <code> requisiteId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> requisiteOptionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeRequsiteOption(org.osid.id.Id requisiteId, 
                                     org.osid.id.Id requisiteOptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> Requisites </code> as options from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeRequsiteOptions(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> CourseRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> 
     *  CourseRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer create operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseRequirement </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCourseRequirements();


    /**
     *  Tests if this user can create a single <code> CourseRequirement 
     *  </code> using the desired record types. While <code> 
     *  CourseRequisiteManager.getCourseRequirementRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  CourseRequirement. </code> Providing an empty array tests if a <code> 
     *  CourseRequirement </code> can be created with no records. 
     *
     *  @param  courseRequirementRecordTypes array of course requirement 
     *          record types 
     *  @return <code> true </code> if <code> CourseRequirement </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseRequirementRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCourseRequirementWithRecordTypes(org.osid.type.Type[] courseRequirementRecordTypes);


    /**
     *  Gets the course requirement form for creating new course requirements. 
     *  A new form should be requested for each create transaction. 
     *
     *  @param  courseId an <code> Id </code> of a <code> Course </code> 
     *  @param  courseRequirementRecordTypes array of course requirement 
     *          record types 
     *  @return the course requirement form 
     *  @throws org.osid.NotFoundException <code> courseId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseId </code> or 
     *          <code> courseRequirementRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementForm getCourseRequirementFormForCreate(org.osid.id.Id courseId, 
                                                                                             org.osid.type.Type[] courseRequirementRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CourseRequirement. </code> 
     *
     *  @param  courseId an <code> Id </code> of a <code> Course </code> 
     *  @param  courseRequirementForm the form for this <code> 
     *          CourseRequirement </code> 
     *  @return the new <code> CourseRequirement </code> 
     *  @throws org.osid.AlreadyExistsException attempt at duplicating a 
     *          property the underlying system is enforcing to be unique 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> courseId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> courseId </code> or 
     *          <code> courseRequirementForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> courseRequirementForm 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirement createCourseRequirement(org.osid.id.Id courseId, 
                                                                               org.osid.course.requisite.CourseRequirementForm courseRequirementForm)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> CourseRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> 
     *  CourseRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer update operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseRequirement </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCourseRequirements();


    /**
     *  Tests if this user can update a specified <code> CourseRequirement. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known updating the <code> 
     *  CourseRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer an update operation to an unauthorized user for this <code> 
     *  CourseRequirement. </code> 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> 
     *  @return <code> false </code> if course requirement modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> courseRequirementId </code> is not found, then 
     *          it is acceptable to return false to indicate the lack of an 
     *          update available. 
     */

    public boolean canUpdateCourseRequirement(org.osid.id.Id courseRequirementId);


    /**
     *  Gets the course requirement form for updating an existing course 
     *  requirement. A new requisite form should be requested for each update 
     *  transaction. 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> 
     *  @return the course requirement form 
     *  @throws org.osid.NotFoundException <code> courseRequirementId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementForm getCourseRequirementFormForUpdate(org.osid.id.Id courseRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing course requirement. 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> 
     *  @param  courseRequirementForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> courseRequirementId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> or <code> courseRequirementForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> courseRequirementForm 
     *          </code> is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCourseRequirement(org.osid.id.Id courseRequirementId, 
                                        org.osid.course.requisite.CourseRequirementForm courseRequirementForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> CourseRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> 
     *  CourseRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer delete operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseRequirement </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCourseRequirements();


    /**
     *  Tests if this user can delete a specified <code> CourseRequirement. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known deleting the <code> 
     *  CourseRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer a delete operation to an unauthorized user for this course 
     *  requirement. 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          CourseRequirement </code> is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> courseRequirementId, </code> is not found, then 
     *          it is acceptable to return false to indicate the lack of a 
     *          delete available. 
     */

    public boolean canDeleteCourseRequirement(org.osid.id.Id courseRequirementId);


    /**
     *  Deletes a <code> CourseRequirement. </code> 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> to remove 
     *  @throws org.osid.NotFoundException <code> courseRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCourseRequirement(org.osid.id.Id courseRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> CourseRequirements </code> in this <code> 
     *  CourseCatalog. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCourseRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  CourseRequirements. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CourseRequirement </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCourseRequirementAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CourseRequirement </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> CourseRequirement </code> is determined by the provider. 
     *  The new <code> Id </code> performs as an alias to the primary <code> 
     *  Id. </code> If the alias is a pointer to another course requirement, 
     *  it is reassigned to the given course requirement <code> Id. </code> 
     *
     *  @param  courseRequirementId the <code> Id </code> of a <code> 
     *          CourseRequirement </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> courseRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCourseRequirement(org.osid.id.Id courseRequirementId, 
                                       org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a <code> CourseRequirement </code> to a <code> Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  courseRequirementId the <code> Id </code> of a <code> 
     *          CourseRequirement </code> 
     *  @throws org.osid.AlreadyExistsException <code> courseRequirementId 
     *          </code> is already part of <code> requisiteId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> courseRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> courseRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addCourseRequirement(org.osid.id.Id requisiteId, 
                                     org.osid.id.Id courseRequirementId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CourseRequirement </code> from a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  courseRequirementId the <code> Id </code> of a <code> 
     *          CourseRequirement </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> courseRequirementId </code> not found or <code> 
     *          courseRequirementId </code> not part of <code> requisiteId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> courseRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeCourseRequirement(org.osid.id.Id requisiteId, 
                                        org.osid.id.Id courseRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> CourseRequirements </code> from a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeCourseRequirements(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an alternative <code> Requisite </code> to a <code> 
     *  CourseRequirement. </code> 
     *
     *  @param  courseRequirementId the <code> Id </code> of a <code> 
     *          CourseRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> requisiteId </code> is 
     *          already part of <code> courseRequirementId </code> 
     *  @throws org.osid.NotFoundException <code> courseRequirementId </code> 
     *          or <code> requisiteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAltRequisiteToCourseRequirement(org.osid.id.Id courseRequirementId, 
                                                   org.osid.id.Id requisiteId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an alternative <code> Requisite </code> from a <code> 
     *  CourseRequirement. </code> 
     *
     *  @param  courseRequirementId the <code> Id </code> of a <code> 
     *          CourseRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> courseRequirementId </code> 
     *          or <code> requisiteId </code> not found or <code> requisiteId 
     *          </code> not part of <code> courseRequirementId </code> 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisiteFromCourseRequirement(org.osid.id.Id courseRequirementId, 
                                                        org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> Requisites </code> from a <code> CourseRequirement. 
     *  </code> 
     *
     *  @param  courseRequirementId the <code> Id </code> of a <code> 
     *          CourseRequirement </code> 
     *  @throws org.osid.NotFoundException <code> courseRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisitesFromCourseRequirement(org.osid.id.Id courseRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ProgramRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> 
     *  ProgramRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer create operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramRequirement </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProgramRequirements();


    /**
     *  Tests if this user can create a single <code> ProgramRequirement 
     *  </code> using the desired record types. While <code> 
     *  CourseRequisiteManager.getProgramRequirementRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  ProgramRequirement. </code> Providing an empty array tests if a <code> 
     *  ProgramRequirement </code> can be created with no records. 
     *
     *  @param  programRequirementRecordTypes array of program requirement 
     *          record types 
     *  @return <code> true </code> if <code> ProgramRequirement </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          programRequirementRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProgramRequirementWithRecordTypes(org.osid.type.Type[] programRequirementRecordTypes);


    /**
     *  Gets the program requirement form for creating new program 
     *  requirements. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  programId an <code> Id </code> of a program 
     *  @param  programRequirementRecordTypes array of program requirement 
     *          record types 
     *  @return the program requirement form 
     *  @throws org.osid.NotFoundException <code> programId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> 
     *          programRequirementRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementForm getProgramRequirementFormForCreate(org.osid.id.Id programId, 
                                                                                               org.osid.type.Type[] programRequirementRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ProgramRequirement. </code> 
     *
     *  @param  programId an <code> Id </code> of a program 
     *  @param  programRequirementForm the form for this <code> 
     *          ProgramRequirement </code> 
     *  @return the new <code> ProgramRequirement </code> 
     *  @throws org.osid.AlreadyExistsException attempt at duplicating a 
     *          property the underlying system is enforcing to be unique 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> programId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> programId </code> or 
     *          <code> programRequirementForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> programRequirementForm 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirement createProgramRequirement(org.osid.id.Id programId, 
                                                                                 org.osid.course.requisite.ProgramRequirementForm programRequirementForm)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ProgramRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> 
     *  ProgramRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer update operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramRequirement </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProgramRequirements();


    /**
     *  Tests if this user can update a specified <code> ProgramRequirement. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known updating the <code> 
     *  ProgramRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer an update operation to an unauthorized user for this <code> 
     *  ProgramRequirement. </code> 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> 
     *  @return <code> false </code> if program requirement modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> programRequirementId </code> is not found, then 
     *          it is acceptable to return false to indicate the lack of an 
     *          update available. 
     */

    public boolean canUpdateProgramRequirement(org.osid.id.Id programRequirementId);


    /**
     *  Gets the program requirement form for updating an existing program 
     *  requirement. A new requisite form should be requested for each update 
     *  transaction. 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> 
     *  @return the program requirement form 
     *  @throws org.osid.NotFoundException <code> programRequirementId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementForm getProgramRequirementFormForUpdate(org.osid.id.Id programRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing program requirement. 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> 
     *  @param  programRequirementForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> programRequirementId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> or <code> programRequirementForm </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> programRequirementForm 
     *          </code> is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProgramRequirement(org.osid.id.Id programRequirementId, 
                                         org.osid.course.requisite.ProgramRequirementForm programRequirementForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ProgramRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> 
     *  ProgramRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer delete operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramRequirement </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProgramRequirements();


    /**
     *  Tests if this user can delete a specified <code> ProgramRequirement. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known deleting the <code> 
     *  ProgramRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer a delete operation to an unauthorized user for this program 
     *  requirement. 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          ProgramRequirement </code> is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> programRequirementId, </code> is not found, then 
     *          it is acceptable to return false to indicate the lack of a 
     *          delete available. 
     */

    public boolean canDeleteProgramRequirement(org.osid.id.Id programRequirementId);


    /**
     *  Deletes a <code> ProgramRequirement. </code> 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> to remove 
     *  @throws org.osid.NotFoundException <code> programRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProgramRequirement(org.osid.id.Id programRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> ProgramRequirements </code> in this <code> 
     *  CourseCatalog. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProgramRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ProgramRequirements. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProgramRequirement </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageProgramRequirementAliases();


    /**
     *  Adds an <code> Id </code> to a <code> ProgramRequirement </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> ProgramRequirement </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id. </code> If the alias is a pointer to another 
     *  program requirement, it is reassigned to the given program requirement 
     *  <code> Id. </code> 
     *
     *  @param  programRequirementId the <code> Id </code> of a <code> 
     *          ProgramRequirement </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> programRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasProgramRequirement(org.osid.id.Id programRequirementId, 
                                        org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a <code> ProgramRequirement </code> to a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  programRequirementId the <code> Id </code> of a <code> 
     *          ProgramRequirement </code> 
     *  @throws org.osid.AlreadyExistsException <code> programRequirementId 
     *          </code> is already part of <code> requisiteId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> programRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> programRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addProgramRequirement(org.osid.id.Id requisiteId, 
                                      org.osid.id.Id programRequirementId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ProgramRequirement </code> from a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  programRequirementId the <code> Id </code> of a <code> 
     *          ProgramRequirement </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> programRequirementId </code> not found or <code> 
     *          programRequirementId </code> not part of <code> requisiteId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> programRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeProgramRequirement(org.osid.id.Id requisiteId, 
                                         org.osid.id.Id programRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> ProgramRequirements </code> from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeProgramRequirements(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an alternative <code> Requisite </code> to a <code> 
     *  ProgramRequirement. </code> 
     *
     *  @param  programRequirementId the <code> Id </code> of a <code> 
     *          ProgramRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> requisiteId </code> is 
     *          already part of <code> programRequirementId </code> 
     *  @throws org.osid.NotFoundException <code> programRequirementId </code> 
     *          or <code> requisiteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAltRequisiteToProgramRequirement(org.osid.id.Id programRequirementId, 
                                                    org.osid.id.Id requisiteId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an alternative <code> Requisite </code> from a <code> 
     *  ProgramRequirement. </code> 
     *
     *  @param  programRequirementId the <code> Id </code> of a <code> 
     *          ProgramRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> programRequirementId </code> 
     *          or <code> requisiteId </code> not found or <code> requisiteId 
     *          </code> not part of <code> programRequirementId </code> 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisiteFromProgramRequirement(org.osid.id.Id programRequirementId, 
                                                         org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> Requisites </code> from a <code> 
     *  ProgramRequirement. </code> 
     *
     *  @param  programRequirementId the <code> Id </code> of a <code> 
     *          ProgramRequirement </code> 
     *  @throws org.osid.NotFoundException <code> programRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisitesFromProgramRequirement(org.osid.id.Id programRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> CredentialRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> 
     *  CredentialRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialRequirement </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCredentialRequirements();


    /**
     *  Tests if this user can create a single <code> CredentialRequirement 
     *  </code> using the desired record types. While <code> 
     *  CourseRequisiteManager.getCredentialRequirementRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  CredentialRequirement. </code> Providing an empty array tests if a 
     *  <code> CredentialRequirement </code> can be created with no records. 
     *
     *  @param  credentialRequirementRecordTypes array of credential 
     *          requirement record types 
     *  @return <code> true </code> if <code> CredentialRequirement </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialRequirementRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCredentiaRequirementWithRecordTypes(org.osid.type.Type[] credentialRequirementRecordTypes);


    /**
     *  Gets the credential requirement form for creating new credential 
     *  requirements. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  credentialId a credential <code> Id </code> 
     *  @param  credentialRequirementRecordTypes array of credential 
     *          requirement record types 
     *  @return the credential requirement form 
     *  @throws org.osid.NotFoundException <code> credentialId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> or 
     *          <code> credentialRequirementRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementForm getCredentialRequirementFormForCreate(org.osid.id.Id credentialId, 
                                                                                                     org.osid.type.Type[] credentialRequirementRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CredentialRequirement. </code> 
     *
     *  @param  credentialId a credential <code> Id </code> 
     *  @param  credentialRequirementForm the form for this <code> 
     *          CredentialRequirement </code> 
     *  @return the new <code> CredentialRequirement </code> 
     *  @throws org.osid.AlreadyExistsException attempt at duplicating a 
     *          property the underlying system is enforcing to be unique 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> credentialId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> or 
     *          <code> credentialRequirementForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> credentialRequirementForm 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirement createCredentialRequirement(org.osid.id.Id credentialId, 
                                                                                       org.osid.course.requisite.CredentialRequirementForm credentialRequirementForm)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> CredentialRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> 
     *  CredentialRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialRequirement </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCredentialRequirements();


    /**
     *  Tests if this user can update a specified <code> 
     *  CredentialRequirement. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  updating the <code> CredentialRequirement </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer an update operation to an 
     *  unauthorized user for this <code> CredentialRequirement. </code> 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> 
     *  @return <code> false </code> if credential requirement modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> credentialRequirementId </code> is not found, 
     *          then it is acceptable to return false to indicate the lack of 
     *          an update available. 
     */

    public boolean canUpdateCredentialRequirement(org.osid.id.Id credentialRequirementId);


    /**
     *  Gets the credential requirement form for updating an existing 
     *  credential requirement. A new requisite form should be requested for 
     *  each update transaction. 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> 
     *  @return the credential requirement form 
     *  @throws org.osid.NotFoundException <code> credentialRequirementId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementForm getCredentialRequirementFormForUpdate(org.osid.id.Id credentialRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing credential requirement. 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> 
     *  @param  credentialRequirementForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> credentialRequirementId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> or <code> credentialRequirementForm </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> credentialRequirementForm 
     *          </code> is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCredentialRequirement(org.osid.id.Id credentialRequirementId, 
                                            org.osid.course.requisite.CredentialRequirementForm credentialRequirementForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> CredentialRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> 
     *  CredentialRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialRequirement </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCredentialRequirements();


    /**
     *  Tests if this user can delete a specified <code> 
     *  CredentialRequirement. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  deleting the <code> CredentialRequirement </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer a delete operation to an 
     *  unauthorized user for this credential requirement. 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          CredentialRequirement </code> is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> credentialRequirementId, </code> is not found, 
     *          then it is acceptable to return false to indicate the lack of 
     *          a delete available. 
     */

    public boolean canDeleteCredentialRequirement(org.osid.id.Id credentialRequirementId);


    /**
     *  Deletes a <code> CredentialRequirement. </code> 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> to remove 
     *  @throws org.osid.NotFoundException <code> credentialRequirementId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCredentialRequirement(org.osid.id.Id credentialRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> CredentialRequirements </code> in this <code> 
     *  CourseCatalog. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCredentialRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  CredentialRequirements. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CredentialRequirement </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCredentialRequirementAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CredentialRequirement </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> CredentialRequirement </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id. </code> If the alias is a pointer to another 
     *  credential requirement, it is reassigned to the given credential 
     *  requirement <code> Id. </code> 
     *
     *  @param  credentialRequirementId the <code> Id </code> of a <code> 
     *          CredentialRequirement </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> credentialRequirementId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCredentialRequirement(org.osid.id.Id credentialRequirementId, 
                                           org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a <code> CredentialRequirement </code> to a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  credentialRequirementId the <code> Id </code> of a <code> 
     *          CredentialRequirement </code> 
     *  @throws org.osid.AlreadyExistsException <code> credentialRequirementId 
     *          </code> is already part of <code> requisiteId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> credentialRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> credentialRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addCredentialRequirement(org.osid.id.Id requisiteId, 
                                         org.osid.id.Id credentialRequirementId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CredentialRequirement </code> from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  credentialRequirementId the <code> Id </code> of a <code> 
     *          CredentialRequirement </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> credentialRequirementId </code> not found or <code> 
     *          credentialRequirementId </code> not part of <code> requisiteId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> credentialRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeCredentialRequirement(org.osid.id.Id requisiteId, 
                                            org.osid.id.Id credentialRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> CredentialRequirements </code> from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeCredentialRequirements(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an alternative <code> Requisite </code> to a <code> 
     *  CredentialRequirement. </code> 
     *
     *  @param  credentialRequirementId the <code> Id </code> of a <code> 
     *          CredentialRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> requisiteId </code> is 
     *          already part of <code> credentialRequirementId </code> 
     *  @throws org.osid.NotFoundException <code> credentialRequirementId 
     *          </code> or <code> requisiteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAltRequisiteToCredentialRequirement(org.osid.id.Id credentialRequirementId, 
                                                       org.osid.id.Id requisiteId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an alternative <code> Requisite </code> from a <code> 
     *  CredentialRequirement. </code> 
     *
     *  @param  credentialRequirementId the <code> Id </code> of a <code> 
     *          CredentialRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> credentialRequirementId 
     *          </code> or <code> requisiteId </code> not found or <code> 
     *          requisiteId </code> not part of <code> credentialRequirementId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisiteFromCredentialRequirement(org.osid.id.Id credentialRequirementId, 
                                                            org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> Requisites </code> from a <code> 
     *  CredentialRequirement. </code> 
     *
     *  @param  credentialRequirementId the <code> Id </code> of a <code> 
     *          CredentialRequirement </code> 
     *  @throws org.osid.NotFoundException <code> credentialRequirementId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisitesFromCredentialRequirement(org.osid.id.Id credentialRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> LearningObjectiveRequirements. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known creating a <code> 
     *  LearningObjectiveRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> LearningObjectiveRequirement 
     *          </code> creation is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateLearningObjectiveRequirements();


    /**
     *  Tests if this user can create a single <code> 
     *  LearningObjectiveRequirement </code> using the desired record types. 
     *  While <code> 
     *  CourseRequisiteManager.getLearningObjectiveRequirementRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> LearningObjectiveRequirement. </code> Providing an empty array 
     *  tests if a <code> LearningObjectiveRequirement </code> can be created 
     *  with no records. 
     *
     *  @param  learningObjectiveRequirementRecordTypes array of learning 
     *          objective requirement record types 
     *  @return <code> true </code> if <code> LearningObjectiveRequirement 
     *          </code> creation using the specified record <code> Types 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateLearningObjectiveRequirementWithRecordTypes(org.osid.type.Type[] learningObjectiveRequirementRecordTypes);


    /**
     *  Gets the learning objective requirement form for creating new learning 
     *  objective requirements. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  objectiveId a learning objective <code> Id </code> 
     *  @param  learningObjectiveRequirementForm array of learning objective 
     *          requirement record types 
     *  @return the learning objective requirement form 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> learningObjectiveRequirementRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementForm getLearningObjectiveRequirementFormForCreate(org.osid.id.Id objectiveId, 
                                                                                                                   org.osid.type.Type[] learningObjectiveRequirementForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> LearningObjectiveRequirement. </code> 
     *
     *  @param  objectiveId a learning objective <code> Id </code> 
     *  @param  learningObjectiveRequirementForm the form for this <code> 
     *          LearningObjectiveRequirement </code> 
     *  @return the new <code> LearningObjectiveRequirement </code> 
     *  @throws org.osid.AlreadyExistsException attempt at duplicating a 
     *          property the underlying system is enforcing to be unique 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> learningObjectiveRequirementForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          learningObjectiveRequirementForm </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirement createLearningObjectiveRequirement(org.osid.id.Id objectiveId, 
                                                                                                     org.osid.course.requisite.LearningObjectiveRequirementForm learningObjectiveRequirementForm)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> LearningObjectiveRequirements. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known updating a <code> 
     *  LearningObjectiveRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> LearningObjectiveRequirement 
     *          </code> modification is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateLearningObjectiveRequirements();


    /**
     *  Tests if this user can update a specified <code> 
     *  LearningObjectiveRequirement. </code> A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating the <code> LearningObjectiveRequirement </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer an update operation 
     *  to an unauthorized user for this <code> LearningObjectiveRequirement. 
     *  </code> 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> 
     *  @return <code> false </code> if learning objective requirement 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> learningObjectiveRequirementRequirementId 
     *          </code> is not found, then it is acceptable to return false to 
     *          indicate the lack of an update available. 
     */

    public boolean canUpdateLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId);


    /**
     *  Gets the learning objective requirement form for updating an existing 
     *  learning objective requirement. A new requisite form should be 
     *  requested for each update transaction. 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> 
     *  @return the learning objective requirement form 
     *  @throws org.osid.NotFoundException <code> 
     *          learningObjectiveRequirementId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementForm getLearningObjectiveRequirementFormForUpdate(org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing learning objective requirement. 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> 
     *  @param  learningObjectiveRequirementForm the form containing the 
     *          elements to be updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> 
     *          learningObjectiveRequirementId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> or <code> 
     *          learningObjectiveRequirementForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          learningObjectiveRequirementForm </code> is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId, 
                                                   org.osid.course.requisite.LearningObjectiveRequirementForm learningObjectiveRequirementForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> LearningObjectiveRequirements. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known deleting a <code> 
     *  LearningObjectiveRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> LearningObjectiveRequirement 
     *          </code> deletion is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteLearningObjectiveRequirements();


    /**
     *  Tests if this user can delete a specified <code> 
     *  LearningObjectiveRequirement. </code> A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting the <code> LearningObjectiveRequirement </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer a delete operation 
     *  to an unauthorized user for this learning objective requirement. 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          LearningObjectiveRequirement </code> is not authorized, <code> 
     *          true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> learningObjectiveRequirementId, </code> is not 
     *          found, then it is acceptable to return false to indicate the 
     *          lack of a delete available. 
     */

    public boolean canDeleteLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId);


    /**
     *  Deletes a <code> LearningObjectiveRequirement. </code> 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> to remove 
     *  @throws org.osid.NotFoundException <code> 
     *          learningObjectiveRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> LearningObjectiveRequirements </code> in this 
     *  <code> CourseCatalog. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteLearningObjectiveRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  LearningObjectiveRequirements. </code> A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known changing an alias will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> LearningObjectiveRequirement 
     *          </code> aliasing is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageLearningObjectiveRequirementAliases();


    /**
     *  Adds an <code> Id </code> to a <code> LearningObjectiveRequirement 
     *  </code> for the purpose of creating compatibility. The primary <code> 
     *  Id </code> of the <code> LearningObjectiveRequirement </code> is 
     *  determined by the provider. The new <code> Id </code> performs as an 
     *  alias to the primary <code> Id. </code> If the alias is a pointer to 
     *  another credential requirement, it is reassigned to the given learning 
     *  objective requirement <code> Id. </code> 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of a 
     *          <code> LearningObjectiveRequirement </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          learningObjectiveRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> or <code> aliasId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId, 
                                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a <code> LearningObjectiveRequirement </code> to a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  learningObjectiveRequirementId the <code> Id </code> of a 
     *          <code> LearningObjectiveRequirement </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          learningObjectiveRequirementId </code> is already part of 
     *          <code> requisiteId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> learningObjectiveRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> learningObjectiveRequirementId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addLearningObjectiveRequirement(org.osid.id.Id requisiteId, 
                                                org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> LearningObjectiveRequirement </code> from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  learningObjectiveRequirementId the <code> Id </code> of a 
     *          <code> LearningObjectiveRequirement </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> learningObjectiveRequirementId </code> not found or 
     *          <code> learningObjectiveRequirementId </code> not part of 
     *          <code> requisiteId </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> credentialRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeLearningObjectiveRequirement(org.osid.id.Id requisiteId, 
                                                   org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> LearningObjectiveRequirements </code> from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeLearningObjectiveRequirements(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an alternative <code> Requisite </code> to a <code> 
     *  LearningObjectiveRequirement. </code> 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of a 
     *          <code> LearningObjectiveRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> requisiteId </code> is 
     *          already part of <code> learningObjectiveRequirementId </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          learningObjectiveRequirementId </code> or <code> requisiteId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> or <code> requisiteId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAltRequisiteToLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId, 
                                                              org.osid.id.Id requisiteId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an alternative <code> Requisite </code> from a <code> 
     *  LearningObjectiveRequirement. </code> 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of a 
     *          <code> LearningObjectiveRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          learningObjectiveRequirementId </code> or <code> requisiteId 
     *          </code> not found or <code> requisiteId </code> not part of 
     *          <code> learningObjectiveRequirementId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> or <code> requisiteId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisiteFromLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId, 
                                                                   org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> Requisites </code> from a <code> 
     *  LearningObjectiveRequirement. </code> 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of a 
     *          <code> LearningObjectiveRequirement </code> 
     *  @throws org.osid.NotFoundException <code> 
     *          learningObjectiveRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisitesFromLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> AssessmentRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating an <code> 
     *  AssessmentRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentRequirement </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentRequirements();


    /**
     *  Tests if this user can create a single <code> AssessmentRequirement 
     *  </code> using the desired record types. While <code> 
     *  CourseRequisiteManager.getAssessmentRequirementRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  AssessmentRequirement. </code> Providing an empty array tests if an 
     *  <code> AssessmentRequirement </code> can be created with no records. 
     *
     *  @param  assessmentRequirementRecordTypes array of assessment 
     *          requirement record types 
     *  @return <code> true </code> if <code> AssessmentRequirement </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentRequirementRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAssessmentRequirementWithRecordTypes(org.osid.type.Type[] assessmentRequirementRecordTypes);


    /**
     *  Gets the assessment requirement form for creating new credential 
     *  requirements. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  assessmentId a assessment <code> Id </code> 
     *  @param  assessmentRequirementRecordTypes array of assessment 
     *          requirement record types 
     *  @return the assessment requirement form 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> or 
     *          <code> assessmentRequirementRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementForm getAssessmentRequirementFormForCreate(org.osid.id.Id assessmentId, 
                                                                                                     org.osid.type.Type[] assessmentRequirementRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AssessmentRequirement. </code> 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  assessmentRequirementForm the form for this <code> 
     *          AssessmentRequirement </code> 
     *  @return the new <code> AssessmentRequirement </code> 
     *  @throws org.osid.AlreadyExistsException attempt at duplicating a 
     *          property the underlying system is enforcing to be unique 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> assessmentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assessmentid </code> or 
     *          <code> assessmentRequirementForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assessmentRequirementForm 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirement createAssessmentRequirement(org.osid.id.Id assessmentId, 
                                                                                       org.osid.course.requisite.AssessmentRequirementForm assessmentRequirementForm)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AssessmentRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating an <code> 
     *  AssessmentRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentRequirement </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAssessmentRequirements();


    /**
     *  Tests if this user can update a specified <code> 
     *  AssessmentRequirement. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  updating the <code> AssessmentRequirement </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer an update operation to an 
     *  unauthorized user for this <code> AssessmentRequirement. </code> 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> 
     *  @return <code> false </code> if assessment requirement modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> assessmentRequirementId </code> is not found, 
     *          then it is acceptable to return false to indicate the lack of 
     *          an update available. 
     */

    public boolean canUpdateAssessmentRequirement(org.osid.id.Id assessmentRequirementId);


    /**
     *  Gets the assessment requirement form for updating an existing 
     *  credential requirement. A new requisite form should be requested for 
     *  each update transaction. 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> 
     *  @return the assessment requirement form 
     *  @throws org.osid.NotFoundException <code> assessmentRequirementId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementForm getAssessmentRequirementFormForUpdate(org.osid.id.Id assessmentRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing assessment requirement. 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> 
     *  @param  assessmentRequirementForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> assessmentRequirementId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> or <code> assessmentRequirementForm </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> assessmentRequirementForm 
     *          </code> is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAssessmentRequirement(org.osid.id.Id assessmentRequirementId, 
                                            org.osid.course.requisite.AssessmentRequirementForm assessmentRequirementForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AssessmentRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting an <code> 
     *  AssessmentRequirement </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentRequirement </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAssessmentRequirements();


    /**
     *  Tests if this user can delete a specified <code> 
     *  AssessmentRequirement. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  deleting the <code> AssessmentRequirement </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer a delete operation to an 
     *  unauthorized user for this assessment requirement. 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          AssessmentRequirement </code> is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> assessmentRequirementId, </code> is not found, 
     *          then it is acceptable to return false to indicate the lack of 
     *          a delete available. 
     */

    public boolean canDeleteAssessmentRequirement(org.osid.id.Id assessmentRequirementId);


    /**
     *  Deletes an <code> AssessmentRequirement. </code> 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> to remove 
     *  @throws org.osid.NotFoundException <code> assessmentRequirementId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAssessmentRequirement(org.osid.id.Id assessmentRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> AssessmentRequirements </code> in this <code> 
     *  CourseCatalog. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAssessmentRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  AssessmentRequirements. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AssessmentRequirement </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAssessmentRequirementAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AssessmentRequirement </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> AssessmentRequirement </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id. </code> If the alias is a pointer to another 
     *  assessment requirement, it is reassigned to the given assessment 
     *  requirement <code> Id. </code> 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of an <code> 
     *          AssessmentRequirement </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> assessmentRequirementId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAssessmentRequirement(org.osid.id.Id assessmentRequirementId, 
                                           org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> AssessmentRequirement </code> to a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  assessmentRequirementId the <code> Id </code> of an <code> 
     *          AssessmentRequirement </code> 
     *  @throws org.osid.AlreadyExistsException <code> assessmentRequirementId 
     *          </code> is already part of <code> requisiteId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> assessmentRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> assessmentRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAssessmentRequirement(org.osid.id.Id requisiteId, 
                                         org.osid.id.Id assessmentRequirementId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes anAssessment <code> Requirement </code> from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  assessmentRequirementId the <code> Id </code> of an <code> 
     *          AssessmentRequirement </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> assessmentRequirementId </code> not found or <code> 
     *          assessmentRequirementId </code> not part of <code> requisiteId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> assessmentRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAssessmentRequirement(org.osid.id.Id requisiteId, 
                                            org.osid.id.Id assessmentRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> AssessmentRequirements </code> from a <code> 
     *  Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAssessmentRequirements(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an alternative <code> Requisite </code> to an <code> 
     *  AssessmentRequirement. </code> 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of an <code> 
     *          AssessmentRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> requisiteId </code> is 
     *          already part of <code> assessmentRequirementId </code> 
     *  @throws org.osid.NotFoundException <code> assessmentRequirementId 
     *          </code> or <code> requisiteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAltRequisiteToAssessmentRequirement(org.osid.id.Id assessmentRequirementId, 
                                                       org.osid.id.Id requisiteId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an alternative <code> Requisite </code> from an <code> 
     *  AssessmentRequirement. </code> 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of an <code> 
     *          AssessmentRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> assessmentRequirementId 
     *          </code> or <code> requisiteId </code> not found or <code> 
     *          requisiteId </code> not part of <code> assessmentRequirementId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisiteFromAssessmentRequirement(org.osid.id.Id assessmentRequirementId, 
                                                            org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> Requisites </code> from an <code> 
     *  AssessmentRequirement. </code> 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of an <code> 
     *          AssessmentRequirement </code> 
     *  @throws org.osid.NotFoundException <code> assessmentRequirementId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisitesFromAssessmentRequirement(org.osid.id.Id assessmentRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> AwardRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating an <code> 
     *  AwardRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer create operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AwardRequirement </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAwardRequirements();


    /**
     *  Tests if this user can create a single <code> AwardRequirement </code> 
     *  using the desired record types. While <code> 
     *  CourseRequisiteManager.getAwardRequirementRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  AwardRequirement. </code> Providing an empty array tests if an <code> 
     *  AwardRequirement </code> can be created with no records. 
     *
     *  @param  awardRequirementRecordTypes array of award requirement record 
     *          types 
     *  @return <code> true </code> if <code> AwardRequirement </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          awardRequirementRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAwardRequirementWithRecordTypes(org.osid.type.Type[] awardRequirementRecordTypes);


    /**
     *  Gets the award requirement form for creating new credential 
     *  requirements. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  awardId a award <code> Id </code> 
     *  @param  awardRequirementRecordTypes array of award requirement record 
     *          types 
     *  @return the award requirement form 
     *  @throws org.osid.NotFoundException <code> awardId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> awardId </code> or 
     *          <code> awardRequirementRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementForm getAwardRequirementFormForCreate(org.osid.id.Id awardId, 
                                                                                           org.osid.type.Type[] awardRequirementRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> AwardRequirement. </code> 
     *
     *  @param  awardId an award <code> Id </code> 
     *  @param  awardRequirementForm the form for this <code> AwardRequirement 
     *          </code> 
     *  @return the new <code> AwardRequirement </code> 
     *  @throws org.osid.AlreadyExistsException attempt at duplicating a 
     *          property the underlying system is enforcing to be unique 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> awardId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> awardid </code> or 
     *          <code> awardRequirementForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> awardRequirementForm 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirement createAwardRequirement(org.osid.id.Id awardId, 
                                                                             org.osid.course.requisite.AwardRequirementForm awardRequirementForm)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> AwardRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating an <code> 
     *  AwardRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer update operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AwardRequirement </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAwardRequirements();


    /**
     *  Tests if this user can update a specified <code> AwardRequirement. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known updating the <code> 
     *  AwardRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer an update operation to an unauthorized user for this <code> 
     *  AwardRequirement. </code> 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> 
     *  @return <code> false </code> if award requirement modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> awardRequirementId </code> is not found, then it 
     *          is acceptable to return false to indicate the lack of an 
     *          update available. 
     */

    public boolean canUpdateAwardRequirement(org.osid.id.Id awardRequirementId);


    /**
     *  Gets the award requirement form for updating an existing credential 
     *  requirement. A new requisite form should be requested for each update 
     *  transaction. 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> 
     *  @return the award requirement form 
     *  @throws org.osid.NotFoundException <code> awardRequirementId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementForm getAwardRequirementFormForUpdate(org.osid.id.Id awardRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing award requirement. 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> 
     *  @param  awardRequirementForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> awardRequirementId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> or <code> awardRequirementForm </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> awardRequirementForm 
     *          </code> is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAwardRequirement(org.osid.id.Id awardRequirementId, 
                                       org.osid.course.requisite.AwardRequirementForm awardRequirementForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> AwardRequirements. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting an <code> 
     *  AwardRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer delete operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AwardRequirement </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAwardRequirements();


    /**
     *  Tests if this user can delete a specified <code> AwardRequirement. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known deleting the <code> 
     *  AwardRequirement </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer a delete operation to an unauthorized user for this award 
     *  requirement. 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          AwardRequirement </code> is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> awardRequirementId, </code> is not found, then 
     *          it is acceptable to return false to indicate the lack of a 
     *          delete available. 
     */

    public boolean canDeleteAwardRequirement(org.osid.id.Id awardRequirementId);


    /**
     *  Deletes an <code> AwardRequirement. </code> 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> to remove 
     *  @throws org.osid.NotFoundException <code> awardRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAwardRequirement(org.osid.id.Id awardRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> AwardRequirements </code> in this <code> 
     *  CourseCatalog. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAwardRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  AwardRequirements. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> AwardRequirement </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAwardRequirementAliases();


    /**
     *  Adds an <code> Id </code> to an <code> AwardRequirement </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> AwardRequirement </code> is determined by the provider. 
     *  The new <code> Id </code> performs as an alias to the primary <code> 
     *  Id. </code> If the alias is a pointer to another award requirement, it 
     *  is reassigned to the given award requirement <code> Id. </code> 
     *
     *  @param  awardRequirementId the <code> Id </code> of an <code> 
     *          AwardRequirement </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> awardRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAwardRequirement(org.osid.id.Id awardRequirementId, 
                                      org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> AwardRequirement </code> to a <code> Requisite. </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  awardRequirementId the <code> Id </code> of an <code> 
     *          AwardRequirement </code> 
     *  @throws org.osid.AlreadyExistsException <code> awardRequirementId 
     *          </code> is already part of <code> requisiteId </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> awardRequirementId </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> awardRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAwardRequirement(org.osid.id.Id requisiteId, 
                                    org.osid.id.Id awardRequirementId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes anAward <code> Requirement </code> from a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @param  awardRequirementId the <code> Id </code> of an <code> 
     *          AwardRequirement </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> or 
     *          <code> awardRequirementId </code> not found or <code> 
     *          awardRequirementId </code> not part of <code> requisiteId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> or 
     *          <code> awardRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAwardRequirement(org.osid.id.Id requisiteId, 
                                       org.osid.id.Id awardRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> AwardRequirements </code> from a <code> Requisite. 
     *  </code> 
     *
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> requisiteId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAwardRequirements(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an alternative <code> Requisite </code> to an <code> 
     *  AwardRequirement. </code> 
     *
     *  @param  awardRequirementId the <code> Id </code> of an <code> 
     *          AwardRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> requisiteId </code> is 
     *          already part of <code> awardRequirementId </code> 
     *  @throws org.osid.NotFoundException <code> awardRequirementId </code> 
     *          or <code> requisiteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAltRequisiteToAwardRequirement(org.osid.id.Id awardRequirementId, 
                                                  org.osid.id.Id requisiteId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an alternative <code> Requisite </code> from an <code> 
     *  AwardRequirement. </code> 
     *
     *  @param  awardRequirementId the <code> Id </code> of an <code> 
     *          AwardRequirement </code> 
     *  @param  requisiteId the <code> Id </code> of a <code> Requisite 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> awardRequirementId </code> 
     *          or <code> requisiteId </code> not found or <code> requisiteId 
     *          </code> not part of <code> awardRequirementId </code> 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> or <code> requisiteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisiteFromAwardRequirement(org.osid.id.Id awardRequirementId, 
                                                       org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all <code> Requisites </code> from an <code> AwardRequirement. 
     *  </code> 
     *
     *  @param  awardRequirementId the <code> Id </code> of an <code> 
     *          AwardRequirement </code> 
     *  @throws org.osid.NotFoundException <code> awardRequirementId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAltRequisitesFromAwardRequirement(org.osid.id.Id awardRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
