//
// org.osid.course.requisite.RequisiteLookupSession
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteLookupSession.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>This session defines methods for retrieving requirements and 
 *  requirement components. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated course catalog view: All requisite methods in this 
 *      session operate, retrieve and pertain to requisites defined explicitly 
 *      in the current course catalog. Using an isolated view is useful for 
 *      managing <code> Requisites </code> with the Requisite <code> 
 *      AdminSession. </code> </li> 
 *      <li> federated course catalog view: All requisite lookup methods in 
 *      this session operate, retrieve and pertain to all requisites defined 
 *      in this course catalog and any other requisites implicitly available 
 *      in this course catalog through course catalog inheritence. </li> 
 *      <li> active requisite view: All requisite lookup methods return active 
 *      requisites. </li> 
 *      <li> any status requisite view: Requisite of any active or inactive 
 *      status are returned from methods. </li> 
 *      <li> sequestered requisite viiew: All requisite methods suppress 
 *      sequestered requisites. </li> 
 *      <li> unsequestered requisite view: All requisite methods return all 
 *      requisites. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCourseCatalogView() </code> and <code> 
 *  useIsolatedCourseCatalogView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Requisites may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Requisite. </code> </p>
 */

public interface RequisiteLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> CourseCatalog </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> CourseCatalog Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCourseCatalogId();


    /**
     *  Gets the <code> CourseCatalog </code> associated with this session. 
     *
     *  @return the course catalog 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalog getCourseCatalog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Requisite </code> and component 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRequisites();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRequisiteView();


    /**
     *  A complete view of the <code> Requisite </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRequisiteView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include requisites in catalogs which are children of this catalog in 
     *  the course catalog hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCourseCatalogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this course catalog only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCourseCatalogView();


    /**
     *  Only active requisites are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveRequisiteView();


    /**
     *  All active and inactive requisites are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusRequisiteView();


    /**
     *  The returns from the lookup methods omit sequestered requisites. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useSequesteredRequisiteView();


    /**
     *  All requisites are returned including sequestered requisites. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useUnsequesteredRequisiteView();


    /**
     *  Gets the <code> Requisite </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Requisite </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Requisite </code> and retained for compatibility. 
     *  
     *  In active mode, requisites are returned that are currently active. In 
     *  any status mode, active and inactive requisites are returned. 
     *  
     *  In sequestered mode, no sequestered requisites are returned. In 
     *  unsequestered mode, all requisites are returned. 
     *
     *  @param  requisiteId the <code> Id </code> of the <code> Requisite 
     *          </code> to retrieve 
     *  @return the returned <code> requisite </code> 
     *  @throws org.osid.NotFoundException no <code> Requisite </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.Requisite getRequisite(org.osid.id.Id requisiteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  requisites specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Requisites </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, requisites are returned that are currently active. In 
     *  any status mode, active and inactive requisites are returned. 
     *  
     *  In sequestered mode, no sequestered requisites are returned. In 
     *  unsequestered mode, all requisites are returned. 
     *
     *  @param  requisiteIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> requisiteIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesByIds(org.osid.id.IdList requisiteIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> corresponding to the given 
     *  requisite genus <code> Type </code> which does not include requisites 
     *  of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  requisites or an error results. Otherwise, the returned list may 
     *  contain only those requisites that are accessible through this 
     *  session. 
     *  
     *  In active mode, requisites are returned that are currently active. In 
     *  any status mode, active and inactive requisites are returned. 
     *  
     *  In sequestered mode, no sequestered requisites are returned. In 
     *  unsequestered mode, all requisites are returned. 
     *
     *  @param  requisiteGenusType a requisite genus type 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesByGenusType(org.osid.type.Type requisiteGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> corresponding to the given 
     *  requisite genus <code> Type </code> and include any additional 
     *  requisites with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  requisites or an error results. Otherwise, the returned list may 
     *  contain only those requisites that are accessible through this 
     *  session. 
     *  
     *  In active mode, requisites are returned that are currently active. In 
     *  any status mode, active and inactive requisites are returned. 
     *  
     *  In sequestered mode, no sequestered requisites are returned. In 
     *  unsequestered mode, all requisites are returned. 
     *
     *  @param  requisiteGenusType a requisite genus type 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesByParentGenusType(org.osid.type.Type requisiteGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> containing the given requisite 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, requisites are returned that are currently active. In 
     *  any status mode, active and inactive requisites are returned. 
     *  
     *  In sequestered mode, no sequestered requisites are returned. In 
     *  unsequestered mode, all requisites are returned. 
     *
     *  @param  requisiteRecordType a requisite record type 
     *  @return the returned <code> RequisiteList </code> list 
     *  @throws org.osid.NullArgumentException <code> requisiteRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesByRecordType(org.osid.type.Type requisiteRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> immediately containing the given 
     *  requisite option. 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, requisites are returned that are currently active. In 
     *  any status mode, active and inactive requisites are returned. 
     *  
     *  In sequestered mode, no sequestered requisites are returned. In 
     *  unsequestered mode, all requisites are returned. 
     *
     *  @param  requisiteOptionId a requisite option <code> Id </code> 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteOptionId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesForRequisiteOption(org.osid.id.Id requisiteOptionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Requisites. </code> 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, requisites are returned that are currently active. In 
     *  any status mode, active and inactive requisites are returned. 
     *  
     *  In sequestered mode, no sequestered requisites are returned. In 
     *  unsequestered mode, all requisites are returned. 
     *
     *  @return a list of <code> Requisites </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisites()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> CourseRequirement </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CourseRequirement </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> CourseRequirement </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @param  courseRequirementId the <code> Id </code> of the <code> 
     *          CourseRequirement </code> to retrieve 
     *  @return the returned <code> CourseRequirement </code> 
     *  @throws org.osid.NotFoundException no <code> CourseRequirement </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirement getCourseRequirement(org.osid.id.Id courseRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseRequirementList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  course requirements specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> CourseRequirements </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @param  courseRequirementIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> CourseRequirementList </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> courseRequirementIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementList getCourseRequirementsByIds(org.osid.id.IdList courseRequirementIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseRequirementList </code> corresponding to the given 
     *  course requirement genus <code> Type </code> which does not include 
     *  course requirements of types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course requirements or an error results. Otherwise, the returned list 
     *  may contain only those course requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @param  courseRequirementGenusType a course requirement genus type 
     *  @return the returned <code> CourseRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementList getCourseRequirementsByGenusType(org.osid.type.Type courseRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseRequirementList </code> corresponding to the given 
     *  course requirement genus <code> Type </code> and include any 
     *  additional course requirements with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  course requirements or an error results. Otherwise, the returned list 
     *  may contain only those course requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @param  courseRequirementGenusType a course requirements genus type 
     *  @return the returned <code> CourseRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementList getCourseRequirementsByParentGenusType(org.osid.type.Type courseRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseRequirementList </code> containing the given 
     *  course requirement record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known course 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those course requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @param  courseRequirementRecordType a course requirement record type 
     *  @return the returned <code> CourseRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          courseRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementList getCourseRequirementsByRecordType(org.osid.type.Type courseRequirementRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseRequirementList </code> containing the given 
     *  course. 
     *  
     *  In plenary mode, the returned list contains all known course 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those course requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @return the returned <code> CourseRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementList getCourseRequirementsByCourse(org.osid.id.Id courseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CourseRequirementList </code> with the given <code> 
     *  Requisite. </code> 
     *  
     *  In plenary mode, the returned list contains all known course 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those course requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @return the returned <code> CourseRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementList getCourseRequirementsByAltRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> immediately containing the given 
     *  course requirement. 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, course requirements are processed and requisites are 
     *  returned that are currently active. In any status mode, active and 
     *  inactive requisites are returned. 
     *
     *  @param  courseRequirementId a course requirement <code> Id </code> 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NullArgumentException <code> courseRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesForCourseRequirement(org.osid.id.Id courseRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CourseRequirements. </code> 
     *  
     *  In plenary mode, the returned list contains all known course 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those course requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, course requirements are returned that are currently 
     *  active. In any status mode, active and inactive course requirements 
     *  are returned. 
     *
     *  @return a list of <code> CourseRequirements </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CourseRequirementList getCourseRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ProgramRequirement </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ProgramRequirement </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> ProgramRequirement </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @param  programRequirementId the <code> Id </code> of the <code> 
     *          ProgramRequirement </code> to retrieve 
     *  @return the returned <code> ProgramRequirement </code> 
     *  @throws org.osid.NotFoundException no <code> ProgramRequirement 
     *          </code> found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirement getProgramRequirement(org.osid.id.Id programRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramRequirementList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  program requirements specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> ProgramRequirements </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @param  programRequirementIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> ProgramRequirementList </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> programRequirementIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementList getProgramRequirementsByIds(org.osid.id.IdList programRequirementIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramRequirementList </code> corresponding to the 
     *  given program requirement genus <code> Type </code> which does not 
     *  include program requirements of types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  program requirements or an error results. Otherwise, the returned list 
     *  may contain only those program requirements that are accessible 
     *  through this session. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @param  programRequirementGenusType a program requirement genus type 
     *  @return the returned <code> ProgramRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          programRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementList getProgramRequirementsByGenusType(org.osid.type.Type programRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramRequirementList </code> corresponding to the 
     *  given program requirement genus <code> Type </code> and include any 
     *  additional program requirements with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  program requirements or an error results. Otherwise, the returned list 
     *  may contain only those program requirements that are accessible 
     *  through this session. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @param  programRequirementGenusType a program requirements genus type 
     *  @return the returned <code> ProgramRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          programRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementList getProgramRequirementsByParentGenusType(org.osid.type.Type programRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramRequirementList </code> containing the given 
     *  program requirement record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those program requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @param  programRequirementRecordType a program requirement record type 
     *  @return the returned <code> ProgramRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          programRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementList getProgramRequirementsByRecordType(org.osid.type.Type programRequirementRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramRequirementList </code> containing the given 
     *  program. 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those program requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @return the returned <code> ProgramRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementList getProgramRequirementsByProgram(org.osid.id.Id programId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProgramRequirementList </code> with the given <code> 
     *  Requisite. </code> 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those program requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @return the returned <code> ProgramRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementList getProgramRequirementsByAltRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> immediately containing the given 
     *  program requirement. 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, program requirements are processed and requisites are 
     *  returned that are currently active. In any status mode, active and 
     *  inactive requisites are returned. 
     *
     *  @param  programRequirementId a program requirement <code> Id </code> 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NullArgumentException <code> programRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesForProgramRequirement(org.osid.id.Id programRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ProgramRequirements. </code> 
     *  
     *  In plenary mode, the returned list contains all known program 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those program requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, program requirements are returned that are currently 
     *  active. In any status mode, active and inactive program requirements 
     *  are returned. 
     *
     *  @return a list of <code> ProgramRequirements </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.ProgramRequirementList getProgramRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> CredentialRequirement </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  CredentialRequirement </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> CredentialRequirement </code> and retained 
     *  for compatibility. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @param  credentialRequirementId the <code> Id </code> of the <code> 
     *          CredentialRequirement </code> to retrieve 
     *  @return the returned <code> CredentialRequirement </code> 
     *  @throws org.osid.NotFoundException no <code> CredentialRequirement 
     *          </code> found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirement getCredentialRequirement(org.osid.id.Id credentialRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialRequirementList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  credential requirements specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> CredentialRequirements </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @param  credentialRequirementIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> CredentialRequirementList </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementList getCredentialRequirementsByIds(org.osid.id.IdList credentialRequirementIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialRequirementList </code> corresponding to the 
     *  given credential requirement genus <code> Type </code> which does not 
     *  include credential requirements of types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  credential requirements or an error results. Otherwise, the returned 
     *  list may contain only those credential requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @param  credentialRequirementGenusType a credential requirement genus 
     *          type 
     *  @return the returned <code> CredentialRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementList getCredentialRequirementsByGenusType(org.osid.type.Type credentialRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialRequirementList </code> corresponding to the 
     *  given credential requirement genus <code> Type </code> and include any 
     *  additional credential requirements with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  credential requirements or an error results. Otherwise, the returned 
     *  list may contain only those credential requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @param  credentialRequirementGenusType a credential requirements genus 
     *          type 
     *  @return the returned <code> CredentialRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementList getCredentialRequirementsByParentGenusType(org.osid.type.Type credentialRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialRequirementList </code> containing the given 
     *  credential requirement record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known credential 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those credential requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @param  credentialRequirementRecordType a credential requirement 
     *          record type 
     *  @return the returned <code> CredentialRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          credentialRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementList getCredentialRequirementsByRecordType(org.osid.type.Type credentialRequirementRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialRequirementList </code> containing the given 
     *  credential. 
     *  
     *  In plenary mode, the returned list contains all known credential 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those credential requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @param  credentialId a credential <code> Id </code> 
     *  @return the returned <code> CredentialRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementList getCredentialRequirementsByCredential(org.osid.id.Id credentialId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> CredentialRequirementList </code> with the given <code> 
     *  Requisite. </code> 
     *  
     *  In plenary mode, the returned list contains all known credential 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those credential requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @return the returned <code> CredentialRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementList getCredentialRequirementsByAltRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> immediately containing the given 
     *  credential requirement. 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, credential requirements are processed and requisites 
     *  are returned that are currently active. In any status mode, active and 
     *  inactive requisites are returned. 
     *
     *  @param  credentialRequirementId a credential requirement <code> Id 
     *          </code> 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NullArgumentException <code> credentialRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesForCredentialRequirement(org.osid.id.Id credentialRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> CredentialRequirements. </code> 
     *  
     *  In plenary mode, the returned list contains all known credential 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those credential requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, credential requirements are returned that are 
     *  currently active. In any status mode, active and inactive credential 
     *  requirements are returned. 
     *
     *  @return a list of <code> CredentialRequirements </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.CredentialRequirementList getCredentialRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> LearningObjectiveRequirement </code> specified by its 
     *  <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  LearningObjectiveRequirement </code> may have a different <code> Id 
     *  </code> than requested, such as the case where a duplicate <code> Id 
     *  </code> was assigned to a <code> LearningObjectiveRequirement </code> 
     *  and retained for compatibility. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @param  learningObjectiveRequirementId the <code> Id </code> of the 
     *          <code> LearningObjectiveRequirement </code> to retrieve 
     *  @return the returned <code> LearningObjectiveRequirement </code> 
     *  @throws org.osid.NotFoundException no <code> 
     *          LearningObjectiveRequirement </code> found with the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirement getLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LearningObjectiveRequirementList </code> corresponding 
     *  to the given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  learning objective requirements specified in the <code> Id </code> 
     *  list, in the order of the list, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible <code> 
     *  LearningObjectiveRequirements </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @param  learningObjectiveRequirementIds the list of <code> Ids </code> 
     *          to retrieve 
     *  @return the returned <code> LearningObjectiveRequirement </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementList getLearningObjectiveRequirementsByIds(org.osid.id.IdList learningObjectiveRequirementIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LearningObjectiveRequirementList </code> corresponding 
     *  to the given learning objective requirement genus <code> Type </code> 
     *  which does not include learning objective requirements of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  learning objective requirements or an error results. Otherwise, the 
     *  returned list may contain only those learning objective requirements 
     *  that are accessible through this session. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @param  learningObjectiveRequirementGenusType a learning objective 
     *          requirement genus type 
     *  @return the returned <code> LearningObjectiveRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementList getLearningObjectiveRequirementsByGenusType(org.osid.type.Type learningObjectiveRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LearningObjectiveRequirementList </code> corresponding 
     *  to the given learning objective requirement genus <code> Type </code> 
     *  and include any additional learning objective requirements with genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  learning objective requirements or an error results. Otherwise, the 
     *  returned list may contain only those learning objective requirements 
     *  that are accessible through this session. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @param  learningObjectiveRequirementGenusType a learning objective 
     *          requirements genus type 
     *  @return the returned <code> LearningObjectiveRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementList getLearningObjectiveRequirementsByParentGenusType(org.osid.type.Type learningObjectiveRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LearningObjectiveRequirementList </code> containing the 
     *  given learning objective requirement record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known learning 
     *  objective requirements or an error results. Otherwise, the returned 
     *  list may contain only those learning objective requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @param  learningObjectiveRequirementRecordType a learning objective 
     *          requirement record type 
     *  @return the returned <code> LearningObjectiveRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiverequirementRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementList getLearningObjectiveRequirementsByRecordType(org.osid.type.Type learningObjectiveRequirementRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LearningObjectiveRequirementList </code> containing the 
     *  given learning objective. 
     *  
     *  In plenary mode, the returned list contains all known learning 
     *  objective requirements or an error results. Otherwise, the returned 
     *  list may contain only those learning objective requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @param  objectiveId a learning objective <code> Id </code> 
     *  @return the returned <code> LearningObjectiveRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementList getLearningObjectiveRequirementsByObjective(org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LearningObjectiveRequirementList </code> with the given 
     *  <code> Requisite. </code> 
     *  
     *  In plenary mode, the returned list contains all known learning 
     *  objective requirements or an error results. Otherwise, the returned 
     *  list may contain only those learning objective requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @return the returned <code> LearningObjectiveRequirementList </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementList getLearningObjectiveRequirementsByAltRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> immediately containing the given 
     *  learning objective requirement. 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, learning objective requirements are processed and 
     *  requisites are returned that are currently active. In any status mode, 
     *  active and inactive requirements are returned. 
     *
     *  @param  learningObjectiveRequirementId a learning objective 
     *          requirement <code> Id </code> 
     *  @return the returned <code> RequisiteList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          learningObjectiveRequirementId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesForLearningObjectiveRequirement(org.osid.id.Id learningObjectiveRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> LearningObjectiveRequirements. </code> 
     *  
     *  In plenary mode, the returned list contains all known learning 
     *  objective requirements or an error results. Otherwise, the returned 
     *  list may contain only those learning objective requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, learning objective requirements are returned that are 
     *  currently active. In any status mode, active and inactive learning 
     *  objective requirements are returned. 
     *
     *  @return a list of <code> LearningObjectiveRequirements </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.LearningObjectiveRequirementList getLearningObjectiveRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AssessmentRequirement </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  AssessmentRequirement </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to an <code> AssessmentRequirement </code> and retained 
     *  for compatibility. 
     *  
     *  In active mode, assessment requirements are returned that are 
     *  currently active. In any status mode, active and inactive assessment 
     *  requirements are returned. 
     *
     *  @param  assessmentRequirementId the <code> Id </code> of the <code> 
     *          AssessmentRequirement </code> to retrieve 
     *  @return the returned <code> AssessmentRequirement </code> 
     *  @throws org.osid.NotFoundException no <code> AssessmentRequirement 
     *          </code> found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirement getAssessmentRequirement(org.osid.id.Id assessmentRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentRequirementList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  assessment requirements specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> AssessmentlRequirements </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, assessment requirements are returned that are 
     *  currently active. In any status mode, active and inactive assessment 
     *  requirements are returned. 
     *
     *  @param  assessmentRequirementIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return a list of <code> AssessmentRequirements </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementList getAssessmentRequirementsByIds(org.osid.id.IdList assessmentRequirementIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentRequirementList </code> corresponding to the 
     *  given assessment requirement genus <code> Type </code> which does not 
     *  include assessment requirements of types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  assessment requirements or an error results. Otherwise, the returned 
     *  list may contain only those assessment requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, assessment requirements are returned that are 
     *  currently active. In any status mode, active and inactive assessment 
     *  requirements are returned. 
     *
     *  @param  assessmentRequirementGenusType an assessment requirement genus 
     *          type 
     *  @return a list of <code> AssessmentRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementList getAssessmentRequirementsByGenusType(org.osid.type.Type assessmentRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentRequirementList </code> corresponding to the 
     *  given assessment requirement genus <code> Type </code> and include any 
     *  additional assessment requirements with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  assessment requirements or an error results. Otherwise, the returned 
     *  list may contain only those assessment requirements that are 
     *  accessible through this session. 
     *  
     *  In active mode, assessment requirements are returned that are 
     *  currently active. In any status mode, active and inactive assessment 
     *  requirements are returned. 
     *
     *  @param  assessmentRequirementGenusType an assessment requirements 
     *          genus type 
     *  @return a list of <code> AssessmentRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementList getAssessmentRequirementsByParentGenusType(org.osid.type.Type assessmentRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentRequirementList </code> containing the given 
     *  assessment requirement record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known assessment 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those assessment requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, assessment requirements are returned that are 
     *  currently active. In any status mode, active and inactive assessment 
     *  requirements are returned. 
     *
     *  @param  assessmentRequirementRecordType an assessment requirement 
     *          record type 
     *  @return a list of <code> AssessmentRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          assessmentRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementList getAssessmentRequirementsByRecordType(org.osid.type.Type assessmentRequirementRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentRequirementList </code> containing the given 
     *  assessment. In plenary mode, the returned list contains all known 
     *  assessment requirements or an error results. Otherwise, the returned 
     *  list may contain only those assessment requirements that are 
     *  accessible through this session. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @return a list of <code> AssessmentRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementList getAssessmentRequirementsByAssessment(org.osid.id.Id assessmentId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AssessmentRequirementList </code> with the given <code> 
     *  Requisite. </code> 
     *  
     *  In plenary mode, the returned list contains all known assessment 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those assessment requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, assessment requirements are returned that are 
     *  currently active. In any status mode, active and inactive assessment 
     *  requirements are returned. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @return a list of <code> AssessmentRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementList getAssessmentRequirementsByAltRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> immediately containing the given 
     *  assessment requirement. 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, assessment requirements are processed and requisites 
     *  are returned that are currently active. In any status mode, active and 
     *  inactive assessment requirements are returned. 
     *
     *  @param  assessmentRequirementId an assessment requirement <code> Id 
     *          </code> 
     *  @return a list of <code> Requisites </code> 
     *  @throws org.osid.NullArgumentException <code> assessmentRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesForAssessmentRequirement(org.osid.id.Id assessmentRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> AssessmentRequirements. </code> 
     *  
     *  In plenary mode, the returned list contains all known assessment 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those assessment requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, assessment requirements are returned that are 
     *  currently active. In any status mode, active and inactive assessment 
     *  requirements are returned. 
     *
     *  @return a list of <code> AssessmentRequirements </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AssessmentRequirementList getAssessmentRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> AwardRequirement </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  AwardRequirement </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> AwardRequirement </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @param  awardRequirementId the <code> Id </code> of the <code> 
     *          AwardRequirement </code> to retrieve 
     *  @return the returned <code> AwardRequirement </code> 
     *  @throws org.osid.NotFoundException no <code> AwardRequirement </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirement getAwardRequirement(org.osid.id.Id awardRequirementId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardRequirementList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  award requirements specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> AwardlRequirements </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @param  awardRequirementIds the list of <code> Ids </code> to retrieve 
     *  @return a list of <code> AwardRequirements </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> awardRequirementIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementList getAwardRequirementsByIds(org.osid.id.IdList awardRequirementIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardRequirementList </code> corresponding to the given 
     *  award requirement genus <code> Type </code> which does not include 
     *  award requirements of types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  award requirements or an error results. Otherwise, the returned list 
     *  may contain only those award requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @param  awardRequirementGenusType an award requirement genus type 
     *  @return a list of <code> AwardRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          awardRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementList getAwardRequirementsByGenusType(org.osid.type.Type awardRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardRequirementList </code> corresponding to the given 
     *  award requirement genus <code> Type </code> and include any additional 
     *  award requirements with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  award requirements or an error results. Otherwise, the returned list 
     *  may contain only those award requirements that are accessible through 
     *  this session. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @param  awardRequirementGenusType an award requirements genus type 
     *  @return a list of <code> AwardRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          awardRequirementGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementList getAwardRequirementsByParentGenusType(org.osid.type.Type awardRequirementGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardRequirementList </code> containing the given award 
     *  requirement record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known award 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those award requirements that are accessible through this 
     *  session. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @param  awardRequirementRecordType an award requirement record type 
     *  @return a list of <code> AwardRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          awardRequirementRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementList getAwardRequirementsByRecordType(org.osid.type.Type awardRequirementRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardRequirementList </code> containing the given 
     *  award. 
     *  
     *  In plenary mode, the returned list contains all known award 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those award requirements that are accessible through this 
     *  session. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @param  awardId an award <code> Id </code> 
     *  @return a list of <code> AwardRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementList getAwardRequirementsByAward(org.osid.id.Id awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardRequirementList </code> with the given <code> 
     *  Requisite. </code> 
     *  
     *  In plenary mode, the returned list contains all known award 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those award requirements that are accessible through this 
     *  session. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @return a list of <code> AwardRequirements </code> 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementList getAwardRequirementsByAltRequisite(org.osid.id.Id requisiteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RequisiteList </code> immediately containing the given 
     *  award requirement. 
     *  
     *  In plenary mode, the returned list contains all known requisites or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  requisites that are accessible through this session. 
     *  
     *  In active mode, award requirements are processed and requisites are 
     *  returned that are currently active. In any status mode, active and 
     *  inactive requisites are returned. 
     *
     *  @param  awardRequirementId an award requirement <code> Id </code> 
     *  @return a list of <code> Requisites </code> 
     *  @throws org.osid.NullArgumentException <code> awardRequirementId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteList getRequisitesForAwardRequirement(org.osid.id.Id awardRequirementId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> AwardRequirements. </code> 
     *  
     *  In plenary mode, the returned list contains all known award 
     *  requirements or an error results. Otherwise, the returned list may 
     *  contain only those award requirements that are accessible through this 
     *  session. 
     *  
     *  In active mode, award requirements are returned that are currently 
     *  active. In any status mode, active and inactive award requirements are 
     *  returned. 
     *
     *  @return a list of <code> AwardRequirements </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.AwardRequirementList getAwardRequirements()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
