//
// org.osid.course.requisite.RequisiteQuery
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteQuery.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>This is the query for searching requisites. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface RequisiteQuery
    extends org.osid.OsidRuleQuery,
            org.osid.OsidEnablerQuery,
            org.osid.OsidContainableQuery {


    /**
     *  Sets the requisite <code> Id </code> for this query to match 
     *  requisites that a requisite option. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequisiteOptionId(org.osid.id.Id requisiteId, 
                                       boolean match);


    /**
     *  Clears the requisite <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequisiteOptionIdTerms();


    /**
     *  Tests if a <code> RequisiteQuery </code> is available. 
     *
     *  @return <code> true </code> if a requisite query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequisiteOptionQuery();


    /**
     *  Gets the query for a requisite option. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a requisite query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequisiteOptionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequisiteOptionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.requisite.RequisiteQuery getRequisiteOptionQuery();


    /**
     *  Matches requisites that have any requisite option. 
     *
     *  @param  match <code> true </code> to match requisites with any 
     *          requisite option, <code> false </code> to match requisites 
     *          with no requisite options 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequisiteOption(boolean match);


    /**
     *  Clears the requisite option terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequisiteOptionTerms();


    /**
     *  Sets the course <code> Id </code> for this query to match requisites 
     *  that have a requirement for the given course. 
     *
     *  @param  courseId a course <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseId(org.osid.id.Id courseId, boolean match);


    /**
     *  Clears the course <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseIdTerms();


    /**
     *  Tests if a <code> CourseQuery </code> is available. 
     *
     *  @return <code> true </code> if a course query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseQuery();


    /**
     *  Gets the query for a course requirement. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return a course query 
     *  @throws org.osid.UnimplementedException <code> supportsCourseQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.CourseQuery getCourseQuery();


    /**
     *  Matches requisites that have any course requirement. 
     *
     *  @param  match <code> true </code> to match requisites with any course 
     *          requirement, <code> false </code> to match requisites with no 
     *          course requirements 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCourse(boolean match);


    /**
     *  Clears the course terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseTerms();


    /**
     *  Sets the program <code> Id </code> for this query to match requisites 
     *  that have a requirement for the given program. 
     *
     *  @param  programId a program <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> programId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProgramId(org.osid.id.Id programId, boolean match);


    /**
     *  Clears the program <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProgramIdTerms();


    /**
     *  Tests if a <code> ProgramQuery </code> is available. 
     *
     *  @return <code> true </code> if a program query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProgramQuery();


    /**
     *  Gets the query for a program requirement. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return a program query 
     *  @throws org.osid.UnimplementedException <code> supportsProgramQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProgramQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.program.ProgramQuery getProgramQuery();


    /**
     *  Matches requisites that have any program requirement. 
     *
     *  @param  match <code> true </code> to match requisites with any program 
     *          requirement, <code> false </code> to match requisites with no 
     *          program requirements 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProgram(boolean match);


    /**
     *  Clears the program terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProgramTerms();


    /**
     *  Sets the credential <code> Id </code> for this query to match 
     *  requisites that have a requirement for the given credential. 
     *
     *  @param  credentialId a credential <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> credentialId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCredentialId(org.osid.id.Id credentialId, boolean match);


    /**
     *  Clears the credential <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredentialIdTerms();


    /**
     *  Tests if a <code> CredentialQuery </code> is available. 
     *
     *  @return <code> true </code> if a credential query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCredentialQuery();


    /**
     *  Gets the query for a credential requirement. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return a credential query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCredentialQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCredentialQuery() </code> is <code> true. </code> 
     */

    public org.osid.course.program.CredentialQuery getCredentialQuery();


    /**
     *  Matches requisites that have any credential requirement. 
     *
     *  @param  match <code> true </code> to match requisites with any 
     *          credential requirement, <code> false </code> to match 
     *          requisites with no credential requirements 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCredential(boolean match);


    /**
     *  Clears the credential terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCredentialTerms();


    /**
     *  Sets the learning objective <code> Id </code> for this query to match 
     *  requisites that have a requirement for the given learning objective. 
     *
     *  @param  objectiveId a learning objective <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLearningObjectiveId(org.osid.id.Id objectiveId, 
                                         boolean match);


    /**
     *  Clears the learning objective <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveIdTerms();


    /**
     *  Tests if a <code> LearningObjectiveQuery </code> is available. 
     *
     *  @return <code> true </code> if a learning objective query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningObjectiveQuery();


    /**
     *  Gets the query for a learning objective requirement. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return a learning objective query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsLearningObjectiveQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLearningObjectiveQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.learning.ObjectiveQuery getLearningObjectiveQuery();


    /**
     *  Matches requisites that have any learning objective requirement. 
     *
     *  @param  match <code> true </code> to match requisites with any 
     *          learning objective requirement, <code> false </code> to match 
     *          requisites with no learning objective requirements 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLearningObjective(boolean match);


    /**
     *  Clears the learning objective terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectiveTerms();


    /**
     *  Sets the assessment <code> Id </code> for this query to match 
     *  requisites that have a requirement for the given assessment. 
     *
     *  @param  assessmentId an assessment <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assessmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssessmentId(org.osid.id.Id assessmentId, boolean match);


    /**
     *  Clears the assessment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentIdTerms();


    /**
     *  Tests if an <code> AssessmentQuery </code> is available. 
     *
     *  @return <code> true </code> if an assessment query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentQuery();


    /**
     *  Gets the query for a assessment requirement. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return an assessment query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.assessment.AssessmentQuery getAssessmentQuery();


    /**
     *  Matches requisites that have any assessment requirement. 
     *
     *  @param  match <code> true </code> to match requisites with any 
     *          assessment requirement, <code> false </code> to match 
     *          requisites with no assessment requirements 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssessment(boolean match);


    /**
     *  Clears the assessment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessmentTerms();


    /**
     *  Sets the award <code> Id </code> for this query to match requisites 
     *  that have a requirement for the given award. 
     *
     *  @param  awardId an award <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAwardId(org.osid.id.Id awardId, boolean match);


    /**
     *  Clears the award <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAwardIdTerms();


    /**
     *  Tests if an <code> AwardQuery </code> is available. 
     *
     *  @return <code> true </code> if an award query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardQuery();


    /**
     *  Gets the query for a award requirement. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return an award query 
     *  @throws org.osid.UnimplementedException <code> supportsAwardQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardQuery getAwardQuery();


    /**
     *  Matches requisites that have any award requirement. 
     *
     *  @param  match <code> true </code> to match requisites with any award 
     *          requirement, <code> false </code> to match requisites with no 
     *          award requirements 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAward(boolean match);


    /**
     *  Clears the award terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAwardTerms();


    /**
     *  Sets the requisite <code> Id </code> for this query to match 
     *  requisites that have the specified requisite as an ancestor. 
     *
     *  @param  requisiteId a requisite <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> requisiteId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContainingRequisiteId(org.osid.id.Id requisiteId, 
                                           boolean match);


    /**
     *  Clears the containing requisite <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainingRequisiteIdTerms();


    /**
     *  Tests if a containing requisite query is available. 
     *
     *  @return <code> true </code> if a containing requisite query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContainingRequisiteQuery();


    /**
     *  Gets the query for a containing requisite. 
     *
     *  @return the containing requisite query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContainingRequisiteQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContainingRequisiteQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.requisite.RequisiteQuery getContainingRequisiteQuery();


    /**
     *  Matches requisites with any ancestor requisite. 
     *
     *  @param  match <code> true </code> to match requisites with any 
     *          ancestor requisite, <code> false </code> to match requisites 
     *          with no ancestor requisites 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyContainingRequisite(boolean match);


    /**
     *  Clears the containing requisite terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainingRequisiteTerms();


    /**
     *  Sets the course catalog <code> Id </code> for this query to match 
     *  requisites assigned to course catalogs. 
     *
     *  @param  courseCatalogId the course catalog <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCourseCatalogId(org.osid.id.Id courseCatalogId, 
                                     boolean match);


    /**
     *  Clears the course catalog <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogIdTerms();


    /**
     *  Tests if a <code> CourseCatalogQuery </code> is available. 
     *
     *  @return <code> true </code> if a course catalog query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseCatalogQuery();


    /**
     *  Gets the query for a course catalog. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the course catalog query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCourseCatalogQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseCatalogQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.CourseCatalogQuery getCourseCatalogQuery();


    /**
     *  Clears the course catalog terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCourseCatalogTerms();


    /**
     *  Gets the requisite query record corresponding to the given <code> 
     *  Requisite </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  requisiteRecordType a requisites record type 
     *  @return the requisite query record 
     *  @throws org.osid.NullArgumentException <code> requisiteRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requisiteRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.records.RequisiteQueryRecord getRequisiteQueryRecord(org.osid.type.Type requisiteRecordType)
        throws org.osid.OperationFailedException;
}
