//
// org.osid.course.requisite.RequisiteQueryInspector
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteQueryInspector.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface RequisiteQueryInspector
    extends org.osid.OsidRuleQueryInspector,
            org.osid.OsidEnablerQueryInspector,
            org.osid.OsidContainableQueryInspector {


    /**
     *  Gets the requisite option <code> Id </code> query terms. 
     *
     *  @return the requisite <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRequisiteOptionIdTerms();


    /**
     *  Gets the requisite option query terms. 
     *
     *  @return the requisite query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteQueryInspector[] getRequisiteOptionTerms();


    /**
     *  Gets the course <code> Id </code> query terms. 
     *
     *  @return the course <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseIdTerms();


    /**
     *  Gets the course query terms. 
     *
     *  @return the course terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseQueryInspector[] getCourseTerms();


    /**
     *  Gets the program <code> Id </code> query terms. 
     *
     *  @return the program <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getProgramIdTerms();


    /**
     *  Gets the program query terms. 
     *
     *  @return the program terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.ProgramQueryInspector[] getProgramTerms();


    /**
     *  Gets the credential <code> Id </code> query terms. 
     *
     *  @return the credential <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCredentialIdTerms();


    /**
     *  Gets the credential query terms. 
     *
     *  @return the credential terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.program.CredentialQueryInspector[] getCredentialTerms();


    /**
     *  Gets the learning objective <code> Id </code> query terms. 
     *
     *  @return the learning objective <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLearningObjectiveIdTerms();


    /**
     *  Gets the learning objective query terms. 
     *
     *  @return the learning objective terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getLearningObjectiveTerms();


    /**
     *  Gets the assessment <code> Id </code> query terms. 
     *
     *  @return the assessment <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssessmentIdTerms();


    /**
     *  Gets the assessment query terms. 
     *
     *  @return the assessment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQueryInspector[] getAssessmentTerms();


    /**
     *  Gets the award <code> Id </code> query terms. 
     *
     *  @return the award <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAwardIdTerms();


    /**
     *  Gets the award query terms. 
     *
     *  @return the award terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AwardQueryInspector[] getAwardTerms();


    /**
     *  Gets the containing This method must be implemented. <code> Id </code> 
     *  terms. 
     *
     *  @return the This method must be implemented. <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getContainingRequisiteIdTerms();


    /**
     *  Gets the containing This method must be implemented. terms. 
     *
     *  @return the requisite terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.RequisiteQueryInspector[] getContainingRequisiteTerms();


    /**
     *  Gets the course catalog <code> Id </code> query terms. 
     *
     *  @return the course catalog <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseCatalogIdTerms();


    /**
     *  Gets the course catalog query terms. 
     *
     *  @return the course catalog query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogQueryInspector[] getCourseCatalogTerms();


    /**
     *  Gets the requisite query inspector record corresponding to the given 
     *  <code> Requisite </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  requisiteRecordType a requisite record type 
     *  @return the requisite query inspector record 
     *  @throws org.osid.NullArgumentException <code> requisiteRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requisiteRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.requisite.records.RequisiteQueryInspectorRecord getRequisiteQueryInspectorRecord(org.osid.type.Type requisiteRecordType)
        throws org.osid.OperationFailedException;
}
