//
// org.osid.course.requisite.RequisiteReceiver
//
//     The OSID Java specification for org.osid.course.requisite.RequisiteReceiver.
//
// Copyright (C) 2011 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an ""AS 
//     IS"" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
//     THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR 
//     OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.requisite;


/**
 *  <p>The requisite receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Requisites. 
 *  </code> </p>
 */

public interface RequisiteReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new requisites. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  requisiteIds the <code> Ids </code> of the new <code> 
     *          Requisites </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newRequisites(org.osid.id.Id notificationId, 
                              org.osid.id.IdList requisiteIds);


    /**
     *  The callback for notification of updated requisites. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  requisiteIds the <code> Ids </code> of the updated <code> 
     *          Requisites </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedRequisites(org.osid.id.Id notificationId, 
                                  org.osid.id.IdList requisiteIds);


    /**
     *  the callback for notification of deleted requisites. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  requisiteIds the <code> Ids </code> of the deleted <code> 
     *          Requisites </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedRequisites(org.osid.id.Id notificationId, 
                                  org.osid.id.IdList requisiteIds);


    /**
     *  The callback for notifications of new course requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  courseRequirementIds the <code> Ids </code> of the new <code> 
     *          CourseRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newCourseRequirements(org.osid.id.Id notificationId, 
                                      org.osid.id.IdList courseRequirementIds);


    /**
     *  The callback for notification of updated course requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  courseRequirementIds the <code> Ids </code> of the updated 
     *          <code> CourseRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedCourseRequirements(org.osid.id.Id notificationId, 
                                          org.osid.id.IdList courseRequirementIds);


    /**
     *  the callback for notification of deleted course requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  courseRequirementIds the <code> Ids </code> of the deleted 
     *          <code> CourseRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedCourseRequirements(org.osid.id.Id notificationId, 
                                          org.osid.id.IdList courseRequirementIds);


    /**
     *  The callback for notifications of new program requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  programRequirementIds the <code> Ids </code> of the new <code> 
     *          ProgramRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newProgramRequirements(org.osid.id.Id notificationId, 
                                       org.osid.id.IdList programRequirementIds);


    /**
     *  The callback for notification of updated program requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  programRequirementIds the <code> Ids </code> of the updated 
     *          <code> ProgramRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedProgramRequirements(org.osid.id.Id notificationId, 
                                           org.osid.id.IdList programRequirementIds);


    /**
     *  the callback for notification of deleted program requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  programRequirementIds the <code> Ids </code> of the deleted 
     *          <code> ProgramRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedProgramRequirements(org.osid.id.Id notificationId, 
                                           org.osid.id.IdList programRequirementIds);


    /**
     *  The callback for notifications of new credential requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  credentialRequirementIds the <code> Ids </code> of the new 
     *          <code> CredentialRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newCredentialRequirements(org.osid.id.Id notificationId, 
                                          org.osid.id.IdList credentialRequirementIds);


    /**
     *  The callback for notification of updated credential requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  credentialRequirementIds the <code> Ids </code> of the updated 
     *          <code> CredentialRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedCredentialRequirements(org.osid.id.Id notificationId, 
                                              org.osid.id.IdList credentialRequirementIds);


    /**
     *  the callback for notification of deleted credential requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  credentialRequirementIds the <code> Ids </code> of the deleted 
     *          <code> CredentialRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedCredentialRequirements(org.osid.id.Id notificationId, 
                                              org.osid.id.IdList credentialRequirementIds);


    /**
     *  The callback for notifications of new learning objective requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  learningObjectiveRequirementIds the <code> Ids </code> of the 
     *          new <code> LearningObjectiveRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newLearningObjectiveRequirements(org.osid.id.Id notificationId, 
                                                 org.osid.id.IdList learningObjectiveRequirementIds);


    /**
     *  The callback for notification of updated learning objective 
     *  requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  learningObjectiveRequirementIds the <code> Ids </code> of the 
     *          updated <code> LearningObjectiveRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedLearningObjectiveRequirements(org.osid.id.Id notificationId, 
                                                     org.osid.id.IdList learningObjectiveRequirementIds);


    /**
     *  the callback for notification of deleted learning objective 
     *  requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  learningObjectiveRequirementIds the <code> Ids </code> of the 
     *          deleted <code> LearningObjectiveRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedLearningObjectiveRequirements(org.osid.id.Id notificationId, 
                                                     org.osid.id.IdList learningObjectiveRequirementIds);


    /**
     *  The callback for notifications of new assessment requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  assessmentRequirementIds the <code> Ids </code> of the new 
     *          <code> AssessmentRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAssessmentRequirements(org.osid.id.Id notificationId, 
                                          org.osid.id.IdList assessmentRequirementIds);


    /**
     *  The callback for notification of updated assessment requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  assessmentRequirementIds the <code> Ids </code> of the updated 
     *          <code> AssessmentRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedAssessmentRequirements(org.osid.id.Id notificationId, 
                                              org.osid.id.IdList assessmentRequirementIds);


    /**
     *  the callback for notification of deleted assessment requirements. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  assessmentRequirementIds the <code> Ids </code> of the deleted 
     *          <code> AssessmentRequirements </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAssessmentRequirements(org.osid.id.Id notificationId, 
                                              org.osid.id.IdList assessmentRequirementIds);
}
