/**
 * <p>The Open Service Interface Definitions for the org.osid.course.requisite
 * service.</p>
 * 
 * <p>The Course Requisite OSID provides services for authoring requirements 
 * for <code> Courses </code> and <code> Programs. </code> </p> 
 * <h4> Requisites </h4> 
 * 
 * <p> The <code> Requisite </code> is an <code> OsidRule </code> used for a 
 * requirement component. A <code> Requisite </code> has 7 terms for 
 * evaluation that must all be true for this Requisite to be satisfied. 
 * Additional terms may be defined in the <code> RequisiteRecord. </code> </p> 
 * 
 * <ul>
 *     <li> CourseRequirements </li> 
 *     <li> ProgramRequirements </li> 
 *     <li> CredentialRequirements </li> 
 *     <li> AssessmentRequirements </li> 
 *     <li> LearningObjectiveRequirements </li> 
 *     <li> an external Rule </li> 
 *     <li> Requisite options for nested OR terms </li> 
 * </ul>
 * 
 * 
 * <p> A <code> Requsite </code> is true if the active <code> Requisite 
 * </code> options term <code> AND </code> the <code> CourseRequirements 
 * </code> term <code> AND </code> the <code> ProgramRequirements </code> term 
 * <code> AND </code> <code> CredentialRequirements </code> <code> AND </code> 
 * <code> AssessmentRequirements </code> <code> AND </code> the <code> 
 * LearningObjectiveRequirements </code> <code> AND </code> <code> Rule 
 * </code> are all true. </p> 
 * 
 * <p> A <code> Requisite </code> may also contain options, or sub-requisites. 
 * These options are <code> Requisite </code> nodes in a statement tree 
 * hierarchy that represent <code> OR </code> terms. </p> 
 * 
 * <p> <code> Requisites </code> are also <code> OsidEnablers </code> that 
 * have effectiveness and may apply to specific populations of students. </p> 
 * <h4> CourseRequirements </h4> 
 * 
 * <p> A <code> CourseRequirement </code> is an <code> OsidRule </code> for a 
 * <code> Course </code> to be satisfied. The <code> Course </code> may be 
 * required to be taken in the past for a prerequisite, in the present for a 
 * co-requisite, or completed at some point in the future. The <code> 
 * CourseRequirement </code> may also require a minimum grade or credits 
 * earned. Additional constraints may be specified in the <code> 
 * CourseRequirementRecord </code> or an external <code> Rule </code> . </p> 
 * 
 * <p> All specified rules in the <code> CourseRequirement </code> must be 
 * true for the requirement to be satisifed. Alternative <code> Requisites 
 * </code> may be specified inside the <code> CourseRequirement </code> to 
 * append <code> OR </code> terms. </p> 
 * <h4> ProgramRequirements </h4> 
 * 
 * <p> A <code> ProgramRequirement </code> is an <code> OsidRule </code> for a 
 * <code> Program </code> to be satisfied. The <code> Program </code> may be 
 * required to be taken in the past for a prerequisite, in the present for a 
 * co-requisite, or completed at some point in the future. The <code> 
 * ProgramRequirement </code> may also require a minimum GPA or credits 
 * earned. Additional constraints may be specified in the <code> 
 * ProgramRequirementRecord </code> or an external <code> Rule </code> . </p> 
 * 
 * <p> All specified rules in the <code> ProgramRequirement </code> must be 
 * true for the requirement to be satisifed. Alternative <code> Requisites 
 * </code> may be specified inside the <code> ProgramRequirement </code> to 
 * append <code> OR </code> terms. </p> 
 * <h4> CredentialRequirements </h4> 
 * 
 * <p> A <code> CredentialRequirement </code> is an <code> OsidRule </code> 
 * for a <code> Credential </code> to be satisfied. The Course may be required 
 * to be taken in the past for a prerequisite, in the present for a 
 * co-requisite, or completed at some point in the future. Additional 
 * constraints may be specified in the <code> CredentialRequirementRecord 
 * </code> or an external <code> Rule </code> . </p> 
 * 
 * <p> All specified rules in the <code> CredentialRequirement </code> must be 
 * true for the requirement to be satisifed. Alternative <code> Requisites 
 * </code> may be specified inside the <code> CredentialRequirement </code> to 
 * append <code> OR </code> terms. </p> 
 * <h4> LearningObjectiveRequirements </h4> 
 * 
 * <p> A <code> LearningObjectiveRequirement </code> is an <code> OsidRule 
 * </code> for a learning <code> Objective </code> to be satisfied. The <code> 
 * LearningObjectiveRequirement </code> may also require a minimum proficiency 
 * expressed as a <code> Grade. </code> Additional constraints may be 
 * specified in the <code> ProgramRequirmentRecord </code> or an external 
 * <code> Rule </code> . </p> 
 * 
 * <p> All specified rules in the <code> LearningObjectiveRequirement </code> 
 * must be true for the requirement to be satisifed. Alternative <code> 
 * Requisites </code> may be specified inside the <code> 
 * LearningObjectiveRequirement </code> to append <code> OR </code> terms. 
 * </p> 
 * <h4> AssessmentRequirements </h4> 
 * 
 * <p> An <code> AssessmentRequirement </code> is an <code> OsidRule </code> 
 * for an <code> Assessment </code> to be satisfied. The <code> Assessment 
 * </code> may be required to be taken in the past for a prerequisite, in the 
 * present for a co-requisite, or completed at some point in the future. The 
 * <code> AssessmentRequirement </code> may also require a minimum <code> 
 * Grade </code> or score. Additional constraints may be specified in the 
 * <code> AssessmentRequirementRecord </code> or an external <code> Rule 
 * </code> . </p> 
 * 
 * <p> All specified rules in the <code> AssessmentRequirement </code> must be 
 * true for the requirement to be satisifed. Alternative <code> Requisites 
 * </code> may be specified inside the <code> AssessmentRequirement </code> to 
 * append <code> OR </code> terms. </p> 
 * <h4> AwardRequirements </h4> 
 * 
 * <p> An <code> AwardRequirement </code> is an <code> OsidRule </code> for an 
 * <code> Award </code> to be satisfied. </p> 
 * 
 * <p> All specified rules in the <code> AwardRequirement </code> must be true 
 * for the requirement to be satisifed. Alternative <code> Requisites </code> 
 * may be specified inside the <code> AwardRequirement </code> to append 
 * <code> OR </code> terms. </p> 
 * <h4> Example </h4> 
 * 
 * <p> The prerequisite for course 16.36 is (16.004 or 6.003) and (16.09 or 
 * 6.041). The coorse prequisite will have two top level <code> Requisites 
 * </code> for the and terms. </p> 
 * 
 * <p> The first <code> Requisite </code> will include a <code> 
 * CourseRequirement </code> for 16.004. That <code> CourseRequirement </code> 
 * will also include an alternative <code> Requisite </code> that will have a 
 * <code> CourseRequirement </code> for 6.003. </p> 
 * 
 * <p> The second <code> Requisite </code> will include a <code> 
 * CourseRequirement </code> for 16.09. That <code> CourseRequirement </code> 
 * will also include an alternative <code> Requisite </code> that will have a 
 * <code> CourseRequirement </code> for 6.041. </p> 
 * <h4> CourseCatalog Cataloging </h4> 
 * 
 * <p> <code> Requisites, </code> <code> CourseRequirements, </code> <code> 
 * ProgramRequirements, CredentialRequirements, LearningObjectiveRequirements, 
 * </code> and <code> AssessmentRequirements </code> can be organized into 
 * federateble <code> OsidCatalogs. </code> </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2011 Massachusetts Institute of Technology. All Rights 
 * Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an ""AS 
 * IS"" basis. The Massachusetts Institute of Technology, the Open Knowledge 
 * Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS OR IMPLIED, 
 * INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
 * PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR 
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF 
 * OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. 
 * </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notice and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, Derivative shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization comtemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.course.requisite;
