//
// org.osid.course.syllabus.CourseSyllabusProfile
//
//     The OSID Java specification for org.osid.course.syllabus.CourseSyllabusProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>The course profile describes the interoperability among course 
 *  services. </p>
 */

public interface CourseSyllabusProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any docet federation is exposed. Federation is exposed when a 
     *  specific docet may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of 
     *  docetsappears as a single docet. 
     *
     *  @return <code> true </code> if visible federation is supproted, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a syllabus lookup service. 
     *
     *  @return <code> true </code> if syllabus lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusLookup();


    /**
     *  Tests if querying syllabi is available. 
     *
     *  @return <code> true </code> if syllabus query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusQuery();


    /**
     *  Tests if searching for syllabi is available. 
     *
     *  @return <code> true </code> if syllabus search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusSearch();


    /**
     *  Tests if searching for syllabi is available. 
     *
     *  @return <code> true </code> if syllabus search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusAdmin();


    /**
     *  Tests if syllabus notification is available. 
     *
     *  @return <code> true </code> if syllabus notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusNotification();


    /**
     *  Tests if a syllabus to course catalog lookup session is available. 
     *
     *  @return <code> true </code> if syllabus course catalog lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusCourseCatalog();


    /**
     *  Tests if a syllabus to course catalog assignment session is available. 
     *
     *  @return <code> true </code> if syllabus course catalog assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusCourseCatalogAssignment();


    /**
     *  Tests if a syllabus smart course catalog session is available. 
     *
     *  @return <code> true </code> if syllabus smart course catalog is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusSmartCourseCatalog();


    /**
     *  Tests for the availability of a module service for getting available 
     *  modules for a resource. 
     *
     *  @return <code> true </code> if module is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModule();


    /**
     *  Tests for the availability of a module lookup service. 
     *
     *  @return <code> true </code> if module lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleLookup();


    /**
     *  Tests if querying modules is available. 
     *
     *  @return <code> true </code> if module query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleQuery();


    /**
     *  Tests if searching for modules is available. 
     *
     *  @return <code> true </code> if module search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleSearch();


    /**
     *  Tests if searching for modules is available. 
     *
     *  @return <code> true </code> if module search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleAdmin();


    /**
     *  Tests if module notification is available. 
     *
     *  @return <code> true </code> if module notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleNotification();


    /**
     *  Tests if a module to course catalog lookup session is available. 
     *
     *  @return <code> true </code> if module course catalog lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleCourseCatalog();


    /**
     *  Tests if a module to course catalog assignment session is available. 
     *
     *  @return <code> true </code> if module course catalog assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleCourseCatalogAssignment();


    /**
     *  Tests if a module smart course catalog session is available. 
     *
     *  @return <code> true </code> if module smart course catalog is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleSmartCourseCatalog();


    /**
     *  Tests for the availability of a docet lookup service. 
     *
     *  @return <code> true </code> if docet lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetLookup();


    /**
     *  Tests if querying docetsis available. 
     *
     *  @return <code> true </code> if docet query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetQuery();


    /**
     *  Tests if searching for docets is available. 
     *
     *  @return <code> true </code> if docet search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetSearch();


    /**
     *  Tests for the availability of a docet administrative service for 
     *  creating and deleting docets. 
     *
     *  @return <code> true </code> if docet administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetAdmin();


    /**
     *  Tests for the availability of a docet notification service. 
     *
     *  @return <code> true </code> if docet notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsDocetNotification();


    /**
     *  Tests if a docet to course catalog lookup session is available. 
     *
     *  @return <code> true </code> if docet course catalog lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetCourseCatalog();


    /**
     *  Tests if a docet to course catalog assignment session is available. 
     *
     *  @return <code> true </code> if docet course catalog assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetCourseCatalogAssignment();


    /**
     *  Tests if a docet smart course catalog session is available. 
     *
     *  @return <code> true </code> if docet smart course catalog is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetSmartCourseCatalog();


    /**
     *  Tests if a course syllabus batch service is available. 
     *
     *  @return <code> true </code> if a course syllabus batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseSyllabusBatch();


    /**
     *  Gets the supported <code> Syllabus </code> record types. 
     *
     *  @return a list containing the supported syllabus record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSyllabusRecordTypes();


    /**
     *  Tests if the given <code> Syllabus </code> record type is supported. 
     *
     *  @param  syllabusRecordType a <code> Type </code> indicating a <code> 
     *          Syllabus </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> syllabusRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusRecordType(org.osid.type.Type syllabusRecordType);


    /**
     *  Gets the supported syllabus search record types. 
     *
     *  @return a list containing the supported syllabus search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSyllabusSearchRecordTypes();


    /**
     *  Tests if the given syllabus search record type is supported. 
     *
     *  @param  syllabusSearchRecordType a <code> Type </code> indicating a 
     *          syllabus record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> syllabusSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusSearchRecordType(org.osid.type.Type syllabusSearchRecordType);


    /**
     *  Gets the supported <code> Module </code> record types. 
     *
     *  @return a list containing the supported module record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getModuleRecordTypes();


    /**
     *  Tests if the given <code> Module </code> record type is supported. 
     *
     *  @param  moduleRecordType a <code> Type </code> indicating a <code> 
     *          Module </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> moduleRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleRecordType(org.osid.type.Type moduleRecordType);


    /**
     *  Gets the supported module search record types. 
     *
     *  @return a list containing the supported module search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getModuleSearchRecordTypes();


    /**
     *  Tests if the given module search record type is supported. 
     *
     *  @param  moduleSearchRecordType a <code> Type </code> indicating a 
     *          module record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> moduleSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModuleSearchRecordType(org.osid.type.Type moduleSearchRecordType);


    /**
     *  Gets the supported <code> Docet </code> record types. 
     *
     *  @return a list containing the supported docet record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDocetRecordTypes();


    /**
     *  Tests if the given <code> Docet </code> record type is supported. 
     *
     *  @param  docetRecordType a <code> Type </code> indicating a <code> 
     *          Docet </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> docetRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetRecordType(org.osid.type.Type docetRecordType);


    /**
     *  Gets the supported docet search record types. 
     *
     *  @return a list containing the supported docet search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDocetSearchRecordTypes();


    /**
     *  Tests if the given docet search record type is supported. 
     *
     *  @param  docetSearchRecordType a <code> Type </code> indicating a docet 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> docetSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDocetSearchRecordType(org.osid.type.Type docetSearchRecordType);
}
