//
// org.osid.course.syllabus.Docet
//
//     The OSID Java specification for org.osid.course.syllabus.Docet.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>An <code> Docet </code> is an <code> OsidRelationship </code> between a 
 *  <code> Module </code> and an <code> ActivityUnit. </code> A <code> Docet 
 *  </code> may represent a descriptive portion of an in-class lesson plan, an 
 *  assignment, or an assessment. A Docet may exist at any level of 
 *  granularity. A Docet may cover an entire Module or there may be lots of 
 *  Docets specific to fine-grained learning objectives. </p>
 */

public interface Docet
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Ids </code> of the learning module. 
     *
     *  @return the learning module <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getModuleId();


    /**
     *  Gets the learning module 
     *
     *  @return the learning module 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.Module getModule()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the activity unit. 
     *
     *  @return the activity unit <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getActivityUnitId();


    /**
     *  Gets the activity unit. 
     *
     *  @return the activity unit 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.ActivityUnit getActivityUnit()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the learning objectives. 
     *
     *  @return the learning objective <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getLearningObjectiveIds();


    /**
     *  Gets the learning objectives. 
     *
     *  @return the learning objectives 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getLearningObjectives()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this <code> Docet </code> occurs within an <code> Activity 
     *  </code> or it outlines efforts spent outside a convened activity. In 
     *  class docets can be used to align the estimated duration with the 
     *  schedule of activities. 
     *
     *  @return <code> true </code> if this occurs within an activity, <code> 
     *          false </code> if occurs outside a convened activity 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isInClass();


    /**
     *  Gets the estimated duration. 
     *
     *  @return the duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getDuration();


    /**
     *  Tests if this <code> Docet </code> has a reading materials expressed 
     *  as <code> Assets. </code> 
     *
     *  @return <code> true </code> if assets are avilable, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAssets();


    /**
     *  Gets a list of asset materials distributed to the students. 
     *
     *  @return the asset <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasAssets() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssetIds();


    /**
     *  Gets the assets distributed to the students. 
     *
     *  @return a list of assets 
     *  @throws org.osid.IllegalStateException <code> hasAssets() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetList getAssets()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this <code> Docet </code> has a quiz or assignment expressed 
     *  as an <code> Assessment </code> . 
     *
     *  @return <code> true </code> if assessments are avilable, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasAssessments();


    /**
     *  Gets a list of assessments. 
     *
     *  @return the assessment <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasAssessments() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssessmentIds();


    /**
     *  Gets the assessments. 
     *
     *  @return a list of assessments 
     *  @throws org.osid.IllegalStateException <code> hasAssessments() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAssessments()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the docet record corresponding to the given <code> Docet </code> 
     *  record <code> Type. </code> This method must be used to retrieve an 
     *  object implementing the requested record. The <code> docetRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(docetRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  docetRecordType the type of docet record to retrieve 
     *  @return the docet record 
     *  @throws org.osid.NullArgumentException <code> docetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(docetRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.records.DocetRecord getDocetRecord(org.osid.type.Type docetRecordType)
        throws org.osid.OperationFailedException;
}
