//
// org.osid.course.syllabus.DocetForm
//
//     The OSID Java specification for org.osid.course.syllabus.DocetForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This is the form for creating and updating <code> Docets. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> DocetAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface DocetForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for the learning obectives. 
     *
     *  @return metadata for the objectives 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLearningObjectivesMetadata();


    /**
     *  Sets the learning objectives. 
     *
     *  @param  objectiveIds the new objectives 
     *  @throws org.osid.InvalidArgumentException <code> objectiveIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> objectiveIds </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> objectiveIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLearningObjectives(org.osid.id.IdList objectiveIds);


    /**
     *  Clears the in class flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLearningObjectives();


    /**
     *  Gets the metadata for the in class flag. 
     *
     *  @return metadata for the in class flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInClassMetadata();


    /**
     *  Sets the in class flag. 
     *
     *  @param  inClass the new in class flag 
     *  @throws org.osid.InvalidArgumentException <code> inClass </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> inClass </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInClass(boolean inClass);


    /**
     *  Clears the in class flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInClass();


    /**
     *  Gets the metadata for the duration. 
     *
     *  @return metadata for the duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDurationMetadata();


    /**
     *  Sets the duration. 
     *
     *  @param  duration the new duration 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> duration </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDuration(org.osid.calendaring.Duration duration);


    /**
     *  Clears the duration. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDuration();


    /**
     *  Gets the metadata for the assets. 
     *
     *  @return metadata for the assets 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAssetsMetadata();


    /**
     *  Sets the assets. 
     *
     *  @param  assetIds the new assets 
     *  @throws org.osid.InvalidArgumentException <code> assetIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> assetIds </code> cannot be 
     *          modified 
     *  @throws org.osid.NullArgumentException <code> assetIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAssets(org.osid.id.IdList assetIds);


    /**
     *  Clears the assets. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssets();


    /**
     *  Gets the metadata for the assessments. 
     *
     *  @return metadata for the assessments 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAssessmentsMetadata();


    /**
     *  Sets the assessments. 
     *
     *  @param  assessmentIds the new assessments 
     *  @throws org.osid.InvalidArgumentException <code> assessmentIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> assessmentIds </code> cannot 
     *          be modified 
     *  @throws org.osid.NullArgumentException <code> assessmentIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAssessments(org.osid.id.IdList assessmentIds);


    /**
     *  Clears the assessments. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssessments();


    /**
     *  Gets the <code> DocetFormRecord </code> corresponding to the given 
     *  docet record <code> Type. </code> 
     *
     *  @param  docetRecordType the docet record type 
     *  @return the docet form record 
     *  @throws org.osid.NullArgumentException <code> docetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(docetRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.records.DocetFormRecord getDocetFormRecord(org.osid.type.Type docetRecordType)
        throws org.osid.OperationFailedException;
}
