//
// org.osid.course.syllabus.DocetSearchSession
//
//     The OSID Java specification for org.osid.course.syllabus.DocetSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This session provides methods for searching <code> Docet </code> 
 *  objects. The search query is constructed using the <code> DocetQuery. 
 *  </code> The docet record <code> Type </code> also specifies the record for 
 *  the docet query. </p> 
 *  
 *  <p> <code> getDocetsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Docet </code> elements. A more advanced search 
 *  may be performed with <code> getDocetsBySearch(). </code> It accepts an 
 *  <code> DocetSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getDocetsBySearch() </code> returns an <code> 
 *  DocetSearchResults </code> that can be used to access the resulting <code> 
 *  DocetList </code> or be used to perform a search within the result set 
 *  through <code> DocetSearch. </code> </p> 
 *  
 *  <p> Docetsmay have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> DocetQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface DocetSearchSession
    extends org.osid.course.syllabus.DocetQuerySession {


    /**
     *  Gets a docet search. 
     *
     *  @return the docet search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetSearch getDocetSearch();


    /**
     *  Gets a docet search order. The <code> DocetSearchOrder </code> is 
     *  supplied to an <code> DocetSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the docet search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetSearchOrder getDocetSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  docetQuery the docet query 
     *  @param  docetSearch the docet search 
     *  @return the docet search results 
     *  @throws org.osid.NullArgumentException <code> docetQuery </code> or 
     *          <code> docetSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> docetQuery </code> or 
     *          <code> docetSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetSearchResults getDocetsBySearch(org.osid.course.syllabus.DocetQuery docetQuery, 
                                                                         org.osid.course.syllabus.DocetSearch docetSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a docet query from an inspector. The inspector is available from 
     *  an <code> DocetSearchResults. </code> 
     *
     *  @param  docetQueryInspector a docet query inspector 
     *  @return the course catalog query 
     *  @throws org.osid.NullArgumentException <code> docetQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> docetQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.DocetQuery getDocetQueryFromInspector(org.osid.course.syllabus.DocetQueryInspector docetQueryInspector);
}
