//
// org.osid.course.syllabus.ModuleCourseCatalogSession
//
//     The OSID Java specification for org.osid.course.syllabus.ModuleCourseCatalogSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This session provides methods to retrieve <code> Module </code> to 
 *  <code> CourseCatalog </code> mappings. A <code> Module </code> may appear 
 *  in multiple <code> Course Catalogs. </code> Each <code> CourseCatalog 
 *  </code> may have its own authorizations governing who is allowed to look 
 *  at it. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface ModuleCourseCatalogSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of module/course catalog 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intendedas a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupModuleCourseCatalogMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCourseCatalogView();


    /**
     *  A complete view of the <code> Module </code> and <code> CourseCatalog 
     *  </code> returns is desired. Methods will return what is requested or 
     *  result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCourseCatalogView();


    /**
     *  Gets the list of Module Ids associated with an <code> CourseCatalog. 
     *  </code> 
     *
     *  @param  courseCatalogId <code> Id </code> of an <code> CourseCatalog. 
     *          </code> 
     *  @return list of related module <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> courseCatalogId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getModuleIdsByCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Modules </code> associated with an <code> 
     *  CourseCatalog. </code> 
     *
     *  @param  courseCatalogId <code> Id </code> of an <code> CourseCatalog 
     *          </code> 
     *  @return list of related modules 
     *  @throws org.osid.NotFoundException <code> courseCatalogId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> courseCatalogId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleList getModulesByCourseCatalog(org.osid.id.Id courseCatalogId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Module Ids </code> corresponding to a list of 
     *  <code> CourseCatalog </code> objects. 
     *
     *  @param  courseCatalogIds list of course catalog <code> Ids </code> 
     *  @return list of module <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> courseCatalogIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getModuleIdsByCourseCatalogs(org.osid.id.IdList courseCatalogIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Modules </code> corresponding to a list of 
     *  <code> Course Catalogs. </code> 
     *
     *  @param  courseCatalogIds list of course catalog <code> Ids </code> 
     *  @return list of modules 
     *  @throws org.osid.NullArgumentException <code> courseCatalogIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.ModuleList getModulesByCourseCatalogs(org.osid.id.IdList courseCatalogIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> CourseCatalog </code> <code> Ids </code> 
     *  mapped to a <code> Module. </code> 
     *
     *  @param  moduleId <code> Id </code> of a <code> Module </code> 
     *  @return list of course catalog <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> moduleId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> moduleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCourseCatalogIdsByModule(org.osid.id.Id moduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> CourseCatalog </code> objects mapped to a 
     *  <code> Module. </code> 
     *
     *  @param  moduleId <code> Id </code> of a <code> Module </code> 
     *  @return list of course catalogs 
     *  @throws org.osid.NotFoundException <code> moduleId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> moduleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseCatalogList getCourseCatalogsByModule(org.osid.id.Id moduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
