//
// org.osid.course.syllabus.ModuleSearchOrder
//
//     The OSID Java specification for org.osid.course.syllabus.ModuleSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface ModuleSearchOrder
    extends org.osid.OsidGovernatorSearchOrder,
            org.osid.OsidSubjugateableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the syllabus. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySyllabus(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a syllabus order is available. 
     *
     *  @return <code> true </code> if a syllabus order is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSyllabusSearchOrder();


    /**
     *  Gets the syllabus order. 
     *
     *  @return the syllabus search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSyllabusSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCourseSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.course.syllabus.SyllabusSearchOrder getSyllabusSearchOrder();


    /**
     *  Gets the module search order record corresponding to the given module 
     *  record <code> Type. </code> Multiple retrievals return the same 
     *  underlying object. 
     *
     *  @param  moduleRecordType a module record type 
     *  @return the module search order record 
     *  @throws org.osid.NullArgumentException <code> moduleRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(moduleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.records.ModuleSearchOrderRecord getModuleSearchOrderRecord(org.osid.type.Type moduleRecordType)
        throws org.osid.OperationFailedException;
}
