//
// org.osid.course.syllabus.SyllabusReceiver
//
//     The OSID Java specification for org.osid.course.syllabus.SyllabusReceiver.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>The syllabus receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new or deleted syllabi. </p>
 */

public interface SyllabusReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new syllabi. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  syllabusIds the <code> Ids </code> of the new syllabi 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newSyllabi(org.osid.id.Id notificationId, 
                           org.osid.id.IdList syllabusIds);


    /**
     *  The callback for notifications of updated syllabi. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  syllabusIds the <code> Ids </code> of the updated syllabi 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedSyllabi(org.osid.id.Id notificationId, 
                               org.osid.id.IdList syllabusIds);


    /**
     *  the callback for notification of deleted syllabi. 
     *
     *  @param  notificationId the notification <code> Id </code> 
     *  @param  syllabusIds the <code> Ids </code> of the deleted syllabi 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedSyllabi(org.osid.id.Id notificationId, 
                               org.osid.id.IdList syllabusIds);
}
