//
// org.osid.course.syllabus.SyllabusSearchSession
//
//     The OSID Java specification for org.osid.course.syllabus.SyllabusSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus;


/**
 *  <p>This session provides methods for searching <code> Syllabus </code> 
 *  objects. The search query is constructed using the <code> SyllabusQuery. 
 *  </code> The syllabus record <code> Type </code> also specifies the record 
 *  for the syllabus query. </p> 
 *  
 *  <p> <code> getSyllabiByQuery() </code> is the basic search method and 
 *  returns a list of <code> CourseCatalog </code> elements. A more advanced 
 *  search may be performed with <code> getSyllabiBySearch(). </code> It 
 *  accepts a <code> SyllabusSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getSyllabiBySearch() </code> returns a <code> 
 *  SyllabusSearchResults </code> that can be used to access the resulting 
 *  <code> SyllabusList </code> or be used to perform a search within the 
 *  result set through <code> SyllabusSearch. </code> </p> 
 *  
 *  <p> Syllabi may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> SyllabusQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface SyllabusSearchSession
    extends org.osid.course.syllabus.SyllabusQuerySession {


    /**
     *  Gets a syllabus search. 
     *
     *  @return the syllabus search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.SyllabusSearch getSyllabusSearch();


    /**
     *  Gets a syllabus search order. The <code> SyllabusSearchOrder </code> 
     *  is supplied to a <code> SyllabusSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the syllabus search order interface 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.SyllabusSearchOrder getSyllabusSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  syllabusQuery the syllabus query 
     *  @param  syllabusSearch the syllabus search 
     *  @return the syllabus search results 
     *  @throws org.osid.NullArgumentException <code> syllabusQuery </code> or 
     *          <code> syllabusSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> syllabusQuery </code> or 
     *          <code> syllabusSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.SyllabusSearchResults getSyllabiBySearch(org.osid.course.syllabus.SyllabusQuery syllabusQuery, 
                                                                             org.osid.course.syllabus.SyllabusSearch syllabusSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a syllabus query from an inspector. The inspector is available 
     *  from a <code> SyllabusSearchResults. </code> 
     *
     *  @param  syllabusQueryInspector a syllabus query inspector 
     *  @return the syllabus query 
     *  @throws org.osid.NullArgumentException <code> syllabusQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> syllabusQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.SyllabusQuery getSyllabusQueryFromInspector(org.osid.course.syllabus.SyllabusQueryInspector syllabusQueryInspector);
}
