//
// org.osid.course.syllabus.batch.DocetBatchAdminSession
//
//     The OSID Java specification for org.osid.course.syllabus.batch.DocetBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.course.syllabus.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Docets </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Docet, </code> an <code> DocetForm </code> is requested using 
 *  <code> getDocetFormsForCreate() </code> specifying the desired module, 
 *  activity unit, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> DocetForms </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once an <code> 
 *  DocetForm </code> is submiited to a create operation, it cannot be reused 
 *  with another create operation unless the first operation was unsuccessful. 
 *  Each <code> DocetForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> The <code> DocetForms </code> returned from <code> 
 *  getDocetFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> DocetForm. </code> In 
 *  the case where there may be duplicates, any <code> DocetForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> DocetForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> DocetForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createDocets(), 
 *  </code> errors specific to an individual <code> DocetForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> DocetForm 
 *  </code> through the <code> DocetForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> DocetForms </code> are requested to the <code> 
 *  Docet </code> <code> Id </code> that is to be updated using <code> 
 *  getDocetFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> DocetForm </code> may be used to link the request. Similarly, 
 *  the <code> DocetForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> DocetForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> DocetForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> DocetForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateDocets(), 
 *  </code> errors specific to an individual <code> DocetForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> DocetForm 
 *  </code> through the <code> DocetForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Docets </code> in bulk. To unmap 
 *  an <code> Docet </code> from the current <code> CourseCatalog, </code> the 
 *  <code> DocetCourseCatalogAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Docet </code> itself thus 
 *  removing it from all known <code> CourseCatalog </code> catalogs. Bulk 
 *  delete operations return the results in <code> DeleteResponses. </code> 
 *  </p>
 */

public interface DocetBatchAdminSession
    extends org.osid.course.syllabus.DocetAdminSession {


    /**
     *  Gets the docet forms for creating a bunch of new docets. A form is 
     *  returned for each activity and resource pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  docetRecordTypes array of docet record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the docet forms 
     *  @throws org.osid.NotFoundException a <code> moduleId </code> or <code> 
     *          activityUnitId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          docetRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.batch.DocetBatchFormList getDocetFormsForCreate(org.osid.course.syllabus.batch.DocetPeerList peers, 
                                                                                    org.osid.type.Type[] docetRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Docets. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  docetForms the docet forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> docetForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createDocets(org.osid.course.syllabus.batch.DocetBatchFormList docetForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the docet forms for updating an existing set of docets. A new 
     *  docet form should be requested for each update transaction. 
     *
     *  @param  docetIds the <code> Ids </code> of the <code> Docet </code> 
     *  @return the docet form 
     *  @throws org.osid.NotFoundException an <code> docetId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> docetIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.syllabus.batch.DocetBatchFormList getDocetFormsForUpdate(org.osid.id.IdList docetIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing docets. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  docetForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> docetForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateDocets(org.osid.course.syllabus.batch.DocetBatchFormList docetForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Docets </code> in this <code> CourseCatalog </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllDocets()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes docets for the given <code> Ids. </code> 
     *
     *  @param  docetIds the <code> Ids </code> of the docets to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> docetIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteDocets(org.osid.id.IdList docetIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes docets for the given module. 
     *
     *  @param  moduleId an <code> Id </code> of a module 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> moduleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteDocetsForModule(org.osid.id.Id moduleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes docets for the given activity unit. 
     *
     *  @param  activityUnitId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> activityUnitId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteDocetsForActivityUnit(org.osid.id.Id activityUnitId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes docets expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveDocetsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Docet </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Docet </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another docet, it is reassigned to the given docet <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasDocets(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
