//
// org.osid.dictionary.DictionaryManager
//
//     The OSID Java specification for org.osid.dictionary.DictionaryManager.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>The dictionary manager provides access to dictionary sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> EntryRetrievalSession: </code> a basic session for 
 *      retrieving dictoonary entries </li> 
 *      <li> <code> EntryLookupSession: </code> a session for looking up 
 *      dictionary entries </li> 
 *      <li> <code> EntryQuerySession: </code> a session for querying 
 *      dictionary entries </li> 
 *      <li> <code> EntrySearchSession: </code> a session for searching for 
 *      dictionary entries </li> 
 *      <li> <code> EntryAdminSession: </code> a session for creating, 
 *      updating, and delting dictionary entries </li> 
 *      <li> <code> EntryNotificationSession: </code> a session for 
 *      subscribing to notifications about dictionary entries </li> 
 *      <li> <code> EntryDictionarySession: </code> a session to look up entry 
 *      to dictionary mappings </li> 
 *      <li> <code> EntryDictionaryAssignmentSession: </code> a session to 
 *      manage entry to dictionary mappings </li> 
 *      <li> <code> EntrySmartDictionarySession: </code> a session to manage 
 *      smart entry dictionaries </li> 
 *      <li> <code> DictionaryLookupSession </code> a session for looking up 
 *      dictionaries </li> 
 *      <li> <code> DictionaryQuerySession </code> a session for querying 
 *      dictionaries </li> 
 *      <li> <code> DictionarySearchSession </code> a session for searchin 
 *      gamong dictionaries </li> 
 *      <li> <code> DictionaryAdminSession </code> a session creating, 
 *      updating or deleting dictionaries </li> 
 *      <li> <code> DictionaryNotificationSession: </code> a session for 
 *      subscribing to adds and changes of dictionaries </li> 
 *      <li> <code> DictionaryHierarchySession: </code> a session for 
 *      traversing the hierarchy of dictionaries </li> 
 *      <li> <code> DictionaryHierarchyDesignSession: </code> a session for 
 *      managing the dictionary hierarchy </li> 
 *  </ul>
 *  
 */

public interface DictionaryManager
    extends org.osid.OsidManager,
            org.osid.dictionary.DictionaryProfile {


    /**
     *  Gets the <code> OsidSession </code> used to retrieve dictionary 
     *  entries. 
     *
     *  @return the new <code> EntryRetrievalSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryRetrieval() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryRetrieval() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.EntryRetrievalSession getEntryRetrievalSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to retrieve dictionary 
     *  entries for the specified <code> Dictionary. </code> 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> to use 
     *  @return an <code> EntryRetrievalSession </code> 
     *  @throws org.osid.NotFoundException no <code> Dictionary </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryRetrieval() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryRetrieval() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntryRetrievalSession getEntryRetrievalSessionForDictionary(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to retrieve dictionary 
     *  entries. 
     *
     *  @return an <code> EntryLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryLookup() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.EntryLookupSession getEntryLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to lookup dictionary entries 
     *  for the specified <code> Dictionary. </code> 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> to use 
     *  @return an <code> EntryLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Dictionary </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntryLookupSession getEntryLookupSessionForDictionary(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to query dictionary entries. 
     *
     *  @return an <code> EntryQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.EntryQuerySession getEntryQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to query dictionary entries 
     *  for the specified <code> Dictionary. </code> 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> to use 
     *  @return an <code> EntryQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Dictionary </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntryQuerySession getEntryQuerySessionForDictionary(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to search dictionary entries. 
     *
     *  @return an <code> EntrySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntrySearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntrySearch() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.EntrySearchSession getEntrySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to search dictionary entries 
     *  for the specified <code> Dictionary. </code> 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> to use 
     *  @return an <code> EntrySearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Dictionary </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntrySearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntrySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntrySearchSession getEntrySearchSessionForDictionary(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to administer dictionary 
     *  entries. 
     *
     *  @return an <code> EntryAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.EntryAdminSession getEntryAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to administer dictionary 
     *  entries for the specified <code> Dictionary. </code> 
     *
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> to use 
     *  @return an <code> EntryAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Dictionary </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEntryAdmin() 
     *          </code> os <code> supportsVisibleFederration() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntryAdminSession getEntryAdminSessionForDictionary(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an <code> EntryNotificationSession </code> which is responsible 
     *  for subscribing to entry changes within a default <code> Dictionary. 
     *  </code> 
     *
     *  @param  entryReceiver the notification callback 
     *  @return an <code> EntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> entryReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntryNotificationSession getEntryNotificationSession(org.osid.dictionary.EntryReceiver entryReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> EntryNotificationSession </code> which is responsible 
     *  for subscribing to entry changes for a specified <code> Dictionary. 
     *  </code> 
     *
     *  @param  entryReceiver the notification callback 
     *  @param  dictionaryId the <code> Id </code> of the <code> Dictionary 
     *          </code> to use 
     *  @return an <code> EntryNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Dictionary </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> entryReceiver </code> or 
     *          <code> dictionaryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryNotification () </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntryNotificationSession getEntryNotificationSessionForDictionary(org.osid.dictionary.EntryReceiver entryReceiver, 
                                                                                                 org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving entry to dictionary mappings. 
     *
     *  @return a <code> EntryDictionarySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryDictionary() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryDictionary() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.EntryDictionarySession getEntryDictionarySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning entry to dictionary mappings. 
     *
     *  @return a <code> EntryDictionaryAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntryDictionaryAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryDictionaryAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.dictionary.EntryDictionaryAssignmentSession getEntryDictionaryAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic entry dictionarys. 
     *
     *  @param  dictionaryId the <code> Id </code> of the dictionary 
     *  @return a <code> EntrySmartDictionarySession </code> 
     *  @throws org.osid.NotFoundException <code> dictionaryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEntrySmartDictionary() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntrySmartDictionary() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.EntrySmartDictionarySession getEntrySmartDictionarySession(org.osid.id.Id dictionaryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to lookup dictionaries. 
     *
     *  @return a <code> DictionaryLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionaryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.DictionaryLookupSession getDictionaryLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to query dictionaries. 
     *
     *  @return a <code> DictionaryQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionaryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.DictionaryQuerySession getDictionaryQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to search dictionaries. 
     *
     *  @return a <code> DictionarySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionarySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionarySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.DictionarySearchSession getDictionarySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to administer dictionaries 
     *
     *  @return a <code> DictionaryAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionaryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.DictionaryAdminSession getDictionaryAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> used to receive notifications of 
     *  dictionary changes. 
     *
     *  @param  dictionaryReceiver the notification callback 
     *  @return a <code> DictionaryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> dictionaryReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionaryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.DictionaryNotificationSession getDictionaryNotificationSession(org.osid.dictionary.DictionaryReceiver dictionaryReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets hierarchy service for traversing the <code> Dictionary </code> 
     *  hierarchy. A parent includes all the dictionary entries of its 
     *  children. 
     *
     *  @return a Dictionary <code> HierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryHierarchyTraversal() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented. 
     */

    public org.osid.dictionary.DictionaryHierarchySession getDictionaryHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets hierarchy service for structuring <code> Dictionary </code> 
     *  objects. 
     *
     *  @return a <code> DictionaryHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented. 
     */

    public org.osid.dictionary.DictionaryHierarchyDesignSession getDictionaryHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> DictionaryBatchManager. </code> 
     *
     *  @return a <code> DictionaryBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented. 
     */

    public org.osid.dictionary.batch.DictionaryBatchManager getDictionaryBatchManager()
        throws org.osid.OperationFailedException;
}
