//
// org.osid.dictionary.DictionaryQuery
//
//     The OSID Java specification for org.osid.dictionary.DictionaryQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>This is the query for searching dictionaries. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface DictionaryQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the entry <code> Id. </code> 
     *
     *  @param  entryId an entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> entryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEntryId(org.osid.id.Id entryId, boolean match);


    /**
     *  Clears the entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEntryIdTerms();


    /**
     *  Tests if an <code> EntryQuery </code> is available. 
     *
     *  @return <code> true </code> if an entry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEntryQuery();


    /**
     *  Gets the query for an entry. Multiple retrievale produce a nested 
     *  boolean <code> OR </code> term. 
     *
     *  @return the entry query 
     *  @throws org.osid.UnimplementedException <code> supportsEntryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.EntryQuery getEntryQuery();


    /**
     *  Matches dictionaries with any entry. 
     *
     *  @param  match <code> true </code> to match dictionaries with any 
     *          entry, <code> false </code> to match dictionaries with no 
     *          entry 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEntry(boolean match);


    /**
     *  Clears the entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEntryTerms();


    /**
     *  Sets the dictionary <code> Id </code> for to match dictionaries in 
     *  which the specified dictionary is an acestor. 
     *
     *  @param  dictionaryId a dictionary <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorDictionaryId(org.osid.id.Id dictionaryId, 
                                          boolean match);


    /**
     *  Clears the ancestor dictionary <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorDictionaryIdTerms();


    /**
     *  Tests if a <code> DictionaryQuery </code> is available. 
     *
     *  @return <code> true </code> if a dictionary query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorDictionaryQuery();


    /**
     *  Gets the query for an ancestor dictionary. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the dictionary query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorDictionaryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorDictionaryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.dictionary.DictionaryQuery getAncestorDictionaryQuery();


    /**
     *  Matches a dictionary that has any ancestor. 
     *
     *  @param  match <code> true </code> to match dictionaries with any 
     *          ancestor dictionaries, <code> false </code> to match root 
     *          dictionaries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorDictionary(boolean match);


    /**
     *  Clears the ancestor dictionary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorDictionaryTerms();


    /**
     *  Sets the dictionary <code> Id </code> for to match dictionaries in 
     *  which the specified dictionary is a descendant. 
     *
     *  @param  dictionaryId a dictionary <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantDictionaryId(org.osid.id.Id dictionaryId, 
                                            boolean match);


    /**
     *  Clears the dictionary <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantDictionaryIdTerms();


    /**
     *  Tests if a <code> DictionaryQuery </code> is available. 
     *
     *  @return <code> true </code> if a dictionary query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantDictionaryQuery();


    /**
     *  Gets the query for a descendant dictioonary. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the dictionary query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantDictionaryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantDictionaryQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.dictionary.DictionaryQuery getDescendantDictionaryQuery();


    /**
     *  Matches a dictionary that has any descendant. 
     *
     *  @param  match <code> true </code> to match dictionaries with any 
     *          descendant dictionaries, <code> false </code> to match leaf 
     *          dictionaries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantDictionary(boolean match);


    /**
     *  Clears the dictionary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantDictionaryTerms();


    /**
     *  Gets the dictionary query record corresponding to the given <code> 
     *  Dictionary </code> record <code> Type. </code> Multiple retrievale 
     *  produce a nested boolean <code> OR </code> term. 
     *
     *  @param  dictionaryRecordType a dictionary record type 
     *  @return the dictionary query record 
     *  @throws org.osid.NullArgumentException <code> dictionaryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(dictionaryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.records.DictionaryQueryRecord getDictionaryQueryRecord(org.osid.type.Type dictionaryRecordType)
        throws org.osid.OperationFailedException;
}
