//
// org.osid.dictionary.Entry
//
//     The OSID Java specification for org.osid.dictionary.Entry.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>An <code> Entry </code> contains a key and a value. The key and value 
 *  have a Type such that an entry is identified by the combination of the 
 *  key, key type, and value type. The Type may indicate the key and value are 
 *  simple strings or, more complex objects may be managed that allows for a 
 *  translation from one arbitrary object to another. </p>
 */

public interface Entry
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Type </code> of this entry key. 
     *
     *  @return the key <code> Type </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getKeyType();


    /**
     *  Gets the key of this entry. 
     *
     *  @return the key 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.lang.Object getKey();


    /**
     *  Gets the <code> Type </code> of this entry value. 
     *
     *  @return the value <code> Type </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getValueType();


    /**
     *  Gets the value in this entry. 
     *
     *  @return the value 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.lang.Object getValue();


    /**
     *  Gets the entry record corresponding to the given <code> Entry </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> entryRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(entryRecordType) </code> is <code> true </code> . 
     *
     *  @param  entryRecordType the type of the record to retrieve 
     *  @return the entry record 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(entryRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.records.EntryRecord getEntryRecord(org.osid.type.Type entryRecordType)
        throws org.osid.OperationFailedException;
}
