//
// org.osid.dictionary.EntryAdminSession
//
//     The OSID Java specification for org.osid.dictionary.EntryAdminSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p><code> EntryAdminSession </code> creates, updates and deletes 
 *  dictionary entries. </p>
 */

public interface EntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Dictionary </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Dictionary </code> <code> Id </code> associated 
     *          with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDictionaryId();


    /**
     *  Gets the <code> Dictionary </code> associated with this session. 
     *
     *  @return the <code> Dictionary </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.Dictionary getDictionary()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create entries A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating an <code> Entry </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if entry creation is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEntries();


    /**
     *  Tests if this user can create a single <code> Entry </code> using the 
     *  desired record types. While <code> 
     *  DictionaryManager.getEntryRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Entry. </code> Providing an 
     *  empty array tests if an <code> Entry </code> can be created with no 
     *  records. 
     *
     *  @param  entryRecordTypes array of entry record types 
     *  @return <code> true </code> if <code> Entry </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> entryRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEntryWithRecordTypes(org.osid.type.Type[] entryRecordTypes);


    /**
     *  Gets the entry form for creating new inquiries. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  keyType the <code> Type </code> of the key 
     *  @param  key the key 
     *  @param  valueType the <code> Type </code> of the value 
     *  @param  entryRecordTypes array of entry record types 
     *  @return the entry form 
     *  @throws org.osid.AlreadyExistsException an entry by this <code> key, 
     *          </code> <code> keyType, </code> and <code> valueType </code> 
     *          already exists 
     *  @throws org.osid.NullArgumentException <code> keyType, key, valueType, 
     *          </code> or <code> entryRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          key/value or record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryForm getEntryFormForCreate(org.osid.type.Type keyType, 
                                                               java.lang.Object key, 
                                                               org.osid.type.Type valueType, 
                                                               org.osid.type.Type[] entryRecordTypes)
        throws org.osid.AlreadyExistsException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Entry. </code> 
     *
     *  @param  entryForm the form for this entry 
     *  @return the created entry 
     *  @throws org.osid.IllegalStateException <code> entryForm </code> 
     *          already used in a create transaction. 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> entryForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> entryForm </code> did not 
     *          originate from <code> getEntryFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.Entry createEntry(org.osid.dictionary.EntryForm entryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update entries. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating an <code> Entry </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if entry modification is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateEntries();


    /**
     *  Gets the entry form for updating an existing entry. A new entry form 
     *  should be requested for each update transaction. 
     *
     *  @param  entryId the <code> Id </code> of the <code> Entry </code> 
     *  @return the entry form 
     *  @throws org.osid.NotFoundException <code> entryId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> entryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryForm getEntryFormForUpdate(org.osid.id.Id entryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing <code> Entry. </code> 
     *
     *  @param  entryForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> entryForm </code> 
     *          already used in an update transatcion 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> entryForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> entryyForm </code> did 
     *          not originate from <code> getEntryFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateEntry(org.osid.dictionary.EntryForm entryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Entries. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Entry </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Entry </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteEntries();


    /**
     *  Updates an existing <code> Dictionary </code> entry identified with 
     *  the specified key with the given value. 
     *
     *  @param  entryId the <code> Id </code> of the entry 
     *  @throws org.osid.NotFoundException entry is not found 
     *  @throws org.osid.NullArgumentException <code> entryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteEntry(org.osid.id.Id entryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Entries. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Entry </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageEntryAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Entry </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Entry </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another entry, it is reassigned to the given entry <code> 
     *  Id. </code> 
     *
     *  @param  entryId the <code> Id </code> of an <code> Entry </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> entryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> entryId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasEntry(org.osid.id.Id entryId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
