//
// org.osid.dictionary.EntryQuery
//
//     The OSID Java specification for org.osid.dictionary.EntryQuery.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>This is the query for searching dictionary entries. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface EntryQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the <code> Type </code> for querying keys of a given type. 
     *
     *  @param  keyType the key <code> Type </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> keyType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchKeyType(org.osid.type.Type keyType, boolean match);


    /**
     *  Clears the key type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKeyTypeTerms();


    /**
     *  Matches entries of this key. 
     *
     *  @param  key the key 
     *  @param  keyType the key <code> Type </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> key </code> or <code> 
     *          keyType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchKey(java.lang.Object key, org.osid.type.Type keyType, 
                         boolean match);


    /**
     *  Clears the key terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKeyTerms();


    /**
     *  Sets the <code> Type </code> of this entry value. 
     *
     *  @param  valueType the value <code> Type </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> valueType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValueType(org.osid.type.Type valueType, boolean match);


    /**
     *  Clears the value type terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueTypeTerms();


    /**
     *  Sets the value in this entry. 
     *
     *  @param  value the value 
     *  @param  valueType the value <code> Type </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> value </code> or <code> 
     *          valueType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchValue(java.lang.Object value, 
                           org.osid.type.Type valueType, boolean match);


    /**
     *  Clears the value terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearValueTerms();


    /**
     *  Sets the dictionary <code> Id </code> for this query. 
     *
     *  @param  dictionaryId a dictionary <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> dictionaryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDictionaryId(org.osid.id.Id dictionaryId, boolean match);


    /**
     *  Clears the dictionary <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDictionaryIdTerms();


    /**
     *  Tests if a <code> DictionaryQuery </code> is available. 
     *
     *  @return <code> true </code> if a dictionary query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryQuery();


    /**
     *  Gets the query for a dictionary. Multiple retrievals produce a nested 
     *  boolean <code> OR </code> term. 
     *
     *  @return the dictionary query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDictionaryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDictionaryQuery() </code> is <code> true. </code> 
     */

    public org.osid.dictionary.DictionaryQuery getDictionaryQuery();


    /**
     *  Clears the dictionary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDictionaryTerms();


    /**
     *  Gets the entry query record corresponding to the given <code> 
     *  Dictionary </code> record <code> Type. </code> Multiple retrievale 
     *  produce a nested boolean <code> OR </code> term. 
     *
     *  @param  entryRecordType an entry record type 
     *  @return the entry query record 
     *  @throws org.osid.NullArgumentException <code> entryRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(entryRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.records.EntryQueryRecord getEntryQueryRecord(org.osid.type.Type entryRecordType)
        throws org.osid.OperationFailedException;
}
