//
// org.osid.dictionary.EntrySmartDictionarySession
//
//     The OSID Java specification for org.osid.dictionary.EntrySmartDictionarySession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.dictionary;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> EntryQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Dictionary </code> to create a virtual 
 *  collection of <code> Entries. </code> The entries may be sequenced using 
 *  the <code> EntrySearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Dictionary </code> has a default query that matches any 
 *  entry and a default search order that specifies no sequencing. The queries 
 *  may be examined using a <code> EntryQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to a <code> EntryQuery. 
 *  </code> </p>
 */

public interface EntrySmartDictionarySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Dictionary </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Dictionary Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDictionaryId();


    /**
     *  Gets the <code> Dictionary </code> associated with this session. 
     *
     *  @return the <code> Dictionary </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.Dictionary getDictionary()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart dictionarys. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart dictionary management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartDictionaries();


    /**
     *  Gets a entry query. 
     *
     *  @return the entry query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryQuery getEntryQuery();


    /**
     *  Gets a entry search order. 
     *
     *  @return the entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntrySearchOrder getEntrySearchOrder();


    /**
     *  Applies a entry query to this dictionary. 
     *
     *  @param  entryQuery the entry query 
     *  @throws org.osid.NullArgumentException <code> entryQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> entryQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyEntryQuery(org.osid.dictionary.EntryQuery entryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a entry query inspector for this dictionary. 
     *
     *  @return the entry query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryQueryInspector inspectEntryQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a entry search order to this dictionary. 
     *
     *  @param  entrySearchOrder the entry search order 
     *  @throws org.osid.NullArgumentException <code> entrySearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> entrySearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyEntrySequencing(org.osid.dictionary.EntrySearchOrder entrySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a entry query from an inspector. 
     *
     *  @param  entryQueryInspector a entry query inspector 
     *  @return the entry query 
     *  @throws org.osid.NullArgumentException <code> entryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> entryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.dictionary.EntryQuery getEntryQueryFromInspector(org.osid.dictionary.EntryQueryInspector entryQueryInspector);
}
