//
// org.osid.filing.DirectoryEntry
//
//     The OSID Java specification for org.osid.filing.DirectoryEntry.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p><code> DirectoryEntry </code> defines methods in common to both <code> 
 *  File </code> and <code> Directory </code> . The concatenated path and name 
 *  are assumed to be unique. </p>
 */

public interface DirectoryEntry
    extends org.osid.OsidObject {


    /**
     *  Gets the name of this entry. The name does not include the path. If 
     *  this entry represents an alias, the name of the alias is returned. 
     *
     *  @return the entry name 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getName();


    /**
     *  Tests if this entry is an alias. 
     *
     *  @return <code> true </code> if this is an alias, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAlias();


    /**
     *  Gets the full path of this entry. The path includes the name. Path 
     *  components are separated by a /. If this entry represents an alias, 
     *  the path to the alias is returned. 
     *
     *  @return the path 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getPath();


    /**
     *  Gets the real path of this entry. The path includes the name. Path 
     *  components are separated by a /. If this entry represents an alias, 
     *  the full path to the target file or directory is returned. 
     *
     *  @return the path 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getRealPath();


    /**
     *  Gets the <code> Id </code> of the <code> Agent </code> that owns this 
     *  entry. 
     *
     *  @return the <code> Agent Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOwnerId();


    /**
     *  Gets the <code> Agent </code> that owns this entry. 
     *
     *  @return the <code> Agent </code> 
     *  @throws org.osid.OperationFailedException authentication service not 
     *          available 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getOwner()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the created time of this entry. 
     *
     *  @return the created time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCreatedTime();


    /**
     *  Gets the last modified time of this entry. 
     *
     *  @return the last modified time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getLastModifiedTime();


    /**
     *  Gets the last access time of this entry. 
     *
     *  @return the last access time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getLastAccessTime();
}
