//
// org.osid.filing.DirectoryEntryQuery
//
//     The OSID Java specification for org.osid.filing.DirectoryEntryQuery.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p><code> DirectoryEntryQuery </code> defines methods in common to both 
 *  <code> FileQuery </code> and <code> DirectoryQuery. </code> </p>
 */

public interface DirectoryEntryQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches entry names. Supplying multiple strings behaves like a boolean 
     *  <code> AND </code> among the elements each which must correspond to 
     *  the <code> stringMatchType. </code> An <code> OR </code> can be 
     *  performed with multiple queries. 
     *
     *  @param  name name to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> name </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> name </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchName(String name, org.osid.type.Type stringMatchType, 
                          boolean match);


    /**
     *  Clears the name terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNameTerms();


    /**
     *  Matches an absolute pathname of a directory entry. Supplying multiple 
     *  strings behaves like a boolean <code> AND </code> among the elements 
     *  each which must correspond to the <code> stringMatchType. </code> An 
     *  <code> OR </code> can be performed with multiple queries. 
     *
     *  @param  path path to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> name </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> path </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPath(String path, org.osid.type.Type stringMatchType, 
                          boolean match);


    /**
     *  Clears the path terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathTerms();


    /**
     *  Tests if a <code> DirectoryQuery </code> is available. 
     *
     *  @return <code> true </code> if a directory query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDirectoryQuery();


    /**
     *  Gets the query for a directory to match the parent directory. There is 
     *  only one <code> DirectoryQuery </code> per <code> 
     *  DifrectoryEntryQuery. </code> Multiple retrievals return the same 
     *  object. 
     *
     *  @return the directory query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryQuery() </code> is <code> true. </code> 
     */

    public org.osid.filing.DirectoryQuery getDirectoryQuery();


    /**
     *  Clears the directory terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDirectoryTerms();


    /**
     *  Matches aliases only. 
     *
     *  @param  match <code> true </code> to match aliases, <code> false 
     *          </code> to match target files 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAliases(boolean match);


    /**
     *  Matches a file that has any aliases. 
     *
     *  @param  match <code> true </code> to match any alias, <code> false 
     *          </code> to match objects with no aliases 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAliases(boolean match);


    /**
     *  Clears the aliases terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAliasesTerms();


    /**
     *  Matches files whose entries are owned by the given agent id. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOwnerId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the owner <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOwnerIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available for querying 
     *  agents. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOwnerQuery();


    /**
     *  Gets the query for an agent. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> supportsAgentQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgentQuery() </code> is <code> true. </code> 
     */

    public org.osid.authentication.AgentQuery getOwnerQuery();


    /**
     *  Clears the owner terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOwnerTerms();


    /**
     *  Match directory entries that are created between the specified time 
     *  period inclusive. 
     *
     *  @param  start start time of the query 
     *  @param  end end time of the query 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is les 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreatedTime(org.osid.calendaring.DateTime start, 
                                 org.osid.calendaring.DateTime end, 
                                 boolean match);


    /**
     *  Clears the created time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatedTimeTerms();


    /**
     *  Match directory entries that are modified between the specified time 
     *  period inclusive. 
     *
     *  @param  start start time of the query 
     *  @param  end end time of the query 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is les 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchModifiedTime(org.osid.calendaring.DateTime start, 
                                  org.osid.calendaring.DateTime end, 
                                  boolean match);


    /**
     *  Clears the modified time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModifiedTimeTerms();


    /**
     *  Match directory entries that were last accessed between the specified 
     *  time period. 
     *
     *  @param  start start time of the query 
     *  @param  end end time of the query 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is les 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLastAccessTime(org.osid.calendaring.DateTime start, 
                                    org.osid.calendaring.DateTime end, 
                                    boolean match);


    /**
     *  Clears the last access time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLastAccessTimeTerms();
}
