//
// org.osid.filing.DirectoryNotificationSession
//
//     The OSID Java specification for org.osid.filing.DirectoryNotificationSession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Directories. </code> This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> Two view are defined in this session: </p> 
 *  
 *  <p> federated view: includes notifications of directories located in 
 *  descendants of this directory </p> 
 *  
 *  <p> isolated view: includes notifcations of directories in this directory 
 *  only </p>
 */

public interface DirectoryNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Id </code> of this directory. 
     *
     *  @return the <code> Id </code> of this directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDirectoryId();


    /**
     *  Gets the <code> Directory </code> associated with this session. 
     *
     *  @return the <code> Directory </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Directory </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForDirectoryNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include directories in directories which are children of this 
     *  directory. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDirectoryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this diretory only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDirectoryView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeDirectoryNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableDirectoryNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableDirectoryNotifications();


    /**
     *  Acknowledge a directory notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeDirectoryNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new directories. <code> 
     *  DirectoryReceiver.newDirectories() </code> is invoked when a new 
     *  <code> Directory </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewDirectories()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated directories. <code> 
     *  DirectoryReceiver.changedDirectories() </code> is invoked when a file 
     *  is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedDirectories()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated file. <code> 
     *  DirectoryReceiver.changedDirectories() </code> is invoked when the 
     *  specified directory is changed. 
     *
     *  @param  directoryId the <code> Id </code> of the directory to monitor 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedDirectory(org.osid.id.Id directoryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted directories. <code> 
     *  DirectoryReceiver.deletedDirectories() </code> is invoked when a 
     *  directory is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedDirectories()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted directory. <code> 
     *  DirectoryReceiver.changedDirectories() </code> is invoked when the 
     *  specified directory is deleted. 
     *
     *  @param  directoryId the <code> Id </code> of the directory to monitor 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedDirectory(org.osid.id.Id directoryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
