//
// org.osid.filing.DirectoryReceiver
//
//     The OSID Java specification for org.osid.filing.DirectoryReceiver.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>The directory receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted directories. </p> 
 *  
 *  <p> An example showing how to receive notifications of new directories 
 *  created under a user's home directory. </p> 
 *  
 *  <pre>
 *       
 *       
 *       notificationSession = manager.getDirectoryNotificationSessionForDirectory(myReceiver, "/Users/tom");
 *       notificationSession.useFederatedDirectoryView();
 *       notificationSession.registerForNewDirectories();
 *       
 *                   
 *       
 *  </pre>
 *  
 *  
 *  <pre>
 *       
 *       
 *       class myReceiver {
 *           void newDirectories(osid.id.IdList directoryIds) {
 *               while (directoryIds.hasNext()) {
 *                  osid.filing.Directory directory = lookupSession.getDirectory(directoryIds.getNextId());
 *                  print "new directory created: " + directory.getPath());
 *               }
 *       
 *               notificationSession.acknowledgeDiectoryNotification(notificationId);
 *           }
 *       
 *           void changedDirectories(osid.id.IdList directoryIds) {}
 *           void deletedDirectories(osid.id.IdList directoryIds) {}
 *           void up() {}
 *           void down() {}
 *       }
 *       
 *                   
 *       
 *  </pre>
 *  
 */

public interface DirectoryReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new directories. 
     *
     *  @param  notificationId the notification Id 
     *  @param  directoryIds the <code> Ids </code> of the new directories 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDirectories(org.osid.id.Id notificationId, 
                               org.osid.id.IdList directoryIds);


    /**
     *  The callback for notification of updated directories. 
     *
     *  @param  notificationId the notification Id 
     *  @param  directoryIds the <code> Ids </code> of the new directories 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedDirectories(org.osid.id.Id notificationId, 
                                   org.osid.id.IdList directoryIds);


    /**
     *  the callback for notification of deleted directories. 
     *
     *  @param  notificationId the notification Id 
     *  @param  directoryIds the <code> Ids </code> of the new directories 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDirectories(org.osid.id.Id notificationId, 
                                   org.osid.id.IdList directoryIds);
}
