//
// org.osid.filing.FileLookupSession
//
//     The OSID Java specification for org.osid.filing.FileLookupSession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session defines methods for looking up on files in the current 
 *  directory. </p> 
 *  
 *  <p> This session defines the following views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> federated directory view: searches include entries in directories 
 *      of which this directory is an ancestor </li> 
 *      <li> isolated directory view: lookups are restricted to entries in 
 *      this directory only </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data out of sync. Some 
 *  administrative applications may need to know whether it had retrieved an 
 *  entire set of objects and may sacrifice some interoperability for the sake 
 *  of precision using the plenary view. </p>
 */

public interface FileLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Id </code> of this directory. 
     *
     *  @return the <code> Id </code> of this directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDirectoryId();


    /**
     *  Gets the directory associated with this session. 
     *
     *  @return the directory associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform entry lookups. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupFiles();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeFileView();


    /**
     *  A complete view of the file returns is desired. Methods will return 
     *  what is requested or result in an error. This view is used when 
     *  greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryFileView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in directories which are children of this directory. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDirectoryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this directory only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDirectoryView();


    /**
     *  Gets a specified file or alias to the file. 
     *
     *  @param  fileId the <code> Id </code> to the file 
     *  @return the file 
     *  @throws org.osid.NotFoundException <code> fileId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> fileId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.File getFile(org.osid.id.Id fileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FileList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  files specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Fies </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  fileIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> File </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> fileIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileList getFilesByIds(org.osid.id.IdList fileIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FileList </code> corresponding to the given file genus 
     *  <code> Type </code> which does not include files of genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known files or an error results. Otherwise, 
     *  the returned list may contain only those files that are accessible 
     *  through this session. 
     *
     *  @param  fileGenusType a file genus type 
     *  @return the returned <code> File list </code> 
     *  @throws org.osid.NullArgumentException <code> fileGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileList getFilesByGenusType(org.osid.type.Type fileGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FileList </code> corresponding to the given file genus 
     *  <code> Type </code> and include any additional files with genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known files or an error results. Otherwise, 
     *  the returned list may contain only those files that are accessible 
     *  through this session. 
     *
     *  @param  fileGenusType a file genus type 
     *  @return the returned <code> File </code> list 
     *  @throws org.osid.NullArgumentException <code> fileGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileList getFilesByParentGenusType(org.osid.type.Type fileGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> FileList </code> corresponding to the given file record 
     *  <code> Type. </code> The set of files implementing the given record 
     *  type is returned. <code> </code> In plenary mode, the returned list 
     *  contains all known files or an error results. Otherwise, the returned 
     *  list may contain only those files that are accessible through this 
     *  session. 
     *
     *  @param  fileRecordType a file record type 
     *  @return the returned <code> File </code> list 
     *  @throws org.osid.NullArgumentException <code> fileRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileList getFilesByRecordType(org.osid.type.Type fileRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of files and aliases to files in this directory. In a 
     *  federated view, this method returns all files in descendant 
     *  directories. In plenary mode, the returned list contains all known 
     *  files or an error results. Otherwise, the returned list may contain 
     *  only those files that are accessible through this session. 
     *
     *  @return the list of files in this directory 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileList getFiles()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
