//
// org.osid.filing.FileSearchSession
//
//     The OSID Java specification for org.osid.filing.FileSearchSession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session provides methods for searching among files and directories 
 *  objects. The search query is constructed using a <code> FileQuery. </code> 
 *  </p> 
 *  
 *  <p> <code> getFilesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Files. </code> A more advanced search may be 
 *  performed with <code> getFilesBySearch(). </code> It accepts a <code> 
 *  FileSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getFilesBySearch() </code> returns an <code> FileSearchResults </code> 
 *  that can be used to access the resulting <code> FileList </code> or be 
 *  used to perform a search within the result set through <code> FileSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> federated directory view: searches include entries in directories 
 *      of which this directory is a ancestor </li> 
 *      <li> isolated directory view: searches are restricted this directory 
 *      only </li> 
 *  </ul>
 *  
 */

public interface FileSearchSession
    extends org.osid.filing.FileQuerySession {


    /**
     *  Gets a file search. 
     *
     *  @return the file search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileSearch getFileSearch();


    /**
     *  Gets a file search order. The <code> FileSearchOrder </code> is 
     *  supplied to a <code> FileSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the file search order. 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileSearchOrder getFileSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  fileQuery the file query 
     *  @param  fileSearch the file search 
     *  @return the file search results 
     *  @throws org.osid.NullArgumentException <code> fileQuery </code> or 
     *          <code> fileSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> fileQuery </code> or 
     *          <code> fileSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileSearchResults getFilesBySearch(org.osid.filing.FileQuery fileQuery, 
                                                              org.osid.filing.FileSearch fileSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a file query from an inspector. The inspector is available from a 
     *  <code> FileSearchResults. </code> 
     *
     *  @param  fileQueryInspector a query inspector 
     *  @return the file query 
     *  @throws org.osid.NullArgumentException <code> fileQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> fileQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.FileQuery getFileQueryFromInspector(org.osid.filing.FileQueryInspector fileQueryInspector);
}
