//
// org.osid.filing.FileSystemManagementSession
//
//     The OSID Java specification for org.osid.filing.FileSystemManagementSession.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>This session defines methods for operating on files and directories. 
 *  This session is an expanded version of the <code> DirectoryAdminSession 
 *  </code> that defines methods requiring path names for navigating a 
 *  federation of directories as opposed to working within a single directory 
 *  node. </p> 
 *  
 *  <p> The directory associated with this session is the current working 
 *  directory and any relative path names provided are with respect to this 
 *  directory. Absolute pathnames may be supplied outside this directory. </p>
 */

public interface FileSystemManagementSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Id </code> of this directory. 
     *
     *  @return the <code> Id </code> of this directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDirectoryId();


    /**
     *  Gets the directory associated with this session. 
     *
     *  @return the directory associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform functions in this session. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if filing management methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageFiling();


    /**
     *  Overwrite files if a destination pathname exists. 
     *
     *  @param  overwite <code> true </code> if files can be overwritten, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method is must be implemented. 
     */

    public void overwrite(boolean overwite);


    /**
     *  Create any missing directories for a destination path that does not 
     *  exist. 
     *
     *  @param  create <code> true </code> if intermediate directories should 
     *          be created, <code> false </code> otherwise 
     *  @compliance mandatory This method is must be implemented. 
     */

    public void createMissingPaths(boolean create);


    /**
     *  Moves a file to another path. The detination path may be a file or 
     *  directory. If the destination is a file and exists, the destination is 
     *  only replaced if <code> overwrite() </code> is <code> true. </code> If 
     *  the destination is a directory and does not exist, the missing 
     *  directories are only created if <code> createMissingPaths() </code> is 
     *  <code> true. </code> 
     *
     *  @param  src the source <code> Id </code> of the file 
     *  @param  dst the destination name or path of the directory or file 
     *  @throws org.osid.AlreadyExistsException <code> dst </code> exists and 
     *          <code> overwrite() </code> is <code> false </code> 
     *  @throws org.osid.InvalidArgumentException <code> src </code> is not a 
     *          file 
     *  @throws org.osid.NotFoundException <code> src </code> is not found, or 
     *          the path to <code> dst </code> is not found and <code> 
     *          createMissingPaths() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> src </code> or <code> 
     *          dst </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveFile(org.osid.id.Id src, String dst)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a directory to another path. The destination must be a directory 
     *  and if exists, the source directory is placed as a child to the given 
     *  directory. If a path component in the destination does not exist, the 
     *  path is created is <code> createMissingPaths() </code> is <code> true. 
     *  </code> 
     *
     *  @param  src the source <code> Id </code> of the directory 
     *  @param  dst the destination name or path of the directory 
     *  @throws org.osid.InvalidArgumentException <code> src </code> is not a 
     *          directory 
     *  @throws org.osid.NotFoundException <code> src </code> is not found, or 
     *          the path to <code> dst </code> is not found and <code> 
     *          createMissingPaths() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> src </code> or <code> 
     *          dst </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveDirectory(org.osid.id.Id src, String dst)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Copies a file to another path. The detination path may be a file or 
     *  directory. If the destination is a file and exists, the destination is 
     *  only replaced if <code> overwrite() </code> is <code> true. </code> If 
     *  the destination is a directory and does not exist, the missing 
     *  directories are only created if <code> createMissingPaths() </code> is 
     *  <code> true. </code> 
     *
     *  @param  src the source <code> Id </code> of the file 
     *  @param  dst the destination name or path of the directory or file 
     *  @return the new file 
     *  @throws org.osid.AlreadyExistsException <code> dst </code> exists and 
     *          <code> overwrite() </code> is <code> false </code> 
     *  @throws org.osid.InvalidArgumentException <code> src </code> is not a 
     *          file 
     *  @throws org.osid.NotFoundException <code> src </code> is not found, or 
     *          the path to <code> dst </code> is not found and <code> 
     *          createMissingPaths() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> src </code> or <code> 
     *          dst </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.File copyFile(org.osid.id.Id src, String dst)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Copies a directory and all of its contents to another path. The 
     *  destination must be a directory and if exists, the source directory is 
     *  placed as a child to the given directory. If a path component in the 
     *  destination does not exist, the path is created is <code> 
     *  createMissingPaths() </code> is <code> true. </code> 
     *
     *  @param  src the source <code> Id </code> of the directory 
     *  @param  dst the destination name or path of the directory 
     *  @return the new file 
     *  @throws org.osid.InvalidArgumentException <code> src </code> is not a 
     *          directory 
     *  @throws org.osid.NotFoundException <code> src </code> is not found, or 
     *          the path to <code> dst </code> is not found and <code> 
     *          createMissingPaths() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> src </code> or <code> 
     *          dst </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory copyDirectory(org.osid.id.Id src, 
                                                   String dst)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a link from one file to another. 
     *
     *  @param  fileId the <code> Id </code> of a file 
     *  @param  link the link path 
     *  @return the link 
     *  @throws org.osid.AlreadyExistsException <code> link already </code> 
     *          exists 
     *  @throws org.osid.NotFoundException <code> fileId </code> is not found, 
     *          or the path to <code> link </code> is not found and <code> 
     *          createMissingPaths() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> fileId </code> or <code> 
     *          link </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.File linkFile(org.osid.id.Id fileId, String link)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a link from one directory to another. 
     *
     *  @param  directoryId the <code> Id </code> of a directory 
     *  @param  link the destination path 
     *  @return the link 
     *  @throws org.osid.AlreadyExistsException <code> link already </code> 
     *          exists 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found, or the path to <code> link </code> is not found and 
     *          <code> createMissingPaths() </code> is <code> false </code> 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> or 
     *          <code> link </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory linkDirectory(org.osid.id.Id directoryId, 
                                                   String link)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
