//
// org.osid.filing.FilingManager
//
//     The OSID Java specification for org.osid.filing.FilingManager.
//
// Copyright (C) 2003-2004, 2007 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010, 2014 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing;


/**
 *  <p>The filing manager provides access sessions to retrieve and manage 
 *  files and directories. Some of the federated access methods support 
 *  pathnames in addition to directory <code> Ids. </code> The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> FileSystemSession: </code> a session for traversing file 
 *      systems </li> 
 *      <li> <code> FileSystemManagementSession: </code> a session for 
 *      performing operations across directories </li> 
 *      <li> <code> FileContentSession: </code> a basic session for reading 
 *      and writing a file </li> 
 *      <li> FileLookupSession: a session for looking up files </li> 
 *      <li> <code> FileQuerySession: </code> a session for searching for 
 *      files </li> 
 *      <li> <code> FileSearchSession: </code> a session for searching for 
 *      files </li> 
 *      <li> <code> FileNotificationSession: </code> a session for subscribing 
 *      to changes in files </li> 
 *      <li> <code> FileSmartDirectorySession: </code> a session for managing 
 *      smart directories of files </li> 
 *      <li> <code> DirectoryLookupSession: </code> a session for looking up a 
 *      directories </li> 
 *      <li> <code> DirectorQuerySession: </code> a session for searching for 
 *      directories </li> 
 *      <li> <code> DirectorySearchSession: </code> a session for searching 
 *      for directories </li> 
 *      <li> <code> DirectoryNotificationSession: </code> a session for 
 *      subscribing to changes in directories </li> 
 *  </ul>
 *  
 */

public interface FilingManager
    extends org.osid.OsidManager,
            org.osid.filing.FilingProfile {


    /**
     *  Gets the session for examining file systems. 
     *
     *  @return a <code> FileSystemSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSystem() </code> is <code> true. </code> 
     */

    public org.osid.filing.FileSystemSession getFileSystemSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for exmaning file systems for the given path. 
     *
     *  @param  path the path to a directory 
     *  @return a <code> FileSystemSession </code> 
     *  @throws org.osid.NotFoundException <code> path </code> is not found or 
     *          is not a directory 
     *  @throws org.osid.NullArgumentException <code> path </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSystem() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileSystemSession getFileSystemSessionForPath(String path)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for exmaning file systems for the given directory. 
     *
     *  @param  directoryId the <code> Id </code> of a directory 
     *  @return a <code> FileSystemSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileSystem() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSystem() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileSystemSession getFileSystemSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for manipulating file systems. 
     *
     *  @return a <code> FileSystemManagementSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFileSystemManagement() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSystemManagement() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileSystemManagementSession getFileSystemManagementSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for manipulating files for the given path. 
     *
     *  @param  path the path to a directory 
     *  @return a <code> FileSystemManagementSession </code> 
     *  @throws org.osid.NotFoundException <code> path </code> is not found or 
     *          is not a directory 
     *  @throws org.osid.NullArgumentException <code> path </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFileSystemManagement() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSystemManagement() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileSystemManagementSession getFileSystemManagementSessionForPath(String path)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for manipulating files for the given path. 
     *
     *  @param  directoryId the <code> Id </code> of a directory 
     *  @return a <code> FileSystemManagementSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFileSystemManagement() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSystemManagement() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileSystemManagementSession getFileSystemManagementSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for reading and writing files. 
     *
     *  @return a <code> FileContentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileContent() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileContent() </code> is <code> true. </code> 
     */

    public org.osid.filing.FileContentSession getFileContentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for reading and writing files for the given path. 
     *
     *  @param  path the path to a directory 
     *  @return a <code> FileContentSession </code> 
     *  @throws org.osid.NotFoundException <code> path </code> is not found or 
     *          is not a directory 
     *  @throws org.osid.NullArgumentException <code> path </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileContent() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileContent() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileContentSession getFileContentSessionForPath(String path)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for reading and writing files for the given path. 
     *
     *  @param  directoryId the <code> Id </code> of a directory 
     *  @return a <code> FileContentSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileContent() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileContent() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileContentSession getFileContentSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for looking up files. 
     *
     *  @return the <code> FileLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileLookup() </code> is <code> true. </code> 
     */

    public org.osid.filing.FileLookupSession getFileLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for manipulating files for the given path. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> FileLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileLookupSession getFileLookupSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for querying files. 
     *
     *  @return the <code> FileQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileQuery() </code> is <code> true. </code> 
     */

    public org.osid.filing.FileQuerySession getFileQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a file query session for the specified directory. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> FileQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileQuerySession getFileQuerySessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for searching for files. 
     *
     *  @return the <code> FileSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSearch() </code> is <code> true. </code> 
     */

    public org.osid.filing.FileSearchSession getFileSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a file search session for the specified directory. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> FileSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFileSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileSearchSession getFileSearchSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for receiving messages about changes to files. 
     *
     *  @param  fileReceiver the notification callback 
     *  @return <code> a FileNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> fileReceiver </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFileNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileNotification() </code> is <code> true. </code> 
     */

    public org.osid.filing.FileNotificationSession getFileNotificationSession(org.osid.filing.FileReceiver fileReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a file notification session for the specified directory. 
     *
     *  @param  fileReceiver the notification callback 
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> FileNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> fileReceiver </code> or 
     *          <code> directoryId </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFileNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileNotificationSession getFileNotificationSessionForDirectory(org.osid.filing.FileReceiver fileReceiver, 
                                                                                          org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic directories. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> FileSmartDirectorySession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFileSmartDirectory() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFileSmartDirectory() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.FileSmartDirectorySession getFileSmartDirectorySession(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for examining directories. 
     *
     *  @return a <code> DirectoryLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryLookup() </code> is <code> true. </code> 
     */

    public org.osid.filing.DirectoryLookupSession getDirectoryLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for examining a given directory. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> DirectoryLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.DirectoryLookupSession getDirectoryLookupSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for querying directories. 
     *
     *  @return a <code> DirectoryQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryQuery() </code> is <code> true. </code> 
     */

    public org.osid.filing.DirectoryQuerySession getDirectoryQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for querying directories within a given directory. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> DirectoryQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.DirectoryQuerySession getDirectoryQuerySessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for searching for directories. 
     *
     *  @return a <code> DirectorySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectorySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectorySearch() </code> is <code> true. </code> 
     */

    public org.osid.filing.DirectorySearchSession getDirectorySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for searching for directories within a given 
     *  directory. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> DirectorySearchSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectorySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectorySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.DirectorySearchSession getDirectorySearchSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for creating and removing files. 
     *
     *  @return a <code> DirectoryAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.filing.DirectoryAdminSession getDirectoryAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for searching for creating and removing files in the 
     *  given directory. 
     *
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> DirectoryAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryId </code> is 
     *          null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.DirectoryAdminSession getDirectoryAdminSessionForDirectory(org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for receiving messages about changes to directories. 
     *
     *  @param  directoryReceiver the notification callback 
     *  @return a <code> DirectoryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> directoryReceiver 
     *          </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.filing.DirectoryNotificationSession getDirectoryNotificationSession(org.osid.filing.DirectoryReceiver directoryReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for receiving messages about changes to directories 
     *  in the given directory. 
     *
     *  @param  directoryReceiver the notification callback 
     *  @param  directoryId the <code> Id </code> of the directory 
     *  @return a <code> DirectoryNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> directoryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryReceiver 
     *          </code> or <code> directoryId </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectoryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.DirectoryNotificationSession getDirectoryNotificationSessionForDirectory(org.osid.filing.DirectoryReceiver directoryReceiver, 
                                                                                                    org.osid.id.Id directoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> FilingAllocationManager. </code> 
     *
     *  @return a <code> FilingAllocationManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFilingAllocation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFilingAllocation() </code> is <code> true. </code> 
     */

    public org.osid.filing.allocation.FilingAllocationManager getFilingAllocationManager()
        throws org.osid.OperationFailedException;
}
