//
// org.osid.filing.allocation.Allocation
//
//     The OSID Java specification for org.osid.filing.allocation.Allocation.
//
// Copyright (C) 2010 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing.allocation;


/**
 *  <p><code> Allocation </code> represents allocated resources in a file 
 *  system. </p>
 */

public interface Allocation
    extends org.osid.Extensible,
            org.osid.Browsable {


    /**
     *  Gets the absolute path to the directory responsible for these usage 
     *  stats. The return may be a partition or volume containing the 
     *  requested directory. 
     *
     *  @return path name 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getDirectoryPath();


    /**
     *  Gets the directory responsible for these usage stats. The return may 
     *  be a partition, quota controlled directory, or volume containing the 
     *  requested directory. 
     *
     *  @return directory 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.Directory getDirectory();


    /**
     *  Tests if this allocation is assigned to a specific user. 
     *
     *  @return <code> true </code> if this allocation is assigned to a 
     *          specific user, <code> false </code> if this allocation applied 
     *          to all users 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAssignedToUser();


    /**
     *  Gets the agent <code> Id </code> of the user. 
     *
     *  @return the agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isAssignedToUser() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgentId();


    /**
     *  Gets the agent of the user. 
     *
     *  @return the agent 
     *  @throws org.osid.IllegalStateException <code> isAssignedToUser() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the total space in bytes of this allocation. 
     *
     *  @return number of bytes in this allocation 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getTotalSpace();


    /**
     *  Gets the used space in bytes of this allocation. 
     *
     *  @return number of used bytes in this allocation 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getUsedSpace();


    /**
     *  Gets the available space in bytes of this allocation. 
     *
     *  @return number of available bytes in this allocation 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getAvailableSpace();


    /**
     *  Gets the total number of files of this allocation. 
     *
     *  @return number of files in this allocation 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getTotalFiles();


    /**
     *  Gets the used number of files of this allocation. 
     *
     *  @return number of used files in this allocation 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getUsedFiles();


    /**
     *  Gets the available number o files of this allocation. 
     *
     *  @return number of available files in this allocation 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getAvailableFiles();


    /**
     *  Gets the allocation record corresponding to the given <code> 
     *  Allocation </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  allocationRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(allocationRecordType) </code> is <code> true </code> . 
     *
     *  @param  allocationRecordType the allocation record type 
     *  @return the allocation record 
     *  @throws org.osid.NullArgumentException <code> allocationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(allocationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.filing.allocation.records.AllocationRecord getAllocationRecord(org.osid.type.Type allocationRecordType)
        throws org.osid.OperationFailedException;
}
