//
// org.osid.filing.allocation.FilingAllocationProfile
//
//     The OSID Java specification for org.osid.filing.allocation.FilingAllocationProfile.
//
// Copyright (C) 2010 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing.allocation;


/**
 *  <p>The filing allocation profile describes the interoperability among 
 *  filing allocation services. </p>
 */

public interface FilingAllocationProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any dictionary federation is exposed. Federation is exposed 
     *  when a specific dictionary may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of dictionaries appears as a single dictionary. 
     *
     *  @return <code> true </code> if federation is visible <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if filing allocation is supported. 
     *
     *  @return <code> true </code> if a <code> AllocationSession </code> is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAllocation();


    /**
     *  Tests if filing allocation lookup is supported. 
     *
     *  @return <code> true </code> if a <code> AllocationLookupSession 
     *          </code> is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAllocationLookup();


    /**
     *  Tests if quota administration is supported. 
     *
     *  @return <code> true </code> if a <code> AllocationAdminSession </code> 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAllocationAdmin();


    /**
     *  Tests if an allocation <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if a <code> AllocationNotificationSession 
     *          </code> is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAllocationNotification();


    /**
     *  Gets the supported allocation record types. 
     *
     *  @return a list containing the supported <code> Allocation </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAllocationRecordTypes();


    /**
     *  Tests if the given allocation record type is supported. 
     *
     *  @param  allocationRecordType a <code> Type </code> indicating an 
     *          allocation record type 
     *  @return <code> true </code> if the given record <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> allocationRecordType 
     *          </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAllocationRecordType(org.osid.type.Type allocationRecordType);
}
