//
// org.osid.filing.allocation.FilingAllocationProxyManager
//
//     The OSID Java specification for org.osid.filing.allocation.FilingAllocationProxyManager.
//
// Copyright (C) 2010 Ingnescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.filing.allocation;


/**
 *  <p>The filing allocation manager provides access sessions to allocations. 
 *  Methods in this manager support the passing of a <code> Proxy </code> to 
 *  pass information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AllocationSession: </code> a session for accessing usage 
 *      information and quotas for the current user </li> 
 *      <li> <code> AllocationLookupSession: </code> a session for accessing 
 *      usage information and quotas </li> 
 *      <li> <code> AllocationAdminSession </code> a session for assigning 
 *      quotas </li> 
 *      <li> <code> AllocationNotificationSession: </code> a session for 
 *      subscribing to usage warnings and quota changes </li> 
 *  </ul>
 *  
 */

public interface FilingAllocationProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.filing.allocation.FilingAllocationProfile {


    /**
     *  Gets the session for accessing usage and quotas. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AllocationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAllocation() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAllocation() </code> is <code> true. </code> 
     */

    public org.osid.filing.allocation.AllocationSession getAllocationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for accessing usage and quotas for a given directory. 
     *  If the path is an alias, the target directory is used. The path 
     *  indicates the file alias and the real path indicates the target 
     *  directory. 
     *
     *  @param  directoryPath the pathname to the directory 
     *  @param  proxy a proxy 
     *  @return an <code> AllocationSession </code> 
     *  @throws org.osid.InvalidArgumentException <code> directoryPath </code> 
     *          is not a directory or an alias to a directory 
     *  @throws org.osid.NotFoundException <code> directoryPath </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryPath </code> or 
     *          <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAllocation() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAllocation() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.allocation.AllocationSession getAllocationSessionForDirectory(String directoryPath, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for accessing usage and quotas. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AllocationLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAllocationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAllocationLookup() </code> is <code> true. </code> 
     */

    public org.osid.filing.allocation.AllocationLookupSession getAllocationLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for accessing usage and quotas for a given directory. 
     *  If the path is an alias, the target directory is used. The path 
     *  indicates the file alias and the real path indicates the target 
     *  directory. 
     *
     *  @param  directoryPath the pathname to the directory 
     *  @param  proxy a proxy 
     *  @return an <code> AllocationLookupSession </code> 
     *  @throws org.osid.InvalidArgumentException <code> directoryPath </code> 
     *          is not a directory or an alias to a directory 
     *  @throws org.osid.NotFoundException <code> directoryPath </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryPath </code> or 
     *          <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAllocationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAllocationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.allocation.AllocationLookupSession getAllocationLookupSessionForDirectory(String directoryPath, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning quotas. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AllocationAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAllocationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAllocationAdmin() </code> is <code> true. </code> 
     */

    public org.osid.filing.allocation.AllocationAdminSession getAllocationAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning quotas for the given directory. If the 
     *  path is an alias, the target directory is used. The path indicates the 
     *  file alias and the real path indicates the target directory. 
     *
     *  @param  directoryPath the pathname to the directory 
     *  @param  proxy a proxy 
     *  @return an <code> AllocationAdminSession </code> 
     *  @throws org.osid.InvalidArgumentException <code> directoryPath </code> 
     *          is not a directory or an alias to a directory 
     *  @throws org.osid.NotFoundException <code> directoryPath </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directoryPath </code> or 
     *          <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAllocationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAllocationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.allocation.AllocationAdminSession getAllocationAdminSessionForDirectory(String directoryPath, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for receiving messages about changes to directories. 
     *
     *  @param  allocationReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AllocationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> allocationReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAllocationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectoryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.filing.allocation.AllocationNotificationSession getAllocationNotificationSession(org.osid.filing.allocation.AllocationReceiver allocationReceiver, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for receiving messages about usage warnings and quota 
     *  changes for the given directory. If the path is an alias, the target 
     *  directory is used. The path indicates the file alias and the real path 
     *  indicates the target directory. 
     *
     *  @param  allocationReceiver the notification callback 
     *  @param  directoryPath the pathname to the directory 
     *  @param  proxy a proxy 
     *  @return an <code> AllocationNotificationSession </code> 
     *  @throws org.osid.InvalidArgumentException <code> directoryPath </code> 
     *          is not a directory or an alias to a directory 
     *  @throws org.osid.NotFoundException <code> directoryPath </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> allocationReceiver, 
     *          directoryPath </code> or <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAllocationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAllocationNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.filing.allocation.AllocationNotificationSession getAllocationNotificationSessionForDirectory(org.osid.filing.allocation.AllocationReceiver allocationReceiver, 
                                                                                                                 String directoryPath, 
                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
