//
// org.osid.financials.AccountQueryInspector
//
//     The OSID Java specification for org.osid.financials.AccountQueryInspector.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface AccountQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidFederateableQueryInspector {


    /**
     *  Gets the credit balance query terms. 
     *
     *  @return the credit balance query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getCreditBalanceTerms();


    /**
     *  Gets the code query terms. 
     *
     *  @return the code query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getCodeTerms();


    /**
     *  Gets the summary query terms. 
     *
     *  @return the summary query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryQueryInspector[] getSummaryTerms();


    /**
     *  Gets the ancestor account <code> Id </code> query terms. 
     *
     *  @return the ancestor account <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorAccountIdTerms();


    /**
     *  Gets the ancestor account query terms. 
     *
     *  @return the ancestor account terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.AccountQueryInspector[] getAncestorAccountTerms();


    /**
     *  Gets the descendant account <code> Id </code> query terms. 
     *
     *  @return the descendant account <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantAccountIdTerms();


    /**
     *  Gets the descendant account query terms. 
     *
     *  @return the descendant account terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.AccountQueryInspector[] getDescendantAccountTerms();


    /**
     *  Gets the business <code> Id </code> query terms. 
     *
     *  @return the business <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBusinessIdTerms();


    /**
     *  Gets the business query terms. 
     *
     *  @return the business query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.BusinessQueryInspector[] getBusinessTerms();


    /**
     *  Gets the account query inspector record corresponding to the given 
     *  <code> Account </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  accountRecordType an account record type 
     *  @return the account query inspector record 
     *  @throws org.osid.NullArgumentException <code> accountRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(accountRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.AccountQueryInspectorRecord getAccountQueryInspectorRecord(org.osid.type.Type accountRecordType)
        throws org.osid.OperationFailedException;
}
