//
// org.osid.financials.AccountReceiver
//
//     The OSID Java specification for org.osid.financials.AccountReceiver.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>The account receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Account </code> 
 *  objects. </p>
 */

public interface AccountReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new accounts. 
     *
     *  @param  accountIds the <code> Ids </code> of the new <code> Accounts 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAccounts(org.osid.id.IdList accountIds);


    /**
     *  The callback for notifications of new account ancestors. 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Account 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorAccount(org.osid.id.Id accountId, 
                                   org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new account descendants. 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Account 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantAccount(org.osid.id.Id accountId, 
                                     org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated accounts. 
     *
     *  @param  accountIds the <code> Ids </code> of the updated <code> 
     *          Accounts </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedAccounts(org.osid.id.IdList accountIds);


    /**
     *  the callback for notification of deleted accounts. 
     *
     *  @param  accountIds the <code> Ids </code> of the deleted <code> 
     *          Accounts </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAccounts(org.osid.id.IdList accountIds);


    /**
     *  The callback for notifications of deleted account ancestors. 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Account 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorAccount(org.osid.id.Id accountId, 
                                       org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted account descendants. 
     *
     *  @param  accountId the <code> Id </code> of the <code> Account </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Account 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantAccount(org.osid.id.Id accountId, 
                                         org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to an account hierarchy 
     *  where the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredAccountHierarchy();
}
