//
// org.osid.financials.BusinessNotificationSession
//
//     The OSID Java specification for org.osid.financials.BusinessNotificationSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Business </code> objects. This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this sess </p>
 */

public interface BusinessNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Business </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForBusinessNotifications();


    /**
     *  Register for notifications of new businesses. <code> 
     *  BusinessReceiver.newBusinesses() </code> is invoked when a new <code> 
     *  Business </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBusinesses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is added to the specified 
     *  business in the business hierarchy. <code> 
     *  BusinessReceiver.newBusinessAncestor() </code> is invoked when the 
     *  specified business experiences an addition in ancestry. 
     *
     *  @param  businessId the <code> Id </code> of the business to monitor 
     *  @throws org.osid.NullArgumentException <code> businessId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBusinessAncestors(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is added to the specified 
     *  business in the business hierarchy. <code> 
     *  BusinessReceiver.newBusinessDescendant() </code> is invoked when the 
     *  specified business experiences an addition in descendants. 
     *
     *  @param  businessId the <code> Id </code> of the business to monitor 
     *  @throws org.osid.NullArgumentException <code> businessId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewBusinessDescendants(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated businesses. <code> 
     *  BusinessReceiver.changedBusinesses() </code> is invoked when a 
     *  business is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBusinesses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated business. <code> 
     *  BusinessReceiver.changedBusinesses() </code> is invoked when the 
     *  specified business is changed. 
     *
     *  @param  businessId the Id of the <code> Business </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> businessId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedBusiness(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted businesses. <code> 
     *  BusinessReceiver.deletedBusinesses() </code> is invoked when a 
     *  business is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBusinesses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted business. <code> 
     *  BusinessReceiver.deletedBusinesses() </code> is invoked when the 
     *  specified business is deleted. 
     *
     *  @param  businessId the Id of the <code> Business </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> businessId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBusiness(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is removed from the 
     *  specified business in the business hierarchy. <code> 
     *  BusinessReceiver.deletedBusinessAncestor() </code> is invoked when the 
     *  specified business experiences a removal of an ancestor. 
     *
     *  @param  businessId the <code> Id </code> of the business to monitor 
     *  @throws org.osid.NullArgumentException <code> businessId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBusinessAncestors(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is removed from fthe 
     *  specified business in the business hierarchy. <code> 
     *  BusinessReceiver.deletedBusinessDescednant() </code> is invoked when 
     *  the specified business experiences a removal of one of its 
     *  descdendents. 
     *
     *  @param  businessId the <code> Id </code> of the business to monitor 
     *  @throws org.osid.NullArgumentException <code> businessId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedBusinessDescendants(org.osid.id.Id businessId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
