//
// org.osid.financials.FinancialsProfile
//
//     The OSID Java specification for org.osid.financials.FinancialsProfile.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>The financials profile describes the interoperability of financial 
 *  services. </p>
 */

public interface FinancialsProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if visible federation is supported. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up accounts is supported. 
     *
     *  @return <code> true </code> if account lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountLookup();


    /**
     *  Tests if querying accounts is supported. 
     *
     *  @return <code> true </code> if account query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountQuery();


    /**
     *  Tests if searching accounts is supported. 
     *
     *  @return <code> true </code> if account search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountSearch();


    /**
     *  Tests if an account <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if account administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountAdmin();


    /**
     *  Tests if an account <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if account notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountNotification();


    /**
     *  Tests if an account hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if an account hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountHierarchy();


    /**
     *  Tests if account hierarchy design is supported. 
     *
     *  @return <code> true </code> if an account hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountHierarchyDesign();


    /**
     *  Tests if an account cataloging service is supported. 
     *
     *  @return <code> true </code> if account catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountBusiness();


    /**
     *  Tests if an account cataloging service is supported. A cataloging 
     *  service maps accounts to catalogs. 
     *
     *  @return <code> true </code> if account cataloging is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountBusinessAssignment();


    /**
     *  Tests if an account smart business session is available. 
     *
     *  @return <code> true </code> if an account smart business session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountSmartBusiness();


    /**
     *  Tests if looking up activities is supported. 
     *
     *  @return <code> true </code> if activity lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityLookup();


    /**
     *  Tests if querying activities is supported. 
     *
     *  @return <code> true </code> if activity query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Tests if searching activities is supported. 
     *
     *  @return <code> true </code> if activity search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySearch();


    /**
     *  Tests if activity administrative service is supported. 
     *
     *  @return <code> true </code> if activity administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityAdmin();


    /**
     *  Tests if an activity <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if activity notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityNotification();


    /**
     *  Tests if an activity hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if an activity hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityHierarchy();


    /**
     *  Tests if activity hierarchy design is supported. 
     *
     *  @return <code> true </code> if an activity hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityHierarchyDesign();


    /**
     *  Tests if an activity cataloging service is supported. 
     *
     *  @return <code> true </code> if activity catalog is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBusiness();


    /**
     *  Tests if an activity cataloging service is supported. A cataloging 
     *  service maps activities to catalogs. 
     *
     *  @return <code> true </code> if activity cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityBusinessAssignment();


    /**
     *  Tests if an activity smart business session is available. 
     *
     *  @return <code> true </code> if an activity smart business session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySmartBusiness();


    /**
     *  Tests if looking up fiscal periods is supported. 
     *
     *  @return <code> true </code> if fiscal period lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodLookup();


    /**
     *  Tests if querying fiscal periods is supported. 
     *
     *  @return <code> true </code> if fiscal period query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodQuery();


    /**
     *  Tests if searching fiscal periods is supported. 
     *
     *  @return <code> true </code> if fiscal period search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodSearch();


    /**
     *  Tests if fiscal period <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if fiscal period administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodAdmin();


    /**
     *  Tests if a fiscal period <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if fiscal period notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodNotification();


    /**
     *  Tests if a fiscal period cataloging service is supported. 
     *
     *  @return <code> true </code> if fiscal period catalog is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodBusiness();


    /**
     *  Tests if a fiscal period cataloging service is supported. A cataloging 
     *  service maps fiscal periods to catalogs. 
     *
     *  @return <code> true </code> if fiscal period cataloging is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodBusinessAssignment();


    /**
     *  Tests if a fiscal period smart business session is available. 
     *
     *  @return <code> true </code> if a fiscal period smart business session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodSmartBusiness();


    /**
     *  Tests if looking up businesses is supported. 
     *
     *  @return <code> true </code> if business lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessLookup();


    /**
     *  Tests if searching businesses is supported. 
     *
     *  @return <code> true </code> if business search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessSearch();


    /**
     *  Tests if querying businesses is supported. 
     *
     *  @return <code> true </code> if business query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Tests if business administrative service is supported. 
     *
     *  @return <code> true </code> if business administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessAdmin();


    /**
     *  Tests if a business <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if business notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessNotification();


    /**
     *  Tests for the availability of a business hierarchy traversal service. 
     *
     *  @return <code> true </code> if business hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsBusinessHierarchy();


    /**
     *  Tests for the availability of a business hierarchy design service. 
     *
     *  @return <code> true </code> if business hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessHierarchyDesign();


    /**
     *  Tests for the availability of a financials batch service. 
     *
     *  @return <code> true </code> if a financials batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFinancialsBatch();


    /**
     *  Tests for the availability of a financials budgeting service. 
     *
     *  @return <code> true </code> if a financials budgeting service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFinancialsBudgeting();


    /**
     *  Tests for the availability of a financials postng service. 
     *
     *  @return <code> true </code> if a financials posting service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFinancialsPosting();


    /**
     *  Gets the supported <code> Account </code> record types. 
     *
     *  @return a list containing the supported <code> Account </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAccountRecordTypes();


    /**
     *  Tests if the given <code> Account </code> record type is supported. 
     *
     *  @param  accountRecordType a <code> Type </code> indicating an <code> 
     *          Account </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> accountRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountRecordType(org.osid.type.Type accountRecordType);


    /**
     *  Gets the supported <code> Account </code> search record types. 
     *
     *  @return a list containing the supported <code> Account </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAccountSearchRecordTypes();


    /**
     *  Tests if the given <code> Account </code> search record type is 
     *  supported. 
     *
     *  @param  accountSearchRecordType a <code> Type </code> indicating an 
     *          <code> Account </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> accountSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountSearchRecordType(org.osid.type.Type accountSearchRecordType);


    /**
     *  Gets the supported <code> Activity </code> record types. 
     *
     *  @return a list containing the supported <code> Activity </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityRecordTypes();


    /**
     *  Tests if the given <code> Activity </code> record type is supported. 
     *
     *  @param  activityRecordType a <code> Type </code> indicating an <code> 
     *          Activity </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRecordType(org.osid.type.Type activityRecordType);


    /**
     *  Gets the supported <code> Activity </code> search record types. 
     *
     *  @return a list containing the supported <code> Activity </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivitySearchRecordTypes();


    /**
     *  Tests if the given <code> Activity </code> search record type is 
     *  supported. 
     *
     *  @param  activitySearchRecordType a <code> Type </code> indicating an 
     *          <code> Activity </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activitySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySearchRecordType(org.osid.type.Type activitySearchRecordType);


    /**
     *  Gets the supported <code> FiscalPeriod </code> record types. 
     *
     *  @return a list containing the supported <code> FiscalPeriod </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFiscalPeriodRecordTypes();


    /**
     *  Tests if the given <code> FiscalPeriod </code> record type is 
     *  supported. 
     *
     *  @param  fiscalPeriodRecordType a <code> Type </code> indicating an 
     *          <code> FiscalPeriod </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodRecordType(org.osid.type.Type fiscalPeriodRecordType);


    /**
     *  Gets the supported <code> FiscalPeriod </code> search record types. 
     *
     *  @return a list containing the supported <code> FiscalPeriod </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFiscalPeriodSearchRecordTypes();


    /**
     *  Tests if the given <code> FiscalPeriod </code> search record type is 
     *  supported. 
     *
     *  @param  fiscalPeriodSearchRecordType a <code> Type </code> indicating 
     *          a <code> FiscalPeriod </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          fiscalPeriodSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodSearchRecordType(org.osid.type.Type fiscalPeriodSearchRecordType);


    /**
     *  Gets the supported <code> Summary </code> record types. 
     *
     *  @return a list containing the supported <code> Summary </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSummaryRecordTypes();


    /**
     *  Tests if the given <code> Summary </code> record type is supported. 
     *
     *  @param  summaryRecordType a <code> Type </code> indicating a <code> 
     *          Summary </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> summaryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSummaryRecordType(org.osid.type.Type summaryRecordType);


    /**
     *  Gets the supported <code> Business </code> record types. 
     *
     *  @return a list containing the supported <code> Business </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBusinessRecordTypes();


    /**
     *  Tests if the given <code> Business </code> record type is supported. 
     *
     *  @param  businessRecordType a <code> Type </code> indicating an <code> 
     *          Business </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> businessRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessRecordType(org.osid.type.Type businessRecordType);


    /**
     *  Gets the supported <code> Business </code> search record types. 
     *
     *  @return a list containing the supported <code> Business </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBusinessSearchRecordTypes();


    /**
     *  Tests if the given <code> Business </code> search record type is 
     *  supported. 
     *
     *  @param  businessSearchRecordType a <code> Type </code> indicating an 
     *          <code> Business </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> businessSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessSearchRecordType(org.osid.type.Type businessSearchRecordType);
}
