//
// org.osid.financials.FiscalPeriod
//
//     The OSID Java specification for org.osid.financials.FiscalPeriod.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>A <code> FiscalPeriod </code> represents a period of time on a fiscal 
 *  calendar. </p>
 */

public interface FiscalPeriod
    extends org.osid.OsidObject {


    /**
     *  Gets a display label for this fiscal period which may be less formal 
     *  than the display name. 
     *
     *  @return the display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayLabel();


    /**
     *  Ges the fiscal year. 
     *
     *  @return the fiscal year 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getFiscalYear();


    /**
     *  Get sthe start date of this period. 
     *
     *  @return the start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getStartDate();


    /**
     *  Get sthe end date of this period. 
     *
     *  @return the end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getEndDate();


    /**
     *  Tests if this fiscal period has milestones. 
     *
     *  @return <code> true </code> if milestones are available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasMilestones();


    /**
     *  Tests if budgets need to be submiited for this fiscal period. 
     *
     *  @return <code> true </code> if budgets require submission, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasMilestones() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresBudgetSubmission();


    /**
     *  Gets the budget deadline. 
     *
     *  @return the closing date 
     *  @throws org.osid.IllegalStateException <code> hasMilestones() </code> 
     *          or <code> requiresBudgetSubmission() </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getBudgetDeadline();


    /**
     *  Tests if this period has a cutoff date for posting transactions. 
     *
     *  @return <code> true </code> if a posting deadline date is available, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasMilestones() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasPostingDeadline();


    /**
     *  Gets the last date transactions can be posted for this period. 
     *
     *  @return the cutoff date 
     *  @throws org.osid.IllegalStateException <code> hasMilestones() </code> 
     *          or <code> hasPostingDeadline() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getPostingDeadline();


    /**
     *  Tests if this period has a closing date. 
     *
     *  @return <code> true </code> if a closing date is available, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> hasMilestones() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasClosing();


    /**
     *  Gets the date of the closing for this period. 
     *
     *  @return the closing date 
     *  @throws org.osid.IllegalStateException <code> hasMilestones() </code> 
     *          or <code> hasClosing() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getClosing();


    /**
     *  Gets the fiscal period record corresponding to the given <code> 
     *  FiscalPeriod </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  fiscalPeriodRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(fiscalPeriodRecordType) </code> is <code> true </code> . 
     *
     *  @param  fiscalPeriodRecordType the type of fiscal period record to 
     *          retrieve 
     *  @return the fiscal period record 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(fiscalPeriodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.FiscalPeriodRecord getFiscalPeriodRecord(org.osid.type.Type fiscalPeriodRecordType)
        throws org.osid.OperationFailedException;
}
