//
// org.osid.financials.FiscalPeriodAdminSession
//
//     The OSID Java specification for org.osid.financials.FiscalPeriodAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This session creates, updates, and deletes <code> FiscalPeriods. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  FiscalPeriod, </code> a <code> FiscalPeriodForm </code> is requested using 
 *  <code> getFiscalPeriodFormForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> FiscalPeriodForm </code> will indicate that it 
 *  is to be used with a create operation and can be used to examine metdata 
 *  or validate data prior to creation. Once the <code> FiscalPeriodForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> FiscalPeriodForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> FiscalPeriodForms </code> are requested to the 
 *  <code> FiscalPeriod </code> <code> Id </code> that is to be updated using 
 *  <code> getFiscalPeriodFormForUpdate(). </code> Similarly, the <code> 
 *  FiscalPeriodForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  FiscalPeriodForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> FiscalPeriods. </code> To unmap a 
 *  <code> FiscalPeriod </code> from the current <code> Business, </code> the 
 *  <code> FiscalPeriodBusinessAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> FiscalPeriod </code> itself 
 *  thus removing it from all known <code> Business </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface FiscalPeriodAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> FiscalPeriods. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> FiscalPeriod </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> FiscalPeriod </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateFiscalPeriods();


    /**
     *  Tests if this user can create a single <code> FiscalPeriod </code> 
     *  using the desired record types. While <code> 
     *  FinancialsManager.getFiscalPeriodRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> FiscalPeriod. </code> 
     *  Providing an empty array tests if a <code> FiscalPeriod </code> can be 
     *  created with no records. 
     *
     *  @param  fiscalPeriodRecordTypes array of fiscal period record types 
     *  @return <code> true </code> if <code> FiscalPeriod </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateFiscalPeriodWithRecordTypes(org.osid.type.Type[] fiscalPeriodRecordTypes);


    /**
     *  Gets the fiscal period form for creating new fiscal periods. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  fiscalPeriodRecordTypes array of fiscal period record types 
     *  @return the fiscal period form 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodForm getFiscalPeriodFormForCreate(org.osid.type.Type[] fiscalPeriodRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> FiscalPeriod. </code> 
     *
     *  @param  fiscalPeriodForm the form for this <code> FiscalPeriod </code> 
     *  @return the new <code> FiscalPeriod </code> 
     *  @throws org.osid.IllegalStateException <code> fiscalPeriodForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> fiscalPeriodForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> fiscalPeriodForm </code> 
     *          did not originate from <code> getFiscalPeriodFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriod createFiscalPeriod(org.osid.financials.FiscalPeriodForm fiscalPeriodForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> FiscalPeriods. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> FiscalPeriod </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> FiscalPeriod </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateFiscalPeriods();


    /**
     *  Gets the fiscal period form for updating an existing fiscal period. A 
     *  new fiscal period form should be requested for each update 
     *  transaction. 
     *
     *  @param  fiscalPeriodId the <code> Id </code> of the <code> 
     *          FiscalPeriod </code> 
     *  @return the fiscal period form 
     *  @throws org.osid.NotFoundException <code> fiscalPeriodId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodForm getFiscalPeriodFormForUpdate(org.osid.id.Id fiscalPeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing fiscal period. 
     *
     *  @param  fiscalPeriodForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> fiscalPeriodForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> fiscalPeriodForm </code> 
     *          did not originate from <code> getFiscalPeriodFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateFiscalPeriod(org.osid.financials.FiscalPeriodForm fiscalPeriodForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> FiscalPeriods. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> FiscalPeriod </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> FiscalPeriod </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteFiscalPeriods();


    /**
     *  Deletes a <code> FiscalPeriod. </code> 
     *
     *  @param  fiscalPeriodId the <code> Id </code> of the <code> 
     *          FiscalPeriod </code> to remove 
     *  @throws org.osid.NotFoundException <code> fiscalPeriodId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteFiscalPeriod(org.osid.id.Id fiscalPeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  FiscalPeriods. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> FiscalPeriod </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageFiscalPeriodAliases();


    /**
     *  Adds an <code> Id </code> to a <code> FiscalPeriod </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> FiscalPeriod </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another fiscal period, it is 
     *  reassigned to the given fiscal period <code> Id. </code> 
     *
     *  @param  fiscalPeriodId the <code> Id </code> of a <code> FiscalPeriod 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> fiscalPeriodId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasFiscalPeriod(org.osid.id.Id fiscalPeriodId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
