//
// org.osid.financials.FiscalPeriodQuery
//
//     The OSID Java specification for org.osid.financials.FiscalPeriodQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This is the query for searching fiscal periods. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface FiscalPeriodQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Adds a display label for this query. 
     *
     *  @param  label label string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> label </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> label </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDisplayLabel(String label, 
                                  org.osid.type.Type stringMatchType, 
                                  boolean match);


    /**
     *  Matches a display label that has any value. 
     *
     *  @param  match <code> true </code> to match fiscal periods with any 
     *          display label, <code> false </code> to match fiscal periods 
     *          with no display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDisplayLabel(boolean match);


    /**
     *  Clears the display label terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabelTerms();


    /**
     *  Adds a fiscal year for this query to match periods in the given fiscal 
     *  years inclusive. 
     *
     *  @param  from start of year range 
     *  @param  to end of year range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFiscalYear(long from, long to, boolean match);


    /**
     *  Matches a fiscal year that has any value. 
     *
     *  @param  match <code> true </code> to match fiscal periods with any 
     *          fiscal year, <code> false </code> to match fiscal periods with 
     *          no fiscal year 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFiscalYear(boolean match);


    /**
     *  Clears the fiscal year terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFiscalYearTerms();


    /**
     *  Matches a start date within the given date range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartDate(org.osid.calendaring.DateTime from, 
                               org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches a start date that has any value. 
     *
     *  @param  match <code> true </code> to match fiscal periods with any 
     *          start date, <code> false </code> to match fiscal periods with 
     *          no start date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStartDate(boolean match);


    /**
     *  Clears the start date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartDateTerms();


    /**
     *  Matches an end date within the given date range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEndDate(org.osid.calendaring.DateTime from, 
                             org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches an end date that has any value. 
     *
     *  @param  match <code> true </code> to match fiscal periods with any end 
     *          date, <code> false </code> to match fiscal periods with no end 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEndDate(boolean match);


    /**
     *  Clears the end date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndDateTerms();


    /**
     *  Matches a fiscal period duratione within the given date range 
     *  inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDuration(org.osid.calendaring.Duration from, 
                              org.osid.calendaring.Duration to, boolean match);


    /**
     *  Clears the duration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDurationTerms();


    /**
     *  Matches a budget deadline within the given date range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBudgetDeadline(org.osid.calendaring.DateTime from, 
                                    org.osid.calendaring.DateTime to, 
                                    boolean match);


    /**
     *  Matches a budget deadline that has any value. 
     *
     *  @param  match <code> true </code> to match fiscal periods with any 
     *          budget deadline, <code> false </code> to match fiscal periods 
     *          with no budget deadline 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBudgetDeadline(boolean match);


    /**
     *  Clears the budget deadline terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBudgetDeadlineTerms();


    /**
     *  Matches a posting deadline within the given date range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPostingDeadline(org.osid.calendaring.DateTime from, 
                                     org.osid.calendaring.DateTime to, 
                                     boolean match);


    /**
     *  Matches a posting deadline that has any value. 
     *
     *  @param  match <code> true </code> to match fiscal periods with any 
     *          posting deadline, <code> false </code> to match fiscal periods 
     *          with no posting deadline 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPostingDeadline(boolean match);


    /**
     *  Clears the posting deadline terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPostingDeadlineTerms();


    /**
     *  Matches a closing date within the given date range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClosing(org.osid.calendaring.DateTime from, 
                             org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches a closing date that has any value. 
     *
     *  @param  match <code> true </code> to match fiscal periods with any 
     *          closing date, <code> false </code> to match fiscal periods 
     *          with no closing date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyClosing(boolean match);


    /**
     *  Clears the closing terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosingTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match fiscal 
     *  periods assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the fiscal period query record corresponding to the given <code> 
     *  FiscalPeriod </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  fiscalPeriodRecordType a fiscal period record type 
     *  @return the fiscal period query record 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(fiscalPeriodRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.FiscalPeriodQueryRecord getFiscalPeriodQueryRecord(org.osid.type.Type fiscalPeriodRecordType)
        throws org.osid.OperationFailedException;
}
