//
// org.osid.financials.ReportingSession
//
//     The OSID Java specification for org.osid.financials.ReportingSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This session defines methods for retrieving financial transaction 
 *  reports. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated business view: All methods in this session operate, 
 *      retrieve and pertain to accounts defined explicitly in the current 
 *      business. Using an isolated view is useful for managing <code> 
 *      Accounts </code> with the <code> AccountAdminSession. </code> </li> 
 *      <li> federated business view: All lookup methods in this session 
 *      operate, retrieve and pertain to all accounts and activities defined 
 *      in this business and any other courses implicitly available in this 
 *      business through business inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBusinessView() </code> and <code> 
 *  useIsolatedBusinessView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Summaries may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Summary. </code> </p>
 */

public interface ReportingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Summary </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSummaries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSummaryView();


    /**
     *  A complete view of the <code> Summary </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySummaryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include accounts and activities in catalogs which are children of this 
     *  catalog in the business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Gets a summary of financial transactions for a fiscal year for the 
     *  given account. A summary is returned for each fiscal time period 
     *  within the fiscal year. 
     *
     *  @param  accountId the <code> Id </code> of an <code> Account </code> 
     *  @param  year a fiscal year 
     *  @return the account summaries 
     *  @throws org.osid.NotFoundException no <code> Account </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryList getSummaryByYearForAccount(org.osid.id.Id accountId, 
                                                                      long year)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a summary of financial transactions for a fiscal year for all 
     *  root accounts. A summary is returned for each fiscal time period 
     *  within the fiscal year. 
     *
     *  @param  year a fiscal year 
     *  @return the account summaries 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryList getSummariesByYearForRootAccounts(long year)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a summary of financial transactions for a fiscal period for the 
     *  given account. 
     *
     *  @param  accountId the <code> Id </code> of an <code> Account </code> 
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the account summaries 
     *  @throws org.osid.NotFoundException no <code> Account </code> or <code> 
     *          fiscalPeriodId </code> found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> accountId </code> or 
     *          <code> fiscalPeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryList getSummaryByFiscalPeriodForAccount(org.osid.id.Id accountId, 
                                                                              org.osid.id.Id fiscalPeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a summary of financial transactions for a fiscal period for all 
     *  root accounts. 
     *
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the account summaries 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryList getSummariesByFiscalPeriodForRootAccounts(org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a summary of financial transactions for a fiscal year for the 
     *  given activity. A summary is returned for each fiscal time period 
     *  within the fiscal year. 
     *
     *  @param  activityId the <code> Id </code> of an <code> Activity </code> 
     *  @param  year a fiscal year 
     *  @return the activity summaries 
     *  @throws org.osid.NotFoundException no <code> Activity </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryList getSummaryByYearForActivity(org.osid.id.Id activityId, 
                                                                       long year)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a summary of financial transactions for a fiscal year for all 
     *  root activities. A summary is returned for each fiscal time period 
     *  within the fiscal year. 
     *
     *  @param  year a fiscal year 
     *  @return the activity summaries 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryList getSummariesByYearForRootActivities(long year)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a summary of financial transactions for a fiscal period for the 
     *  given activity. 
     *
     *  @param  activityId the <code> Id </code> of an <code> Activity </code> 
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the returned <code> Summary </code> 
     *  @throws org.osid.NotFoundException no <code> Activity </code> or 
     *          <code> fiscalPeriodId </code> found with the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> activityId </code> or 
     *          <code> fiscalPeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Summary getSummaryByFiscalPeriodForActivity(org.osid.id.Id activityId, 
                                                                           org.osid.id.Id fiscalPeriodId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a summary of financial transactions for a fiscal period for all 
     *  root activities. 
     *
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the activity summaries 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.SummaryList getSummariesByFiscalPeriodForRootActivities(org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
