//
// org.osid.financials.SummaryQuery
//
//     The OSID Java specification for org.osid.financials.SummaryQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials;


/**
 *  <p>This is the query for searching summaries. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface SummaryQuery
    extends org.osid.OsidCompendiumQuery {


    /**
     *  Matches an account <code> Id. </code> 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAccountId(org.osid.id.Id accountId, boolean match);


    /**
     *  Clears the account <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAccountIdTerms();


    /**
     *  Tests if an <code> AccountQuery </code> is available. 
     *
     *  @return <code> true </code> if an account query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountQuery();


    /**
     *  Gets the query for an account. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the account query 
     *  @throws org.osid.UnimplementedException <code> supportsAccountQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAccountQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.AccountQuery getAccountQuery();


    /**
     *  Clears the account terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAccountTerms();


    /**
     *  Sets the fiscal period <code> Id </code> for this query. 
     *
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFiscalPeriodId(org.osid.id.Id fiscalPeriodId, 
                                    boolean match);


    /**
     *  Clears the fiscal period <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFiscalPeriodIdTerms();


    /**
     *  Tests if a <code> FiscalPeriodQuery </code> is available. 
     *
     *  @return <code> true </code> if a fiscal period query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFiscalPeriodQuery();


    /**
     *  Gets the query for a fiscal period. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the fiscal period query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFiscalPeriodQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFiscalPeriodQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.financials.FiscalPeriodQuery getFiscalPeriodQuery();


    /**
     *  Clears the fiscal period query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFiscalPeriodTerms();


    /**
     *  Matches credits within the given range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCredits(org.osid.financials.Currency from, 
                             org.osid.financials.Currency to, boolean match);


    /**
     *  Clears the credits terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreditsTerms();


    /**
     *  Matches debits within the given range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDebits(org.osid.financials.Currency from, 
                            org.osid.financials.Currency to, boolean match);


    /**
     *  Clears the debits terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDebitsTerms();


    /**
     *  Matches summaries with a delta between debits and credits. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBalance(java.math.BigDecimal from, 
                             java.math.BigDecimal to, boolean match);


    /**
     *  Clears the balance terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBalanceTerms();


    /**
     *  Matches a budget within the given range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBudget(org.osid.financials.Currency from, 
                            org.osid.financials.Currency to, boolean match);


    /**
     *  Clears the budget terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBudgetTerms();


    /**
     *  Matches summaries with a delta between the balance and the budget. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDelta(java.math.BigDecimal from, java.math.BigDecimal to, 
                           boolean match);


    /**
     *  Clears the delta terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeltaTerms();


    /**
     *  Matches a forecast within the given range inclusive. 
     *
     *  @param  from start of range 
     *  @param  to end of range 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchForecast(org.osid.financials.Currency from, 
                              org.osid.financials.Currency to, boolean match);


    /**
     *  Clears the forecast terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearForecastTerms();


    /**
     *  Gets the summary query record corresponding to the given <code> 
     *  Summary </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  summaryRecordType a summary record type 
     *  @return the summary query record 
     *  @throws org.osid.NullArgumentException <code> summaryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(summaryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.records.SummaryQueryRecord getSummaryQueryRecord(org.osid.type.Type summaryRecordType)
        throws org.osid.OperationFailedException;
}
