//
// org.osid.financials.budgeting.BudgetAdminSession
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>This session creates, updates, and deletes <code> Budgets. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Budget, </code> a <code> BudgetForm </code> is requested using <code> 
 *  getBudgetFormForCreate() </code> specifying the desired activity, fiscal 
 *  period, and record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> BudgetForm </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> BudgetForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> BudgetForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> BudgetForms </code> are requested to the <code> 
 *  Budget </code> <code> Id </code> that is to be updated using <code> 
 *  getBudgetFormForUpdate(). </code> Similarly, the <code> BudgetForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> BudgetForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Budgets. </code> To unmap a <code> 
 *  Budget </code> from the current <code> Business, </code> the <code> 
 *  BudgetBusinessAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Budget </code> itself thus 
 *  removing it from all known <code> Business </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface BudgetAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Budgets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Budget </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Budget </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBudgets();


    /**
     *  Tests if this user can create a single <code> Budget </code> using the 
     *  desired record types. While <code> 
     *  FinancialsBudgetManager.getBudgetRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Budget. </code> Providing 
     *  an empty array tests if a <code> Budget </code> can be created with no 
     *  records. 
     *
     *  @param  budgetRecordTypes array of budget record types 
     *  @return <code> true </code> if <code> Budget </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> budgetRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBudgetWithRecordTypes(org.osid.type.Type[] budgetRecordTypes);


    /**
     *  Gets the budget form for creating new budgets. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  activityId the Id of the associated <code> Activity </code> 
     *  @param  fiscalPeriodId the Id of the fiscal period 
     *  @param  budgetRecordTypes array of budget record types 
     *  @return the budget form 
     *  @throws org.osid.NotFoundException <code> activityId </code> or <code> 
     *          fiscalPeriodId </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityId, 
     *          fiscalPeriodId, </code> or <code> budgetRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetForm getBudgetFormForCreate(org.osid.id.Id activityId, 
                                                                           org.osid.id.Id fiscalPeriodId, 
                                                                           org.osid.type.Type[] budgetRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Budget. </code> 
     *
     *  @param  budgetForm the form for this <code> Budget </code> 
     *  @return the new <code> Budget </code> 
     *  @throws org.osid.IllegalStateException <code> budgetForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> budgetForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> entryForm did not 
     *          originate from getBudgetFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.Budget createBudget(org.osid.financials.budgeting.BudgetForm budgetForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Budgets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Budget </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Budget </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateBudgets();


    /**
     *  Gets the budget form for updating an existing budget. A new budget 
     *  form should be requested for each update transaction. 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> 
     *  @return the budget form 
     *  @throws org.osid.NotFoundException <code> budgetId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetForm getBudgetFormForUpdate(org.osid.id.Id budgetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing budget. 
     *
     *  @param  budgetForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> budgetForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> budgetForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> entryForm did not 
     *          originate from getBudgetFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateBudget(org.osid.financials.budgeting.BudgetForm budgetForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Budgets. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Budget </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Budget </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteBudgets();


    /**
     *  Deletes a <code> Budget. </code> 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> budgetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteBudget(org.osid.id.Id budgetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Budgets. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Budget </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageBudgetAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Budget </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Budget </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another budget, it is reassigned to the given 
     *  budget <code> Id. </code> 
     *
     *  @param  budgetId the <code> Id </code> of a <code> Budget </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> budgetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasBudget(org.osid.id.Id budgetId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
