//
// org.osid.financials.budgeting.BudgetEntryLookupSession
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetEntryLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>This session provides methods for retrieving <code> BudgetEntry </code> 
 *  objects. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated business view: All budget entry methods in this session 
 *      operate, retrieve and pertain to budget entries defined explicitly in 
 *      the current business. Using an isolated view is useful for managing 
 *      <code> BudgetEntries </code> with the <code> BudgetEntryAdminSession. 
 *      </code> </li> 
 *      <li> federated business view: All budget entry methods in this session 
 *      operate, retrieve and pertain to all budget entries defined in this 
 *      business and any other budget entries implicitly available in this 
 *      business through business inheritence. </li> 
 *      <li> effective budget entry view: All budget entry lookup methods 
 *      return budget entries where the current date falls in between the 
 *      effective dates inclusive. </li> 
 *      <li> any effective budget entry view: Budget entries of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedBusinessView() </code> and <code> 
 *  useIsolatedBusinessView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface BudgetEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> BudgetEntry </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBudgetEntries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBudgetEntryView();


    /**
     *  A complete view of the <code> BudgetEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBudgetEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include budget entries in businesses which are children of this 
     *  business in the business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Only budget entries whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveBudgetEntryView();


    /**
     *  All budget entries of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveBudgetEntryView();


    /**
     *  Gets the <code> BudgetEntry </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  BudgetEntry </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> BudgetEntry </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, budget entries are returned that are currently 
     *  effective. In any effective mode, effective budget entries and those 
     *  currently expired are returned. 
     *
     *  @param  budgetEntryId <code> Id </code> of the <code> BudgetEntry 
     *          </code> 
     *  @return the entry 
     *  @throws org.osid.NotFoundException <code> budgetEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> budgetEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntry getBudgetEntry(org.osid.id.Id budgetEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> BudgetEntryList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  budget entries specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> BudgetEntries </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, budget entries are returned that are currently 
     *  effective. In any effective mode, effective budget entries and those 
     *  currently expired are returned. 
     *
     *  @param  budgetEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> BudgetEntry </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> budgetEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesByIds(org.osid.id.IdList budgetEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> corresponding to the given 
     *  budget entry genus <code> Type </code> which does not include budget 
     *  entries of genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budget entries or an error results. Otherwise, the returned list may 
     *  contain only those budget entries that are accessible through this 
     *  session. 
     *
     *  @param  entryGenusType a budget entry genus type 
     *  @return the returned <code> BudgetEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesByGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> corresponding to the given 
     *  budget entry genus <code> Type </code> and include any additional 
     *  budget entries with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budget entries or an error results. Otherwise, the returned list may 
     *  contain only those budget entries that are accessible through this 
     *  session. 
     *
     *  @param  entryGenusType a budget entry genus type 
     *  @return the returned <code> BudgetEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesByParentGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> containing the given budget 
     *  entry record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budget entries or an error results. Otherwise, the returned list may 
     *  contain only those budget entries that are accessible through this 
     *  session. 
     *
     *  @param  budgetEntryRecordType a budget entry record type 
     *  @return the returned <code> BudgetEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> budgetEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesByRecordType(org.osid.type.Type budgetEntryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known budget entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those budget entries that are accessible through this session. 
     *  
     *  In effective mode, budget entries are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective budget entries and those currently 
     *  expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> BudgetEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from or to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesOnDate(org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> for the given budget. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budget entries or an error results. Otherwise, the returned list may 
     *  contain only those budget entries that are accessible through this 
     *  session. 
     *
     *  @param  budgetId a budget <code> Id </code> 
     *  @return the returned <code> BudgetEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesForBudget(org.osid.id.Id budgetId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> for the given budget and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known budget entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those budget entries that are accessible through this session. 
     *  
     *  In effective mode, budget entries are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective budget entries and those currently 
     *  expired are returned. 
     *
     *  @param  budgetId a budget <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> BudgetEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> budgetId, from or to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesForBudgetOnDate(org.osid.id.Id budgetId, 
                                                                                         org.osid.calendaring.DateTime from, 
                                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> for the given account. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budget entries or an error results. Otherwise, the returned list may 
     *  contain only those budget entries that are accessible through this 
     *  session. 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @return the returned <code> BudgetEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesForAccount(org.osid.id.Id accountId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> for the given account and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known budget entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those budget entries that are accessible through this session. 
     *  
     *  In effective mode, budget entries are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective budget entries and those currently 
     *  expired are returned. 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> BudgetEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> accountId, from or to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesForAccountOnDate(org.osid.id.Id accountId, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> for the given budget and 
     *  account. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budget entries or an error results. Otherwise, the returned list may 
     *  contain only those budget entries that are accessible through this 
     *  session. 
     *
     *  @param  budgetId a budget <code> Id </code> 
     *  @param  accountId an account <code> Id </code> 
     *  @return the returned <code> BudgetEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> or 
     *          <code> accountId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesForBudgetAndAccount(org.osid.id.Id budgetId, 
                                                                                             org.osid.id.Id accountId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetEntryList </code> for the given budget, account, 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known budget entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those budget entries that are accessible through this session. 
     *  
     *  In effective mode, budget entries are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective budget entries and those currently 
     *  expired are returned. 
     *
     *  @param  budgetId a budget <code> Id </code> 
     *  @param  accountId an account <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> BudgetEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> budgetId, accountId, 
     *          from or to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntriesForBudgetAndAccountOnDate(org.osid.id.Id budgetId, 
                                                                                                   org.osid.id.Id accountId, 
                                                                                                   org.osid.calendaring.DateTime from, 
                                                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> BudgetEntries. </code> 
     *  
     *  In plenary mode, the returned list contains all known budget entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those budget entries that are accessible through this session. 
     *
     *  @return a list of <code> BudgetEntries </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryList getBudgetEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
