//
// org.osid.financials.budgeting.BudgetEntryQuery
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetEntryQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>This is the query for searching budget entries. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface BudgetEntryQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the budget <code> Id </code> for this query. 
     *
     *  @param  budgetId a budget <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBudgetId(org.osid.id.Id budgetId, boolean match);


    /**
     *  Clears the budget <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBudgetIdTerms();


    /**
     *  Tests if a <code> BudgetQuery </code> is available. 
     *
     *  @return <code> true </code> if a budget query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBudgetQuery();


    /**
     *  Gets the query for a budget. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the payer query 
     *  @throws org.osid.UnimplementedException the budget query 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBudgetQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.budgeting.BudgetQuery getBudgetQuery();


    /**
     *  Clears the budget terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBudgetTerms();


    /**
     *  Sets the account <code> Id </code> for this query. 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAccountId(org.osid.id.Id accountId, boolean match);


    /**
     *  Clears the account <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAccountIdTerms();


    /**
     *  Tests if an <code> AccountQuery </code> is available. 
     *
     *  @return <code> true </code> if an account query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAccountQuery();


    /**
     *  Gets the query for an account. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the account query 
     *  @throws org.osid.UnimplementedException <code> supportsAccountQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAccountQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.AccountQuery getAccountQuery();


    /**
     *  Matches entries that have any account set. 
     *
     *  @param  match <code> true </code> to match entries with any account, 
     *          <code> false </code> to match entries with no account 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAccount(boolean match);


    /**
     *  Clears the account terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAccountTerms();


    /**
     *  Matches the amount between the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAmount(org.osid.financials.Currency low, 
                            org.osid.financials.Currency high, boolean match);


    /**
     *  Matches entries that have any amount set. 
     *
     *  @param  match <code> true </code> to match entries with any amount, 
     *          <code> false </code> to match entries with no amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAmount(boolean match);


    /**
     *  Clears the amount terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAmountTerms();


    /**
     *  Matches entries that have debit amounts. 
     *
     *  @param  match <code> true </code> to match entries with a debit 
     *          amount, <code> false </code> to match entries with a credit 
     *          amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDebit(boolean match);


    /**
     *  Clears the debit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDebitTerms();


    /**
     *  Sets the business <code> Id </code> for this query to match budget 
     *  entries assigned to businesses. 
     *
     *  @param  businessId the business <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> businessId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBusinessId(org.osid.id.Id businessId, boolean match);


    /**
     *  Clears the business <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessIdTerms();


    /**
     *  Tests if a <code> BusinessQuery </code> is available. 
     *
     *  @return <code> true </code> if a business query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBusinessQuery();


    /**
     *  Gets the query for a business. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the business query 
     *  @throws org.osid.UnimplementedException <code> supportsBusinessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBusinessQuery() </code> is <code> true. </code> 
     */

    public org.osid.financials.BusinessQuery getBusinessQuery();


    /**
     *  Clears the business terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBusinessTerms();


    /**
     *  Gets the budget entry query record corresponding to the given <code> 
     *  BudgetEntry </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  budgetEntryRecordType a budget entry record type 
     *  @return the budget entry query record 
     *  @throws org.osid.NullArgumentException <code> budgetEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(budgetEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.records.BudgetEntryQueryRecord getBudgetEntryQueryRecord(org.osid.type.Type budgetEntryRecordType)
        throws org.osid.OperationFailedException;
}
