//
// org.osid.financials.budgeting.BudgetEntrySearchSession
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetEntrySearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>This session provides methods for searching among <code> BudgetEntry 
 *  </code> objects. The search query is constructed using the <code> 
 *  BudgetEntryQuery. </code> </p> 
 *  
 *  <p> <code> getBudgetEntriesByQuery() </code> is the basic search method 
 *  and returns a list of <code> BudgetEntrys. </code> A more advanced search 
 *  may be performed with <code> getBudgetEntrysBySearch(). </code> It accepts 
 *  an <code> BudgetEntrySearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getBudgetEntriesBySearch() </code> returns an <code> 
 *  BudgetEntrySearchResults </code> that can be used to access the resulting 
 *  <code> BudgetEntryList </code> or be used to perform a search within the 
 *  result set through <code> BudgetEntrySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include budget entries in 
 *      businesses of which this business is an ancestor in the business 
 *      hierarchy </li> 
 *      <li> isolated business view: searches are restricted to budget entries 
 *      in this business </li> 
 *  </ul>
 *  
 *  
 *  <p> BudgetBudget Entries may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  BudgetEntryQuery. </code> </p>
 */

public interface BudgetEntrySearchSession
    extends org.osid.financials.budgeting.BudgetEntryQuerySession {


    /**
     *  Gets a budget entry search. 
     *
     *  @return the budget entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntrySearch getBudgetEntrySearch();


    /**
     *  Gets a budget entry search order. The <code> BudgetEntrySearchOrder 
     *  </code> is supplied to an <code> BudgetEntrySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the budget entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntrySearchOrder getBudgetEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  budgetEntryQuery the budget entry query 
     *  @param  budgetEntrySearch the budget entry search 
     *  @return the budget entry search results 
     *  @throws org.osid.NullArgumentException <code> budgetEntryQuery </code> 
     *          or <code> budgetEntrySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> budgetEntryQuery </code> 
     *          or <code> budgetEntrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntrySearchResults getBudgetEntriesBySearch(org.osid.financials.budgeting.BudgetEntryQuery budgetEntryQuery, 
                                                                                           org.osid.financials.budgeting.BudgetEntrySearch budgetEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a budget entry query from an inspector. The inspector is 
     *  available from an <code> BudgetEntrySearchResults. </code> 
     *
     *  @param  budgetEntryQueryInspector a budget entry query inspector 
     *  @return the budget entry query 
     *  @throws org.osid.NullArgumentException <code> 
     *          budgetEntryQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> budgetEntryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetEntryQuery getBudgetEntryQueryFromInspector(org.osid.financials.budgeting.BudgetEntryQueryInspector budgetEntryQueryInspector);
}
