//
// org.osid.financials.budgeting.BudgetLookupSession
//
//     The OSID Java specification for org.osid.financials.budgeting.BudgetLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.budgeting;


/**
 *  <p>This session defines methods for retrieving budgets. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated business view: All budget methods in this session 
 *      operate, retrieve and pertain to budgets defined explicitly in the 
 *      current business. Using an isolated view is useful for managing <code> 
 *      Budgets </code> with the <code> BudgetAdminSession. </code> </li> 
 *      <li> federated business view: All budget lookup methods in this 
 *      session operate, retrieve and pertain to all budgets defined in this 
 *      business and any other budgets implicitly available in this business 
 *      through business inheritence. </li> 
 *      <li> effective budget view: All budget lookup methods return budgets 
 *      where the current date falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective budget view: Budgets of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedBusinessView() </code> and <code> 
 *  useIsolatedBusinessView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Budgets may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Budget. </code> </p>
 */

public interface BudgetLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Budget </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBudgets();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBudgetView();


    /**
     *  A complete view of the <code> Budget </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBudgetView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include budgets in catalogs which are children of this catalog in the 
     *  business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Only budgets whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveBudgetView();


    /**
     *  All budgets of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveBudgetView();


    /**
     *  Gets the <code> Budget </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Budget </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Budget </code> and retained for compatibility. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  budgetId the <code> Id </code> of the <code> Budget </code> to 
     *          retrieve 
     *  @return the returned <code> Budget </code> 
     *  @throws org.osid.NotFoundException no <code> Budget </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> budgetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.Budget getBudget(org.osid.id.Id budgetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  budgets specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Budgets </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  budgetIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> budgetIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsByIds(org.osid.id.IdList budgetIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> corresponding to the given budget 
     *  genus <code> Type </code> which does not include budgets of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budgets or an error results. Otherwise, the returned list may contain 
     *  only those budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  budgetGenusType a budget genus type 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.NullArgumentException <code> budgetGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsByGenusType(org.osid.type.Type budgetGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> corresponding to the given budget 
     *  genus <code> Type </code> and include any additional budgets with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  budgets or an error results. Otherwise, the returned list may contain 
     *  only those budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  budgetGenusType a budget genus type 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.NullArgumentException <code> budgetGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsByParentGenusType(org.osid.type.Type budgetGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> containing the given budget record 
     *  <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known mode,s or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  budgetRecordType a budget record type 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.NullArgumentException <code> budgetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsByRecordType(org.osid.type.Type budgetRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known budgets or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective budgets and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from or to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsOnDate(org.osid.calendaring.DateTime from, 
                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> for the given activity. 
     *  
     *  In plenary mode, the returned list contains all known mode,s or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsForActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> for the given activity and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known budgets or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective budgets and those currently expired are 
     *  returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> activityId, from or to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsForActivityOnDate(org.osid.id.Id activityId, 
                                                                                org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> for the given fiscal period. 
     *  
     *  In plenary mode, the returned list contains all known mode,s or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsForFiscalPeriod(org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> for the given fiscal period and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known budgets or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective budgets and those currently expired are 
     *  returned. 
     *
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId, from or 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsForFiscalPeriodOnDate(org.osid.id.Id fiscalPeriodId, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> for the given activity and fiscal 
     *  period. 
     *  
     *  In plenary mode, the returned list contains all known mode,s or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.NullArgumentException <code> activityId </code> or 
     *          <code> fiscalPeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsForActivityAndFiscalPeriod(org.osid.id.Id activityId, 
                                                                                         org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BudgetList </code> for the given activity, fiscal 
     *  period, and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known budgets or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective budgets and those currently expired are 
     *  returned. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Budget </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> activityId, 
     *          fiscalPeriodId, from or to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgetsForActivityAndFiscalPeriodOnDate(org.osid.id.Id activityId, 
                                                                                               org.osid.id.Id fiscalPeriodId, 
                                                                                               org.osid.calendaring.DateTime from, 
                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Budgets. </code> 
     *  
     *  In plenary mode, the returned list contains all known budgets or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  budgets that are accessible through this session. 
     *  
     *  In effective mode, budgets are returned that are currently effective. 
     *  In any effective mode, effective budgets and those currently expired 
     *  are returned. 
     *
     *  @return a list of <code> Budgets </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.budgeting.BudgetList getBudgets()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
