//
// org.osid.financials.posting.Post
//
//     The OSID Java specification for org.osid.financials.posting.Post.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>A <code> Post </code> is a set of <code> PostEntries </code> 
 *  representing a complete accounting transaction. </p>
 */

public interface Post
    extends org.osid.OsidObject,
            org.osid.Aggregateable {


    /**
     *  Gets the <code> Id </code> of the <code> FiscalPeriod. </code> 
     *
     *  @return the <code> FiscalPeriod </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFiscalPeriodId();


    /**
     *  Gets the <code> FiscalPeriod. </code> 
     *
     *  @return the fiscal period 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriod getFiscalPeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this has been posted. 
     *
     *  @return <code> true </code> if this has been posted, <code> false 
     *          </code> if just lying around 
     *  @compliance mandatory This method is must be implemented. 
     */

    public boolean isPosted();


    /**
     *  Gets the posting date. 
     *
     *  @return the posting date 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.calendaring.DateTime getDate();


    /**
     *  Gets the <code> Ids </code> of the <code> PostEntries. </code> 
     *
     *  @return the <code> PostEntry </code> <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPostEntryIds();


    /**
     *  Gets the <code> PostEntries. </code> 
     *
     *  @return the post entries 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntries()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this <code> Post </code> is a correction to a previous post. 
     *
     *  @return <code> true </code> if this post is a correction, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isCorrection();


    /**
     *  Gets the <code> Id </code> of the corrected <code> Post. </code> 
     *
     *  @return the corrected <code> Post </code> <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isCorrection() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCorrectedPostId();


    /**
     *  Gets the corrected <code> Post. </code> 
     *
     *  @return the corrected post 
     *  @throws org.osid.IllegalStateException <code> isCorrection() </code> 
     *          is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.Post getCorrectedPost()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the post record corresponding to the given <code> Post </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> postRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(postRecordType) </code> is <code> true </code> . 
     *
     *  @param  postRecordType the type of post record to retrieve 
     *  @return the post record 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(postRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.records.PostRecord getPostRecord(org.osid.type.Type postRecordType)
        throws org.osid.OperationFailedException;
}
