//
// org.osid.financials.posting.PostEntryLookupSession
//
//     The OSID Java specification for org.osid.financials.posting.PostEntryLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>This session provides methods for retrieving <code> PostEntry </code> 
 *  objects. The <code> PostEntry </code> represents a period in which payers 
 *  are offered. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated business view: All post entry methods in this session 
 *      operate, retrieve and pertain to post entries defined explicitly in 
 *      the current business. Using an isolated view is useful for managing 
 *      <code> PostEntries </code> with the <code> PostEntryAdminSession. 
 *      </code> </li> 
 *      <li> federated business view: All post entry methods in this session 
 *      operate, retrieve and pertain to all post entries defined in this 
 *      business and any other post entries implicitly available in this 
 *      business through business inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedBusinessView() </code> and <code> 
 *  useIsolatedBusinessView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface PostEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Business </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Business Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBusinessId();


    /**
     *  Gets the <code> Business </code> associated with this session. 
     *
     *  @return the business 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Business getBusiness()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> PostEntry </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPostEntries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePostEntryView();


    /**
     *  A complete view of the <code> PostEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPostEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include post entries in businesses which are children of this business 
     *  in the business hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBusinessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this business only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBusinessView();


    /**
     *  Gets the <code> PostEntry </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  PostEntry </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> PostEntry </code> and retained for compatibility. 
     *
     *  @param  postEntryId <code> Id </code> of the <code> PostEntry </code> 
     *  @return the entry 
     *  @throws org.osid.NotFoundException <code> postEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> postEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.financials.posting.PostEntry getPostEntry(org.osid.id.Id postEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  post entries specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> PostEntries </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  postEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> postEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByIds(org.osid.id.IdList postEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> corresponding to the given post 
     *  entry genus <code> Type </code> which does not include post entries of 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  entryGenusType a post entry genus type 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> corresponding to the given post 
     *  entry genus <code> Type </code> and include any additional post 
     *  entries with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  entryGenusType a post entry genus type 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> entryGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByParentGenusType(org.osid.type.Type entryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets q <code> PostEntryList </code> containing the given post entry 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  postEntryRecordType a post entry record type 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> postEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByRecordType(org.osid.type.Type postEntryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> for the given post. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  postId a post <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesForPost(org.osid.id.Id postId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> in the given fiscal period. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> fiscalPeriodId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByFiscalPeriod(org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> posted within given date range 
     *  inclusive. 
     *  
     *  In plenary mode, the returned list contains all known post entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  post entries that are accessible through this session. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByDate(org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> for the given account. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> accountId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByAccount(org.osid.id.Id accountId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> for the given account in a fiscal 
     *  period. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> accountId </code> or 
     *          <code> fiscalPeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByAccountAndFiscalPeriod(org.osid.id.Id accountId, 
                                                                                            org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> for the given activity. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByActivity(org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> for the given activity in a fiscal 
     *  period. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  activityId an activity <code> Id </code> 
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> activityId </code> or 
     *          <code> fiscalPeriodId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByActivityAndFiscalPeriod(org.osid.id.Id activityId, 
                                                                                             org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> for the given activity and 
     *  account. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @param  activityId an activity <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> accountId </code> or 
     *          <code> activityId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByAccountAndActivity(org.osid.id.Id accountId, 
                                                                                        org.osid.id.Id activityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PostEntryList </code> for the given account in a fiscal 
     *  period. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  post entries or an error results. Otherwise, the returned list may 
     *  contain only those post entries that are accessible through this 
     *  session. 
     *
     *  @param  accountId an account <code> Id </code> 
     *  @param  activityId an activity <code> Id </code> 
     *  @param  fiscalPeriodId a fiscal period <code> Id </code> 
     *  @return the returned <code> PostEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> accountId, activityId, 
     *          </code> or <code> fiscalPeriodId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntriesByAccountAndActivityAndFiscalPeriod(org.osid.id.Id accountId, 
                                                                                                       org.osid.id.Id activityId, 
                                                                                                       org.osid.id.Id fiscalPeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> PostEntries. </code> 
     *  
     *  In plenary mode, the returned list contains all known post entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  post entries that are accessible through this session. 
     *
     *  @return a list of <code> PostEntries </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryList getPostEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
