//
// org.osid.financials.posting.PostQueryInspector
//
//     The OSID Java specification for org.osid.financials.posting.PostQueryInspector.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>The query inspectors provide a means of accessing the match terms of a 
 *  query. These interfaces are used to examine the actual query terms used in 
 *  a search or that may be used to create a smart catalog. Query inspectors 
 *  may be converted to <code> OsidQuery </code> interfaces for reuse or 
 *  modification in the search sessions. </p>
 */

public interface PostQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidAggregateableQueryInspector {


    /**
     *  Gets the fiscal period <code> Id </code> query terms. 
     *
     *  @return the fiscal period <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getFiscalPeriodIdTerms();


    /**
     *  Gets the fiscal period query terms. 
     *
     *  @return the fiscal period query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.FiscalPeriodQueryInspector[] getFiscalPeriodTerms();


    /**
     *  Gets the posted query terms. 
     *
     *  @return the posted query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getPostedTerms();


    /**
     *  Gets the date query terms. 
     *
     *  @return the date query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getDateTerms();


    /**
     *  Gets the post entry <code> Id </code> query terms. 
     *
     *  @return the post entry <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getPostEntryIdTerms();


    /**
     *  Gets the post entry query terms. 
     *
     *  @return the post entry query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostEntryQueryInspector[] getPostEntryTerms();


    /**
     *  Gets the corrected post <code> Id </code> query terms. 
     *
     *  @return the post <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCorrectedPostIdTerms();


    /**
     *  Gets the corrected post query terms. 
     *
     *  @return the post query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostQueryInspector[] getCorrectedPostTerms();


    /**
     *  Gets the business <code> Id </code> query terms. 
     *
     *  @return the business <code> Id </code> query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBusinessIdTerms();


    /**
     *  Gets the business query terms. 
     *
     *  @return the business query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.BusinessQueryInspector[] getBusinessTerms();


    /**
     *  Gets the post query inspector record corresponding to the given <code> 
     *  Post </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  postRecordType a post record type 
     *  @return the post query inspector record 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(postRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.records.PostQueryInspectorRecord getPostQueryInspectorRecord(org.osid.type.Type postRecordType)
        throws org.osid.OperationFailedException;
}
