//
// org.osid.financials.posting.PostSearchSession
//
//     The OSID Java specification for org.osid.financials.posting.PostSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.financials.posting;


/**
 *  <p>This session provides methods for searching among <code> Post </code> 
 *  objects. The search query is constructed using the <code> PostQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getPostsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Posts. </code> A more advanced search may be 
 *  performed with <code> getPostsBySearch(). </code> It accepts a <code> 
 *  PostSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getPostsBySearch() </code> returns a <code> PostSearchResults </code> that 
 *  can be used to access the resulting <code> PostList </code> or be used to 
 *  perform a search within the result set through <code> PostSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated business view: searches include posts in businesses of 
 *      which this business is an ancestor in the business hierarchy </li> 
 *      <li> isolated business view: searches are restricted to posts in this 
 *      business </li> 
 *  </ul>
 *  
 *  
 *  <p> Posts may have a query record indicated by their respective record 
 *  types. The queryrecord is accessed via the <code> PostQuery. </code> </p>
 */

public interface PostSearchSession
    extends org.osid.financials.posting.PostQuerySession {


    /**
     *  Gets a post search. 
     *
     *  @return the post search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostSearch getPostSearch();


    /**
     *  Gets a post search order. The <code> PostSearchOrder </code> is 
     *  supplied to a <code> PostSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the post search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostSearchOrder getPostSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  postQuery the post query 
     *  @param  postSearch the post search 
     *  @return the post search results 
     *  @throws org.osid.NullArgumentException <code> postQuery </code> or 
     *          <code> postSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> postQuery </code> or 
     *          <code> postSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostSearchResults getPostsBySearch(org.osid.financials.posting.PostQuery postQuery, 
                                                                          org.osid.financials.posting.PostSearch postSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a post query from an inspector. The inspector is available from a 
     *  <code> PostSearchResults. </code> 
     *
     *  @param  postQueryInspector a post query inspector 
     *  @return the post query 
     *  @throws org.osid.NullArgumentException <code> postQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> postQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.posting.PostQuery getPostQueryFromInspector(org.osid.assessment.ItemQueryInspector postQueryInspector);
}
