//
// org.osid.forum.ForumProfile
//
//     The OSID Java specification for org.osid.forum.ForumProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>The reply profile describes the interoperability among forum services. 
 *  </p>
 */

public interface ForumProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any post federation is exposed. Federation is exposed when a 
     *  specific post may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of posts 
     *  appears as a single post. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of an post lookup service. 
     *
     *  @return <code> true </code> if post lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostLookup();


    /**
     *  Tests if querying posts is available. 
     *
     *  @return <code> true </code> if post query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostQuery();


    /**
     *  Tests if searching for posts is available. 
     *
     *  @return <code> true </code> if post search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostSearch();


    /**
     *  Tests for the availability of a post administrative service for 
     *  creating and deleting posts. 
     *
     *  @return <code> true </code> if post administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostAdmin();


    /**
     *  Tests for the availability of a post notification service. 
     *
     *  @return <code> true </code> if post notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsPostNotification();


    /**
     *  Tests if a post to forum lookup session is available. 
     *
     *  @return <code> true </code> if post forum lookup session is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostForum();


    /**
     *  Tests if a post to forum assignment session is available. 
     *
     *  @return <code> true </code> if post forum assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostForumAssignment();


    /**
     *  Tests if a post smart foruming session is available. 
     *
     *  @return <code> true </code> if post smart foruming is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostSmartForum();


    /**
     *  Tests for the availability of a reply lookup service. 
     *
     *  @return <code> true </code> if reply lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReplyLookup();


    /**
     *  Tests if searching for replies is available. 
     *
     *  @return <code> true </code> if reply search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReplyAdmin();


    /**
     *  Tests if reply notification is available. 
     *
     *  @return <code> true </code> if reply notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReplyNotification();


    /**
     *  Tests for the availability of an forum lookup service. 
     *
     *  @return <code> true </code> if forum lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumLookup();


    /**
     *  Tests if querying forums is available. 
     *
     *  @return <code> true </code> if forum query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumQuery();


    /**
     *  Tests if searching for forums is available. 
     *
     *  @return <code> true </code> if forum search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumSearch();


    /**
     *  Tests for the availability of a forum administrative service for 
     *  creating and deleting forums. 
     *
     *  @return <code> true </code> if forum administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumAdmin();


    /**
     *  Tests for the availability of a forum notification service. 
     *
     *  @return <code> true </code> if forum notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsForumNotification();


    /**
     *  Tests for the availability of a forum hierarchy traversal service. 
     *
     *  @return <code> true </code> if forum hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumHierarchy();


    /**
     *  Tests for the availability of a forum hierarchy design service. 
     *
     *  @return <code> true </code> if forum hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsForumHierarchyDesign();


    /**
     *  Tests if forum batch service is available. 
     *
     *  @return <code> true </code> if forum batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumBatch();


    /**
     *  Gets the supported <code> Post </code> record types. 
     *
     *  @return a list containing the supported post record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPostRecordTypes();


    /**
     *  Tests if the given <code> Post </code> record type is supported. 
     *
     *  @param  postRecordType a <code> Type </code> indicating a <code> Post 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostRecordType(org.osid.type.Type postRecordType);


    /**
     *  Gets the supported post search record types. 
     *
     *  @return a list containing the supported post search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPostSearchRecordTypes();


    /**
     *  Tests if the given post search record type is supported. 
     *
     *  @param  postSearchRecordType a <code> Type </code> indicating a post 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> postSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostSearchRecordType(org.osid.type.Type postSearchRecordType);


    /**
     *  Gets the supported <code> Reply </code> record types. 
     *
     *  @return a list containing the supported reply record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getReplyRecordTypes();


    /**
     *  Tests if the given <code> Reply </code> record type is supported. 
     *
     *  @param  replyRecordType a <code> Type </code> indicating a <code> 
     *          Reply </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> replyRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReplyRecordType(org.osid.type.Type replyRecordType);


    /**
     *  Gets the supported reply search record types. 
     *
     *  @return a list containing the supported reply search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getReplySearchRecordTypes();


    /**
     *  Tests if the given reply search record type is supported. 
     *
     *  @param  replySearchRecordType a <code> Type </code> indicating a reply 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> replySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReplySearchRecordType(org.osid.type.Type replySearchRecordType);


    /**
     *  Gets the supported <code> Forum </code> record types. 
     *
     *  @return a list containing the supported forum record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getForumRecordTypes();


    /**
     *  Tests if the given <code> Forum </code> record type is supported. 
     *
     *  @param  forumRecordType a <code> Type </code> indicating a <code> 
     *          Forum </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> forumRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumRecordType(org.osid.type.Type forumRecordType);


    /**
     *  Gets the supported forum search record types. 
     *
     *  @return a list containing the supported forum search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getForumSearchRecordTypes();


    /**
     *  Tests if the given forum search record type is supported. 
     *
     *  @param  forumSearchRecordType a <code> Type </code> indicating a forum 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> forumSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumSearchRecordType(org.osid.type.Type forumSearchRecordType);
}
