//
// org.osid.forum.ForumQuery
//
//     The OSID Java specification for org.osid.forum.ForumQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>This is the query for searching for forums. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ForumQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the reply <code> Id </code> for this query to match replies 
     *  assigned to forums. 
     *
     *  @param  replyId a reply <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> replyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReplyId(org.osid.id.Id replyId, boolean match);


    /**
     *  Clears the reply <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReplyIdTerms();


    /**
     *  Tests if a reply query is available. 
     *
     *  @return <code> true </code> if a reply query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReplyQuery();


    /**
     *  Gets the query for a forum. 
     *
     *  @return the reply query 
     *  @throws org.osid.UnimplementedException <code> supportsReplyQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsReplyQuery() </code> is <code> true. </code> 
     */

    public org.osid.forum.ReplyQuery getReplyQuery();


    /**
     *  Matches forums with any reply. 
     *
     *  @param  match <code> true </code> to match forums with any reply, 
     *          <code> false </code> to match forums with no replies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyReply(boolean match);


    /**
     *  Clears the reply terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReplyTerms();


    /**
     *  Sets the post <code> Id </code> for this query to match replies 
     *  assigned to posts. 
     *
     *  @param  postId a post <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPostId(org.osid.id.Id postId, boolean match);


    /**
     *  Clears the post <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPostIdTerms();


    /**
     *  Tests if a <code> PostQuery </code> is available. 
     *
     *  @return <code> true </code> if a post query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPostQuery();


    /**
     *  Gets the query for a post query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the post query 
     *  @throws org.osid.UnimplementedException <code> supportsPostQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPostQuery() </code> is <code> true. </code> 
     */

    public org.osid.forum.PostQuery getPostQuery();


    /**
     *  Matches forums with any post. 
     *
     *  @param  match <code> true </code> to match forums with any post, 
     *          <code> false </code> to match forums with no posts 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPost(boolean match);


    /**
     *  Clears the post terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPostTerms();


    /**
     *  Sets the forum <code> Id </code> for this query to match forums that 
     *  have the specified forum as an ancestor. 
     *
     *  @param  forumId a forum <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> forumId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorForumId(org.osid.id.Id forumId, boolean match);


    /**
     *  Clears the ancestor forum <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorForumIdTerms();


    /**
     *  Tests if a <code> ForumQuery </code> is available. 
     *
     *  @return <code> true </code> if a forum query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorForumQuery();


    /**
     *  Gets the query for a forum. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the forum query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorForumQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorForumQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.forum.ForumQuery getAncestorForumQuery();


    /**
     *  Matches forums with any ancestor. 
     *
     *  @param  match <code> true </code> to match forums with any ancestor, 
     *          <code> false </code> to match root forums 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorForum(boolean match);


    /**
     *  Clears the ancestor forum terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorForumTerms();


    /**
     *  Sets the forum <code> Id </code> for this query to match forums that 
     *  have the specified forum as a descendant. 
     *
     *  @param  forumId a forum <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> forumId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantForumId(org.osid.id.Id forumId, boolean match);


    /**
     *  Clears the descendant forum <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantForumIdTerms();


    /**
     *  Tests if a <code> ForumQuery </code> is available. 
     *
     *  @return <code> true </code> if a forum query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantForumQuery();


    /**
     *  Gets the query for a forum. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the forum query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantForumQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantForumQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.forum.ForumQuery getDescendantForumQuery();


    /**
     *  Matches forums with any descendant. 
     *
     *  @param  match <code> true </code> to match forums with any descendant, 
     *          <code> false </code> to match leaf forums 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantForum(boolean match);


    /**
     *  Clears the descendant forum terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantForumTerms();


    /**
     *  Gets the forum query record corresponding to the given <code> Forum 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  forumRecordType a forum record type 
     *  @return the forum query record 
     *  @throws org.osid.NullArgumentException <code> forumRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(forumRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.records.ForumQueryRecord getForumQueryRecord(org.osid.type.Type forumRecordType)
        throws org.osid.OperationFailedException;
}
