//
// org.osid.forum.Post
//
//     The OSID Java specification for org.osid.forum.Post.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>A <code> Post </code> represents a blob of text posted to a forum by a 
 *  poster. Like all OSID objects, a <code> Post </code> is identified by its 
 *  <code> Id </code> and any persisted references should use the <code> Id. 
 *  </code> </p>
 */

public interface Post
    extends org.osid.OsidObject {


    /**
     *  Gets the time of this post. 
     *
     *  @return the time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimestamp();


    /**
     *  Gets the poster <code> Id </code> of this post. 
     *
     *  @return the poster resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPosterId();


    /**
     *  Gets the poster of this post. 
     *
     *  @return the poster resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getPoster()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the posting agent <code> Id </code> of this post. 
     *
     *  @return the posting agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPostingAgentId();


    /**
     *  Gets the posting agent of this post. 
     *
     *  @return the posting agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getPostingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the subject line of this post. 
     *
     *  @return the subject 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSubjectLine();


    /**
     *  Gets the text of the post. 
     *
     *  @return the entry text 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getText();


    /**
     *  Gets the post record corresponding to the given <code> Post </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> postRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(postRecordType) </code> is <code> true </code> . 
     *
     *  @param  postRecordType the type of post record to retrieve 
     *  @return the post record 
     *  @throws org.osid.NullArgumentException <code> postRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(postRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.records.PostRecord getPostRecord(org.osid.type.Type postRecordType)
        throws org.osid.OperationFailedException;
}
