//
// org.osid.forum.PostAdminSession
//
//     The OSID Java specification for org.osid.forum.PostAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>This session creates, updates, and deletes <code> Posts. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Post, </code> a <code> PostForm </code> is requested using <code> 
 *  getPostFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> PostForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> PostForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> PostForm </code> corresponds 
 *  to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> PostForms </code> are requested to the <code> Post 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getPostFormForUpdate(). </code> Similarly, the <code> PostForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> PostForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Posts. </code> To unmap a <code> 
 *  Post </code> from the current <code> Forum, </code> the <code> 
 *  PostForumAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Post </code> itself thus removing it from all 
 *  known <code> Forum </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface PostAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Forum </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Forum Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getForumId();


    /**
     *  Gets the <code> Forum </code> associated with this session. 
     *
     *  @return the forum 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Forum getForum()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Posts. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Post </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Post </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePosts();


    /**
     *  Tests if this user can create a single <code> Post </code> using the 
     *  desired record types. While <code> ForumManager.getPostRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> Post. </code> Providing an empty array tests if a <code> Post 
     *  </code> can be created with no records. 
     *
     *  @param  postRecordTypes array of post record types 
     *  @return <code> true </code> if <code> Post </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> postRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePostWithRecordTypes(org.osid.type.Type[] postRecordTypes);


    /**
     *  Gets the post form for creating new posts. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  postRecordTypes array of post record types 
     *  @return the post form 
     *  @throws org.osid.NullArgumentException <code> postRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostForm getPostFormForCreate(org.osid.type.Type[] postRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Post. </code> 
     *
     *  @param  postForm the form for this <code> Post </code> 
     *  @return the new <code> Post </code> 
     *  @throws org.osid.IllegalStateException <code> postForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> postForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> postForm </code> did not 
     *          originate from <code> getPostFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Post createPost(org.osid.forum.PostForm postForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Posts. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Post </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Post </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdatePosts();


    /**
     *  Gets the post form for updating an existing post. A new post form 
     *  should be requested for each update transaction. 
     *
     *  @param  postId the <code> Id </code> of the <code> Post </code> 
     *  @return the post form 
     *  @throws org.osid.NotFoundException <code> postId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.PostForm getPostFormForUpdate(org.osid.id.Id postId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing post. 
     *
     *  @param  postForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> postForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> postForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> postForm </code> did not 
     *          originate from <code> getPostFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updatePost(org.osid.forum.PostForm postForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Posts </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Post </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Post </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeletePosts();


    /**
     *  Deletes a <code> Post. </code> 
     *
     *  @param  postId the <code> Id </code> of the <code> Post </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> postId </code> not found 
     *  @throws org.osid.NullArgumentException <code> postId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletePost(org.osid.id.Id postId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Posts. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Post </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManagePostAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Post </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Post </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another post, it is reassigned to the given post <code> 
     *  Id. </code> 
     *
     *  @param  postId the <code> Id </code> of a <code> Post </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> postId </code> not found 
     *  @throws org.osid.NullArgumentException <code> postId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasPost(org.osid.id.Id postId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
