//
// org.osid.forum.Reply
//
//     The OSID Java specification for org.osid.forum.Reply.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>A <code> Reply </code> is a response to a <code> Post </code> or 
 *  another <code> Reply. </code> </p>
 */

public interface Reply
    extends org.osid.OsidObject,
            org.osid.Containable,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the original top level post for this 
     *  reply. 
     *
     *  @return the post <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPostId();


    /**
     *  Gets the original top level post. 
     *
     *  @return the post 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Post getPost()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the replies to this rpely. 
     *
     *  @return the reply <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getReplyIds();


    /**
     *  Gets the replies to this reply. 
     *
     *  @return the replies 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyList getReplies()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the time of this entry. 
     *
     *  @return the time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimestamp();


    /**
     *  Gets the poster resource <code> Id </code> of this entry. 
     *
     *  @return the poster resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPosterId();


    /**
     *  Gets the posting of this entry. 
     *
     *  @return the poster resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getPoster()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the posting <code> Id </code> of this entry. 
     *
     *  @return the posting agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPostingAgentId();


    /**
     *  Gets the posting of this entry. 
     *
     *  @return the posting agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getPostingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the subject line of this entry. 
     *
     *  @return the subject 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSubjectLine();


    /**
     *  Gets the text of the entry. 
     *
     *  @return the entry text 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getText();


    /**
     *  Gets the reply record corresponding to the given <code> Reply </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> replyRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(replyRecordType) </code> is <code> true </code> . 
     *
     *  @param  replyRecordType the type of reply record to retrieve 
     *  @return the reply record 
     *  @throws org.osid.NullArgumentException <code> replyRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(replyRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.records.ReplyRecord getReplyRecord(org.osid.type.Type replyRecordType)
        throws org.osid.OperationFailedException;
}
