//
// org.osid.forum.ReplyAdminSession
//
//     The OSID Java specification for org.osid.forum.ReplyAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>This session creates, updates, and deletes <code> Replies. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Reply, </code> a <code> ReplyForm </code> is requested using <code> 
 *  getReplyFormForCreate() </code> specifying the desired post and record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> ReplyForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> ReplyForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> ReplyForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ReplyForms </code> are requested to the <code> 
 *  Reply </code> <code> Id </code> that is to be updated using <code> 
 *  getReplyFormForUpdate(). </code> Similarly, the <code> ReplyForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> ReplyForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Replies. </code> To unmap a <code> 
 *  Reply </code> from the current <code> Forum, </code> the <code> 
 *  ReplyForumAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Reply </code> itself thus removing 
 *  it from all known <code> Forum </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ReplyAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Forum </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Forum Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getForumId();


    /**
     *  Gets the <code> Forum </code> associated with this session. 
     *
     *  @return the forum 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Forum getForum()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create hournal entries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> Reply </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Reply </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateReplies();


    /**
     *  Tests if this user can create a single <code> Reply </code> using the 
     *  desired record types. While <code> ForumManager.getReplyRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> Reply. </code> Providing an empty array tests if a <code> Reply 
     *  </code> can be created with no records. 
     *
     *  @param  replyRecordTypes array of reply record types 
     *  @return <code> true </code> if <code> Reply </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> replyRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateReplyWithRecordTypes(org.osid.type.Type[] replyRecordTypes);


    /**
     *  Gets the reply form for creating new replies to a post. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  postId the <code> Id </code> for the post 
     *  @param  replyRecordTypes array of reply record types 
     *  @return the reply form 
     *  @throws org.osid.NotFoundException <code> postId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> postId </code> or <code> 
     *          replyRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyForm getReplyFormForCreateToPost(org.osid.id.Id postId, 
                                                                org.osid.type.Type[] replyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the reply form for creating new replies to another reply. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  replyId the <code> Id </code> for the reply 
     *  @param  replyRecordTypes array of reply record types 
     *  @return the reply form 
     *  @throws org.osid.NotFoundException <code> replyId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> replyId </code> or 
     *          <code> replyRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyForm getReplyFormForCreateToReply(org.osid.id.Id replyId, 
                                                                 org.osid.type.Type[] replyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Reply. </code> 
     *
     *  @param  replyForm the form for this <code> Reply </code> 
     *  @return the new <code> Reply </code> 
     *  @throws org.osid.IllegalStateException <code> replyForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> replyForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> replyForm </code> did not 
     *          originate from <code> getReplyFormForCreateToPost() </code> or 
     *          <code> getReplyFormForCreateToReply() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.Reply createReply(org.osid.forum.ReplyForm replyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update replies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Reply </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Reply </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateReplies();


    /**
     *  Gets the reply form for updating an existing reply. A new reply form 
     *  should be requested for each update transaction. 
     *
     *  @param  replyId the <code> Id </code> of the <code> Reply </code> 
     *  @return the reply form 
     *  @throws org.osid.NotFoundException <code> replyId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> replyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyForm getReplyFormForUpdate(org.osid.id.Id replyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing reply. 
     *
     *  @param  replyForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> replyForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> replyForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> replyForm </code> did not 
     *          originate from <code> getReplyFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateReply(org.osid.forum.ReplyForm replyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete replies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Reply </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Reply </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteReplies();


    /**
     *  Deletes an <code> Reply. </code> 
     *
     *  @param  replyId the <code> Id </code> of the <code> Reply </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> replyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> replyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteReply(org.osid.id.Id replyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Comnents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Reply </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageReplyAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Reply </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Reply </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another reply, it is reassigned to the given reply <code> 
     *  Id. </code> 
     *
     *  @param  replyId the <code> Id </code> of a <code> Reply </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> replyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> replyId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasReply(org.osid.id.Id replyId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
