//
// org.osid.forum.ReplyQueryInspector
//
//     The OSID Java specification for org.osid.forum.ReplyQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.forum;


/**
 *  <p>This is the query inspector for examining reply queries. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface ReplyQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidContainableQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the post <code> Id </code> terms. 
     *
     *  @return the post <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getPostIdTerms();


    /**
     *  Gets the post terms. 
     *
     *  @return the post terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyQueryInspector[] getPostTerms();


    /**
     *  Gets the timestamp terms. 
     *
     *  @return the timestamp terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeTerm[] getTimestampTerms();


    /**
     *  Gets the poster <code> Id </code> terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getPosterIdTerms();


    /**
     *  Gets the poster terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getPosterTerms();


    /**
     *  Gets the posting agent <code> Id </code> terms. 
     *
     *  @return the agent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getPostingAgentIdTerms();


    /**
     *  Gets the posting agent terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentQueryInspector[] getPostingAgentTerms();


    /**
     *  Gets the subject line terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getSubjectLineTerms();


    /**
     *  Gets the text terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.StringTerm[] getTextTerms();


    /**
     *  Gets the containing reply <code> Id </code> terms. 
     *
     *  @return the containing reply <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getContainingReplyIdTerms();


    /**
     *  Gets the containing reply terms. 
     *
     *  @return the containing reply terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyQueryInspector[] getContainingReplyTerms();


    /**
     *  Gets the contained reply <code> Id </code> terms. 
     *
     *  @return the contained reply <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getContainedReplyIdTerms();


    /**
     *  Gets the contained reply terms. 
     *
     *  @return the contained reply terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ReplyQueryInspector[] getContainedReplyTerms();


    /**
     *  Gets the forum <code> Id </code> terms. 
     *
     *  @return the forum <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getForumIdTerms();


    /**
     *  Gets the forum terms. 
     *
     *  @return the forum terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.ForumQueryInspector[] getForumTerms();


    /**
     *  Gets the reply query inspector record corresponding to the given 
     *  <code> Reply </code> record <code> Type. </code> 
     *
     *  @param  replyRecordType a reply record type 
     *  @return the reply query inspector record 
     *  @throws org.osid.NullArgumentException <code> replyRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(replyRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.forum.records.ReplyQueryInspectorRecord getReplyQueryInspectorRecord(org.osid.type.Type replyRecordType)
        throws org.osid.OperationFailedException;
}
