//
// org.osid.grading.Grade
//
//     The OSID Java specification for org.osid.grading.Grade.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>A <code> Grade. </code> Grades represent qualified performance levels 
 *  defined within some grading system. </p>
 */

public interface Grade
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> GradeSystem Id </code> in which this grade belongs. 
     *
     *  @return the grade system <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradeSystemId();


    /**
     *  Gets the <code> GradeSystem </code> in which this grade belongs. 
     *
     *  @return the grade system 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getGradeSystem();


    /**
     *  Gets the low end of the input score range equivalent to this grade. 
     *
     *  @return the start range 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getInputScoreStartRange();


    /**
     *  Gets the high end of the input score range equivalent to this grade. 
     *
     *  @return the end range 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getInputScoreEndRange();


    /**
     *  Gets the output score for this grade used for calculating cumultives 
     *  or performing articulation. 
     *
     *  @return the output score 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getOutputScore();


    /**
     *  Gets the grade record corresponding to the given <code> Grade </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> gradeRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(gradeRecordType) </code> is <code> true </code> . 
     *
     *  @param  gradeRecordType the type of the record to retrieve 
     *  @return the grade record 
     *  @throws org.osid.NullArgumentException <code> gradeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeRecord getGradeRecord(org.osid.type.Type gradeRecordType)
        throws org.osid.OperationFailedException;
}
