//
// org.osid.grading.GradeEntryLookupSession
//
//     The OSID Java specification for org.osid.grading.GradeEntryLookupSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session provides methods for retrieving <code> GradeEntrie </code> 
 *  s. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated gradebook view: All grade entry methods in this session 
 *      operate, retrieve and pertain to grade entries defined explicitly in 
 *      the current gradebook. Using an isolated view is useful for managing 
 *      grade entries with the <code> GradeEntryAdminSession. </code> </li> 
 *      <li> federated gradebook view: All grade entry methods in this session 
 *      operate, retrieve and pertain to all grade entries defined in this 
 *      gradebook and any other gradebooks implicitly available in this 
 *      gradebook through gradebook inheritence. </li> 
 *      <li> effective grade entry view: All grade entry lookup methods return 
 *      entries where the current date falls in between the effective dates 
 *      inclusive. </li> 
 *      <li> any effective grade entry view: Grade entries of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Grade entries may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> GradeEntry. </code> </p>
 */

public interface GradeEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> GradeEntry </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupGradeEntries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeGradeEntryView();


    /**
     *  A complete view of the <code> GradeEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryGradeEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include grade entries in gradebooks which are children of this 
     *  gradebook in the gradebook hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGradebookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this gradebook only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGradebookView();


    /**
     *  Only grade entries whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveGradeEntryView();


    /**
     *  All grade entries of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveGradeEntryView();


    /**
     *  Gets the <code> GradeEntry </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  GradeEntry </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> GradeEntry </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradeEntryId <code> Id </code> of the <code> GradeEntry 
     *          </code> 
     *  @return the grade entry 
     *  @throws org.osid.NotFoundException <code> gradeEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.GradeEntry getGradeEntry(org.osid.id.Id gradeEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  grade entries specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if a <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible grade entries may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradeEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradeEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesByIds(org.osid.id.IdList gradeEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> corresponding to the given grade 
     *  entry genus <code> Type </code> which does not include grade entries 
     *  of genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  grade entries or an error results. Otherwise, the returned list may 
     *  contain only those grade entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradeEntryGenusType a grade entry genus type 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> gradeEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesByGenusType(org.osid.type.Type gradeEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> corresponding to the given grade 
     *  entry genus <code> Type </code> and include any additional grade entry 
     *  with genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  grade entries or an error results. Otherwise, the returned list may 
     *  contain only those grade entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradeEntryGenusType a grade entry genus type 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> gradeEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesByParentGenusType(org.osid.type.Type gradeEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> containing the given grade entry 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  grade entries or an error results. Otherwise, the returned list may 
     *  contain only those grade entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradeEntryRecordType a grade entry record type 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> gradeEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesByRecordType(org.osid.type.Type gradeEntryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from or to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesOnDate(org.osid.calendaring.DateTime from, 
                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> for the gradebook column. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  grade entries or an error results. Otherwise, the returned list may 
     *  contain only those grade entries that are accessible through this 
     *  session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradebookColumnId a gradebook column <code> Id </code> 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesForGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> for the given gradebook column 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradebookColumnId a gradebook column <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId, from, 
     *          or to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesForGradebookColumnOnDate(org.osid.id.Id gradebookColumnId, 
                                                                                   org.osid.calendaring.DateTime from, 
                                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> for the given key key resource. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a key resource <code> Id </code> 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> for the given key resource and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, or to 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesForResourceOnDate(org.osid.id.Id resourceId, 
                                                                            org.osid.calendaring.DateTime from, 
                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> for the gradebook column and key 
     *  resource. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradebookColumnId a gradebook column <code> Id </code> 
     *  @param  resourceId a key resource <code> Id </code> 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> or <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesForGradebookColumnAndResource(org.osid.id.Id gradebookColumnId, 
                                                                                        org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> for the given gradebook column, 
     *  resource, and effective during the entire given date range inclusive 
     *  but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  gradebookColumnId a gradebook column <code> Id </code> 
     *  @param  resourceId a key resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId, 
     *          resource, from, or to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesForGradebookColumnAndResourceOnDate(org.osid.id.Id gradebookColumnId, 
                                                                                              org.osid.id.Id resourceId, 
                                                                                              org.osid.calendaring.DateTime from, 
                                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeEntryList </code> for the given grader. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> GradeEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntriesByGrader(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all grade entries. 
     *  
     *  In plenary mode, the returned list contains all known grade entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  grade entries that are accessible through this session. 
     *  
     *  In effective mode, grade entries are returned that are currently 
     *  effective. In any effective mode, effective grade entries and those 
     *  currently expired are returned. 
     *
     *  @return a <code> GradeEntryList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryList getGradeEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
