//
// org.osid.grading.GradeEntryNotificationSession
//
//     The OSID Java specification for org.osid.grading.GradeEntryNotificationSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session defines methods to receive asynchronous notifications on 
 *  adds/changes to <code> GradeEntry </code> objects. This session is 
 *  intended for consumers needing to synchronize their state with this 
 *  service without the use of polling. Notifications are cancelled when this 
 *  session is closed. </p> 
 *  
 *  <p> The views defined in this session correspond to the views in the 
 *  <code> GradeEntryLookupSession. </code> </p>
 */

public interface GradeEntryNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> GradeEntry </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForGradeEntryNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for grade entries in gradebooks which are 
     *  children of this gradebook in the gradebook hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGradebookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this gradebook only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGradebookView();


    /**
     *  Register for notifications of new grade entries. <code> 
     *  GradeEntryReceiver.newGradeEntries() </code> is invoked when a new 
     *  grade entry is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradeEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a new grade entry for the specified 
     *  gradebook column. <code> GradeEntryReceiver.newGradeEntries() </code> 
     *  is invoked when a new entry for the resource is created. 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradeEntriesForGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a new grade entry for the specified 
     *  resource. <code> GradeEntryReceiver.newGradeEntries() </code> is 
     *  invoked when a new entry for the resource is created. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradeEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a new grade entry for the specified 
     *  grader agent. <code> GradeEntryReceiver.newGradeEntries() </code> is 
     *  invoked when a new entry for the grader is created. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Agent </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> agentId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewGradeEntriesByGrader(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated grade entries. <code> 
     *  GradeEntryReceiver.changedGradeEntries() </code> is invoked when a 
     *  grade entry is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradeEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated grade entry for the specified 
     *  gradebook column. <code> GradeEntryReceiver.changedGradeEntries() 
     *  </code> is invoked when an entry for the column is updated. 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradeEntriesForGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated grade entry for the specified 
     *  key resource. <code> GradeEntryReceiver.changedGradeEntries() </code> 
     *  is invoked when an entry for the resource is updated. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradeEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated grade entry for the specified 
     *  grader. <code> GradeEntryReceiver.changedGradeEntries() </code> is 
     *  invoked when an entry for the agent is updated. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Agent </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> agentId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradeEntriesByGrader(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated grade entry. <code> 
     *  GradeEntryReceiver.changedGradeEntries() </code> is invoked when the 
     *  specified grade entry is changed. 
     *
     *  @param  gradeEntryId the <code> Id </code> of the <code> GradeEntry 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedGradeEntry(org.osid.id.Id gradeEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted grade entries. <code> 
     *  GradeEntryReceiver.deletedGradeEntries() </code> is invoked when a 
     *  grade entry is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradeEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted grade entry for the specified 
     *  gradebook column. <code> GradeEntryReceiver.changedGradeEntries() 
     *  </code> is invoked when an entry for the column is removed from this 
     *  gradebook. 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradeEntriesForGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted grade entry for the specified 
     *  key resource. <code> GradeEntryReceiver.changedGradeEntries() </code> 
     *  is invoked when an entry for the resource is removed from this 
     *  gradebook. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradeEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted grade entry for the specified 
     *  grader. <code> GradeEntryReceiver.changedGradeEntries() </code> is 
     *  invoked when an entry for the agent is removed from this gradebook. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Agent </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> agentId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradeEntriesByGrader(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted grade entry. <code> 
     *  GradeEntryReceiver.deletedGradeEntries() </code> is invoked when the 
     *  specified entry is deleted. 
     *
     *  @param  gradeEntryId the <code> Id </code> of the <code> GradeEntry 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedGradeEntry(org.osid.id.Id gradeEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
