//
// org.osid.grading.GradeEntryQuery
//
//     The OSID Java specification for org.osid.grading.GradeEntryQuery.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query for searching grade entries. Each method match 
 *  request produces an <code> AND </code> term while multiple invocations of 
 *  a method produces a nested <code> OR. </code> </p>
 */

public interface GradeEntryQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the gradebook column <code> Id </code> for this query. 
     *
     *  @param  gradebookColumnId a gradebook column <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookColumnId(org.osid.id.Id gradebookColumnId, 
                                       boolean match);


    /**
     *  Clears the gradebook column <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnIdTerms();


    /**
     *  Tests if a <code> GradebookColumnQuery </code> is available for 
     *  querying creators. 
     *
     *  @return <code> true </code> if a gradebook column query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnQuery();


    /**
     *  Gets the query for a gradebook column. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the gradebook column query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnQuery getGradebookColumnQuery();


    /**
     *  Clears the gradebook column terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnTerms();


    /**
     *  Sets the key resource <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchKeyResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the key resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKeyResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQUery </code> is available for querying key 
     *  resources. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKeyResourceQuery();


    /**
     *  Gets the query for a key resource. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsKeyResourceQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsKeyResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getKeyResourceQuery();


    /**
     *  Matches grade entries with any key resource. 
     *
     *  @param  match <code> true </code> to match grade entries with any key 
     *          resource, <code> false </code> to match entries with no key 
     *          resource 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyKeyResource(boolean match);


    /**
     *  Clears the key resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearKeyResourceTerms();


    /**
     *  Matches derived grade entries. 
     *
     *  @param  match <code> true </code> to match derived grade entries , 
     *          <code> false </code> to match manual entries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDerived(boolean match);


    /**
     *  Clears the derived terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDerivedTerms();


    /**
     *  Sets the grade entry <code> Id </code> for an overridden calculated 
     *  grade entry. 
     *
     *  @param  gradeEntryId a grade entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverriddenGradeEntryId(org.osid.id.Id gradeEntryId, 
                                            boolean match);


    /**
     *  Clears the overridden grade entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverriddenGradeEntryIdTerms();


    /**
     *  Tests if a <code> GradeEntry </code> is available for querying 
     *  overridden calculated grade entries. 
     *
     *  @return <code> true </code> if a grade entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOverriddenGradeEntryQuery();


    /**
     *  Gets the query for an overridden derived grade entry. Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @return the grade entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOverriddenGradeEntryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOverriddenGradeEntryQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradeEntryQuery getOverriddenGradeEntryQuery();


    /**
     *  Matches grade entries overriding any calculated grade entry. 
     *
     *  @param  match <code> true </code> to match grade entries overriding 
     *          any grade entry, <code> false </code> to match entries not 
     *          overriding any entry 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverriddenGradeEntry(boolean match);


    /**
     *  Clears the overridden grade entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverriddenGradeEntryTerms();


    /**
     *  Matches grade entries ignored for calculations. 
     *
     *  @param  match <code> true </code> to match grade entries ignored for 
     *          calculations, <code> false </code> to match entries used in 
     *          calculations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIgnoredForCalculations(boolean match);


    /**
     *  Clears the ignored for calculation entries terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIgnoredForCalculationsTerms();


    /**
     *  Sets the grade <code> Id </code> for this query. 
     *
     *  @param  gradeId a grade <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeId(org.osid.id.Id gradeId, boolean match);


    /**
     *  Clears the grade <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeIdTerms();


    /**
     *  Tests if a <code> GradeQuery </code> is available for querying grades. 
     *
     *  @return <code> true </code> if a grade query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeQuery();


    /**
     *  Gets the query for a grade. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade query 
     *  @throws org.osid.UnimplementedException <code> supportsGradeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeQuery getGradeQuery();


    /**
     *  Matches grade entries with any grade. 
     *
     *  @param  match <code> true </code> to match grade entries with any 
     *          grade, <code> false </code> to match entries with no grade 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGrade(boolean match);


    /**
     *  Clears the grade terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeTerms();


    /**
     *  Matches grade entries which score is between the specified score 
     *  inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchScore(java.math.BigDecimal start, 
                           java.math.BigDecimal end, boolean match);


    /**
     *  Matches grade entries with any score. 
     *
     *  @param  match <code> true </code> to match grade entries with any 
     *          score, <code> false </code> to match entries with no score 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyScore(boolean match);


    /**
     *  Clears the score terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearScoreTerms();


    /**
     *  Matches grade entries which graded time is between the specified times 
     *  inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeGraded(org.osid.calendaring.DateTime start, 
                                org.osid.calendaring.DateTime end, 
                                boolean match);


    /**
     *  Clears the time graded terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeGradedTerms();


    /**
     *  Sets the agent <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGraderId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the grader <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGraderIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for querying 
     *  graders. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraderQuery();


    /**
     *  Gets the query for an agent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getGraderQuery();


    /**
     *  Matches grade entries with any grader. 
     *
     *  @param  match <code> true </code> to match grade entries with any 
     *          grader, <code> false </code> to match entries with no grader 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGrader(boolean match);


    /**
     *  Clears the grader terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGraderTerms();


    /**
     *  Sets the grading agent <code> Id </code> for this query. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the grader <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available for querying 
     *  grading agents. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingAgentQuery();


    /**
     *  Gets the query for an agent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getGradingAgentQuery();


    /**
     *  Matches grade entries with any grading agent. 
     *
     *  @param  match <code> true </code> to match grade entries with any 
     *          grading agent, <code> false </code> to match entries with no 
     *          grading agent 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradingAgent(boolean match);


    /**
     *  Clears the grading agent terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradingAgentTerms();


    /**
     *  Sets the gradebook <code> Id </code> for this query. 
     *
     *  @param  gradebookId a gradebook <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookId(org.osid.id.Id gradebookId, boolean match);


    /**
     *  Clears the gradebook <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookIdTerms();


    /**
     *  Tests if a <code> GradebookQuery </code> is available for querying 
     *  resources. 
     *
     *  @return <code> true </code> if a gradebook query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookQuery();


    /**
     *  Gets the query for a gradebook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the gradebook query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradebookQuery getGradebookQuery();


    /**
     *  Clears the gradebook terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookTerms();


    /**
     *  Gets the grade entry query record corresponding to the given <code> 
     *  GradeEntry </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  gradeEntryRecordType a grade entry record type 
     *  @return the grade entry query record 
     *  @throws org.osid.NullArgumentException <code> gradeEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeEntryQueryRecord getGradeEntryQueryRecord(org.osid.type.Type gradeEntryRecordType)
        throws org.osid.OperationFailedException;
}
