//
// org.osid.grading.GradeEntrySearchSession
//
//     The OSID Java specification for org.osid.grading.GradeEntrySearchSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session provides methods for searching <code> GradeEntry </code> 
 *  objects. The search query is constructed using the <code> GradeEntryQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getGradeEntriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> GradeEntry </code> objects.A more advanced search 
 *  may be performed with <code> getGradeEntriesBySearch(). </code> It accepts 
 *  a <code> GradeEntrySearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getGradeEntriesBySearch() </code> returns a <code> 
 *  GradeEntrySearchResults </code> that can be used to access the resulting 
 *  <code> GradeEntryList </code> or be used to perform a search within the 
 *  result set through <code> GradeEntrySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated gradebook view: searches include grade entries in 
 *      gradebooks of which this gradebook is a ancestor in the gradebook 
 *      hierarchy </li> 
 *      <li> isolated gradebook view: searches are restricted to grade entries 
 *      in this gradebook </li> 
 *  </ul>
 *  
 *  
 *  <p> Grade entries may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> GradeEntryQuery. 
 *  </code> </p>
 */

public interface GradeEntrySearchSession
    extends org.osid.grading.GradeEntryQuerySession {


    /**
     *  Gets a grade entry search. 
     *
     *  @return the grade entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntrySearch getGradeEntrySearch();


    /**
     *  Gets a grade entry search order. The <code> GradeEntrySearchOrder 
     *  </code> is supplied to a <code> GradeEntrySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the grade entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntrySearchOrder getGradeEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  gradeEntryQuery the grade entry query 
     *  @param  gradeEntrySearch the grade entry search 
     *  @return the grade entry search results 
     *  @throws org.osid.NullArgumentException <code> gradeEntryQuery </code> 
     *          or <code> gradeEntrySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradeEntrySearch </code> 
     *          or <code> gradeEntryQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntrySearchResults getGradeEntriesBySearch(org.osid.grading.GradeEntryQuery gradeEntryQuery, 
                                                                            org.osid.grading.GradeEntrySearch gradeEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a grade entry query from an inspector. The inspector is available 
     *  from an <code> GradeEntrySearchResults. </code> 
     *
     *  @param  gradeEntryQueryInspector a grade entry query inspector 
     *  @return the grade entry query 
     *  @throws org.osid.NullArgumentException <code> gradeEntryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> gradeEntryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryQuery getGradeEntryQueryFromInspector(org.osid.grading.GradeEntryQueryInspector gradeEntryQueryInspector);
}
