//
// org.osid.grading.GradeForm
//
//     The OSID Java specification for org.osid.grading.GradeForm.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the form for creating and updating <code> Grades. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> GradeAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface GradeForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the input score start range. 
     *
     *  @return metadata for the input score start range 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInputScoreStartRangeMetadata();


    /**
     *  Sets the input score start range. 
     *
     *  @param  score the new start range 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> range </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInputScoreStartRange(java.math.BigDecimal score);


    /**
     *  Clears the input score start. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInputStartScoreRange();


    /**
     *  Gets the metadata for the input score start range. 
     *
     *  @return metadata for the input score start range 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInputScoreEndRangeMetadata();


    /**
     *  Sets the input score start range. 
     *
     *  @param  score the new start range 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> range </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInputScoreEndRange(java.math.BigDecimal score);


    /**
     *  Clears the input score start. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInputScoreEndRange();


    /**
     *  Gets the metadata for the output score start range. 
     *
     *  @return metadata for the output score start range 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOutputScoreMetadata();


    /**
     *  Sets the output score. 
     *
     *  @param  score the new output score 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> score </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOutputScore(java.math.BigDecimal score);


    /**
     *  Clears the output score. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOutputScore();


    /**
     *  Gets the <code> GradeFormRecord </code> corresponding to the given 
     *  grade record <code> Type. </code> 
     *
     *  @param  gradeRecordType the grade record type 
     *  @return the grade form record 
     *  @throws org.osid.NullArgumentException <code> gradeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeFormRecord getGradeFormRecord(org.osid.type.Type gradeRecordType)
        throws org.osid.OperationFailedException;
}
