//
// org.osid.grading.GradeQueryInspector
//
//     The OSID Java specification for org.osid.grading.GradeQueryInspector.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query inspector for examining grade queries. </p>
 */

public interface GradeQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the grade system <code> Id </code> terms. 
     *
     *  @return the grade system <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradeSystemIdTerms();


    /**
     *  Gets the grade system terms. 
     *
     *  @return the grade system terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemQueryInspector[] getGradeSystemTerms();


    /**
     *  Gets the input score start range terms. 
     *
     *  @return the input score start range terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getInputScoreStartRangeTerms();


    /**
     *  Gets the input score end range terms. 
     *
     *  @return the input score end range terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getInputScoreEndRangeTerms();


    /**
     *  Gets the input score terms. 
     *
     *  @return the input score range terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getInputScoreTerms();


    /**
     *  Gets the output score terms. 
     *
     *  @return the output score terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getOutputScoreTerms();


    /**
     *  Gets the grade entry <code> Id </code> terms. 
     *
     *  @return the grade entry <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradeEntryIdTerms();


    /**
     *  Gets the grade entry terms. 
     *
     *  @return the grade entry terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeEntryQueryInspector[] getGradeEntryTerms();


    /**
     *  Gets the gradebook <code> Id </code> terms. 
     *
     *  @return the gradebook <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradebookIdTerms();


    /**
     *  Gets the gradebook terms. 
     *
     *  @return the gradebook terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookQueryInspector[] getGradebookTerms();


    /**
     *  Gets the grade query inspector record corresponding to the given 
     *  <code> Grade </code> record <code> Type. </code> 
     *
     *  @param  gradeRecordType a grade record type 
     *  @return the grade query inspector record 
     *  @throws org.osid.NullArgumentException <code> gradeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeQueryInspectorRecord getGradeQueryInspectorRecord(org.osid.type.Type gradeRecordType)
        throws org.osid.OperationFailedException;
}
