//
// org.osid.grading.GradeSystem
//
//     The OSID Java specification for org.osid.grading.GradeSystem.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>A <code> GradeSystem </code> represents a grading system. The system 
 *  can be based on assigned Grades or based on a numeric scale. </p>
 */

public interface GradeSystem
    extends org.osid.OsidObject,
            org.osid.Aggregateable {


    /**
     *  Tests if the grading system is based on grades. 
     *
     *  @return true if the grading system is based on grades, <code> false 
     *          </code> if the system is a numeric score 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBasedOnGrades();


    /**
     *  Gets the grade <code> Ids </code> in this system ranked from highest 
     *  to lowest. 
     *
     *  @return the list of grades <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isBasedOnGrades() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getGradeIds();


    /**
     *  Gets the grades in this system ranked from highest to lowest. 
     *
     *  @return the list of grades 
     *  @throws org.osid.IllegalStateException <code> isBasedOnGrades() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeList getGrades()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the lowest number in a numeric grading system. 
     *
     *  @return the lowest number 
     *  @throws org.osid.IllegalStateException <code> isBasedOnGrades() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getLowestNumericScore();


    /**
     *  Gets the incremental step. 
     *
     *  @return the increment 
     *  @throws org.osid.IllegalStateException <code> isBasedOnGrades() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getNumericScoreIncrement();


    /**
     *  Gets the highest number in a numeric grading system. 
     *
     *  @return the highest number 
     *  @throws org.osid.IllegalStateException <code> isBasedOnGrades() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getHighestNumericScore();


    /**
     *  Gets the grade system record corresponding to the given <code> 
     *  GradeSystem </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  gradeSystemRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(gradeSystemRecordType) </code> is <code> true </code> . 
     *
     *  @param  gradeSystemRecordType the type of the record to retrieve 
     *  @return the grade system record 
     *  @throws org.osid.NullArgumentException <code> gradeSystemRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeSystemRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeSystemRecord getGradeSystemRecord(org.osid.type.Type gradeSystemRecordType)
        throws org.osid.OperationFailedException;
}
