//
// org.osid.grading.GradeSystemForm
//
//     The OSID Java specification for org.osid.grading.GradeSystemForm.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the form for creating and updating <code> GradeSystems. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  GradeSystemAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface GradeSystemForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidAggregateableForm {


    /**
     *  Gets the metadata for a grade-based designation. 
     *
     *  @return metadata for the grade-based designation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBasedOnGradesMetadata();


    /**
     *  Sets the grade-based designation. 
     *
     *  @param  grades the grade-based designation 
     *  @throws org.osid.InvalidArgumentException <code> grades </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> grades </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBaseOnGrades(boolean grades);


    /**
     *  Clears the based on grades designation. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBasedOnGrades();


    /**
     *  Gets the metadata for the lowest numeric score. 
     *
     *  @return metadata for the lowest numeric score 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLowestNumericScoreMetadata();


    /**
     *  Sets the lowest numeric score. 
     *
     *  @param  score the lowest numeric score 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> score </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLowestNumericScore(java.math.BigDecimal score);


    /**
     *  Clears the lowest score. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLowestScore();


    /**
     *  Gets the metadata for the lowest numeric score. 
     *
     *  @return metadata for the lowest numeric score 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNumericScoreIncrementMetadata();


    /**
     *  Sets the numeric score increment. 
     *
     *  @param  increment the numeric score increment 
     *  @throws org.osid.InvalidArgumentException <code> increment </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> increment </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNumericScoreIncrement(java.math.BigDecimal increment);


    /**
     *  Clears the numeric score increment. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumericScoreIncrement();


    /**
     *  Gets the metadata for the highest numeric score. 
     *
     *  @return metadata for the highest numeric score 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getHighestNumericScoreMetadata();


    /**
     *  Sets the highest numeric score. 
     *
     *  @param  score the highest numeric score 
     *  @throws org.osid.InvalidArgumentException <code> score </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> score </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setHighestNumericScore(java.math.BigDecimal score);


    /**
     *  Clears the highest numeric score. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHighestNumericScore();


    /**
     *  Gets the <code> GradeSystemFormRecord </code> corresponding to the 
     *  given grade system record <code> Type. </code> 
     *
     *  @param  gradeSystemRecordType the grade system record type 
     *  @return the grade system form record 
     *  @throws org.osid.NullArgumentException <code> gradeSystemRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeSystemRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeSystemFormRecord getGradeSystemFormRecord(org.osid.type.Type gradeSystemRecordType)
        throws org.osid.OperationFailedException;
}
