//
// org.osid.grading.GradeSystemLookupSession
//
//     The OSID Java specification for org.osid.grading.GradeSystemLookupSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>The session defines methods for retrieving <code> Grades </code> and 
 *  <code> GradeSystems. </code> A Grade represents a qualified ranking 
 *  defined in some grade system. </p> 
 *  
 *  <p> Two views are defined in this session: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> federated gradebook view: lookups include grade systems from this 
 *      gradebook and other gradebooks which are children of this gradebook in 
 *      the gradebook hierarchy </li> 
 *      <li> isolated gradebook view: lookups include only those grade systems 
 *      defined in this gradebook </li> 
 *  </ul>
 *  
 *  
 *  <p> Grades and grade systems may have an additional records indicated by 
 *  their respective record types. The record may not be accessed through a 
 *  cast of the object. </p>
 */

public interface GradeSystemLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> GradeSystem </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> GradeSystem Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> GradeSystem </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupGradeSystems();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeGradeSystemView();


    /**
     *  A complete view of the <code> GradeSystem </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryGradeSystemView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include grade entries in gradebooks which are children of this 
     *  gradebook in the gradebook hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGradebookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this gradebook only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGradebookView();


    /**
     *  Gets the <code> GradeSystem </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  GradeSystem </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> GradeSystem </code> and retained for 
     *  compatibility. 
     *
     *  @param  gradeSystemId <code> Id </code> of the <code> GradeSystem 
     *          </code> 
     *  @return the grade system 
     *  @throws org.osid.NotFoundException <code> gradeSystemId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.GradeSystem getGradeSystem(org.osid.id.Id gradeSystemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> GradeSystem </code> by a <code> Grade </code> <code> 
     *  Id. </code> 
     *
     *  @param  gradeId <code> Id </code> of a <code> Grade </code> 
     *  @return the grade system 
     *  @throws org.osid.NotFoundException <code> gradeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.GradeSystem getGradeSystemByGrade(org.osid.id.Id gradeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the systems specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> GradeSystems </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  gradeSystemIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> GradeSystem </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradeSystemsByIds(org.osid.id.IdList gradeSystemIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemList </code> corresponding to the given grade 
     *  system genus <code> Type </code> which does not include systems of 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known systems or an error 
     *  results. Otherwise, the returned list may contain only those systems 
     *  that are accessible through this session. 
     *
     *  @param  gradeSystemGenusType a grade system genus type 
     *  @return the returned <code> GradeSystem </code> list 
     *  @throws org.osid.NullArgumentException <code> gradeSystemGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradeSystemsByGenusType(org.osid.type.Type gradeSystemGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemList </code> corresponding to the given grade 
     *  system genus <code> Type </code> and include any additional systems 
     *  with genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known systems or an error 
     *  results. Otherwise, the returned list may contain only those systems 
     *  that are accessible through this session. 
     *
     *  @param  gradeSystemGenusType a grade system genus type 
     *  @return the returned <code> GradeSystem </code> list 
     *  @throws org.osid.NullArgumentException <code> gradeSystemGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradeSystemsByParentGenusType(org.osid.type.Type gradeSystemGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemList </code> containing the given grade 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known systems or an error results. Otherwise, the 
     *  returned list may contain only those systems that are accessible 
     *  through this session. 
     *
     *  @param  gradeSystemRecordType a grade system record type 
     *  @return the returned <code> GradeSystem </code> list 
     *  @throws org.osid.NullArgumentException <code> gradeSystemGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradeSystemsByRecordType(org.osid.type.Type gradeSystemRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> GradeSystems. </code> In plenary mode, the returned 
     *  list contains all known grade systems or an error results. Otherwise, 
     *  the returned list may contain only those grade systems that are 
     *  accessible through this session. 
     *
     *  @return a <code> GradeSystemList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getGradeSystems()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
