//
// org.osid.grading.GradeSystemQueryInspector
//
//     The OSID Java specification for org.osid.grading.GradeSystemQueryInspector.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query inspector for examining grade system queries. </p>
 */

public interface GradeSystemQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidAggregateableQueryInspector {


    /**
     *  Gets the grade-based systems terms. 
     *
     *  @return the grade-based systems terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getBasedOnGradesTerms();


    /**
     *  Gets the grade <code> Id </code> terms. 
     *
     *  @return the grade <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradeIdTerms();


    /**
     *  Gets the grade terms. 
     *
     *  @return the grade terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getGradeTerms();


    /**
     *  Gets the lowest numeric score terms. 
     *
     *  @return the lowest numeric score terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getLowestNumericScoreTerms();


    /**
     *  Gets the numeric score increment terms. 
     *
     *  @return the numeric score increment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getNumericScoreIncrementTerms();


    /**
     *  Gets the highest numeric score terms. 
     *
     *  @return the highest numeric score terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getHighestNumericScoreTerms();


    /**
     *  Gets the gradebook column <code> Id </code> terms. 
     *
     *  @return the gradebook column <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradebookColumnIdTerms();


    /**
     *  Gets the gradebook column terms. 
     *
     *  @return the gradebook column terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnQueryInspector[] getGradebookColumnTerms();


    /**
     *  Gets the gradebook <code> Id </code> terms. 
     *
     *  @return the gradebook <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getGradebookIdTerms();


    /**
     *  Gets the gradebook terms. 
     *
     *  @return the gradebook terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookQueryInspector[] getGradebookTerms();


    /**
     *  Gets the grade system query inspector record corresponding to the 
     *  given <code> GradeSystem </code> record <code> Type. </code> 
     *
     *  @param  gradeSystemRecordType a grade system record type 
     *  @return the grade system query inspector record 
     *  @throws org.osid.NullArgumentException <code> gradeSystemRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeSystemRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradeSystemQueryInspectorRecord getGradeSystemQueryInspectorRecord(org.osid.type.Type gradeSystemRecordType)
        throws org.osid.OperationFailedException;
}
