//
// org.osid.grading.GradeSystemSearchSession
//
//     The OSID Java specification for org.osid.grading.GradeSystemSearchSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session provides methods for searching among <code> GradeSystems. 
 *  </code> The search query is constructed using the <code> GradeSystemQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getGradeSystemsByQuery() </code> is the basic search method and 
 *  returns a list of <code> GradeSystems. </code> A more advanced search may 
 *  be performed with <code> getGradeSystemsBySearch(). </code> It accepts a 
 *  <code> GradeSystemSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getGradeSystemsBySearch() </code> returns a <code> 
 *  GradeSystemSearchResults </code> that can be used to access the resulting 
 *  <code> GradeSystemList </code> or be used to perform a search within the 
 *  result set through <code> GradeSystemSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated gradebook view: searches include grade systems in 
 *      gradebooks of which this gradebook is a ancestor in the gradebook 
 *      hierarchy </li> 
 *      <li> isolated gradebook view: searches are restricted to grade systems 
 *      in this gradebook </li> 
 *  </ul>
 *  
 *  
 *  <p> Grade systems may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  GradeSystemQuery. </code> </p>
 */

public interface GradeSystemSearchSession
    extends org.osid.grading.GradeSystemQuerySession {


    /**
     *  Gets a grade system search. 
     *
     *  @return a grade system search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemSearch getGradeSystemSearch();


    /**
     *  Gets a grade system search order. The <code> GradeSystemSearchOrder 
     *  </code> is supplied to a <code> GradeSystemSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the grade system search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemSearchOrder getGradeSystemSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  gradeSystemQuery the grade system query 
     *  @param  gradeSystemSearch the grade system search 
     *  @return the grade system search results 
     *  @throws org.osid.NullArgumentException <code> gradeSystemQuery </code> 
     *          or <code> gradeSystemSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradeSystemQuery </code> 
     *          or <code> gradeSystemSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemSearchResults getGradeSystemsBySearch(org.osid.grading.GradeSystemQuery gradeSystemQuery, 
                                                                             org.osid.grading.GradeSystemSearch gradeSystemSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a grade system query from an inspector. The inspector is 
     *  available from an <code> GradeSystemSearchResults. </code> 
     *
     *  @param  gradeSystemQueryInspector a grade system query inspector 
     *  @return the grade system query 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> gradeSystemQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemQuery getGradeSystemQueryFromInspector(org.osid.grading.GradeSystemQueryInspector gradeSystemQueryInspector);
}
