//
// org.osid.grading.GradebookColumn
//
//     The OSID Java specification for org.osid.grading.GradebookColumn.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>A <code> GradebookColumn </code> represents a series of grade entries 
 *  in a gradebook. Each GradeEntry in a column share the same <code> 
 *  GradeSystem. </code> </p>
 */

public interface GradebookColumn
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> GradeSystem Id </code> in which this grade belongs. 
     *
     *  @return the grade system <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradeSystemId();


    /**
     *  Gets the <code> GradeSystem </code> in which this grade belongs. 
     *
     *  @return the package grade system 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystem getGradeSystem()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the gradebook column record corresponding to the given <code> 
     *  GradeBookColumn </code> record <code> Type. </code> This method ie 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> gradebookColumnRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(gradebookColumnRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  gradebookColumnRecordType the type of the record to retrieve 
     *  @return the gradebook column record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradebookColumnRecord getGradebookColumnRecord(org.osid.type.Type gradebookColumnRecordType)
        throws org.osid.OperationFailedException;
}
