//
// org.osid.grading.GradebookColumnAdminSession
//
//     The OSID Java specification for org.osid.grading.GradebookColumnAdminSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session creates, updates, and deletes <code> GradebookColumns. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  GradebookColumn, </code> a <code> GradebookColumnForm </code> is requested 
 *  using <code> getGradebookColumnFormForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> GradebookColumnForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  GradebookColumnForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> GradebookColumnForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> GradebookColumnForms </code> are requested to the 
 *  <code> GradebookColumn </code> <code> Id </code> that is to be updated 
 *  using <code> getGradebookColumnFormForUpdate(). </code> Similarly, the 
 *  <code> GradebookColumnForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> GradebookColumnForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> GradebookColumns </code> To unmap 
 *  a <code> GradebookColumn </code> from the current <code> Gradebook, 
 *  </code> the <code> GradebookColumnGradebookAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  GradebookColumnForm </code> itself thus removing it from all known <code> 
 *  Gradebook </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface GradebookColumnAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create gradebook columns. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a gradebook column will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradebookColumn </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradebookColumns();


    /**
     *  Tests if this user can create a single <code> GradebookColumn </code> 
     *  using the desired record types. While <code> 
     *  GradingManager.getGradebookColumnRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> GradebookColumn. </code> 
     *  Providing an empty array tests if a <code> GradebookColumn </code> can 
     *  be created with no records. 
     *
     *  @param  gradebookColumnRecordTypes array of gradebook column record 
     *          types 
     *  @return <code> true </code> if <code> GradebookColumn </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradebookColumnWithRecordTypes(org.osid.type.Type[] gradebookColumnRecordTypes);


    /**
     *  Gets the gradebook column form for creating new gradebook columns. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  gradebookColumnRecordTypes array of gradebook column record 
     *          types 
     *  @return the gradebook column form 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnForm getGradebookColumnFormForCreate(org.osid.type.Type[] gradebookColumnRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> GradebookColumn. </code> 
     *
     *  @param  gradebookColumnForm the form for this <code> GradebookColumn 
     *          </code> 
     *  @return the new <code> GradebookColumn </code> 
     *  @throws org.osid.IllegalStateException <code> gradebookColumnForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradebookColumnForm 
     *          </code> did not originate from <code> 
     *          getGradebookColumnFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumn createGradebookColumn(org.osid.grading.GradebookColumnForm gradebookColumnForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update gradebook columns. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> GradebookColumn </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if gradebook column modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateGradebookColumns();


    /**
     *  Gets the gradebook column form for updating an existing gradebook 
     *  column. A new gradebook column form should be requested for each 
     *  update transaction. 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> 
     *  @return the gradebook column form 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnForm getGradebookColumnFormForUpdate(org.osid.id.Id gradebookColumnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing gradebook column. 
     *
     *  @param  gradebookColumnForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> gradebookColumnForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradebookColumnForm 
     *          </code> did not originate from <code> 
     *          getGradebookColumnFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateGradebookColumn(org.osid.grading.GradebookColumnForm gradebookColumnForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Resequences the gradebook columns. 
     *
     *  @param  gradebookColumnIds the <code> Ids </code> of the <code> 
     *          GradebookColumns </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnIdList 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void sequenceGradebookColumns(org.osid.id.IdList gradebookColumnIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a gradebook column in front of another. 
     *
     *  @param  frontGradebookColumnId the <code> Id </code> of a <code> 
     *          GradebookColumn </code> 
     *  @param  backGradebookColumnId the <code> Id </code> of a <code> 
     *          GradebookColumn </code> 
     *  @throws org.osid.NotFoundException <code> frontGradebookColumnId or 
     *          backGradebookColumnId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> frontGradebookColumnId 
     *          or backGradebookColumnId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveGradebookColumn(org.osid.id.Id frontGradebookColumnId, 
                                    org.osid.id.Id backGradebookColumnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Copies gradebook column entries from one column to another. If the 
     *  target grade column grade system differs from the source, the grades 
     *  in the entries are transformed to the new grade system. 
     *
     *  @param  sourceGradebookColumnId the <code> Id </code> of a <code> 
     *          GradebookColumn </code> 
     *  @param  targetGradebookColumnId the <code> Id </code> of a <code> 
     *          GradebookColumn </code> 
     *  @throws org.osid.NotFoundException <code> sourceGradebookColumnId 
     *          ortargetGradebookColumnId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> sourceGradebookColumnId 
     *          targetGradebookColumnId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void copyGradebookColumnEntries(org.osid.id.Id sourceGradebookColumnId, 
                                           org.osid.id.Id targetGradebookColumnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete gradebook columns. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> GradebookColumn </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradebookColumn </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteGradebookColumns();


    /**
     *  Deletes the <code> GradebookColumn </code> identified by the given 
     *  <code> Id. </code> 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> to delete 
     *  @throws org.osid.NotFoundException a <code> GradebookColumn </code> 
     *          was not found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  GradebookColumns. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradebookColumn </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageGradebookColumnAliases();


    /**
     *  Adds an <code> Id </code> to a <code> GradebookColumn </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> GradebookColumn </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another gradebook column, it is 
     *  reassigned to the given gradebook column <code> Id. </code> 
     *
     *  @param  gradebookColumnId the <code> Id </code> of a <code> 
     *          GradebookColumn </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasGradebookColumn(org.osid.id.Id gradebookColumnId, 
                                     org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
