//
// org.osid.grading.GradebookColumnGradebookAssignmentSession
//
//     The OSID Java specification for org.osid.grading.GradebookColumnGradebookAssignmentSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session provides methods to re-assign gradebook columns to <code> 
 *  Gradebooks. </code> A <code> GradebookColumn </code> may map to multiple 
 *  <code> Gradebooks </code> and removing the last reference to a <code> 
 *  GradebookColumn </code> is the equivalent of deleting it. Each <code> 
 *  Gradebook </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> GradebookColumn </code> to 
 *  another <code> Gradebook </code> is not a copy operation (eg: does not 
 *  change its <code> Id </code> ). </p>
 */

public interface GradebookColumnGradebookAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter gradebook column/gradebook mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer assignment 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignGradebookColumns();


    /**
     *  Tests if this user can alter gradebook column/gradebook mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer assignment 
     *  operations to unauthorized users. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignGradebookColumnsToGradebook(org.osid.id.Id gradebookId);


    /**
     *  Gets a list of gradebook <code> Ids </code> including and under the 
     *  given gradebook node in which any gradebook column can be assigned. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @return list of assignable gradebook <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableGradebookIds(org.osid.id.Id gradebookId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of gradebooks including and under the given gradebook node 
     *  in which a specific gradebook column can be assigned. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebokColumn </code> 
     *  @return list of assignable gradebook <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> gradebookColumnId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableGradebookIdsForGradebookColumn(org.osid.id.Id gradebookId, 
                                                                          org.osid.id.Id gradebookColumnId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> GradebookColumn </code> to a <code> Gradebook. 
     *  </code> 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> 
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> gradebookColumnId 
     *          </code> is already assigned to <code> gradebookId </code> 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> or 
     *          <code> gradebookId </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> or <code> gradebookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignGradebookColumnToGradebook(org.osid.id.Id gradebookColumnId, 
                                                 org.osid.id.Id gradebookId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> GradebookColumn </code> from a <code> Gradebook. 
     *  </code> 
     *
     *  @param  gradebookColumnId the <code> Id </code> of the <code> 
     *          GradebookColumn </code> 
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> or 
     *          <code> gradebookId </code> not found or <code> 
     *          gradebookColumnId </code> not assigned to <code> gradebookId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> or <code> gradebookId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignGradebookColumnFromGradebook(org.osid.id.Id gradebookColumnId, 
                                                     org.osid.id.Id gradebookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
