//
// org.osid.grading.GradebookColumnLookupSession
//
//     The OSID Java specification for org.osid.grading.GradebookColumnLookupSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session provides methods for retrieving <code> GradebookColumns 
 *  </code> . </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated gradebook view: All gradebook column methods in this 
 *      session operate, retrieve and pertain to gradebook columns defined 
 *      explicitly in the current gradebook. Using an isolated view is useful 
 *      for managing gradebook columns with the <code> 
 *      GradebookColumnAdminSession. </code> </li> 
 *      <li> federated gradebook view: All gradebook column methods in this 
 *      session operate, retrieve and pertain to all gradebook columns defined 
 *      in this gradebook and any other gradebooks implicitly available in 
 *      this gradebook through gradebook inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Gradebook columns may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> GradebookColumn. </code> </p>
 */

public interface GradebookColumnLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> GradebookColumn </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupGradebookColumns();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeGradebookColumnView();


    /**
     *  A complete view of the <code> GradebookColumn </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryGradebookColumnView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include gradebook columns in gradebooks which are children of this 
     *  gradebook in the gradebook hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGradebookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this gradebook only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGradebookView();


    /**
     *  Gets the <code> GradebookColumn </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  GradebookColumn </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> GradebookColumn </code> and retained for 
     *  compatibility. 
     *
     *  @param  gradebookColumnId <code> Id </code> of the <code> 
     *          GradebookColumn </code> 
     *  @return the gradebook column 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.GradebookColumn getGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the gradebook columns specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if a 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible gradeboook columns may be omitted from the 
     *  list. 
     *
     *  @param  gradebookColumnIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> GradebookColumn </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradeBookColumnIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnList getGradebookColumnsByIds(org.osid.id.IdList gradebookColumnIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnList </code> corresponding to the given 
     *  gradebook column genus <code> Type </code> which does not include 
     *  gradebook columns of genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  gradebook columns or an error results. Otherwise, the returned list 
     *  may contain only those gradebook columns that are accessible through 
     *  this session. 
     *
     *  @param  gradebookColumnGenusType a gradebook column genus type 
     *  @return the returned <code> GradebookColumn </code> list 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnList getGradebookColumnsByGenusType(org.osid.type.Type gradebookColumnGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnList </code> corresponding to the given 
     *  gradebook column genus <code> Type </code> and include any additional 
     *  columns with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  gradebook columns or an error results. Otherwise, the returned list 
     *  may contain only those gradebook columns that are accessible through 
     *  this session. 
     *
     *  @param  gradebookColumnGenusType a gradebook column genus type 
     *  @return the returned <code> GradebookColumn </code> list 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnList getGradebookColumnsByParentGenusType(org.osid.type.Type gradebookColumnGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnList </code> containing the given 
     *  gradebook column record <code> Type. </code> In plenary mode, the 
     *  returned list contains all known gradebook columns or an error 
     *  results. Otherwise, the returned list may contain only those gradebook 
     *  columns that are accessible through this session. 
     *
     *  @param  gradebookColumnRecordType a gradebook column record type 
     *  @return the returned <code> GradebookColumn </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnList getGradebookColumnsByRecordType(org.osid.type.Type gradebookColumnRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all gradebook columns. In plenary mode, the returned list 
     *  contains all known gradebook columns or an error results. Otherwise, 
     *  the returned list may contain only those gradebook columns that are 
     *  accessible through this session. 
     *
     *  @return a <code> GradebookColumn </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnList getGradebookColumns()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a summary entry is available. 
     *
     *  @return <code> true </code> if a summary entry is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSummary();


    /**
     *  Gets the <code> GradebookColumnSummary </code> for summary results. 
     *
     *  @param  gradebookColumnId <code> Id </code> of the <code> 
     *          GradebookColumn </code> 
     *  @return the gradebook column summary 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnimplementedException <code> hasSummary() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.GradebookColumnSummary getGradebookColumnSummary(org.osid.id.Id gradebookColumnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
