//
// org.osid.grading.GradebookColumnSearch
//
//     The OSID Java specification for org.osid.grading.GradebookColumnSearch.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p><code> GradebookColumnSearch </code> defines the interface for 
 *  specifying grading search options. </p>
 */

public interface GradebookColumnSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of gradebook columns. 
     *
     *  @param  gradebookColumnIds list of gradebook columns 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnIds 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongGradebookColumns(org.osid.id.IdList gradebookColumnIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  gradebookColumnSearchOrder gradebook column search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          gradebookColumnSearchOrder </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderGradebookColumnResults(org.osid.grading.GradebookColumnSearchOrder gradebookColumnSearchOrder);


    /**
     *  Gets the gradebook column search record corresponding to the given 
     *  gradebook column search record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. 
     *
     *  @param  gradebookColumnSearchRecordType a gradebook column search 
     *          record type 
     *  @return the gradebook column search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnSearchRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradebookColumnSearchRecord getGradebookColumnSearchRecord(org.osid.type.Type gradebookColumnSearchRecordType)
        throws org.osid.OperationFailedException;
}
