//
// org.osid.grading.GradebookColumnSearchSession
//
//     The OSID Java specification for org.osid.grading.GradebookColumnSearchSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session provides methods for searching <code> GradebookColumn 
 *  </code> objects. The search query is constructed using the <code> 
 *  GradebookColumnQuery. </code> </p> 
 *  
 *  <p> <code> getGradebookColumnsByQuery() </code> is the basic search method 
 *  and returns a list of <code> GradebookColumn </code> objects.A more 
 *  advanced search may be performed with <code> 
 *  getGradebookColumnsBySearch(). </code> It accepts a <code> 
 *  GradebookColumnSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getGradebookColumnsBySearch() </code> returns a <code> 
 *  GradebookColumnSearchResults </code> that can be used to access the 
 *  resulting <code> GradebookColumnList </code> or be used to perform a 
 *  search within the result set through <code> GradebookColumnSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated gradebook view: searches include columns in gradebooks 
 *      of which this gradebook is a ancestor in the gradebook hierarchy </li> 
 *      <li> isolated gradebook view: searches are restricted to columns in 
 *      this gradebook </li> 
 *  </ul>
 *  
 *  
 *  <p> Gradebook columns may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  GradebookColumnQuery. </code> </p>
 */

public interface GradebookColumnSearchSession
    extends org.osid.grading.GradebookColumnQuerySession {


    /**
     *  Gets a gradebook column search. 
     *
     *  @return the gradebook column search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnSearch getGradebookColumnSearch();


    /**
     *  Gets a gradebook column search order. The <code> 
     *  GradebookColumnSearchOrder </code> is supplied to a <code> 
     *  GradebookColumnSearch </code> to specify the ordering of results. 
     *
     *  @return the gradebook column search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnSearchOrder getGradebookColumnSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  gradebookColumnQuery the gradebook column query 
     *  @param  gradebookColumnSearch the gradebook column search 
     *  @return the gradebook column search results 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnQuery 
     *          </code> or <code> gradebookColumnSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradebookColumnSearch 
     *          </code> or <code> gradebookColumnQuery </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnSearchResults getGradebookColumnsBySearch(org.osid.grading.GradebookColumnQuery gradebookColumnQuery, 
                                                                                     org.osid.grading.GradebookColumnSearch gradebookColumnSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a gradebook column query from an inspector. The inspector is 
     *  available from an <code> GradebookColumnSearchResults. </code> 
     *
     *  @param  gradebookColumnQueryInspector a gradebook column query 
     *          inspector 
     *  @return the gradebook column query 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          gradebookColumnQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnQuery getGradebookColumnQueryFromInspector(org.osid.grading.GradebookColumnQueryInspector gradebookColumnQueryInspector);
}
