//
// org.osid.grading.GradebookColumnSmartGradebookSession
//
//     The OSID Java specification for org.osid.grading.GradebookColumnSmartGradebookSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> GradebookColumnQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Gradebook </code> to create a virtual 
 *  collection of <code> GradebookColumns. </code> The entries may be 
 *  sequenced using the <code> GradebookColumnSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> Gradebook </code> has a default query that matches any 
 *  gradebook column and a default search order that specifies no sequencing. 
 *  The queries may be examined using a <code> GradebookColumnQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> GradebookColumnQuery. </code> </p>
 */

public interface GradebookColumnSmartGradebookSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart gradebooks. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart gradebook methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartGradebooks();


    /**
     *  Gets a gradebook column query. 
     *
     *  @return the gradebook column query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnQuery getGradebookColumnQuery();


    /**
     *  Gets a gradebook column search order. 
     *
     *  @return the gradebook column search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnSearchOrder getGradebookColumnSearchOrder();


    /**
     *  Applies a gradebook column query to this gradebook. 
     *
     *  @param  gradebookColumnQuery the gradebook column query 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> gradebookColumnQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyGradebookColumnQuery(org.osid.grading.GradebookColumnQuery gradebookColumnQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a gradebook column query inspector for this gradebook. 
     *
     *  @return the gradebook column query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnQueryInspector inspectGradebookColumnQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a gradebook column search order to this gradebook. 
     *
     *  @param  gradebookColumnSearchOrder the gradebook column search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          gradebookColumnSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyGradebookColumnSequencing(org.osid.grading.GradebookColumnSearchOrder gradebookColumnSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a gradebook column query from an inspector. 
     *
     *  @param  gradebookColumnQueryInspector a gradebook column query 
     *          inspector 
     *  @return the gradebook column query 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          gradebookColumnQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnQuery getGradebookColumnQueryFromInspector(org.osid.grading.GradebookColumnQuery gradebookColumnQueryInspector);
}
