//
// org.osid.grading.GradebookColumnSummary
//
//     The OSID Java specification for org.osid.grading.GradebookColumnSummary.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>A <code> GradebookColumnSummary </code> is a summary of all entries 
 *  within a gradebook column. </p>
 */

public interface GradebookColumnSummary
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Id </code> of the <code> GradebookColumn. </code> 
     *
     *  @return the <code> Id </code> of the <code> GradebookColumn </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookColumnId();


    /**
     *  Gets the <code> GradebookColumn. </code> 
     *
     *  @return the <code> GradebookColumn </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumn getGradebookColumn()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the mean score. If this system is based on grades, the mean 
     *  output score is returned. 
     *
     *  @return the mean score 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMean();


    /**
     *  Gets the median score. If this system is based on grades, the mean 
     *  output score is returned. 
     *
     *  @return the median score 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMedian();


    /**
     *  Gets the mode of the score. If this system is based on grades, the 
     *  mode of the output score is returned. 
     *
     *  @return the median score 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getMode();


    /**
     *  Gets the root mean square of the score. If this system is based on 
     *  grades, the RMS of the output score is returned. 
     *
     *  @return the median score 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getRMS();


    /**
     *  Gets the standard deviation. If this system is based on grades, the 
     *  spread of the output scores is returned. 
     *
     *  @return the standard deviation 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getStandardDeviation();


    /**
     *  Gets the sum of the scores. If this system is based on grades, the sum 
     *  of the output scores is returned. 
     *
     *  @return the median score 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getSum();


    /**
     *  Gets the gradebook column summary record corresponding to the given 
     *  <code> GradebookColumnSummary </code> record <code> Type. </code> This 
     *  method is used to retrieve an object implementing the requested 
     *  record. The <code> gradebookColumnSummaryRecordType </code> may be the 
     *  <code> Type </code> returned in <code> getRecordTypes() </code> or any 
     *  of its parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(gradebookColumnSummaryRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  gradebookColumnSummaryRecordType the type of the record to 
     *          retrieve 
     *  @return the gradebook column summary record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnSummaryRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnSummaryRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradebookColumnSummaryRecord getGradebookColumnSummaryRecord(org.osid.type.Type gradebookColumnSummaryRecordType)
        throws org.osid.OperationFailedException;
}
