//
// org.osid.grading.GradebookColumnSummaryQuery
//
//     The OSID Java specification for org.osid.grading.GradebookColumnSummaryQuery.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query for searching gradebook column summaries. Each method 
 *  match request produces an <code> AND </code> term while multiple 
 *  invocations of a method produces a nested <code> OR. </code> </p>
 */

public interface GradebookColumnSummaryQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Sets the gradebook column <code> Id </code> for this query. 
     *
     *  @param  gradebookColumnId a gradeboo column <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookColumnId(org.osid.id.Id gradebookColumnId, 
                                       boolean match);


    /**
     *  Clears the gradebook column <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnIdTerms();


    /**
     *  Tests if a <code> GradebookColumnQuery </code> is available for 
     *  querying gradebook column. 
     *
     *  @return <code> true </code> if a gradebook column query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnQuery();


    /**
     *  Gets the query for a gradebook column. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the gradebook column query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnQuery getGradebookColumnQuery();


    /**
     *  Matches gradebook column derivations with any gradebookc olumn. 
     *
     *  @param  match <code> true </code> to match gradebook column 
     *          derivations with any gradebook column, <code> false </code> to 
     *          match gradebook column derivations with no gradebook columns 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradebookColumn(boolean match);


    /**
     *  Clears the source grade system terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnTerms();


    /**
     *  Matches a mean between the given values inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMean(java.math.BigDecimal low, java.math.BigDecimal high, 
                          boolean match);


    /**
     *  Clears the mean terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeanTerms();


    /**
     *  Matches a mean greater than or equal to the given value. 
     *
     *  @param  value minimum value 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumMean(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum mean terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumMeanTerms();


    /**
     *  Matches a median between the given values inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMedian(java.math.BigDecimal low, 
                            java.math.BigDecimal high, boolean match);


    /**
     *  Clears the median terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMedianTerms();


    /**
     *  Matches a median greater than or equal to the given value. 
     *
     *  @param  value minimum value 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumMedian(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum median terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumMedianTerms();


    /**
     *  Matches a mode between the given values inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMode(java.math.BigDecimal low, java.math.BigDecimal high, 
                          boolean match);


    /**
     *  Clears the mode terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModeTerms();


    /**
     *  Matches a mode greater than or equal to the given value. 
     *
     *  @param  value minimum value 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumMode(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum mode terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumModeTerms();


    /**
     *  Matches a root mean square between the given values inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRMS(java.math.BigDecimal low, java.math.BigDecimal high, 
                         boolean match);


    /**
     *  Clears the root mean square terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRMSTerms();


    /**
     *  Matches a root mean square greater than or equal to the given value. 
     *
     *  @param  value minimum value 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumRMS(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum RMS terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumRMSTerms();


    /**
     *  Matches a standard deviation mean square between the given values 
     *  inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStandardDeviation(java.math.BigDecimal low, 
                                       java.math.BigDecimal high, 
                                       boolean match);


    /**
     *  Clears the standard deviation terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStandardDeviationTerms();


    /**
     *  Matches a standard deviation greater than or equal to the given value. 
     *
     *  @param  value minimum value 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumStandardDeviation(java.math.BigDecimal value, 
                                              boolean match);


    /**
     *  Clears the minimum standard deviation terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumStandardDeviationTerms();


    /**
     *  Matches a sum mean square between the given values inclusive. 
     *
     *  @param  low low end of range 
     *  @param  high high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSum(java.math.BigDecimal low, java.math.BigDecimal high, 
                         boolean match);


    /**
     *  Clears the sum terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSumTerms();


    /**
     *  Matches a sum greater than or equal to the given value. 
     *
     *  @param  value minimum value 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumSum(java.math.BigDecimal value, boolean match);


    /**
     *  Clears the minimum sum terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumSumTerms();


    /**
     *  Sets the gradebook <code> Id </code> for this query. 
     *
     *  @param  gradebookId a gradebook <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookId(org.osid.id.Id gradebookId, boolean match);


    /**
     *  Clears the gradebook <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookIdTerms();


    /**
     *  Tests if a <code> GradebookQuery </code> is available . 
     *
     *  @return <code> true </code> if a gradebook query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookQuery();


    /**
     *  Gets the query for a gradebook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the gradebook query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookQuery getGradebookQuery();


    /**
     *  Clears the gradebook terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookTerms();


    /**
     *  Gets the gradebook column summary query record corresponding to the 
     *  given <code> GradebookColumnSummary </code> record <code> Type. 
     *  </code> Multiple retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  gradebookColumnSummaryRecordType a gradebook column summary 
     *          record type 
     *  @return the gradebook column summary query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnSummaryRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnSummaryRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradebookColumnSummaryQueryRecord getGradebookColumnSummaryQueryRecord(org.osid.type.Type gradebookColumnSummaryRecordType)
        throws org.osid.OperationFailedException;
}
