//
// org.osid.grading.GradebookQuery
//
//     The OSID Java specification for org.osid.grading.GradebookQuery.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>This is the query for searching gradebooks. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface GradebookQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the grade system <code> Id </code> for this query. 
     *
     *  @param  gradeSystemId a grade system <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeSystemId(org.osid.id.Id gradeSystemId, boolean match);


    /**
     *  Clears the grade system <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeSystemIdTerms();


    /**
     *  Tests if a <code> GradeSystemQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade system query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeSystemQuery();


    /**
     *  Gets the query for a grade system. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the grade system query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuery getGradeSystemQuery();


    /**
     *  Matches gradebooks that have any grade system. 
     *
     *  @param  match <code> true </code> to match gradebooks with any grade 
     *          system, <code> false </code> to match gradebooks with no grade 
     *          system 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradeSystem(boolean match);


    /**
     *  Clears the grade system terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeSystemTerms();


    /**
     *  Sets the grade entry <code> Id </code> for this query. 
     *
     *  @param  gradeEntryId a grade entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradeEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradeEntryId(org.osid.id.Id gradeEntryId, boolean match);


    /**
     *  Clears the grade entry <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeEntryIdTerms();


    /**
     *  Tests if a <code> GradeEntryQuery </code> is available. 
     *
     *  @return <code> true </code> if a grade entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradeEntryQuery();


    /**
     *  Gets the query for a grade entry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the grade entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeEntryQuery getGradeEntryQuery();


    /**
     *  Matches gradebooks that have any grade entry. 
     *
     *  @param  match <code> true </code> to match gradebooks with any grade 
     *          entry, <code> false </code> to match gradebooks with no grade 
     *          entry 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradeEntry(boolean match);


    /**
     *  Clears the grade entry terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradeEntryTerms();


    /**
     *  Sets the gradebook column <code> Id </code> for this query. 
     *
     *  @param  gradebookColumnId a gradebook column <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGradebookColumnId(org.osid.id.Id gradebookColumnId, 
                                       boolean match);


    /**
     *  Clears the gradebook column <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnIdTerms();


    /**
     *  Tests if a <code> GradebookColumnQuery </code> is available. 
     *
     *  @return <code> true </code> if a gradebook column query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradebookColumnQuery();


    /**
     *  Gets the query for a gradebook column. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the gradebook column query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnQuery getGradebookColumnQuery();


    /**
     *  Matches gradebooks that have any column. 
     *
     *  @param  match <code> true </code> to match gradebooks with any column, 
     *          <code> false </code> to match gradebooks with no column 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGradebookColumn(boolean match);


    /**
     *  Clears the gradebook column terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGradebookColumnTerms();


    /**
     *  Sets the gradebook <code> Id </code> for this query to match 
     *  gradebooks that have the specified gradebook as an ancestor. 
     *
     *  @param  gradebookId a gradebook <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorGradebookId(org.osid.id.Id gradebookId, 
                                         boolean match);


    /**
     *  Clears the ancestor gradebook <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorGradebookIdTerms();


    /**
     *  Tests if a <code> GradebookQuery </code> is available. 
     *
     *  @return <code> true </code> if a gradebook query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorGradebookQuery();


    /**
     *  Gets the query for a gradebook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the gradebook query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorGradebookQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorGradebookQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookQuery getAncestorGradebookQuery();


    /**
     *  Matches gradebook with any ancestor. 
     *
     *  @param  match <code> true </code> to match gradebooks with any 
     *          ancestor, <code> false </code> to match root gradebooks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorGradebook(boolean match);


    /**
     *  Clears the ancestor gradebook terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorGradebookTerms();


    /**
     *  Sets the gradebook <code> Id </code> for this query to match 
     *  gradebooks that have the specified gradebook as a descendant. 
     *
     *  @param  gradebookId a gradebook <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantGradebookId(org.osid.id.Id gradebookId, 
                                           boolean match);


    /**
     *  Clears the descendant gradebook <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantGradebookIdTerms();


    /**
     *  Tests if a <code> GradebookQuery </code> is available. 
     *
     *  @return <code> true </code> if a gradebook query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantGradebookQuery();


    /**
     *  Gets the query for a gradebook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the gradebook query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantGradebookQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantGradebookQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookQuery getDescendantGradebookQuery();


    /**
     *  Matches gradebook with any descendant. 
     *
     *  @param  match <code> true </code> to match gradebooks with any 
     *          descendant, <code> false </code> to match leaf gradebooks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantGradebook(boolean match);


    /**
     *  Clears the descendant gradebook terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantGradebookTerms();


    /**
     *  Gets the gradebook query record corresponding to the given <code> 
     *  Gradebook </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  gradebookRecordType a gradebook record type 
     *  @return the gradebook query record 
     *  @throws org.osid.NullArgumentException <code> gradebookRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.records.GradebookQueryRecord getGradebookQueryRecord(org.osid.type.Type gradebookRecordType)
        throws org.osid.OperationFailedException;
}
