//
// org.osid.grading.GradebookReceiver
//
//     The OSID Java specification for org.osid.grading.GradebookReceiver.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>The vault receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Gradebook 
 *  </code> objects. </p>
 */

public interface GradebookReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new gradebooks. 
     *
     *  @param  gradebookIds the <code> Ids </code> of the new <code> 
     *          Gradebooks </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newGradebooks(org.osid.id.IdList gradebookIds);


    /**
     *  The callback for notifications of new gradebook ancestors. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  ancestorId <code> hasRecordType(gradebookRecordType) is false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorGradebook(org.osid.id.Id gradebookId, 
                                     org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new gradebook descendants. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Gradebook 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantGradebook(org.osid.id.Id gradebookId, 
                                       org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated gradebooks. 
     *
     *  @param  gradebookIds the <code> Ids </code> of the updated <code> 
     *          Gradebooks </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedGradebooks(org.osid.id.IdList gradebookIds);


    /**
     *  The callback for notification of deleted gradebooks. 
     *
     *  @param  gradebookIds the <code> Ids </code> of the deleted <code> 
     *          Gradebooks </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedGradebooks(org.osid.id.IdList gradebookIds);


    /**
     *  The callback for notifications of deleted gradebook ancestors. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the removed <code> 
     *          Gradebook </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorGradebook(org.osid.id.Id gradebookId, 
                                         org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted gradebook descendants. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the removed <code> 
     *          Gradebook </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantGradebook(org.osid.id.Id gradebookId, 
                                           org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a gradebook hierarchy 
     *  where the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredGradebookHierarchy();
}
