//
// org.osid.grading.GradingProxyManager
//
//     The OSID Java specification for org.osid.grading.GradingProxyManager.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading;


/**
 *  <p>The grading manager provides access to grading sessions and provides 
 *  interoperability tests for various aspects of this service. Methods in 
 *  this manager accept a <code> Proxy </code> for passing information from 
 *  server environments.The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> GradeSystemLookupSession: </code> a session to look up 
 *      grades and grade systems </li> 
 *      <li> <code> GradeSystemQuerySession: </code> a session to query grade 
 *      systems <code> </code> </li> 
 *      <li> <code> GradeSystemSearchSession: </code> a session to search 
 *      grade systems </li> 
 *      <li> <code> GradeSystemAdminSession: </code> a session to manage grade 
 *      systems </li> 
 *      <li> <code> GradeSystemNotificationSession </code> a session for 
 *      subscribing to new or deleted grades or grade systems </li> 
 *      <li> <code> GradeSystemGradebookSession: </code> a session for 
 *      retrieving grade system to gradebook mappings </li> 
 *      <li> <code> GradeSystemGradebookAssignmentSession: </code> a session 
 *      for managing grade system to gradebook mappings </li> 
 *      <li> <code> GradeSystemSmartGradebookSession: </code> a session for 
 *      managing smart gradebooks of grade systems </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> GradeEntryLookupSession: </code> a session to look up 
 *      grade entries </li> 
 *      <li> <code> GradeEntryQuerySession: </code> a session to query grade 
 *      entries <code> </code> </li> 
 *      <li> <code> GradeEntrySearchSession: </code> a session to search grade 
 *      entries </li> 
 *      <li> <code> GradeEntryAdminSession: </code> a session to create, 
 *      modify and delete grade entries <code> </code> </li> 
 *      <li> <code> GradeEntryNotificationSession: a </code> session to 
 *      receive messages pertaining to grade entry <code> </code> changes 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> GradebookColumnLookupSession: </code> a session to look up 
 *      gradebook columns </li> 
 *      <li> <code> GradebookColumnQuerySession: </code> a session to query 
 *      gradebook columns <code> </code> </li> 
 *      <li> <code> GradebookColumnSearchSession: </code> a session to search 
 *      gradebook columns </li> 
 *      <li> <code> GradebookColumnAdminSession: </code> a session to manage 
 *      gradebook columns </li> 
 *      <li> <code> GradebookColumnDerivationSession: </code> a session to 
 *      manage derived gradebook columns </li> 
 *      <li> <code> GradebookColumnNotificationSession </code> a session for 
 *      subscribing to new or deleted gradebook columns </li> 
 *      <li> <code> GradebookColumnGradebookSession: </code> a session for 
 *      retrieving gradebook column to gradebook mappings </li> 
 *      <li> <code> GradebookColumnGradebookAssignmentSession: </code> a 
 *      session for managing gradebook column to gradebook mappings </li> 
 *      <li> <code> GradebookColumnSmartGradebookSession: </code> a session 
 *      for managing smart gradebooks of gradebook columns </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> GradebookLookupSession: </code> a session to lookup 
 *      gradebooks </li> 
 *      <li> <code> GradebookQuerySession: </code> a session to query 
 *      gradebooks </li> 
 *      <li> <code> GradebookSearchSession </code> : a session to search 
 *      gradebooks </li> 
 *      <li> <code> GradebookAdminSession </code> : a session to create, 
 *      modify and delete gradebooks </li> 
 *      <li> <code> GradebookNotificationSession </code> : a session to 
 *      receive messages pertaining to gradebook changes </li> 
 *      <li> <code> GradebookHierarchySession: </code> a session to traverse 
 *      the gradebook hierarchy </li> 
 *      <li> <code> GradebookHierarchyDesignSession: </code> a session to 
 *      manage the gradebook hierarchy </li> 
 *  </ul>
 *  
 */

public interface GradingProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.grading.GradingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemLookupSession getGradeSystemLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  lookup service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemLookupSession getGradeSystemLookupSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemQuerySession getGradeSystemQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  query service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemQuerySession getGradeSystemQuerySessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemSearchSession getGradeSystemSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  search service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemSearchSession getGradeSystemSearchSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemAdmin() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeSystemAdminSession getGradeSystemAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  admin service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemAdminSession getGradeSystemAdminSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to grade 
     *  system changes. 
     *
     *  @param  gradeSystemReceiver the grade system receiver 
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemNotificationSession getGradeSystemNotificationSession(org.osid.grading.GradeSystemReceiver gradeSystemReceiver, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  notification service for the given gradebook. 
     *
     *  @param  gradeSystemReceiver the grade system receiver 
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemReceiver, 
     *          gradebookId </code> or <code> porxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemNotificationSession getGradeSystemNotificationSessionForGradebook(org.osid.grading.GradeSystemReceiver gradeSystemReceiver, 
                                                                                                         org.osid.id.Id gradebookId, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving grade system to gradebook mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemGradebookSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemGradebook() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemGradebook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeSystemGradebookSession getGradeSystemGradebookSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning grade system to gradebook mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemGradebookAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemGradebookAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemGradebookAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradeSystemGradebookSession getGradeSystemGradebookAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing smart gradebooks of grade systems. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemSmartGradebookSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemSmartGradebook() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemSmartGradebook() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradeSystemSmartGradebookSession getGradeSystemSmartGradebookSession(org.osid.id.Id gradebookId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeEntryLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryLookup() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeEntryLookupSession getGradeEntryLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  lookup service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeEntryLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeEntryLookupSession getGradeEntryLookupSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeEntryQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryQuery() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeEntryQuerySession getGradeEntryQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  query service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeEntryQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeEntryQuerySession getGradeEntryQuerySessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeEntrySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntrySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntrySearch() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeEntrySearchSession getGradeEntrySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  search service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeEntrySearchSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntrySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntrySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeEntrySearchSession getGradeEntrySearchSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeEntryAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.grading.GradeEntryAdminSession getGradeEntryAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  admin service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeEntryAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeEntryAdminSession getGradeEntryAdminSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to grade 
     *  entry changes. 
     *
     *  @param  gradeEntryReceiver the grade entry receiver 
     *  @param  proxy a proxy 
     *  @return a <code> GradeEntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> gradeEntryReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeEntryNotificationSession getGradeEntryNotificationSession(org.osid.grading.GradeEntryReceiver gradeEntryReceiver, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade entry 
     *  notification service for the given gradebook. 
     *
     *  @param  gradeEntryReceiver the grade entry receiver 
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeEntryNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeEntryReceiver, 
     *          gradebookId </code> or <code> porxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradeEntryNotificationSession getGradeEntryNotificationSessionForGradebook(org.osid.grading.GradeEntryReceiver gradeEntryReceiver, 
                                                                                                       org.osid.id.Id gradebookId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnLookupSession getGradebookColumnLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column lookup service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradebookColumnLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnLookupSession getGradebookColumnLookupSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnQuerySession getGradebookColumnQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column query service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnQuerySession getGradebookColumnQuerySessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnSearchSession getGradebookColumnSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column search service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradebookColumnSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnSearchSession getGradebookColumnSearchSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnAdminSession getGradebookColumnAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column admin service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradebookColumnAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnAdminSession getGradebookColumnAdminSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  gradebook column changes. 
     *
     *  @param  gradebookColumnReceiver the grade system receiver 
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradebookColumnNotificationSession getGradebookColumnNotificationSession(org.osid.grading.GradebookColumnReceiver gradebookColumnReceiver, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the gradebook 
     *  column notification service for the given gradebook. 
     *
     *  @param  gradebookColumnReceiver the gradebook column receiver 
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradebookColumnNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnReceiver, 
     *          gradebookId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnNotificationSession getGradebookColumnNotificationSessionForGradebook(org.osid.grading.GradebookColumnReceiver gradebookColumnReceiver, 
                                                                                                                 org.osid.id.Id gradebookId, 
                                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving gradebook column to gradebook 
     *  mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnGradebookSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnGradebook() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnGradebook() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.GradebookColumnGradebookSession getGradebookColumnGradebookSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning gradebook column to gradebook mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnGradebookAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnGradebookAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnGradebookAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.grading.GradebookColumnGradebookAssignmentSession getGradebookColumnGradebookAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing smart gradebooks of gradebook columns. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnSmartGradebookSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnSmartGradebook() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnSmartGradebook() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradebookColumnSmartGradebookSession getGradebookColumnSmartGradebookSession(org.osid.id.Id gradebookId, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the gradebook lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookLookup() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookLookup() </code> is true. 
     */

    public org.osid.grading.GradebookLookupSession getGradebookLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the gradebook query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookQuery() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookQuery() </code> is true. 
     */

    public org.osid.grading.GradebookQuerySession getGradebookQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the gradebook search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookSearch() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookSearch() </code> is true. 
     */

    public org.osid.grading.GradebookSearchSession getGradebookSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the gradebook administration 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookAdmin() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookAdmin() </code> is true. 
     */

    public org.osid.grading.GradebookAdminSession getGradebookAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  gradebook service changes. 
     *
     *  @param  gradebookReceiver the gradebook receiver 
     *  @param  proxy a proxy 
     *  @return a <code> GradebookNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookNotification() </code> is true. 
     */

    public org.osid.grading.GradebookNotificationSession getGradebookNotificationSession(org.osid.grading.GradebookReceiver gradebookReceiver, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing gradebook hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookHierarchy() </code> is true. 
     */

    public org.osid.grading.GradebookHierarchySession getGradebookHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing gradebook hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookHierarchyDesign() </code> is true. 
     */

    public org.osid.grading.GradebookHierarchyDesignSession getGradebookHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> GradingBatchProxyManager. </code> 
     *
     *  @return a <code> GradingBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsGradingBatch() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingBatch() </code> is true. 
     */

    public org.osid.grading.batch.GradingBatchProxyManager getGradingBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> GradingCalculationProxyManager. </code> 
     *
     *  @return a <code> GradingCalculationProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradingCalculation() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingCalculation() </code> is true. 
     */

    public org.osid.grading.calculation.GradingCalculationProxyManager getGradingCalculationProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> GradingTransformProxyManager. </code> 
     *
     *  @return a <code> GradingTransformManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradingTransform() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradingTransform() </code> is true. 
     */

    public org.osid.grading.transform.GradingTransformProxyManager getGradingTransformProxyManager()
        throws org.osid.OperationFailedException;
}
