//
// org.osid.grading.batch.GradeSystemBatchAdminSession
//
//     The OSID Java specification for org.osid.grading.batch.GradeSystemBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.batch;


/**
 *  <p>This session creates, updates, and deletes <code> GradeSystems </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  GradeSystem, </code> a <code> GradeSystemForm </code> is requested using 
 *  <code> getGradeSystemFormsForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> GradeSystemForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> GradeSystemForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> GradeSystemForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> The <code> GradeSystemForms </code> returned from <code> 
 *  getGradeSystemFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> GradeSystemForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  GradeSystemForm </code> of the same peer <code> Ids </code> may be used 
 *  for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> GradeSystemForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  GradeSystemForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createGradeSystems(), </code> errors specific to an individual <code> 
 *  GradeSystemForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> GradeSystemForm </code> through the <code> 
 *  GradeSystemForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> GradeSystemForms </code> are requested to the 
 *  <code> GradeSystem </code> <code> Id </code> that is to be updated using 
 *  <code> getGradeSystemFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> GradeSystemForm </code> may be used to link the 
 *  request. Similarly, the <code> GradeSystemForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> GradeSystemForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> GradeSystemForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  GradeSystemForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateGradeSystems(), </code> errors specific to an individual <code> 
 *  GradeSystemForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> GradeSystemForm </code> through the <code> 
 *  GradeSystemForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> GradeSystems </code> in bulk. To 
 *  unmap a <code> GradeSystem </code> from the current <code> Gradebook, 
 *  </code> the <code> GradeSystemGradebookAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> GradeSystem 
 *  </code> itself thus removing it from all known <code> Gradebook </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface GradeSystemBatchAdminSession
    extends org.osid.grading.GradeSystemAdminSession {


    /**
     *  Gets the grade system forms for creating a bunch of new grade systems. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  gradeSystemRecordTypes array of grade system record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the grade system forms 
     *  @throws org.osid.NullArgumentException <code> gradeSystemRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradeSystemBatchFormList getGradeSystemFormsForCreate(long number, 
                                                                                        org.osid.type.Type[] gradeSystemRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> GradeSystems. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  gradeSystemForms the grade system forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> gradeSystemForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createGradeSystems(org.osid.grading.batch.GradeSystemBatchFormList gradeSystemForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the grade system forms for updating an existing set of grade 
     *  systems. A new grade system form should be requested for each update 
     *  transaction. 
     *
     *  @param  gradeSystemIds the <code> Ids </code> of the <code> 
     *          GradeSystem </code> 
     *  @return the grade system forms 
     *  @throws org.osid.NotFoundException a <code> gradeSystemId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradeSystemBatchFormList getGradeSystemFormsForUpdate(org.osid.id.IdList gradeSystemIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing grade systems. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  gradeSystemForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> gradeSystemForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateGradeSystems(org.osid.grading.batch.GradeSystemBatchFormList gradeSystemForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> GradeSystems </code> in this <code> Gradebook 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllGradeSystems()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes grade systems for the given <code> Ids. </code> 
     *
     *  @param  gradeSystemIds the <code> Ids </code> of the grade systems to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteGradeSystems(org.osid.id.IdList gradeSystemIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> GradeSystem </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> GradeSystem </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another grade system, it is reassigned to the 
     *  given grade system <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasGradeSystems(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the grade forms for creating a bunch of new grades. A 
     *  GradeSystemForm is returned for each supplied grade system. 
     *
     *  @param  gradeSystemIds a list of grade system <code> Ids </code> 
     *  @param  gradeRecordTypes array of grade system record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the grade forms 
     *  @throws org.osid.NotFoundException a <code> gradeSystemId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          or <code> gradeRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradeBatchFormList getGradeFormsForCreate(org.osid.id.IdList gradeSystemIds, 
                                                                            org.osid.type.Type[] gradeRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> GradeSystems. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  gradeForms the grade forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> gradeForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createGrades(org.osid.grading.batch.GradeBatchFormList gradeForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the grade forms for updating an existing set of grade systems. A 
     *  new grade form should be requested for each update transaction. 
     *
     *  @param  gradeIds the <code> Ids </code> of the <code> Grade </code> 
     *  @return the grade forms 
     *  @throws org.osid.NotFoundException a <code> gradeId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.batch.GradeBatchFormList getGradeFormsForUpdate(org.osid.id.IdList gradeIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing grades. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  gradeForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> gradeForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateGrades(org.osid.grading.batch.GradeBatchFormList gradeForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Grades </code> in this <code> Gradebook </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllGrades()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes grade for the given <code> Ids. </code> 
     *
     *  @param  gradeIds the <code> Ids </code> of the grade to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> gradeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteGrades(org.osid.id.IdList gradeIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes grade for the given grade system. 
     *
     *  @param  gradeSystemId the <code> Ids </code> of a grade system 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> gradeSystemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteGradesForGradeSystem(org.osid.id.Id gradeSystemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Grade </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Grade </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another grade, it is reassigned to the given grade <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasGrades(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
