//
// org.osid.grading.batch.GradingBatchProxyManager
//
//     The OSID Java specification for org.osid.grading.batch.GradingBatchProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.batch;


/**
 *  <p>The grading batch proxy manager provides access to grading batch 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager support the passing of a <code> Proxy 
 *  </code> object. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> GradeSystemBatchAdminSession: </code> a session to create, 
 *      modify and delete grade systems in bulk </li> 
 *      <li> <code> GradeEntryBatchSession: </code> a session to create, 
 *      modify and delete grade entries in bulk </li> 
 *      <li> <code> GradebookColumnBatchAdminSession: </code> a session to 
 *      create, modify and delete gradebook columns in bulk </li> 
 *      <li> <code> GradebookBatchAdminSession: </code> a session to create, 
 *      modify and delete gradebooks in bulk </li> 
 *  </ul>
 *  
 */

public interface GradingBatchProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.grading.batch.GradingBatchProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk grade 
     *  system administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemBatchAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.batch.GradeSystemBatchAdminSession getGradeSystemBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk grade 
     *  system administration service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Gradebook </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.grading.batch.GradeSystemBatchAdminSession getGradeSystemBatchAdminSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk grade 
     *  entry administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeEntryBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.batch.GradeEntryBatchAdminSession getGradeEntryBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk grade 
     *  entry administration service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> GradeEntryBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Gradebook </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeEntryBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeEntryBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.grading.batch.GradeEntryBatchAdminSession getGradeEntryBatchAdminSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk gradebook 
     *  columnadministration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnBatchAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnBatchAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.batch.GradebookColumnBatchAdminSession getGradebookColumnBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk gradebook 
     *  columnadministration service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the <code> Gradebook 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> GradebookColumnBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Gradebook </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookColumnBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookColumnBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.grading.batch.GradebookColumnBatchAdminSession getGradebookColumnBatchAdminSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk gradebook 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradebookBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradebookBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradebookBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.grading.batch.GradebookBatchAdminSession getGradebookBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;
}
