//
// org.osid.grading.calculation.CalculationOperation
//
//     Specifies the OSID definition for org.osid.grading.calculation.CalculationOperation.
//
// Copyright (C) 2010 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.calculation;


/**
 *  This enumeration contains the various gradebook column calculations. 
 */

public enum CalculationOperation {

    /** Transform the grade entries between the GradeSystems defined in the 
        input and the target columns. */
    TRANSFORM("Transform", "Transform the grade entries between the GradeSystems defined in the input and the target columns."),

    /** Calculate the mean of the linked column entries. */
    MEAN("Mean", "Calculate the mean of the linked column entries."),

    /** Calculate the median of the linked column entries. */
    MEDIAN("Median", "Calculate the median of the linked column entries."),

    /** Calculate the mode of the linked column entries. */
    MODE("Mode", "Calculate the mode of the linked column entries."),

    /** Calculate the percentile of the linked column. If more than one 
        column is selected, the mean of the row entries is used. */
    PERCENTILE("Percentile", "Calculate the percentile of the linked column. If more than one column is selected, the mean of the row entries is used."),

    /** Calculate the root mean square of the linked column entries. */
    RMS("Rms", "Calculate the root mean square of the linked column entries."),

    /** Use an external rule to process the linked column entries. */
    RULE("Rule", "Use an external rule to process the linked column entries."),

    /** Calculate the offset from the standard deviation calculation of the 
        linked column. If more than one column is selected, the mean of the 
        row entries is used. */
    STD_DEVIATION_OFFSET("Std_deviation_offset", "Calculate the offset from the standard deviation calculation of the linked column. If more than one column is selected, the mean of the row entries is used."),

    /** Calculate the sum of the values of the linked column entries. */
    SUM("Sum", "Calculate the sum of the values of the linked column entries.");


    private final String displayName;
    private final String description;

    CalculationOperation(String displayName, String description) {
        this.displayName = displayName;
        this.description = description;
    }

    public String getDisplayName() {
        return (this.displayName);
    }

    public String getDescription() {
        return (this.description);
    }
}
