//
// org.osid.grading.calculation.GradebookColumnCalculation
//
//     The OSID Java specification for org.osid.grading.calculation.GradebookColumnCalculation.
//
// Copyright (C) 2010 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.calculation;


/**
 *  <p>A <code> GradebookColumnCalculation </code> represents a rule to derive 
 *  a column baed on one or more other columns. </p>
 */

public interface GradebookColumnCalculation
    extends org.osid.OsidRule {


    /**
     *  Gets the <code> GradebookColumn Ids </code> to which this column 
     *  applies. 
     *
     *  @return the gradebook column <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookColumnId();


    /**
     *  Gets the <code> GradebookColumn </code> to which this calculation 
     *  applies. 
     *
     *  @return the gradebook column 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumn getGradebookColumn()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> GradebookColumn Ids </code> from which this column is 
     *  derived. 
     *
     *  @return the derived column <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInputGradebookColumnIds();


    /**
     *  Gets the <code> GradebookColumns </code> from which this column is 
     *  derived. 
     *
     *  @return the derived columns 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradebookColumnList getInputGradebookColumns()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the operation to perform for deriving this column. The output of 
     *  the operation determines the score or grade for the column entries. 
     *
     *  @return the calculation operation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.CalculationOperation getOperation();


    /**
     *  Gets the tweaked midpoint input value of the grading system for 
     *  determining how to center calculated enries in this column. This tweak 
     *  is applied before calculating standard deviation offsets for entries 
     *  in this derived column. 
     *
     *  @return the tweaked center 
     *  @throws org.osid.IllegalStateException <code> getCalculation() </code> 
     *          is not <code> CalculationOperation.STD_DEVIATION_OFFSET 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getTweakedCenter();


    /**
     *  Gets the tweaked standard deviation. This tweak is applied before 
     *  calculating standard deviation offsets for entries in this derived 
     *  column. 
     *
     *  @return the tweaked standard deviation 
     *  @throws org.osid.IllegalStateException <code> getCalculation() </code> 
     *          is not <code> CalculationOperation.STD_DEVIATION_OFFSET 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getTweakedStandardDeviation();


    /**
     *  Gets the gradebook column calculation record corresponding to the 
     *  given <code> GradeBookColumnCalculation </code> record <code> Type. 
     *  </code> This method is used to retrieve an object implementing the 
     *  requested record. The <code> gradebookColumnCalculationRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> 
     *  hasRecordType(gradebookColumnCalculationRecordType) </code> is <code> 
     *  true </code> . 
     *
     *  @param  gradebookColumnCalculationRecordType the type of the record to 
     *          retrieve 
     *  @return the gradebook column calculation record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradebookColumnCalculationRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.records.GradebookColumnCalculationRecord getGradebookColumnCalculationRecord(org.osid.type.Type gradebookColumnCalculationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
