//
// org.osid.grading.calculation.GradebookColumnCalculationLookupSession
//
//     The OSID Java specification for org.osid.grading.calculation.GradebookColumnCalculationLookupSession.
//
// Copyright (C) 2010 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.calculation;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  GradebookColumnCalculationss </code> . </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated gradebook view: All gradebook column calculation methods 
 *      in this session operate, retrieve and pertain to gradebook column 
 *      calculations defined explicitly in the current gradebook. </li> 
 *      <li> federated gradebook view: All gradebook column calculation 
 *      methods in this session operate, retrieve and pertain to all gradebook 
 *      column calculations defined in this gradebook and any other gradebooks 
 *      implicitly available in this gradebook through gradebook inheritence. 
 *      </li> 
 *      <li> active gradebook calculation view: All gradebook column 
 *      calculation lookup methods return active gradebook column 
 *      calculations. </li> 
 *      <li> any status gradebook column calculation view: Gradebook column 
 *      calculations of any active or inactive status are returned from 
 *      methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Gradebook column calculations may have an additional records indicated 
 *  by their respective record types. The record may not be accessed through a 
 *  cast of the <code> GradebookColumnCalculation. </code> </p>
 */

public interface GradebookColumnCalculationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> GradebookColumnCalculation 
     *  </code> lookups. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupGradebookColumnCalculations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeGradebookColumnCalculationView();


    /**
     *  A complete view of the <code> GradebookColumnCalculation </code> 
     *  returns is desired. Methods will return what is requested or result in 
     *  an error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryGradebookColumnCalculationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include gradebook column calculations in gradebooks which are children 
     *  of this gradebook in the gradebook hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGradebookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this gradebook only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGradebookView();


    /**
     *  Only active gradebook column calculations are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveGradebookColumnCalculationView();


    /**
     *  All active and inactive gradebook column calculations are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusGradebookColumnCalculationView();


    /**
     *  Gets the <code> GradebookColumnCalculation </code> specified by its 
     *  <code> Id. </code> In plenary mode, the exact <code> Id </code> is 
     *  found or a <code> NOT_FOUND </code> results. Otherwise, the returned 
     *  <code> GradebookColumnCalculation </code> may have a different <code> 
     *  Id </code> than requested, such as the case where a duplicate <code> 
     *  Id </code> was assigned to a <code> GradebookColumnCalculation </code> 
     *  and retained for compatibility. 
     *
     *  @param  gradebookColumnCalculationId <code> Id </code> of the <code> 
     *          GradebookColumnCalculation </code> 
     *  @return the gradebook column calculation 
     *  @throws org.osid.NotFoundException <code> gradebookColumnCalculationId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculation getGradebookColumnCalculation(org.osid.id.Id gradebookColumnCalculationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnCalculationList </code> corresponding to 
     *  the given <code> IdList. </code> In plenary mode, the returned list 
     *  contains all of the gradebook column calculations specified in the 
     *  <code> Id </code> list, in the order of the list, including 
     *  duplicates, or an error results if a <code> Id </code> in the supplied 
     *  list is not found or inaccessible. Otherwise, inaccessible gradeboook 
     *  column calculations may be omitted from the list. 
     *
     *  @param  gradebookColumnCalculationIds the list of <code> Ids </code> 
     *          to retrieve 
     *  @return the returned <code> GradebookColumnCalculation </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeBookColumnCalculationIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationList getGradebookColumnCalculationsByIds(org.osid.id.IdList gradebookColumnCalculationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnCalculationList </code> corresponding to 
     *  the given gradebook column calculation genus <code> Type </code> which 
     *  does not include gradebook column calculations of genus types derived 
     *  from the specified <code> Type. </code> In plenary mode, the returned 
     *  list contains all known gradebook column calculations or an error 
     *  results. Otherwise, the returned list may contain only those gradebook 
     *  column calculations that are accessible through this session. 
     *
     *  @param  gradebookColumnCalculationGenusType a gradebook column 
     *          calculation genus type 
     *  @return the returned <code> GradebookColumnCalculation </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationList getGradebookColumnCalculationsByGenusType(org.osid.type.Type gradebookColumnCalculationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnCalculationList </code> corresponding to 
     *  the given gradebook column calculation genus <code> Type </code> and 
     *  include any additional column calculations with genus types derived 
     *  from the specified <code> Type. </code> In plenary mode, the returned 
     *  list contains all known gradebook column calculations or an error 
     *  results. Otherwise, the returned list may contain only those gradebook 
     *  column calculations that are accessible through this session. 
     *
     *  @param  gradebookColumnCalculationGenusType a gradebook column 
     *          calculation genus type 
     *  @return the returned <code> GradebookColumnCalculation </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationList getGradebookColumnCalculationsByParentGenusType(org.osid.type.Type gradebookColumnCalculationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnCalculationList </code> containing the 
     *  given gradebook column calculation record <code> Type. </code> In 
     *  plenary mode, the returned list contains all known gradebook column 
     *  calculations or an error results. Otherwise, the returned list may 
     *  contain only those gradebook column calculations that are accessible 
     *  through this session. 
     *
     *  @param  gradebookColumnCalculationRecordType a gradebook column 
     *          calculation record type 
     *  @return the returned <code> GradebookColumnCalculation </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradebookColumnCalculationRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationList getGradebookColumnCalculationsByRecordType(org.osid.type.Type gradebookColumnCalculationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> GradebookColumnCalculation </code> mapped to a <code> 
     *  GradebookColumn </code> to which this calculation is applied. In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  GradebookColumnCalculation </code> may have a different <code> Id 
     *  </code> than requested, such as the case where a duplicate <code> Id 
     *  </code> was assigned to a <code> GradebookColumnCalculation </code> 
     *  and retained for compatibility. 
     *
     *  @param  gradebookColumnId <code> Id </code> of a <code> 
     *          GradebookColumn </code> 
     *  @return the gradebook column calculation 
     *  @throws org.osid.NotFoundException <code> gradebookColumnId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> gradebookColumnId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculation getGradebookColumnCalculationForGradebookColumn(org.osid.id.Id gradebookColumnId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradebookColumnCalculationList </code> corresponding to 
     *  the given gradebook column <code> Ids </code> to which this 
     *  calculation is applied. In plenary mode, the returned list contains 
     *  all of the gradebook column calculations specified in the <code> Id 
     *  </code> list, in the order of the list, including duplicates, or an 
     *  error results if a <code> Id </code> in the supplied list is not found 
     *  or inaccessible. Otherwise, inaccessible gradeboook column 
     *  calculations may be omitted from the list. 
     *
     *  @param  gradebookColumnIds a list of gradebook column <code> Ids 
     *          </code> 
     *  @return the returned <code> GradebookColumnCalculation </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> gradeBookColumnIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationList getGradebookColumnCalculationsForGradebookColumns(org.osid.id.IdList gradebookColumnIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all gradebook column calculations. In plenary mode, the returned 
     *  list contains all known gradebook column calculations or an error 
     *  results. Otherwise, the returned list may contain only those gradebook 
     *  column calculations that are accessible through this session. 
     *
     *  @return a <code> GradebookColumnCalculationList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.calculation.GradebookColumnCalculationList getGradebookColumnCalculations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
