/**
 * <p>The Open Service Interface Definitions for the org.osid.grading
 * service.</p>
 * 
 * <p>The Grading OSID defines a service to apply grades or ratings. </p> 
 * <h4> Grade Systems </h4> 
 * 
 * <p> The grade system sessions provide the means to retrievs and manage 
 * <code> GradeSystem </code> definitions. A <code> GradeSystem </code> is a 
 * fixed set of <code> Grades </code> . <code> GradeSystems </code> may also 
 * take the form of a numerical score as well as a rating based on some 
 * system. <code> GradeEntries </code> belong to a single <code> 
 * GradebookColumn. </code> </p> 
 * <h4> Gradebook Columns </h4> 
 * 
 * <p> A <code> Gradebook </code> is represented by a series of <code> 
 * GradebookColumns. </code> A <code> GradeBookColumn </code> represents a 
 * something to be graded and is joined to a single <code> GradeSystem. 
 * </code> A <code> GradebookColumn </code> may be constrained to a single 
 * grader. </p> 
 * <h4> Grade Entries </h4> 
 * 
 * <p> A <code> GradebookColumn </code> is comprised of a series of <code> 
 * GradeEntry </code> elements. A <code> GradebookColumn </code> may represent 
 * "Assignment 3" while a <code> GradeEntry </code> may represent the 
 * assignment turned in by a particular student. </p> 
 * 
 * <p> A <code> Grade </code> can be applied to a <code> GradeEntry </code> 
 * that relates the entry to a grader and a key <code> Resource. </code> In 
 * the case of a class gradebook, the key resource represents the student. If 
 * there are multiple graders for the same key resource, each grader gets 
 * their own <code> GradebookColumn. </code> </p> 
 * 
 * <p> Gradebooks may also be used to capture ratings about other objects. In 
 * the case where people vote for their favorite assets, the key resource 
 * represents the <code> Asset </code> . </p> 
 * 
 * <p> <code> GradebookColumns </code> may have a <code> 
 * GradebookColumnSummary </code> entry for summary results and statistics 
 * across all <code> GradeEntries </code> in the column. </p> 
 * <h4> Gradebook Cataloging </h4> 
 * 
 * <p> <code> GradebookColumns </code> are organized into <code> Gradebooks. 
 * </code> <code> Gradebooks </code> also provide for a federated hierarchy of 
 * <code> GradebookColumns. </code> Simple reordering of <code> 
 * GradebookColumns </code> can be performed by moving the <code> 
 * GradebookColumn </code> relative to another. The relative positioning may 
 * reference two <code> GradebookColumns </code> through the federation. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Grading OSID includes several subpackages. The Grading Transform 
 * OSID provides a means of translating one <code> GradeSystem </code> to 
 * another. The Grading Calculation OSID defines derived <code> 
 * GradebookColumns. </code> The Grading Batch OSID manages <code> 
 * GradeSystems, </code> <code> GradeEntries, </code> <code> Gradebooks, 
 * </code> and <code> GradebookColumns </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004, 2008 Massachusetts Institute of Technology. 
 * </p> 
 * 
 * <p> Copyright &copy; 2010-2011 Ingeenscus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.grading;
