//
// org.osid.grading.transform.GradeSystemTransformAdminSession
//
//     The OSID Java specification for org.osid.grading.transform.GradeSystemTransformAdminSession.
//
// Copyright (C) 2002-2010 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO PACKAGE 
//     SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES 
//     OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//     OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE 
//     USE OR OTHER DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.transform;


/**
 *  <p>This session creates, updates, and deletes <code> 
 *  GradeSystemTransforms. </code> The data for create and update is provided 
 *  by the consumer via the form object. <code> OsidForms </code> are 
 *  requested for each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  GradeSystemTransform, </code> a <code> GradeSystemTransformForm </code> is 
 *  requested using <code> getGradeSystemTransformFormForCreate() </code> 
 *  specifying the desired record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> 
 *  GradeSystemTransformForm </code> will indicate that it is to be used with 
 *  a create operation and can be used to examine metdata or validate data 
 *  prior to creation. Once the <code> GradeSystemTransformForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  GradeSystemTransformForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> GradeSystemTransformForms </code> are requested to 
 *  the <code> GradeSystemTransformForm </code> <code> Id </code> that is to 
 *  be updated using <code> getGradeSystemTransformFormForUpdate(). </code> 
 *  Similarly, the <code> GradeSystemTransformForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> GradeSystemTransformForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> GradeSystemTransforms. </code> 
 *  </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface GradeSystemTransformAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> GradeSystemTransforms. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> 
     *  GradeSystemTransform </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> GradeSystemTransform </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradeSystemTransforms();


    /**
     *  Tests if this user can create a single <code> GradeSystemTransform 
     *  </code> using the desired record types. While <code> 
     *  GradingTransformManager.getGradeSystemTransformRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  GradeSystemTransform. </code> Providing an empty array tests if a 
     *  <code> GradeSystemTransform </code> can be created with no records. 
     *
     *  @param  gradeSystemTransformRecordTypes array of grade system 
     *          transform record types 
     *  @return <code> true </code> if <code> GradeSystemTransform </code> 
     *          creation using the specified <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGradeSystemTransformWithRecordTypes(org.osid.type.Type[] gradeSystemTransformRecordTypes);


    /**
     *  Gets the grade system transform form for creating new grade system 
     *  transforms. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  sourceGradeSystemId the <code> Id </code> for the source 
     *          <code> GradeSystem </code> 
     *  @param  targetGradeSystemId the <code> Id </code> for the source 
     *          <code> GradeSystem </code> 
     *  @param  gradeSystemTransformRecordTypes array of grade system 
     *          transform record types 
     *  @return the grade system transform form 
     *  @throws org.osid.NotFoundException <code> sourceHradeSystemId </code> 
     *          or <code> targetGradeSystemId </code> not found 
     *  @throws org.osid.NullArgumentException <code> sourceGradeSystemId, 
     *          targetGradeSystemId, </code> <code> 
     *          gradeSystemTransformRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformForm getGradeSystemTransformFormForCreate(org.osid.id.Id sourceGradeSystemId, 
                                                                                                    org.osid.id.Id targetGradeSystemId, 
                                                                                                    org.osid.type.Type[] gradeSystemTransformRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> GradeSystemTransform. </code> 
     *
     *  @param  gradeSystemTransformForm the form for this <code> 
     *          GradeSystemTransform </code> 
     *  @return the new <code> GradeSystemTransform </code> 
     *  @throws org.osid.IllegalStateException <code> gradeSystemTransformForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradeSystemTransformForm 
     *          </code> did not originate from <code> 
     *          getGradeSystemTransformFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransform createGradeSystemTransform(org.osid.grading.transform.GradeSystemTransformForm gradeSystemTransformForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> GradeSystemTransforms. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> 
     *  GradeSystemTransform </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> GradeSystemTransform </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateGradeSystemTransforms();


    /**
     *  Gets the grade system form for updating an existing grade system 
     *  transform. A new grade system transform form should be requested for 
     *  each update transaction. 
     *
     *  @param  gradeSystemTransformId the <code> Id </code> of the <code> 
     *          GradeSystemTransform </code> 
     *  @return the grade system transform form 
     *  @throws org.osid.NotFoundException <code> gradeSystemTransformId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformForm getGradeSystemTransformFormForUpdate(org.osid.id.Id gradeSystemTransformId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing grade system transform. 
     *
     *  @param  gradeSystemTransformForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> gradeSystemTransformForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> gradeSystemTransformForm 
     *          </code> did not originate from <code> 
     *          getGradeSystemTransformFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateGradeSystemTransform(org.osid.grading.transform.GradeSystemTransformForm gradeSystemTransformForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete grade system transforms. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> GradeSystemTransform 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not wish to offer delete 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if <code> GradeSystemTransform </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteGradeSystemTransforms();


    /**
     *  Deletes a <code> GradeSystemTransform. </code> 
     *
     *  @param  gradeSystemTransformId the <code> Id </code> of the <code> 
     *          GradeSystemTransform </code> to remove 
     *  @throws org.osid.NotFoundException <code> gradeSystemTransformId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteGradeSystemTransform(org.osid.id.Id gradeSystemTransformId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  GradeSystemTransforms. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> GradeSystemTransform </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageGradeSystemTransformAliases();


    /**
     *  Adds an <code> Id </code> to a <code> GradeSystemTransform </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> GradeSystemTransform </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id. </code> If the alias is a pointer to another grade 
     *  system transform, it is reassigned to the given grade system transform 
     *  <code> Id. </code> 
     *
     *  @param  gradeSystemTransformId the <code> Id </code> of a <code> 
     *          GradeSystemTransform </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> gradeSystemTransformId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasGradeSystemTransform(org.osid.id.Id gradeSystemTransformId, 
                                          org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a direct grade mapping to a transform. 
     *
     *  @param  gradeSystemTransformId the <code> Id </code> of a <code> 
     *          GradeSystemTransform </code> 
     *  @param  sourceGradeId the source grade <code> Id </code> 
     *  @param  targetGradeId the target grade <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> sourceGradeId </code> 
     *          is already mapped 
     *  @throws org.osid.NotFoundException <code> gradeSystemTransformId, 
     *          sourceGradeId </code> or <code> targetGradeId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformId, 
     *          sourceGradeId </code> or <code> targetGradeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addGradeMap(org.osid.id.Id gradeSystemTransformId, 
                            org.osid.id.Id sourceGradeId, 
                            org.osid.id.Id targetGradeId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a direct grade mapping from a transform. 
     *
     *  @param  gradeSystemTransformId the <code> Id </code> of a <code> 
     *          GradeSystemTransform </code> 
     *  @param  sourceGradeId the source grade <code> Id </code> 
     *  @throws org.osid.NotFoundException no mapping in <code> 
     *          gradeSystemTransformId </code> for <code> sourceGradeId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformId 
     *          </code> or <code> sourceGradeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeGradeMap(org.osid.id.Id gradeSystemTransformId, 
                               org.osid.id.Id sourceGradeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
