//
// org.osid.grading.transform.GradeSystemTransformForm
//
//     The OSID Java specification for org.osid.grading.transform.GradeSystemTransformForm.
//
// Copyright (C) 2002-2010 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO PACKAGE 
//     SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES 
//     OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//     OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE 
//     USE OR OTHER DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.transform;


/**
 *  <p>This is the form for creating and updating <code> 
 *  GradeSystemTransforms. </code> Like all <code> OsidForm </code> objects, 
 *  various data elements may be set here for use in the create and update 
 *  methods in the <code> GradeSystemTransformAdminSession. </code> For each 
 *  data element that may be set, metadata may be examined to provide display 
 *  hints or data constraints. </p>
 */

public interface GradeSystemTransformForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for a score normalization rule. 
     *
     *  @return metadata for the score normalization rule 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getNormalizeInputScoresMetadata();


    /**
     *  Sets the normalize input scores rule. 
     *
     *  @param  enabled the normalize input scores rule 
     *  @throws org.osid.InvalidArgumentException <code> enabled </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> enabled </code> cannot be 
     *          modified 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setNormalizesInputScore(boolean enabled);


    /**
     *  Clears the normalize input scores rule. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNormalizesInputScores();


    /**
     *  Gets the <code> GradeSystemTransformFormRecord </code> corresponding 
     *  to the given grade system record <code> Type. </code> 
     *
     *  @param  gradeSystemTransformRecordType the grade system transform 
     *          record type 
     *  @return the grade system transform form record 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(gradeSystemTransformRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.records.GradeSystemTransformRecord getGradeSystemTransformFormRecord(org.osid.type.Type gradeSystemTransformRecordType)
        throws org.osid.OperationFailedException;
}
