//
// org.osid.grading.transform.GradeSystemTransformLookupSession
//
//     The OSID Java specification for org.osid.grading.transform.GradeSystemTransformLookupSession.
//
// Copyright (C) 2002-2010 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO PACKAGE 
//     SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES 
//     OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//     OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE 
//     USE OR OTHER DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.transform;


/**
 *  <p>The session defines methods for retrieving <code> 
 *  GradeSystemTransformations. </code> </p> 
 *  
 *  <p> Two views are defined in this session: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> federated gradebook view: lookups include grade system 
 *      transformations from this gradebook and other gradebooks which are 
 *      children of this gradebook in the gradebook hierarchy </li> 
 *      <li> isolated gradebook view: lookups include only those grade system 
 *      transformations defined in this gradebook </li> 
 *      <li> active grade system transormations view: All grade system 
 *      transormation lookup methods return active grade system 
 *      transormations. </li> 
 *      <li> any status grade system transormations view: Grade system 
 *      transormations of any active or inactive status are returned from 
 *      methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Grades system transformations may have an additional records indicated 
 *  by their respective record types. The record may not be accessed through a 
 *  cast of the object. </p>
 */

public interface GradeSystemTransformLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Gradebook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Gradebook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGradebookId();


    /**
     *  Gets the <code> Gradebook </code> associated with this session. 
     *
     *  @return the <code> Gradebook </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Gradebook getGradebook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup grade articulations. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if articulation lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupGradeSystemTransforms();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for grade system transformations in gradebooks 
     *  which are children of this gradebook in the gradebook hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGradebookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts grade system transformations to this gradebook only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGradebookView();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeGradeSystemTransformView();


    /**
     *  A complete view of the <code> GradeSystemTransform </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryGradeSystemTransformView();


    /**
     *  Only active grade system transformations are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveGradeSystemTransformView();


    /**
     *  All active and inactive grade system transformations are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusGradeSystemTransformView();


    /**
     *  Gets the <code> GradeSystemTransform </code> specified by its <code> 
     *  Id. </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  GradeSystemTransform </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> GradeSystemTransform </code> and retained for 
     *  compatibility. 
     *
     *  @param  gradeSystemTransformId <code> Id </code> of the <code> 
     *          GradeSystemTransform </code> 
     *  @return the grade system transorm 
     *  @throws org.osid.NotFoundException <code> gradeSystemTransformId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemTransformId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransform getGradeSystemTransform(org.osid.id.Id gradeSystemTransformId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemTransformList </code> corresponding to the 
     *  given <code> IdList. </code> In plenary mode, the returned list 
     *  contains all of the transforms specified in the <code> Id </code> 
     *  list, in the order of the list, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible <code> GradeSystemTransforms 
     *  </code> may be omitted from the list and may present the elements in 
     *  any order including returning a unique set. 
     *
     *  @param  gradeSystemTransformIdList the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> GradeSystemTransform </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformIdList </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformList getGradeSystemTransformsByIds(org.osid.id.IdList gradeSystemTransformIdList)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemTransformList </code> corresponding to the 
     *  given grade system transform genus <code> Type </code> which does not 
     *  include transforms of genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  transforms or an error results. Otherwise, the returned list may 
     *  contain only those transforms that are accessible through this 
     *  session. 
     *
     *  @param  gradeSystemTransformGenusType a grade system transform genus 
     *          type 
     *  @return the returned <code> GradeSystemTransform </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformList getGradeSystemTransformsByGenusType(org.osid.type.Type gradeSystemTransformGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemTransformList </code> corresponding to the 
     *  given grade system transform genus <code> Type </code> and include any 
     *  additional transforms with genus types derived from the specified 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known transforms or an error results. Otherwise, the returned list may 
     *  contain only those transforms that are accessible through this 
     *  session. 
     *
     *  @param  gradeSystemTransformGenusType a grade system transform genus 
     *          type 
     *  @return the returned <code> GradeSystemTransform </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformList getGradeSystemTransformsByParentGenusType(org.osid.type.Type gradeSystemTransformGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> GradeSystemTransformList </code> containing the given 
     *  grade record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known transforms or an error results. Otherwise, the 
     *  returned list may contain only those transforms that are accessible 
     *  through this session. 
     *
     *  @param  gradeSystemTransformRecordType a grade system transform record 
     *          type 
     *  @return the returned <code> GradeSystemTransform </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          gradeSystemTransformGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformList getGradeSystemTransformsByRecordType(org.osid.type.Type gradeSystemTransformRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the grade system transforms from the source grade system. In 
     *  plenary mode, the returned list contains all known grade system 
     *  transforms or an error results. Otherwise, the returned list may 
     *  contain only those grade system transforms that are accessible through 
     *  this session. 
     *
     *  @param  sourceGradeSystemId the source grade system 
     *  @return the returned <code> GradeSystemTransform </code> list 
     *  @throws org.osid.NotFoundException <code> sourceGradeSystemId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> sourceGradeSystemId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformList getGradeSystemTransformsBySource(org.osid.id.Id sourceGradeSystemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a grade system transform by its source and target grade systems. 
     *  In plenary mode, the returned list contains all known grade system 
     *  transforms or an error results. Otherwise, the returned list may 
     *  contain only those grade system transforms that are accessible through 
     *  this session. 
     *
     *  @param  sourceGradeSystemId the source grade system 
     *  @param  targetGradeSystemId the target grade system 
     *  @return the returned <code> GradeSystemTransform </code> 
     *  @throws org.osid.NotFoundException transform not found 
     *  @throws org.osid.NullArgumentException <code> sourceGradeSystemId 
     *          </code> or <code> targetGradeSystemId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransform getGradeSystemTransformBySystems(org.osid.id.Id sourceGradeSystemId, 
                                                                                            org.osid.id.Id targetGradeSystemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> GradeSystemTransforms. </code> In plenary mode, the 
     *  returned list contains all known grade system transforms or an error 
     *  results. Otherwise, the returned list may contain only those grade 
     *  system transforms that are accessible through this session. 
     *
     *  @return a <code> GradeSystemTransformList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.transform.GradeSystemTransformList getGradeSystemTransforms()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
