//
// org.osid.grading.transform.GradingTransformProxyManager
//
//     The OSID Java specification for org.osid.grading.transform.GradingTransformProxyManager.
//
// Copyright (C) 2002-2010 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis. The Massachusetts Institute of Technology, the Open 
//     Knowledge Initiative, and THE AUTHORS DISCLAIM ALL WARRANTIES, EXPRESS 
//     OR IMPLIED, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, 
//     FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO PACKAGE 
//     SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES 
//     OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
//     OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE 
//     USE OR OTHER DEALINGS IN THE WORK. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notice and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, Derivative shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization comtemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.grading.transform;


/**
 *  <p>The grading transform manager provides access to grading transform 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager accept a <code> Proxy </code> interface 
 *  for passing information from server environments.The sessions included in 
 *  this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> GradeSystemTransformationSession: </code> a session to 
 *      convert grades among grade systems </li> 
 *      <li> <code> GradeSystemTransformLookupSession: </code> a session to 
 *      examine grade system transformation rules </li> 
 *      <li> <code> GradeSystemTransformAdminSession: </code> a session to 
 *      manage grade system transformation rules </li> 
 *      <li> <code> GradeSystemTransformNotiicationSession: </code> a session 
 *      to subscribe to grade system transformation notifications </li> 
 *  </ul>
 *  
 */

public interface GradingTransformProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.grading.transform.GradingTransformProfile {


    /**
     *  Gets the session for transforming grades among grade systems. The 
     *  available transformations can be examined through the <code> 
     *  GradeSystemTransformLookupSession. </code> 
     *
     *  @param  sourceGradeSystemId the <code> Id </code> of the source grade 
     *          system 
     *  @param  targetGradeSystemId the <code> Id </code> of the target grade 
     *          system 
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemTransformationSession </code> 
     *  @throws org.osid.NotFoundException no transform exists between <code> 
     *          souceGradebookId </code> and <code> targetGradeSystemId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> sourceGradeSystemId, 
     *          targetGradeSystemIdId </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemTransformation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemTransformation() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.transform.GradeSystemTransformationSession getGradeSystemTransformationSession(org.osid.id.Id sourceGradeSystemId, 
                                                                                                           org.osid.id.Id targetGradeSystemId, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  transform lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemTransformLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemTransformLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemTransformLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.transform.GradeSystemTransformLookupSession getGradeSystemTransformLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  transform lookup service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemTransformLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemTransformLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemTransformLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.transform.GradeSystemTransformLookupSession getGradeSystemTransformLookupSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  transform admin service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemTransformAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemTransformAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemTransformAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.transform.GradeSystemTransformAdminSession getGradeSystemTransformAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  transform admin service for the given gradebook. 
     *
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemTransformAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradebookId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemTransformAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemTransformAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.grading.transform.GradeSystemTransformAdminSession getGradeSystemTransformAdminSessionForGradebook(org.osid.id.Id gradebookId, 
                                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to grade 
     *  system transform changes. 
     *
     *  @param  gradeSystemTransformReceiver the grade system transform 
     *          receiver interface 
     *  @param  proxy a proxy 
     *  @return a <code> GradeSystemTransformNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemTransformNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemTransformNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.grading.transform.GradeSystemTransformNotificationSession getGradeSystemTransformNotificationSession(org.osid.grading.transform.GradeSystemTransformReceiver gradeSystemTransformReceiver, 
                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the grade system 
     *  transform notification service for the given gradebook. 
     *
     *  @param  gradeSystemTransformReceiver the grade system transform 
     *          receiver interface 
     *  @param  gradebookId the <code> Id </code> of the gradebook 
     *  @param  proxy a proxy 
     *  @return <code> a GradeSystemTransformNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> gradebookId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> gradeSystemReceiver, 
     *          gradebookId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGradeSystemTransformNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGradeSystemTransformNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.grading.transform.GradeSystemTransformNotificationSession getGradeSystemTransformNotificationSessionForGradebook(org.osid.grading.transform.GradeSystemTransformReceiver gradeSystemTransformReceiver, 
                                                                                                                                     org.osid.id.Id gradebookId, 
                                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
