//
// org.osid.hierarchy.HierarchyManager
//
//     The OSID Java specification for org.osid.hierarchy.HierarchyManager.
//
// Copyright (C) 2002,2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hierarchy;


/**
 *  <p>The hierarchy manager provides access sessions to traverse and manage 
 *  hierrachies of <code> Ids. </code> The sessions included in this manager 
 *  are: </p> 
 *  
 *  <ul>
 *      <li> <code> HierarchyTraversalSession: </code> a basic session 
 *      traversing a hierarchy </li> 
 *      <li> <code> HierarchyDesignSession: </code> a session to design a 
 *      hierarchy </li> 
 *      <li> <code> HierarchySequencingSession: </code> a session to sequence 
 *      nodes in a hierarchy </li> 
 *      <li> <code> HierarchyStructureNotificationSession: </code> a session 
 *      for notififcations within a hierarchy structure </li> 
 *      <li> <code> HierarchyLookupSession: </code> a session looking up 
 *      hiererachies </li> 
 *      <li> <code> HierarchyQuerySession: </code> a session querying 
 *      hiererachies </li> 
 *      <li> <code> HierarchySearchSession: </code> a session for searching 
 *      for hierarchies </li> 
 *      <li> <code> HierarchyAdminSession: </code> a session for creating and 
 *      deleting hierarchies </li> 
 *      <li> <code> HierarchyNotificationSession: </code> a session for 
 *      subscribing to changes in hierarchies </li> 
 *  </ul>
 *  
 */

public interface HierarchyManager
    extends org.osid.OsidManager,
            org.osid.hierarchy.HierarchyProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the hierarchy 
     *  traversal service. 
     *
     *  @return a <code> HierarchyTraversalSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyTraversal() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyTraversal() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchyTraversalSession getHierarchyTraversalSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the hierarchy 
     *  traversal service for the given hierarchy. 
     *
     *  @param  hierarchyId the <code> Id </code> of the hierarchy 
     *  @return the new <code> HierarchyTraversalSession </code> 
     *  @throws org.osid.NotFoundException <code> hierarchyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> hierarchyid </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyTraversal() </code> or <code> 
     *          supportsVisibleFedaration() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyTraversal() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchyTraversalSession getHierarchyTraversalSessionForHierarchy(org.osid.id.Id hierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the hierarchy 
     *  design service. 
     *
     *  @return a <code> HierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyDesign() </code> is <code> true. </code> 
     */

    public org.osid.hierarchy.HierarchyDesignSession getHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the topology 
     *  design service using for the given hierarchy. 
     *
     *  @param  hierarchyId the <code> Id </code> of the graph 
     *  @return a <code> HierarchyDesignSession </code> 
     *  @throws org.osid.NotFoundException <code> hierarchyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> hierarchyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyDesign() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyDesign() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchyDesignSession getHierarchyDesignSessionForHierarchy(org.osid.id.Id hierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the hierarchy 
     *  sequencing service. 
     *
     *  @return a <code> HierarchySequencingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchySequencing() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchySequencing() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchySequencingSession getHierarchySequencingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the sequencing 
     *  design service using for the given hierarchy. 
     *
     *  @param  hierarchyId the <code> Id </code> of the graph 
     *  @return a <code> HierarchySequencingSession </code> 
     *  @throws org.osid.NotFoundException <code> hierarchyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> hierarchyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchySequencing() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchySequencing() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchySequencingSession getHierarchySequencingSessionForHierarchy(org.osid.id.Id hierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for subscribing to notifications of changes within a 
     *  hierarchy structure. 
     *
     *  @param  hierarchyStructureReceiver a receiver 
     *  @return a <code> HierarchyStructureNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          hierarchyStructureReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyStructureNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyStructureNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.hierarchy.HierarchyStructureNotificationSession getHierarchyStructureNotificationSession(org.osid.hierarchy.HierarchyStructureReceiver hierarchyStructureReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for subscribing to notifications of changes within a 
     *  hierarchy structure for the given hierarchy. 
     *
     *  @param  hierarchyStructureReceiver a receiver 
     *  @param  hierarchyId the <code> Id </code> of the graph 
     *  @return a <code> HierarchyStructureNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> hierarchyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> 
     *          hierarchyStructureReceiver </code> or <code> hierarchyId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyStructureNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyStructureNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.hierarchy.HierarchyStructureNotificationSession getHierarchyStructureNotificationSessionForHierarchy(org.osid.hierarchy.HierarchyStructureReceiver hierarchyStructureReceiver, 
                                                                                                                         org.osid.id.Id hierarchyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the hierarchy 
     *  lookup service. 
     *
     *  @return a <code> HierarchyLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyLookup() </code> is <code> true. </code> 
     */

    public org.osid.hierarchy.HierarchyLookupSession getHierarchyLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the hierarchy 
     *  query service. 
     *
     *  @return a <code> HierarchyQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyQuery() </code> is <code> true. </code> 
     */

    public org.osid.hierarchy.HierarchyQuerySession getHierarchyQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the hierarchy 
     *  search service. 
     *
     *  @return a <code> HierarchySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchySearch() </code> is <code> true. </code> 
     */

    public org.osid.hierarchy.HierarchySearchSession getHierarchySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the hierarchy administrative session. 
     *
     *  @return a <code> HierarchyAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyAdmin() </code> is <code> true. </code> 
     */

    public org.osid.hierarchy.HierarchyAdminSession getHierarchyAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a hierarchy notification session. 
     *
     *  @param  hierarchyReceiver notification callback 
     *  @return a <code> HierarchyNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> hierarchyReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHierarchyNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHierarchyNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hierarchy.HierarchyNotificationSession getHierarchyNotificationSession(org.osid.hierarchy.HierarchyReceiver hierarchyReceiver)
        throws org.osid.OperationFailedException;
}
