//
// org.osid.hierarchy.HierarchyQuery
//
//     The OSID Java specification for org.osid.hierarchy.HierarchyQuery.
//
// Copyright (C) 2002,2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hierarchy;


/**
 *  <p>This is the query for searching hierarchies. Results are returned if 
 *  all the specified elements match. Each method match request produces an 
 *  <code> AND </code> term while multiple invocations of a method produces a 
 *  nested <code> OR, </code> except for accessing the <code> HierarchyQuery 
 *  </code> record. </p>
 */

public interface HierarchyQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Matches an <code> Id </code> of a node in this hierarchy. Multiple 
     *  nodes can be added to this query which behave as a boolean <code> AND. 
     *  </code> 
     *
     *  @param  id <code> Id </code> to match 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNodeId(org.osid.id.Id id, boolean match);


    /**
     *  Matches hierarchies with any node. 
     *
     *  @param  match <code> true </code> to match hierarchies with any nodes, 
     *          <code> false </code> to match hierarchies with no nodes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNodeId(boolean match);


    /**
     *  Clears the node <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNodeIdTerms();


    /**
     *  Gets the hierarchy record query corresponding to the given <code> 
     *  Hierarchy </code> record <code> Type. </code> Multiple record 
     *  retrievals of the same type may return the same underlying object and 
     *  do not result in adding terms to the query. Multiple record retrievals 
     *  of different types add <code> AND </code> terms to the other elements 
     *  set in this form. 
     *
     *  @param  hierarchyRecordType a hierarchy record type 
     *  @return the hierarchy query record 
     *  @throws org.osid.NullArgumentException <code> hierarchyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(hierarchyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.records.HierarchyQueryRecord getHierarchyQueryRecord(org.osid.type.Type hierarchyRecordType)
        throws org.osid.OperationFailedException;
}
