//
// org.osid.hierarchy.HierarchySequencingSession
//
//     The OSID Java specification for org.osid.hierarchy.HierarchySequencingSession.
//
// Copyright (C) 2002,2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hierarchy;


/**
 *  <p>This session provides methods to sequence the nodes in a hierarchy. 
 *  </p>
 */

public interface HierarchySequencingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can change the hierarchy. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known performing any update will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if changing this hierarchy is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceHierarchy();


    /**
     *  Moves a node ahead of a refrence node under the given parent. 
     *
     *  @param  parentId the <code> Id </code> of the parent node 
     *  @param  referenceId the <code> Id </code> of the node 
     *  @param  id the <code> Id </code> of the node to move ahead of <code> 
     *          referenceId </code> 
     *  @throws org.osid.NotFoundException <code> parentId, referenceId, 
     *          </code> or <code> id </code> not found, or <code> referenceId 
     *          </code> or <code> id </code> is not a child of <code> parentId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> parentId, referenceId, 
     *          </code> or <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveNodeAhead(org.osid.id.Id parentId, 
                              org.osid.id.Id referenceId, org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a node behind a refrence node under the given parent. 
     *
     *  @param  parentId the <code> Id </code> of the parent node 
     *  @param  referenceId the <code> Id </code> of the node 
     *  @param  id the <code> Id </code> of the node to move behind <code> 
     *          referenceId </code> 
     *  @throws org.osid.NotFoundException <code> parentId, referenceId, 
     *          </code> or <code> id </code> not found, or <code> referenceId 
     *          </code> or <code> id </code> is not a child of <code> parentId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> parentId, referenceId, 
     *          </code> or <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveNodeBehind(org.osid.id.Id parentId, 
                               org.osid.id.Id referenceId, org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Sequences a set of nodes under a parent. 
     *
     *  @param  parentId the <code> Id </code> of the parent node 
     *  @param  ids the <code> Id </code> of the nodes 
     *  @throws org.osid.NotFoundException <code> parentId </code> or an 
     *          <code> id </code> not found, or an <code> id </code> is not a 
     *          child of <code> parentId </code> 
     *  @throws org.osid.NullArgumentException <code> parentId </code> or 
     *          <code> ids </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void sequenceNodes(org.osid.id.Id parentId, org.osid.id.Id[] ids)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
