//
// org.osid.hierarchy.HierarchyTraversalSession
//
//     The OSID Java specification for org.osid.hierarchy.HierarchyTraversalSession.
//
// Copyright (C) 2002,2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hierarchy;


/**
 *  <p>This session defines methods for traversing a hierarchy. Each node in 
 *  the hierarchy is a unique OSID <code> Id. </code> The hierarchy may be 
 *  traversed recursively to establish the tree structure through <code> 
 *  getParents() </code> and <code> getChildren(). </code> To relate these 
 *  <code> Ids </code> to another OSID, <code> getNodes() </code> can be used 
 *  for retrievals that can be used for bulk lookups in other OSIDs. </p> 
 *  
 *  <p> Any Id available in an associated OSID is known to this hierarchy. A 
 *  lookup up a particular <code> Id </code> in this hierarchy for the 
 *  purposes of establishing a starting point for traversal or determining 
 *  relationships should use the <code> Id </code> returned from the 
 *  corresponding OSID object, not an Id that has been stored, to avoid 
 *  problems with <code> Id </code> translation or aliasing. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParents() </code> or <code> getChildren() </code> in lieu of 
 *  a <code> PERMISSION_DENIED </code> error that may disrupt the traversal 
 *  through authorized pathways. </p>
 */

public interface HierarchyTraversalSession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessHierarchy();


    /**
     *  Gets the root nodes of this hierarchy. 
     *
     *  @return the root nodes 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRoots()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this <code> Id </code> contains any parents. 
     *
     *  @param  id the <code> Id </code> to query 
     *  @return <code> true </code> if this <code> Id </code> contains 
     *          parents, <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParents(org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of another. 
     *
     *  @param  id the <code> Id </code> to query 
     *  @param  parentId the <code> Id </code> of a parent 
     *  @return <code> true </code> if this <code> parentId </code> is a 
     *          parent of <code> id, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          parentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> parentId </code> not found return <code> false. 
     *          </code> 
     */

    public boolean isParent(org.osid.id.Id id, org.osid.id.Id parentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given <code> id. </code> 
     *
     *  @param  id the <code> Id </code> to query 
     *  @return the parents of the <code> id </code> 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParents(org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of another. 
     *
     *  @param  id the <code> Id </code> to query 
     *  @param  ancestorId the <code> Id </code> of an ancestor 
     *  @return <code> true </code> if this <code> ancestorId </code> is a 
     *          parent of <code> id, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          ancestorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> ancestorId </code> not found return <code> false. 
     *          </code> 
     */

    public boolean isAncestor(org.osid.id.Id id, org.osid.id.Id ancestorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this <code> Id </code> has any children. 
     *
     *  @param  id the <code> Id </code> to query 
     *  @return <code> true </code> if this <code> Id </code> has children, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildren(org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a node is a direct child of another. 
     *
     *  @param  id the <code> Id </code> to query 
     *  @param  childId the <code> Id </code> of a child 
     *  @return <code> true </code> if this <code> childId </code> is a child 
     *          of the <code> Id, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          childId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> childId </code> not found return <code> false. 
     *          </code> 
     */

    public boolean isChild(org.osid.id.Id id, org.osid.id.Id childId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given <code> Id. </code> 
     *
     *  @param  id the <code> Id </code> to query 
     *  @return the children of the <code> id </code> 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildren(org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a node is a descendant of another. 
     *
     *  @param  id the <code> Id </code> to query 
     *  @param  descendantId the <code> Id </code> of a descendant 
     *  @return <code> true </code> if this <code> descendantId </code> is a 
     *          child of the <code> Id, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          descendant </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If not found return <code> false. </code> 
     */

    public boolean isDescendant(org.osid.id.Id id, org.osid.id.Id descendantId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given <code> Id. </code> 
     *
     *  @param  id the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the node. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the node. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given node, <code> false </code> to omit the siblings 
     *  @return a node 
     *  @throws org.osid.NotFoundException <code> id </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getNodes(org.osid.id.Id id, 
                                            long ancestorLevels, 
                                            long descendantLevels, 
                                            boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
