//
// org.osid.hold.HoldAdminSession
//
//     The OSID Java specification for org.osid.hold.HoldAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This session creates, updates, and deletes <code> Holds. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Hold, </code> a <code> HoldForm </code> is requested using <code> 
 *  getHoldFormForCreate() </code> specifying the desired relationship peers 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. The returned <code> HoldForm </code> will indicate that it is 
 *  to be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> HoldForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  HoldForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> HoldForms </code> are requested to the <code> Hold 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getHoldFormForUpdate(). </code> Similarly, the <code> HoldForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> HoldForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Holds. </code> To unmap a <code> 
 *  Hold </code> from the current <code> Oubliette, </code> the <code> 
 *  HoldOublietteAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Hold </code> itself thus removing 
 *  it from all known <code> Oubliette </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface HoldAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Oubliette </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Oubliette Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOublietteId();


    /**
     *  Gets the <code> Oubliette </code> associated with this session. 
     *
     *  @return the oubliette 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Oubliette getOubliette()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Holds. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Hold </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Hold </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateHolds();


    /**
     *  Tests if this user can create a single <code> Hold </code> using the 
     *  desired record types. While <code> HoldManager.getHoldRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> Hold. </code> Providing an empty array tests if a <code> Hold 
     *  </code> can be created with no records. 
     *
     *  @param  holdRecordTypes array of hold record types 
     *  @return <code> true </code> if <code> Hold </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> holdRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateHoldWithRecordTypes(org.osid.type.Type[] holdRecordTypes);


    /**
     *  Gets the hold form for creating new holds. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  issueId the <code> Id </code> for the issue 
     *  @param  resourceId the <code> Id </code> for the resource 
     *  @param  holdRecordTypes array of hold record types 
     *  @return the hold form 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> issueId, resourceId 
     *          </code> or <code> holdRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldForm getHoldFormForCreateForResource(org.osid.id.Id issueId, 
                                                                  org.osid.id.Id resourceId, 
                                                                  org.osid.type.Type[] holdRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the hold form for creating new holds. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  issueId the <code> Id </code> for the issue 
     *  @param  agentId the <code> Id </code> for the agent 
     *  @param  holdRecordTypes array of hold record types 
     *  @return the hold form 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          agentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> issueId, agentId </code> 
     *          or <code> holdRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldForm getHoldFormForCreateForAgent(org.osid.id.Id issueId, 
                                                               org.osid.id.Id agentId, 
                                                               org.osid.type.Type[] holdRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Hold. </code> 
     *
     *  @param  holdForm the form for this <code> Hold </code> 
     *  @return the new <code> Hold </code> 
     *  @throws org.osid.IllegalStateException <code> holdForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> holdForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> holdForm </code> did not 
     *          originate from <code> getHoldFormForCreateForResource() 
     *          </code> or <code> getHoldFormForCreateForAgent() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Hold createHold(org.osid.hold.HoldForm holdForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Holds. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Hold </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Hold </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateHolds();


    /**
     *  Gets the hold form for updating an existing hold. A new hold form 
     *  should be requested for each update transaction. 
     *
     *  @param  holdId the <code> Id </code> of the <code> Hold </code> 
     *  @return the hold form 
     *  @throws org.osid.NotFoundException <code> holdId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> holdId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldForm getHoldFormForUpdate(org.osid.id.Id holdId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing hold. 
     *
     *  @param  holdForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> holdForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> holdId </code> or <code> 
     *          holdForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> holdForm </code> did not 
     *          originate from <code> getHoldFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateHold(org.osid.hold.HoldForm holdForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Holds. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Hold </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Hold </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteHolds();


    /**
     *  Deletes a <code> Hold. </code> 
     *
     *  @param  holdId the <code> Id </code> of the <code> Hold </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> holdId </code> not found 
     *  @throws org.osid.NullArgumentException <code> holdId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteHold(org.osid.id.Id holdId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Holds. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Hold </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageHoldAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Hold </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Hold </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another hold, it is reassigned to the given hold <code> 
     *  Id. </code> 
     *
     *  @param  holdId the <code> Id </code> of a <code> Hold </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> holdId </code> not found 
     *  @throws org.osid.NullArgumentException <code> holdId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasHold(org.osid.id.Id holdId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
