//
// org.osid.hold.HoldProfile
//
//     The OSID Java specification for org.osid.hold.HoldProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>The hold profile describes the interoperability among hold services. 
 *  </p>
 */

public interface HoldProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any oubliette federation is exposed. Federation is exposed 
     *  when a specific oubliette may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of oubliettes appears as a single oubliette. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a blocking service is supported for the current agent. 
     *
     *  @return <code> true </code> if blockiings service is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlocking();


    /**
     *  Tests if a my hold service is supported for the current agent. 
     *
     *  @return <code> true </code> if my hold service is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyHold();


    /**
     *  Tests if looking up blocks is supported. 
     *
     *  @return <code> true </code> if block lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockLookup();


    /**
     *  Tests if querying blocks is supported. 
     *
     *  @return <code> true </code> if block query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockQuery();


    /**
     *  Tests if searching blocks is supported. 
     *
     *  @return <code> true </code> if block search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockSearch();


    /**
     *  Tests if block administrative service is supported. 
     *
     *  @return <code> true </code> if block administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockAdmin();


    /**
     *  Tests if a block notification service is supported. 
     *
     *  @return <code> true </code> if block notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockNotification();


    /**
     *  Tests if a block oubliette lookup service is supported. 
     *
     *  @return <code> true </code> if a block oubliette lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockOubliette();


    /**
     *  Tests if a block oubliette service is supported. 
     *
     *  @return <code> true </code> if block to oubliette assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockOublietteAssignment();


    /**
     *  Tests if a block smart oubliette lookup service is supported. 
     *
     *  @return <code> true </code> if a block smart oubliette service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockSmartOubliette();


    /**
     *  Tests if looking up issues is supported. 
     *
     *  @return <code> true </code> if issue lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueLookup();


    /**
     *  Tests if querying issues is supported. 
     *
     *  @return <code> true </code> if issue query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueQuery();


    /**
     *  Tests if searching issues is supported. 
     *
     *  @return <code> true </code> if issue search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueSearch();


    /**
     *  Tests if issue <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if issue administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueAdmin();


    /**
     *  Tests if an issue <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if issue notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueNotification();


    /**
     *  Tests if an issue oubliette lookup service is supported. 
     *
     *  @return <code> true </code> if an issue oubliette lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueOubliette();


    /**
     *  Tests if an issue oubliette assignment service is supported. 
     *
     *  @return <code> true </code> if an issue to oubliette assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueOublietteAssignment();


    /**
     *  Tests if an issue smart oubliette service is supported. 
     *
     *  @return <code> true </code> if an issue smart oubliette service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueSmartOubliette();


    /**
     *  Tests if looking up holds is supported. 
     *
     *  @return <code> true </code> if hold lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldLookup();


    /**
     *  Tests if querying holds is supported. 
     *
     *  @return <code> true </code> if hold query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldQuery();


    /**
     *  Tests if searching holds is supported. 
     *
     *  @return <code> true </code> if hold search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldSearch();


    /**
     *  Tests if hold administrative service is supported. 
     *
     *  @return <code> true </code> if hold administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldAdmin();


    /**
     *  Tests if a hold notification service is supported. 
     *
     *  @return <code> true </code> if hold notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldNotification();


    /**
     *  Tests if a hold oubliette lookup service is supported. 
     *
     *  @return <code> true </code> if a hold oubliette lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldOubliette();


    /**
     *  Tests if a hold oubliette service is supported. 
     *
     *  @return <code> true </code> if hold to oubliette assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldOublietteAssignment();


    /**
     *  Tests if a hold smart oubliette lookup service is supported. 
     *
     *  @return <code> true </code> if a hold smart oubliette service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldSmartOubliette();


    /**
     *  Tests if looking up oubliettes is supported. 
     *
     *  @return <code> true </code> if oubliette lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteLookup();


    /**
     *  Tests if querying oubliettes is supported. 
     *
     *  @return <code> true </code> if an oubliette query service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteQuery();


    /**
     *  Tests if searching oubliettes is supported. 
     *
     *  @return <code> true </code> if oubliette search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteSearch();


    /**
     *  Tests if oubliette administrative service is supported. 
     *
     *  @return <code> true </code> if oubliette administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteAdmin();


    /**
     *  Tests if an oubliette <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if oubliette notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteNotification();


    /**
     *  Tests for the availability of an oubliette hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if oubliette hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsOublietteHierarchy();


    /**
     *  Tests for the availability of an oubliette hierarchy design service. 
     *
     *  @return <code> true </code> if oubliette hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteHierarchyDesign();


    /**
     *  Tests for the availability of a hold batch service. 
     *
     *  @return <code> true </code> if a hold batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldBatch();


    /**
     *  Tests for the availability of a hold rules service. 
     *
     *  @return <code> true </code> if a hold rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldRules();


    /**
     *  Gets the supported <code> Block </code> record types. 
     *
     *  @return a list containing the supported <code> Block </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBlockRecordTypes();


    /**
     *  Tests if the given <code> Block </code> record type is supported. 
     *
     *  @param  blockRecordType a <code> Type </code> indicating a <code> 
     *          Block </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> blockRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockRecordType(org.osid.type.Type blockRecordType);


    /**
     *  Gets the supported <code> Block </code> search record types. 
     *
     *  @return a list containing the supported <code> Block </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBlockSearchRecordTypes();


    /**
     *  Tests if the given <code> Block </code> search record type is 
     *  supported. 
     *
     *  @param  blockSearchRecordType a <code> Type </code> indicating a 
     *          <code> Block </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> blockSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBlockSearchRecordType(org.osid.type.Type blockSearchRecordType);


    /**
     *  Gets the supported <code> Issue </code> record types. 
     *
     *  @return a list containing the supported <code> Issue </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getIssueRecordTypes();


    /**
     *  Tests if the given <code> Issue </code> record type is supported. 
     *
     *  @param  issueRecordType a <code> Type </code> indicating an <code> 
     *          Issue </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> issueRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueRecordType(org.osid.type.Type issueRecordType);


    /**
     *  Gets the supported <code> Issue </code> search types. 
     *
     *  @return a list containing the supported <code> Issue </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getIssueSearchRecordTypes();


    /**
     *  Tests if the given <code> Issue </code> search type is supported. 
     *
     *  @param  issueSearchRecordType a <code> Type </code> indicating an 
     *          <code> Issue </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> issueSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueSearchRecordType(org.osid.type.Type issueSearchRecordType);


    /**
     *  Gets the supported <code> Hold </code> record types. 
     *
     *  @return a list containing the supported <code> Hold </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getHoldRecordTypes();


    /**
     *  Tests if the given <code> Hold </code> record type is supported. 
     *
     *  @param  holdRecordType a <code> Type </code> indicating a <code> Hold 
     *          </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> holdRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldRecordType(org.osid.type.Type holdRecordType);


    /**
     *  Gets the supported <code> Hold </code> search record types. 
     *
     *  @return a list containing the supported <code> Hold </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getHoldSearchRecordTypes();


    /**
     *  Tests if the given <code> Hold </code> search record type is 
     *  supported. 
     *
     *  @param  holdSearchRecordType a <code> Type </code> indicating a <code> 
     *          Hold </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> holdSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldSearchRecordType(org.osid.type.Type holdSearchRecordType);


    /**
     *  Gets the supported <code> Oubliette </code> record types. 
     *
     *  @return a list containing the supported <code> Oubliette </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOublietteRecordTypes();


    /**
     *  Tests if the given <code> Oubliette </code> record type is supported. 
     *
     *  @param  oublietteRecordType a <code> Type </code> indicating a <code> 
     *          Oubliette </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> oublietteRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteRecordType(org.osid.type.Type oublietteRecordType);


    /**
     *  Gets the supported <code> Oubliette </code> search types. 
     *
     *  @return a list containing the supported <code> Oubliette </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOublietteSearchRecordTypes();


    /**
     *  Tests if the given <code> Oubliette </code> search record type is 
     *  supported. 
     *
     *  @param  oublietteSearchRecordType a <code> Type </code> indicating a 
     *          <code> Oubliette </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          oublietteSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOublietteSearchRecordType(org.osid.type.Type oublietteSearchRecordType);
}
