//
// org.osid.hold.HoldSearchSession
//
//     The OSID Java specification for org.osid.hold.HoldSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This session provides methods for searching among <code> Hold </code> 
 *  objects. The search query is constructed using the <code> HoldQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getHoldsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Holds. </code> A more advanced search may be 
 *  performed with <code> getHoldsBySearch(). </code> It accepts a <code> 
 *  HoldSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getHoldsBySearch() </code> returns a <code> HoldSearchResults </code> that 
 *  can be used to access the resulting <code> HoldList </code> or be used to 
 *  perform a search within the result set through <code> HoldSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated oubliette view: searches include holds in oubliettes of 
 *      which this oubliette is an ancestor in the oubliette hierarchy </li> 
 *      <li> isolated oubliette view: searches are restricted to holds in this 
 *      oubliette </li> 
 *  </ul>
 *  
 *  
 *  <p> Holds may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> HoldQuery. </code> </p>
 */

public interface HoldSearchSession
    extends org.osid.hold.HoldQuerySession {


    /**
     *  Gets a hold search. 
     *
     *  @return the hold search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldSearch getHoldSearch();


    /**
     *  Gets a hold search order. The <code> HoldSearchOrder </code> is 
     *  supplied to a <code> HoldSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the hold search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldSearchOrder getHoldSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  holdQuery the hold query 
     *  @param  holdSearch the hold search 
     *  @return the hold search results 
     *  @throws org.osid.NullArgumentException <code> holdQuery </code> or 
     *          <code> holdSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> holdQuery </code> or 
     *          <code> holdSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldSearchResults getHoldsBySearch(org.osid.hold.HoldQuery holdQuery, 
                                                            org.osid.hold.HoldSearch holdSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a hold query from an inspector. The inspector is available from a 
     *  <code> HoldSearchResults. </code> 
     *
     *  @param  holdQueryInspector a hold query inspector 
     *  @return the hold query 
     *  @throws org.osid.NullArgumentException <code> holdQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> holdQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldQuery getHoldQueryFromInspector(org.osid.hold.HoldQueryInspector holdQueryInspector);
}
