//
// org.osid.hold.HoldSmartOublietteSession
//
//     The OSID Java specification for org.osid.hold.HoldSmartOublietteSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> HoldQuery </code> can be retrieved from this session 
 *  and oublietteped to this <code> Oubliette </code> to create a virtual 
 *  collection of <code> Holds. </code> The holds may be sequenced using the 
 *  <code> HoldSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Oubliette </code> has a default query that matches any 
 *  hold and a default search order that specifies no sequencing. The queries 
 *  may be examined using a <code> HoldQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to a <code> HoldQuery. 
 *  </code> </p>
 */

public interface HoldSmartOublietteSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Oubliette </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Oubliette Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOublietteId();


    /**
     *  Gets the <code> Oubliette </code> associated with this session. 
     *
     *  @return the oubliette 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Oubliette getOubliette()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart oubliettes. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart oubliette management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartOubliettes();


    /**
     *  Gets a hold query. 
     *
     *  @return the hold query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldQuery getHoldQuery();


    /**
     *  Gets a hold search order. 
     *
     *  @return the hold search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldSearchOrder getHoldSearchOrder();


    /**
     *  Applies a hold query to this oubliette. 
     *
     *  @param  holdQuery the hold query 
     *  @throws org.osid.NullArgumentException <code> holdQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> holdQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyHoldQuery(org.osid.hold.HoldQuery holdQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a hold query inspector for this oubliette. 
     *
     *  @return the hold query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldQueryInspector inspectHoldQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a hold search order to this oubliette. 
     *
     *  @param  holdSearchOrder the hold search order 
     *  @throws org.osid.NullArgumentException <code> holdSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> holdSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyHoldSequencing(org.osid.hold.HoldSearchOrder holdSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a hold query from an inspector. 
     *
     *  @param  holdQueryInspector a hold query inspector 
     *  @return the hold query 
     *  @throws org.osid.NullArgumentException <code> holdQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> holdQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.HoldQuery getHoldQueryFromInspector(org.osid.hold.HoldQueryInspector holdQueryInspector);
}
