//
// org.osid.hold.IssueOublietteAssignmentSession
//
//     The OSID Java specification for org.osid.hold.IssueOublietteAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold;


/**
 *  <p>This session provides methods to re-assign <code> Issues </code> to 
 *  <code> Oubliette </code> mappings. An <code> Issue </code> may appear in 
 *  multiple <code> Oubliette </code> objects and removing the last reference 
 *  to an <code> Issue </code> is the equivalent of deleting it. Each <code> 
 *  Oubliette </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> Issue </code> to another <code> 
 *  Oubliette </code> is not a copy operation (eg: does not change its <code> 
 *  Id </code> ). </p>
 */

public interface IssueOublietteAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter issue/oubliette mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if issue is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignIssues();


    /**
     *  Tests if this user can alter issue/oubliette mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  oublietteId the <code> Id </code> of the <code> Oubliette 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> oublietteId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignIssuesToOubliette(org.osid.id.Id oublietteId);


    /**
     *  Gets a list of oubliettes including and under the given oubliette node 
     *  in which any issue can be assigned. 
     *
     *  @param  oublietteId the <code> Id </code> of the <code> Oubliette 
     *          </code> 
     *  @return list of assignable oubliette <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> oublietteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOublietteIds(org.osid.id.Id oublietteId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of oubliettes including and under the given oubliette node 
     *  in which a specific issue can be assigned. 
     *
     *  @param  oublietteId the <code> Id </code> of the <code> Oubliette 
     *          </code> 
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @return list of assignable oubliette <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> oublietteId </code> or 
     *          <code> issueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOublietteIdsForIssue(org.osid.id.Id oublietteId, 
                                                                org.osid.id.Id issueId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Issue </code> to a <code> Oubliette. </code> 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  oublietteId the <code> Id </code> of the <code> Oubliette 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> issueId </code> is 
     *          already assigned to <code> oublietteId </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          oublietteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> oublietteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignIssueToOubliette(org.osid.id.Id issueId, 
                                       org.osid.id.Id oublietteId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Issue </code> from a <code> Oubliette. </code> 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  oublietteId the <code> Id </code> of the <code> Oubliette 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          oublietteId </code> not found or <code> issueId </code> is not 
     *          assigned to <code> oublietteId </code> 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> oublietteId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignIssueFromOubliette(org.osid.id.Id issueId, 
                                           org.osid.id.Id oublietteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> Issue </code> from one <code> Oubliette </code> to 
     *  another. Mappings to other <code> Oubliettes </code> are unaffected. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  fromOublietteId the <code> Id </code> of the current <code> 
     *          Oubliette </code> 
     *  @param  toOublietteId the <code> Id </code> of the destination <code> 
     *          Oubliette </code> 
     *  @throws org.osid.NotFoundException <code> issueId, fromOublietteId, 
     *          </code> or <code> toOublietteId </code> not found or <code> 
     *          issueId </code> not mapped to <code> fromOublietteId </code> 
     *  @throws org.osid.NullArgumentException <code> issueId, 
     *          fromOublietteId, </code> or <code> toOublietteId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignIssueToOubliette(org.osid.id.Id issueId, 
                                         org.osid.id.Id fromOublietteId, 
                                         org.osid.id.Id toOublietteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
