//
// org.osid.hold.rules.HoldEnablerAdminSession
//
//     The OSID Java specification for org.osid.hold.rules.HoldEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold.rules;


/**
 *  <p>This session creates and removes hold enablers. The data for create and 
 *  update is provided via the <code> HoldEnablerForm. </code> </p>
 */

public interface HoldEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Oubliette </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Oubliette Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOublietteId();


    /**
     *  Gets the <code> Oubliette </code> associated with this session. 
     *
     *  @return the oubliette 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Oubliette getOubliette()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create hold enablers. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> HoldEnabler </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> HoldEnabler </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateHoldEnabler();


    /**
     *  Tests if this user can create a single <code> HoldEnabler </code> 
     *  using the desired record types. While <code> 
     *  HoldRulesManager.getHoldEnablerRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> HoldEnabler. </code> 
     *  Providing an empty array tests if a <code> HoldEnabler </code> can be 
     *  created with no records. 
     *
     *  @param  holdEnablerRecordTypes array of hold enabler record types 
     *  @return <code> true </code> if <code> HoldEnabler </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> holdEnablerRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateHoldEnablerWithRecordTypes(org.osid.type.Type[] holdEnablerRecordTypes);


    /**
     *  Gets the hold enabler form for creating new hold enablers. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  holdEnablerRecordTypes array of hold enabler record types 
     *  @return the hold enabler form 
     *  @throws org.osid.NullArgumentException <code> holdEnablerRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.rules.HoldEnablerForm getHoldEnablerFormForCreate(org.osid.type.Type[] holdEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> HoldEnabler. </code> 
     *
     *  @param  holdEnablerForm the form for this <code> HoldEnabler </code> 
     *  @return the new <code> HoldEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> holdEnablerForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> holdEnablerForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> holdEnablerForm </code> 
     *          did not originate from <code> getHoldEnablerFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.rules.HoldEnabler createHoldEnabler(org.osid.hold.rules.HoldEnablerForm holdEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update hold enablers. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> HoldEnabler </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> HoldEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateHoldEnablers();


    /**
     *  Gets the hold enabler form for updating an existing hold enabler. A 
     *  new hold enabler form should be requested for each update transaction. 
     *
     *  @param  holdEnablerId the <code> Id </code> of the <code> HoldEnabler 
     *          </code> 
     *  @return the hold enabler form 
     *  @throws org.osid.NotFoundException <code> holdEnablerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> holdEnablerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.rules.HoldEnablerForm getHoldEnablerFormForUpdate(org.osid.id.Id holdEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing hold enabler. 
     *
     *  @param  holdEnablerForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> holdEnablerForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> holdEnablerForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> holdEnablerForm </code> 
     *          did not originate from <code> getHoldEnablerFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateHoldEnabler(org.osid.hold.rules.HoldEnablerForm holdEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete hold enablers. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> HoldEnabler </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> HoldEnabler </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteHoldEnablers();


    /**
     *  Deletes a <code> HoldEnabler. </code> 
     *
     *  @param  holdEnablerId the <code> Id </code> of the <code> HoldEnabler 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> holdEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> holdEnablerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteHoldEnabler(org.osid.id.Id holdEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for hold 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> HoldEnabler </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageHoldEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> HoldEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> HoldEnabler </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another hold enabler. it is 
     *  reassigned to the given hold enabler <code> Id. </code> 
     *
     *  @param  holdEnablerId the <code> Id </code> of a <code> HoldEnabler 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> holdEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> holdEnablerId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasHoldEnabler(org.osid.id.Id holdEnablerId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
