//
// org.osid.hold.rules.HoldEnablerSmartOublietteSession
//
//     The OSID Java specification for org.osid.hold.rules.HoldEnablerSmartOublietteSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.hold.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  oubliettes. A <code> HoldEnablerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Oubliette </code> to create a virtual 
 *  collection of hold enablers. The hold enablers may be sequenced using the 
 *  <code> HoldEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Oubliette </code> has a default query that matches any 
 *  hold enabler and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> HoldEnablerQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  HoldEnablerQuery. </code> </p>
 */

public interface HoldEnablerSmartOublietteSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Oubliette </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Oubliette Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOublietteId();


    /**
     *  Gets the <code> Oubliette </code> associated with this session. 
     *
     *  @return the oubliette 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.Oubliette getOubliette()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart oubliettes. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart oubliette management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartOubliettes();


    /**
     *  Gets a hold enabler query. 
     *
     *  @return the hold enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.rules.HoldEnablerQuery getHoldEnablerQuery();


    /**
     *  Gets a hold enabler search order. 
     *
     *  @return the hold enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.rules.HoldEnablerSearchOrder getHoldEnablerSearchOrder();


    /**
     *  Applies a hold enabler query to this oubliette. 
     *
     *  @param  holdEnablerQuery the hold enabler query 
     *  @throws org.osid.NullArgumentException <code> holdEnablerQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> holdEnablerQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyHoldEnablerQuery(org.osid.hold.rules.HoldEnablerQuery holdEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a hold enabler query inspector for this oubliette. 
     *
     *  @return the hold enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.rules.HoldEnablerQueryInspector inspectHoldEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a hold enabler search order to this oubliette. 
     *
     *  @param  holdEnablerSearchOrder the hold enabler search order 
     *  @throws org.osid.NullArgumentException <code> holdEnablerSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> holdEnablerSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyHoldEnablerSequencing(org.osid.hold.rules.HoldEnablerSearchOrder holdEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a hold enabler query from an inspector. 
     *
     *  @param  holdEnablerQueryInspector a hold enabler query inspector 
     *  @return the hold enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          holdEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> holdEnablerQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.rules.HoldEnablerQuery getHoldEnablerQueryFromInspector(org.osid.hold.rules.HoldEnablerQueryInspector holdEnablerQueryInspector);
}
