//
// org.osid.id.Id
//
//     The OSID Java specification for org.osid.id.Id.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.id;


/**
 *  <p><code> Id </code> represents an identifier object. Ids are designated 
 *  by the following elements: </p> 
 *  
 *  <ul>
 *      <li> <code> identifier: </code> a unique key or guid </li> 
 *      <li> <code> namespace: </code> the namespace of the identifier </li> 
 *      <li> <code> authority: </code> the issuer of the identifier </li> 
 *  </ul>
 *  
 *  
 *  <p> Two Ids are equal if their namespace, identifier and authority strings 
 *  are equal. Only the identifier is case-sensitive. Persisting an <code> Id 
 *  </code> means persisting the above components. </p>
 */

public interface Id
    extends org.osid.OsidPrimitive,
            org.osid.binding.java.Id {


    /**
     *  Gets the authority of this <code> Id. </code> The authority is a 
     *  string used to ensure the uniqueness of this <code> Id </code> when 
     *  using a non-federated identifier space. Generally, it is a service 
     *  name identifying the provider of this <code> Id. </code> This method 
     *  is used to compare one <code> Id </code> to another. 
     *
     *  @return the authority of this <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getAuthority();


    /**
     *  Gets the namespace of the identifier. The namespace reflects the 
     *  domain in which the identifier is unique. When using a global 
     *  identifier schema, the namespace may indicate the name of the scheme. 
     *  When using a local identification scheme, the namespace may be more 
     *  specific, such as the name of a database or file in which the 
     *  identifiers exist. Federating adapters may use a custom namespace to 
     *  include information for routing. This method is used to compare one 
     *  <code> Id </code> to another. 
     *
     *  @return the authority of this <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getIdentifierNamespace();


    /**
     *  Gets the identifier of this <code> Id. </code> This method is used to 
     *  compare one <code> Id </code> to another. 
     *
     *  @return the identifier of this <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getIdentifier();
}
