//
// org.osid.id.IdAdminSession
//
//     The OSID Java specification for org.osid.id.IdAdminSession.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. All Rights 
// Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.id;


/**
 *  <p>This session is used to manually create new <code> Ids. </code> </p>
 */

public interface IdAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Ids. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known create methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations. 
     *
     *  @return <code> false </code> if create methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateIds();


    /**
     *  Gets the <code> Id </code> form for creating new Ids. A new form 
     *  should be requested for each create transaction. 
     *
     *  @return the <code> Id </code> form 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdForm getIdFormForCreate()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Id. </code> A new <code> IdForm </code> should be 
     *  requested for each create transaction. 
     *
     *  @param  idForm the <code> Id </code> form 
     *  @return the created <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException an <code> Id </code> for the 
     *          authority, namespace, and identifier already exists 
     *  @throws org.osid.IllegalStateException <code> idForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> idForm </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> idForm </code> did not 
     *          originate from <code> getIdFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id createId(org.osid.id.IdForm idForm)
        throws org.osid.AlreadyExistsException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alias <code> Ids. </code> A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known add methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations. 
     *
     *  @return <code> false </code> if alias methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAliasIds();


    /**
     *  Makes two <code> Ids </code> equivalent. The primary and equivalent 
     *  <code> Ids </code> are already known to this service <code> . </code> 
     *  If the external <code> Id </code> is already mapped to another <code> 
     *  Id, </code> it is changed to map to the given primary <code> Id. 
     *  </code> Calls to <code> IdLookupSession.getId(equivalentId) </code> 
     *  return the <code> primaryId. </code> 
     *
     *  @param  primaryId the primary <code> Id </code> 
     *  @param  equivalentId an <code> Id </code> to be made equivalent 
     *  @throws org.osid.NotFoundException <code> primaryId </code> or <code> 
     *          equivalentId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> primaryId </code> or 
     *          <code> equivalentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasId(org.osid.id.Id primaryId, org.osid.id.Id equivalentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes equivalence from two <code> Ids. </code> 
     *
     *  @param  primaryId the primary <code> Id </code> 
     *  @param  equivalentId the equivalent <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> primaryId </code> or <code> 
     *          equivalentId </code> is not found or <code> equivalentId 
     *          </code> not mapped to <code> primaryId </code> 
     *  @throws org.osid.NullArgumentException <code> primaryId </code> or 
     *          <code> equivalentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAlias(org.osid.id.Id primaryId, 
                            org.osid.id.Id equivalentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
