//
// org.osid.id.batch.IdBatchAdminSession
//
//     The OSID Java specification for org.osid.id.batch.IdBatchAdminSession.
//
// Copyright (C) 2014 Ingenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.id.batch;


/**
 *  <p>This session creates <code> Ids </code> in bulk. The data for create is 
 *  provided by the consumer via the form object. <code> OsidForms </code> are 
 *  requested for each create or update and may not be reused. </p> 
 *  
 *  <p> Create operations differ in their usage. To create an <code> Id, 
 *  </code> an <code> IdForm </code> is requested using <code> 
 *  getIdFormsForCreate() </code> specifying the desired reference, resource, 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. Each of the returned <code> IdForms </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once an <code> IdForm </code> 
 *  is submiited to a create operation, it cannot be reused with another 
 *  create operation unless the first operation was unsuccessful. Each <code> 
 *  IdForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> IdForms </code> returned from <code> getIdFormsForCreate() 
 *  </code> may be linked to the originating request through the peer <code> 
 *  Ids </code> of the <code> IdForm. </code> </p> 
 *  
 *  <p> Once a batch of <code> IdForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> IdForm, </code> 
 *  although the ordering is not defined. Only errors that pertain to the 
 *  entire create operation are returned from <code> createIds(), </code> 
 *  errors specific to an individual <code> IdForm </code> are indicated in 
 *  the corresponding <code> CreateResponse. </code> <code> CreateResponses 
 *  </code> may be linked to the originating <code> IdForm </code> through the 
 *  <code> IdForm </code> <code> Id </code> . </p>
 */

public interface IdBatchAdminSession
    extends org.osid.id.IdAdminSession {


    /**
     *  Gets the <code> Id </code> forms for creating new Ids. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  number ther number of forms to request 
     *  @return the <code> Id </code> forms 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.batch.IdBatchFormList getIdFormsForCreate(long number)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Ids. </code> This method returns an error 
     *  if the entire operation fails. Otherwise, the status of an individual 
     *  create operation is indicated in the <code> BatchCreateResponse 
     *  </code> . 
     *
     *  @param  idForms the <code> Id </code> forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> idForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createIds(org.osid.id.batch.IdBatchFormList idForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Makes a set of <code> Ids </code> known to this service equivalent 
     *  such that for each primary and equivalent <code> Id </code> in the 
     *  given array, calls to <code> IdLookupSession.getId(equivalentId) 
     *  </code> return the <code> primaryId. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasIds(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
