//
// org.osid.id.batch.IdBatchProxyManager
//
//     The OSID Java specification for org.osid.id.batch.IdBatchProxyManager.
//
// Copyright (C) 2014 Ingenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.id.batch;


/**
 *  <p>The Id batch manager provides access to Id batch sessions and provides 
 *  interoperability tests for various aspects of this service. Methods in 
 *  this manager support the passing of a Proxy object for the purpose of 
 *  pasisng information from a server envrionment. The sessions included in 
 *  this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> IdBatchIssueSession: </code> a session to issue Ids in 
 *      bulk </li> 
 *      <li> <code> IsBatchAdminSession: </code> a session to create, modify 
 *      and delete Ids in bulk </li> 
 *  </ul>
 *  
 */

public interface IdBatchProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.id.batch.IdBatchProfile {


    /**
     *  Gets the session associated with the Id bulk issue service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> IdBatchIssueSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsIdBatchIssue() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdIssue() </code> is <code> true. </code> 
     */

    public org.osid.id.batch.IdBatchIssueSession getIdBatchIssueSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the Id bulk administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> IdBatchAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsIdBatchAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIdBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.id.batch.IdBatchAdminSession getIdBatchAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;
}
