//
// org.osid.inquiry.AuditLookupSession
//
//     The OSID Java specification for org.osid.inquiry.AuditLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session provides methods for retrieving <code> Audits. </code> The 
 *  <code> Audit </code> represents a set of inputs <code> . </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated inquest view: All audit methods in this session operate, 
 *      retrieve and pertain to audits defined explicitly in the current 
 *      inquest. Using an isolated view is useful for managing <code> Audits 
 *      </code> with the <code> AuditAdminSession. </code> </li> 
 *      <li> federated inquest view: All audit methods in this session 
 *      operate, retrieve and pertain to all audits defined in this inquest 
 *      and any other audits implicitly available in this inquest through 
 *      inquest inheritence. </li> 
 *      <li> active audit view: active audits are returned from methods in 
 *      this session </li> 
 *      <li> any status audit view: active and inactive audits are returned 
 *      from methods in this session </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedInquestView() </code> and <code> 
 *  useIsolatedInquestView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface AuditLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Audit </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAudits();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAuditView();


    /**
     *  A complete view of the <code> AuditConstrainer </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAuditView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include audit constrainers in inquests which are children of this 
     *  inquest in the inquest hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedInquestView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this inquest only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedInquestView();


    /**
     *  Only active audits are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveAuditView();


    /**
     *  Borth active and inactive audits are returned from methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusAuditView();


    /**
     *  Gets the <code> Audit </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Audit </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to 
     *  an <code> Audit </code> and retained for compatibility. 
     *  
     *  In active mode, audits are returned that are currently active. In any 
     *  status mode, active and inactive audits are returned. 
     *
     *  @param  auditId <code> Id </code> of the <code> Audit </code> 
     *  @return the audit 
     *  @throws org.osid.NotFoundException <code> auditId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.inquiry.Audit getAudit(org.osid.id.Id auditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuditList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  audits specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Audits </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, audits are returned that are currently active. In any 
     *  status mode, active and inactive audits are returned. 
     *
     *  @param  auditIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Audit </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> auditIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditList getAuditsByIds(org.osid.id.IdList auditIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuditList </code> corresponding to the given audit 
     *  genus <code> Type </code> which does not include audits of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  audits or an error results. Otherwise, the returned list may contain 
     *  only those audits that are accessible through this session. 
     *  
     *  In active mode, audits are returned that are currently active. In any 
     *  status mode, active and inactive audits are returned. 
     *
     *  @param  auditGenusType an audit genus type 
     *  @return the returned <code> Audit </code> list 
     *  @throws org.osid.NullArgumentException <code> auditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditList getAuditsByGenusType(org.osid.type.Type auditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuditList </code> corresponding to the given audit 
     *  genus <code> Type </code> and include any additional audits with genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  audits or an error results. Otherwise, the returned list may contain 
     *  only those audits that are accessible through this session. 
     *  
     *  In active mode, audits are returned that are currently active. In any 
     *  status mode, active and inactive audits are returned. 
     *
     *  @param  auditGenusType an audit genus type 
     *  @return the returned <code> Audit </code> list 
     *  @throws org.osid.NullArgumentException <code> auditGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditList getAuditsByParentGenusType(org.osid.type.Type auditGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuditList </code> containing the given audit record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  audits or an error results. Otherwise, the returned list may contain 
     *  only those audits that are accessible through this session. 
     *  
     *  In active mode, audits are returned that are currently active. In any 
     *  status mode, active and inactive audits are returned. 
     *
     *  @param  auditRecordType an audit record type 
     *  @return the returned <code> Audit </code> list 
     *  @throws org.osid.NullArgumentException <code> auditRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditList getAuditsByRecordType(org.osid.type.Type auditRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AuditList </code> by provider. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  audits or an error results. Otherwise, the returned list may contain 
     *  only those audits that are accessible through this session. 
     *  
     *  In active mode, audits are returned that are currently active. In any 
     *  status mode, active and inactive audits are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Audit </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditList getAuditsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Audits. </code> 
     *  
     *  In plenary mode, the returned list contains all known audits or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  audits that are accessible through this session. 
     *  
     *  In active mode, audits are returned that are currently active. In any 
     *  status mode, active and inactive audits are returned. 
     *
     *  @return a list of <code> Audits </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditList getAudits()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
