//
// org.osid.inquiry.AuditQuerySession
//
//     The OSID Java specification for org.osid.inquiry.AuditQuerySession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session provides methods for searching among <code> Audit </code> 
 *  objects. The search query is constructed using the <code> AuditQuery. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated action group view: searches include audits in action 
 *      groups of which this action group is an ancestor in the action group 
 *      hierarchy </li> 
 *      <li> isolated action group view: searches are restricted to audits in 
 *      this action group </li> 
 *  </ul>
 *  
 *  
 *  <p> Audits may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> AuditQuery. </code> 
 *  </p>
 */

public interface AuditQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Audit </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchAudits();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include audits in inquests which are children of this action group in 
     *  the inquest hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedInquestView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this inquest only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedInquestView();


    /**
     *  Gets an audit query. 
     *
     *  @return the audit query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditQuery getAuditQuery();


    /**
     *  Gets a list of <code> Audits </code> matching the given audit query. 
     *
     *  @param  auditQuery the audit query 
     *  @return the returned <code> AuditList </code> 
     *  @throws org.osid.NullArgumentException <code> auditQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auditQuery </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditList getAuditsByQuery(org.osid.inquiry.AuditQuery auditQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
