//
// org.osid.inquiry.AuditSearchSession
//
//     The OSID Java specification for org.osid.inquiry.AuditSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session provides methods for searching among <code> Audit </code> 
 *  objects. The search query is constructed using the <code> AudityQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getAuditsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Audits. </code> A more advanced search may be 
 *  performed with <code> getAuditsBySearch(). </code> It accepts an <code> 
 *  AuditSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getAuditsBySearch() </code> returns an <code> AuditSearchResults </code> 
 *  that can be used to access the resulting <code> AuditList </code> or be 
 *  used to perform a search within the result set through <code> AuditSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated action group view: searches include audits in action 
 *      groups of which this action group is an ancestor in the action group 
 *      hierarchy </li> 
 *      <li> isolated action group view: searches are restricted to audits in 
 *      this action group </li> 
 *  </ul>
 *  
 *  
 *  <p> Audits may have an audit record indicated by their respective record 
 *  types. The audit record is accessed via the <code> AuditQuery. </code> 
 *  </p>
 */

public interface AuditSearchSession
    extends org.osid.inquiry.AuditQuerySession {


    /**
     *  Gets an audit search. 
     *
     *  @return the audit search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditSearch getAuditSearch();


    /**
     *  Gets an audit search order. The <code> AuditSearchOrder </code> is 
     *  supplied to an <code> AuditSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the audit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditSearchOrder getAuditSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  auditQuery the audit query 
     *  @param  auditSearch the audit search 
     *  @return the audit search results 
     *  @throws org.osid.NullArgumentException <code> auditQuery </code> or 
     *          <code> auditSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> auditQuery </code> or 
     *          <code> auditSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditSearchResults getAuditsBySearch(org.osid.inquiry.AuditQuery auditQuery, 
                                                                 org.osid.inquiry.AuditSearch auditSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an audit query from an inspector. The inspector is available from 
     *  an <code> AuditSearchResults. </code> 
     *
     *  @param  auditQueryInspector an audit query inspector 
     *  @return the audit query 
     *  @throws org.osid.NullArgumentException <code> auditQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> auditQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditQuery getAuditQueryFromInspector(org.osid.inquiry.AuditQueryInspector auditQueryInspector);
}
