//
// org.osid.inquiry.InquestHierarchySession
//
//     The OSID Java specification for org.osid.inquiry.InquestHierarchySession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> 
 *  Inquest </code> objects. Each node in the hierarchy is a unique <code> 
 *  Inquest. </code> The hierarchy may be traversed recursively to establish 
 *  the tree structure through <code> getParentInquests() </code> and <code> 
 *  getChildInquests(). </code> To relate these <code> Ids </code> to another 
 *  OSID, <code> getInquestNodes() </code> can be used for retrievals that can 
 *  be used for bulk lookups in other OSIDs. Any <code> Inquest </code> 
 *  available in the Control OSID is known to this hierarchy but does not 
 *  appear in the hierarchy traversal until added as a root inquest or a child 
 *  of another inquest. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentInquests() </code> or <code> getChildInquests() </code> 
 *  in lieu of a <code> PERMISSION_DENIED </code> error that may disrupt the 
 *  traversal through authorized inquiryways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative inquest view: inquest elements may be silently 
 *      omitted or re-ordered </li> 
 *      <li> plenary inquest view: provides a complete set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface InquestHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getInquestHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessInquestHierarchy();


    /**
     *  The returns from the inquest methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInquestView();


    /**
     *  A complete view of the <code> Inquests </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInquestView();


    /**
     *  Gets the root inquest <code> Ids </code> in this hierarchy. 
     *
     *  @return the root inquest <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootInquestIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root inquest in the inquest hierarchy. an inquest with no 
     *  parents is an orphan. While all inquest <code> Ids </code> are known 
     *  to the hierarchy, an orphan does not appear in the hierarchy unless 
     *  explicitly added as a root inquest or child of another inquest. 
     *
     *  @return the root inquests 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.inquiry.InquestList getRootInquests()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> Inquest </code> has any parents. 
     *
     *  @param  inquestId an inquest <code> Id </code> 
     *  @return <code> true </code> if the inquest has parents, f <code> alse 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> inquestId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentInquests(org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of inquest. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  inquestId the <code> Id </code> of an inquest 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> inquestId, </code> f <code> alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> inquestId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          inquestId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfInquest(org.osid.id.Id id, 
                                     org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given inquest. 
     *
     *  @param  inquestId an inquest <code> Id </code> 
     *  @return the parent <code> Ids </code> of the inquest 
     *  @throws org.osid.NotFoundException <code> inquestId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentInquestIds(org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> to query 
     *  @return the parents of the inquest 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquestList getParentInquests(org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of an inquest. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  inquestId the <code> Id </code> of an inquest 
     *  @return <code> tru </code> e if this <code> id </code> is an ancestor 
     *          of <code> inquestId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfInquest(org.osid.id.Id id, 
                                       org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an inquest has any children. 
     *
     *  @param  inquestId an inquest <code> Id </code> 
     *  @return <code> true </code> if the <code> inquestId </code> has 
     *          children, <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildInquests(org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an inquest is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  inquestId the <code> Id </code> of an inquest 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> inquestId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          inquestId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfInquest(org.osid.id.Id id, 
                                    org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> to query 
     *  @return the children of the inquest 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildInquestIds(org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> to query 
     *  @return the children of the inquest 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquestList getChildInquests(org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of an inquest. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  inquestId the <code> Id </code> of an inquest 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> inquestId, </code> <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          inquestId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfInquest(org.osid.id.Id id, 
                                         org.osid.id.Id inquestId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the inquest. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the inquest. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given inquest, <code> false </code> to omit the siblings 
     *  @return an inquest node 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getInquestNodeIds(org.osid.id.Id inquestId, 
                                                     long ancestorLevels, 
                                                     long descendantLevels, 
                                                     boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the hierarchy. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the hierarchy. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given inquest, <code> false </code> to omit the siblings 
     *  @return an inquest node 
     *  @throws org.osid.NotFoundException <code> inquestId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquestNode getInquestNodes(org.osid.id.Id inquestId, 
                                                        long ancestorLevels, 
                                                        long descendantLevels, 
                                                        boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
