//
// org.osid.inquiry.InquestQuery
//
//     The OSID Java specification for org.osid.inquiry.InquestQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This is the query for searching inquests. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface InquestQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the inquiry <code> Id </code> for this query to match inquests 
     *  that have a related response. 
     *
     *  @param  inquiryId an inquiry <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> inquiryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInquiryId(org.osid.id.Id inquiryId, boolean match);


    /**
     *  Clears the inquiry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInquiryIdTerms();


    /**
     *  Tests if an <code> InquiryQuery </code> is available. 
     *
     *  @return <code> true </code> if an inquiry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryQuery();


    /**
     *  Gets the query for an inquiry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the inquiry query 
     *  @throws org.osid.UnimplementedException <code> supportsInquiryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquiryQuery getInquiryQuery();


    /**
     *  Matches inquests that have any inquiry. 
     *
     *  @param  match <code> true </code> to match inquests with any inquiry, 
     *          <code> false </code> to match inquests with no inquiry 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInquiry(boolean match);


    /**
     *  Clears the inquiry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInquiryTerms();


    /**
     *  Sets the audit <code> Id </code> for this query. 
     *
     *  @param  auditId the audit <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAuditId(org.osid.id.Id auditId, boolean match);


    /**
     *  Clears the audit <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuditIdTerms();


    /**
     *  Tests if an <code> AuditQuery </code> is available. 
     *
     *  @return <code> true </code> if an audit query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditQuery();


    /**
     *  Gets the query for an audit. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the audit query 
     *  @throws org.osid.UnimplementedException <code> supportsAuditQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AuditQuery getAuditQuery();


    /**
     *  Matches inquests with any audit. 
     *
     *  @param  match <code> true </code> to match inquests with any audit, 
     *          <code> false </code> to match inquests with no audit 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAudit(boolean match);


    /**
     *  Clears the audit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuditTerms();


    /**
     *  Sets the response <code> Id </code> for this query. 
     *
     *  @param  responseId the response <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> responseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResponseId(org.osid.id.Id responseId, boolean match);


    /**
     *  Clears the response <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResponseIdTerms();


    /**
     *  Tests if a <code> ResponseQuery </code> is available. 
     *
     *  @return <code> true </code> if a response query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseQuery();


    /**
     *  Gets the query for a response. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the response query 
     *  @throws org.osid.UnimplementedException <code> supportsResponseQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResponseQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.ResponseQuery getResponseQuery();


    /**
     *  Matches inquests with any response. 
     *
     *  @param  match <code> true </code> to match inquests with any response, 
     *          <code> false </code> to match inquests with no response 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResponse(boolean match);


    /**
     *  Clears the response query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResponseTerms();


    /**
     *  Sets the inquest <code> Id </code> for this query to match inquests 
     *  that have the specified inquest as an ancestor. 
     *
     *  @param  inquestId an inquest <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorInquestId(org.osid.id.Id inquestId, boolean match);


    /**
     *  Clears the ancestor inquest <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorInquestIdTerms();


    /**
     *  Tests if an <code> InquestQuery </code> is available. 
     *
     *  @return <code> true </code> if an inquest query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorInquestQuery();


    /**
     *  Gets the query for an inquest. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the inquest query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorInquestQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorInquestQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquestQuery getAncestorInquestQuery();


    /**
     *  Matches inquests with any ancestor. 
     *
     *  @param  match <code> true </code> to match inquests with any ancestor, 
     *          <code> false </code> to match root inquests 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorInquest(boolean match);


    /**
     *  Clears the ancestor inquest query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorInquestTerms();


    /**
     *  Sets the inquest <code> Id </code> for this query to match inquests 
     *  that have the specified inquest as a descendant. 
     *
     *  @param  inquestId an inquest <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantInquestId(org.osid.id.Id inquestId, 
                                         boolean match);


    /**
     *  Clears the descendant inquest <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantInquestIdTerms();


    /**
     *  Tests if an <code> InquestQuery </code> is available. 
     *
     *  @return <code> true </code> if an inquest query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantInquestQuery();


    /**
     *  Gets the query for an inquest/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the inquest query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantInquestQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantInquestQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.InquestQuery getDescendantInquestQuery();


    /**
     *  Matches inquests with any descendant. 
     *
     *  @param  match <code> true </code> to match inquests with any 
     *          descendant, <code> false </code> to match leaf inquests 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantInquest(boolean match);


    /**
     *  Clears the descendant inquest query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantInquestTerms();


    /**
     *  Gets the inquest query record corresponding to the given <code> 
     *  Inquest </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  inquestRecordType an inquest record type 
     *  @return the inquest query record 
     *  @throws org.osid.NullArgumentException <code> inquestRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(inquestRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.records.InquestQueryRecord getInquestQueryRecord(org.osid.type.Type inquestRecordType)
        throws org.osid.OperationFailedException;
}
