//
// org.osid.inquiry.InquestSearchSession
//
//     The OSID Java specification for org.osid.inquiry.InquestSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session provides methods for searching among <code> Inquest 
 *  </code> objects. The search query is constructed using the <code> 
 *  InquestQuery. </code> </p> 
 *  
 *  <p> <code> getInquestsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Inquests. </code> A more advanced search may be 
 *  performed with <code> getInquestsBySearch(). </code> It accepts an <code> 
 *  InquestSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getInquestsBySearch() </code> returns an <code> 
 *  InquestSearchResults </code> that can be used to access the resulting 
 *  <code> InquestList </code> or be used to perform a search within the 
 *  result set through <code> InquestSearch. </code> </p> 
 *  
 *  <p> Inquests may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> InquestQuery. </code> 
 *  </p>
 */

public interface InquestSearchSession
    extends org.osid.inquiry.InquestQuerySession {


    /**
     *  Gets an inquest search. 
     *
     *  @return the inquest search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquestSearch getInquestSearch();


    /**
     *  Gets an inquest search order. The <code> InquestSearchOrder </code> is 
     *  supplied to an <code> InquestSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the inquest search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquestSearchOrder getInquestSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  inquestQuery the inquest query 
     *  @param  inquestSearch the inquest search 
     *  @return the inquest search results 
     *  @throws org.osid.NullArgumentException <code> inquestQuery </code> or 
     *          <code> inquestSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inquestQuery </code> or 
     *          <code> inquestSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquestSearchResults getInquestsBySearch(org.osid.inquiry.InquestQuery inquestQuery, 
                                                                     org.osid.inquiry.InquestSearch inquestSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an inquest query from an inspector. The inspector is available 
     *  from an <code> InquestSearchResults. </code> 
     *
     *  @param  inquestQueryInspector an inquest query inspector 
     *  @return the inquest query 
     *  @throws org.osid.NullArgumentException <code> inquestQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> inquestQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquestQuery getInquestQueryFromInspector(org.osid.inquiry.InquestQueryInspector inquestQueryInspector);
}
