//
// org.osid.inquiry.InquiryProfile
//
//     The OSID Java specification for org.osid.inquiry.InquiryProfile.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>The inquiry profile describes the interoperability among inquiry 
 *  services. </p>
 */

public interface InquiryProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any action group federation is exposed. Federation is exposed 
     *  when a specific action group may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of action groups appears as a single action group. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if an acknowledgement service is supported for the current 
     *  agent. 
     *
     *  @return <code> true </code> if acknowledgement is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcknowledgement();


    /**
     *  Tests if an acknowledgement notification service is supported for the 
     *  current agent. 
     *
     *  @return <code> true </code> if an acknowledgement notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcknowledgementNotification();


    /**
     *  Tests if looking up inquiries is supported. 
     *
     *  @return <code> true </code> if inquiry lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryLookup();


    /**
     *  Tests if querying inquiries is supported. 
     *
     *  @return <code> true </code> if inquiry query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryQuery();


    /**
     *  Tests if searching inquiries is supported. 
     *
     *  @return <code> true </code> if inquiry search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquirySearch();


    /**
     *  Tests if an inquiry administrative service is supported. 
     *
     *  @return <code> true </code> if inquiry administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryAdmin();


    /**
     *  Tests if an inquiry <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if inquiry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryNotification();


    /**
     *  Tests if an inquiry inquest lookup service is supported. 
     *
     *  @return <code> true </code> if an inquiry inquest lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryInquest();


    /**
     *  Tests if an inquiry inquest assignment service is supported. 
     *
     *  @return <code> true </code> if an inquiry to inquest assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryInquestAssignment();


    /**
     *  Tests if an inquiry smart inquest service is supported. 
     *
     *  @return <code> true </code> if a smart inquest service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquirySmartInquest();


    /**
     *  Tests if looking up audits is supported. 
     *
     *  @return <code> true </code> if audit lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditLookup();


    /**
     *  Tests if querying audits is supported. 
     *
     *  @return <code> true </code> if audit query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditQuery();


    /**
     *  Tests if searching audits is supported. 
     *
     *  @return <code> true </code> if audit search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditSearch();


    /**
     *  Tests if audit administrative service is supported. 
     *
     *  @return <code> true </code> if audit administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditAdmin();


    /**
     *  Tests if an audit notification service is supported. 
     *
     *  @return <code> true </code> if audit notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditNotification();


    /**
     *  Tests if an audit inquest lookup service is supported. 
     *
     *  @return <code> true </code> if an audit inquest lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditInquest();


    /**
     *  Tests if an audit inquest service is supported. 
     *
     *  @return <code> true </code> if audit to inquest assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditInquestAssignment();


    /**
     *  Tests if an audit smart inquest lookup service is supported. 
     *
     *  @return <code> true </code> if an audit smart inquest service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditSmartInquest();


    /**
     *  Tests if looking up responses is supported. 
     *
     *  @return <code> true </code> if response lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseLookup();


    /**
     *  Tests if querying responses is supported. 
     *
     *  @return <code> true </code> if response query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseQuery();


    /**
     *  Tests if searching responses is supported. 
     *
     *  @return <code> true </code> if response search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseSearch();


    /**
     *  Tests if response <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if response administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseAdmin();


    /**
     *  Tests if a response <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if response notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseNotification();


    /**
     *  Tests if a response inquest lookup service is supported. 
     *
     *  @return <code> true </code> if a response inquest lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseInquest();


    /**
     *  Tests if a response inquest assignment service is supported. 
     *
     *  @return <code> true </code> if a response to inquest assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseInquestAssignment();


    /**
     *  Tests if a response smart inquest service is supported. 
     *
     *  @return <code> true </code> if a response smart inquest service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseSmartInquest();


    /**
     *  Tests if looking up inquests is supported. 
     *
     *  @return <code> true </code> if inquest lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestLookup();


    /**
     *  Tests if querying inquests is supported. 
     *
     *  @return <code> true </code> if an inquest query service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestQuery();


    /**
     *  Tests if searching inquests is supported. 
     *
     *  @return <code> true </code> if inquest search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestSearch();


    /**
     *  Tests if inquest administrative service is supported. 
     *
     *  @return <code> true </code> if inquest administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestAdmin();


    /**
     *  Tests if an inquest <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if inquest notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestNotification();


    /**
     *  Tests for the availability of an inquest hierarchy traversal service. 
     *
     *  @return <code> true </code> if inquest hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsInquestHierarchy();


    /**
     *  Tests for the availability of an inquest hierarchy design service. 
     *
     *  @return <code> true </code> if inquest hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestHierarchyDesign();


    /**
     *  Tests for the availability of a inquiry batch service. 
     *
     *  @return <code> true </code> if inquiry batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryBatch();


    /**
     *  Tests for the availability of a inquiry rules service. 
     *
     *  @return <code> true </code> if inquiry rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryRules();


    /**
     *  Gets the supported <code> Inquiry </code> record types. 
     *
     *  @return a list containing the supported <code> Inquiry </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInquiryRecordTypes();


    /**
     *  Tests if the given <code> Inquiry </code> record type is supported. 
     *
     *  @param  inquiryRecordType a <code> Type </code> indicating a <code> 
     *          Inquiry </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inquiryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryRecordType(org.osid.type.Type inquiryRecordType);


    /**
     *  Gets the supported <code> Inquiry </code> search types. 
     *
     *  @return a list containing the supported <code> Inquiry </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInquirySearchRecordTypes();


    /**
     *  Tests if the given <code> Inquiry </code> search type is supported. 
     *
     *  @param  inquirySearchRecordType a <code> Type </code> indicating a 
     *          <code> Inquiry </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inquirySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquirySearchRecordType(org.osid.type.Type inquirySearchRecordType);


    /**
     *  Gets the supported <code> Audit </code> record types. 
     *
     *  @return a list containing the supported <code> Audit </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuditRecordTypes();


    /**
     *  Tests if the given <code> Audit </code> record type is supported. 
     *
     *  @param  auditRecordType a <code> Type </code> indicating a <code> 
     *          Audit </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auditRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditRecordType(org.osid.type.Type auditRecordType);


    /**
     *  Gets the supported <code> Audit </code> search record types. 
     *
     *  @return a list containing the supported <code> Audit </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAuditSearchRecordTypes();


    /**
     *  Tests if the given <code> Audit </code> search record type is 
     *  supported. 
     *
     *  @param  auditSearchRecordType a <code> Type </code> indicating a 
     *          <code> Audit </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> auditSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditSearchRecordType(org.osid.type.Type auditSearchRecordType);


    /**
     *  Gets the supported <code> Response </code> record types. 
     *
     *  @return a list containing the supported <code> Response </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResponseRecordTypes();


    /**
     *  Tests if the given <code> Response </code> record type is supported. 
     *
     *  @param  responseRecordType a <code> Type </code> indicating a <code> 
     *          Response </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> responseRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseRecordType(org.osid.type.Type responseRecordType);


    /**
     *  Gets the supported <code> Response </code> search types. 
     *
     *  @return a list containing the supported <code> Response </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResponseSearchRecordTypes();


    /**
     *  Tests if the given <code> Response </code> search type is supported. 
     *
     *  @param  responseSearchRecordType a <code> Type </code> indicating a 
     *          <code> Response </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> responseSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseSearchRecordType(org.osid.type.Type responseSearchRecordType);


    /**
     *  Gets the supported <code> Inquest </code> record types. 
     *
     *  @return a list containing the supported <code> Inquest </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInquestRecordTypes();


    /**
     *  Tests if the given <code> Inquest </code> record type is supported. 
     *
     *  @param  inquestRecordType a <code> Type </code> indicating a <code> 
     *          Inquest </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inquestRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestRecordType(org.osid.type.Type inquestRecordType);


    /**
     *  Gets the supported <code> Inquest </code> search record types. 
     *
     *  @return a list containing the supported <code> Inquest </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInquestSearchRecordTypes();


    /**
     *  Tests if the given <code> Inquest </code> search record type is 
     *  supported. 
     *
     *  @param  inquestSearchRecordType a <code> Type </code> indicating a 
     *          <code> Inquest </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> inquestSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestSearchRecordType(org.osid.type.Type inquestSearchRecordType);
}
