//
// org.osid.inquiry.InquiryQuery
//
//     The OSID Java specification for org.osid.inquiry.InquiryQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This is the query for searching inquiries. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface InquiryQuery
    extends org.osid.OsidRuleQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the audit <code> Id </code> for this query. 
     *
     *  @param  auditId the audit <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAuditId(org.osid.id.Id auditId, boolean match);


    /**
     *  Clears the audit <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuditIdTerms();


    /**
     *  Tests if an <code> AuditQuery </code> is available. 
     *
     *  @return <code> true </code> if an audit query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuditQuery();


    /**
     *  Gets the query for an <code> Audit, </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the audit query 
     *  @throws org.osid.UnimplementedException <code> supportsAuditQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportAuditQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.AuditQuery getAuditQuery();


    /**
     *  Clears the audit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAuditTerms();


    /**
     *  Sets the question for this query. 
     *
     *  @param  question the question 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> question </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQuestion(String question, 
                              org.osid.type.Type stringMatchType, 
                              boolean match);


    /**
     *  Matches inquiries with any question. 
     *
     *  @param  match <code> true </code> to match inquiries with a question, 
     *          <code> false </code> to match inquiries with no question 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQuestion(boolean match);


    /**
     *  Clears the question query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQuestionTerms();


    /**
     *  Matches inquiries that are required. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequired(boolean match);


    /**
     *  Matches inquiries with any required flag set. 
     *
     *  @param  match <code> true </code> to match inquiries with a required 
     *          flag set, <code> false </code> to match inquiries with no 
     *          required flag set 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequired(boolean match);


    /**
     *  Clears the required query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiredTerms();


    /**
     *  Matches inquiries that require a positive response. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAffirmationRequired(boolean match);


    /**
     *  Matches inquiries with any affirmation required flag set. 
     *
     *  @param  match <code> true </code> to match inquiries with an 
     *          affirmation required flag set, <code> false </code> to match 
     *          inquiries with no affirmation required flag set 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAffirmationRequired(boolean match);


    /**
     *  Clears the affirmation required query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAffirmationRequiredTerms();


    /**
     *  Matches inquiries that require a single response. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNeedsOneResponse(boolean match);


    /**
     *  Matches inquiries with any needs one response set. 
     *
     *  @param  match <code> true </code> to match inquiries with a need one 
     *          response flag set, <code> false </code> to match inquiries 
     *          with no needs one response flag set 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNeedsOneResponse(boolean match);


    /**
     *  Clears the needs one response query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNeedsOneResponseTerms();


    /**
     *  Sets the inquest <code> Id </code> for this query to match inquiries 
     *  assigned to inquests. 
     *
     *  @param  inquestId the inquest <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInquestId(org.osid.id.Id inquestId, boolean match);


    /**
     *  Clears the inquest <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInquestIdTerms();


    /**
     *  Tests if an <code> InquestQuery </code> is available. 
     *
     *  @return <code> true </code> if an inquest query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquestQuery();


    /**
     *  Gets the query for an inquest. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the inquest query 
     *  @throws org.osid.UnimplementedException <code> supportsInquestQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquestQuery() </code> is <code> true. </code> 
     */

    public org.osid.inquiry.InquestQuery getInquestQuery();


    /**
     *  Clears the inquest query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInquestTerms();


    /**
     *  Gets the inquiry query record corresponding to the given <code> 
     *  Inquiry </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  inquiryRecordType an inquiry record type 
     *  @return the inquiry query record 
     *  @throws org.osid.NullArgumentException <code> inquiryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(inquiryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.records.InquiryQueryRecord getInquiryQueryRecord(org.osid.type.Type inquiryRecordType)
        throws org.osid.OperationFailedException;
}
