//
// org.osid.inquiry.InquirySearchSession
//
//     The OSID Java specification for org.osid.inquiry.InquirySearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session provides methods for searching among <code> Inquiry 
 *  </code> objects. The search query is constructed using the <code> 
 *  InquiryQuery. </code> </p> 
 *  
 *  <p> <code> getInquiriesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Inquiries. </code> A more advanced search may be 
 *  performed with <code> getInquiriesBySearch(). </code> It accepts an <code> 
 *  InquirySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getInquiriesBySearch() </code> returns an <code> 
 *  InquirySearchResults </code> that can be used to access the resulting 
 *  <code> InquiryList </code> or be used to perform a search within the 
 *  result set through <code> InquirySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated inquest view: searches include inquiries in inquests of 
 *      which this inquest is an ancestor in the inquest hierarchy </li> 
 *      <li> isolated inquest view: searches are restricted to inquiries in 
 *      this inquest </li> 
 *  </ul>
 *  
 *  
 *  <p> Inquiries may have a record indicated by their respective record 
 *  types. The query record is accessed via the <code> InquiryQuery. </code> 
 *  </p>
 */

public interface InquirySearchSession
    extends org.osid.inquiry.InquiryQuerySession {


    /**
     *  Gets an inquiry search. 
     *
     *  @return the inquiry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquirySearch getInquirySearch();


    /**
     *  Gets an inquiry search order. The <code> InquirySearchOrder </code> is 
     *  supplied to an <code> InquirySearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the inquiry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquirySearchOrder getInquirySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  inquiryQuery the inquiry query 
     *  @param  inquirySearch the inquiry search 
     *  @return the inquiry search results 
     *  @throws org.osid.NullArgumentException <code> inquiryQuery </code> or 
     *          <code> inquirySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inquiryQuery </code> or 
     *          <code> inquirySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquirySearchResults getInquiriesBySearch(org.osid.inquiry.InquiryQuery inquiryQuery, 
                                                                      org.osid.inquiry.InquirySearch inquirySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an inquiry query from an inspector. The inspector is available 
     *  from an <code> InquirySearchResults. </code> 
     *
     *  @param  inquiryQueryInspector an inquiry query inspector 
     *  @return the inquiry query 
     *  @throws org.osid.NullArgumentException <code> inquiryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> inquiryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.InquiryQuery getInquiryQueryFromInspector(org.osid.inquiry.InquiryQueryInspector inquiryQueryInspector);
}
