//
// org.osid.inquiry.ResponseLookupSession
//
//     The OSID Java specification for org.osid.inquiry.ResponseLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry;


/**
 *  <p>This session defines methods for retrieving responses. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated inquest view: All response methods in this session 
 *      operate, retrieve and pertain to responses defined explicitly in the 
 *      current inquest. Using an isolated view is useful for managing <code> 
 *      Responses </code> with the <code> ResponseAdminSession. </code> </li> 
 *      <li> federated inquest view: All response lookup methods in this 
 *      session operate, retrieve and pertain to all responses defined in this 
 *      inquest and any other responses implicitly available in this inquest 
 *      through inquest inheritence. </li> 
 *      <li> effective response view: All response lookup methods return 
 *      responses where the current date falls in between the effective dates 
 *      inclusive. </li> 
 *      <li> any effective response view: responses of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedInquestView() </code> and <code> 
 *  useIsolatedInquestView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Responses may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the 
 *  responses. </p>
 */

public interface ResponseLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Response </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupResponses();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeResponseView();


    /**
     *  A complete view of the <code> Response </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryResponseView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include responses in inquests which are children of this inquest in 
     *  the inquest hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedInquestView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this inquest only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedInquestView();


    /**
     *  Only responses whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveResponseView();


    /**
     *  All responses of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveResponseView();


    /**
     *  Gets the <code> Response </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Response </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Response </code> and retained for compatibility. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  responseId the <code> Id </code> of the <code> Response 
     *          </code> to retrieve 
     *  @return the returned <code> Response </code> 
     *  @throws org.osid.NotFoundException no <code> Response </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> responseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Response getResponse(org.osid.id.Id responseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ResponseList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  responses specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Responses </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  responseIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> responseIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesByIds(org.osid.id.IdList responseIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ResponseList </code> corresponding to the given response 
     *  genus <code> Type </code> which does not include responses of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  responseGenusType a response genus type 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.NullArgumentException <code> responseGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesByGenusType(org.osid.type.Type responseGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ResponseList </code> corresponding to the given response 
     *  genus <code> Type </code> and include any additional responses with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  responseGenusType a response genus type 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.NullArgumentException <code> responseGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesByParentGenusType(org.osid.type.Type responseGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ResponseList </code> containing the given response 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known responses or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  responseRecordType a response record type 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.NullArgumentException <code> responseRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesByRecordType(org.osid.type.Type responseRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of responses effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective responses and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesOnDate(org.osid.calendaring.DateTime from, 
                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of responses for an inquiry. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  inquiry an inquiry <code> Id </code> 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiry </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesForInquiry(org.osid.id.Id inquiry)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of responses for the given inquiry effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective responses and those currently expired are 
     *  returned. 
     *
     *  @param  inquiry an inquiry <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesForInquiryOnDate(org.osid.id.Id inquiry, 
                                                                      org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of responses for a resource. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesForResponder(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of responses for a resource and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective responses and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesForResponderOnDate(org.osid.id.Id resourceId, 
                                                                        org.osid.calendaring.DateTime from, 
                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of responses for an inquiry and responder. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @param  inquiryId an inquiry <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.NullArgumentException <code> inquiryId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesForInquiryAndResponder(org.osid.id.Id inquiryId, 
                                                                            org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of responses for an inquiry and responder and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  responses or an error results. Otherwise, the returned list may 
     *  contain only those responses that are accessible through this session. 
     *  
     *  In effective mode, responses are returned that are currently effective 
     *  in addition to being effective in the given date range. In any 
     *  effective mode, effective responses and those currently expired are 
     *  returned. 
     *
     *  @param  inquiryId an inquiry <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponsesForInquiryAndResponderOnDate(org.osid.id.Id inquiryId, 
                                                                                  org.osid.id.Id resourceId, 
                                                                                  org.osid.calendaring.DateTime from, 
                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all responses. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  responses including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Responses </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, responses are returned that are currently 
     *  effective. In any effective mode, effective responses and those 
     *  currently expired are returned. 
     *
     *  @return the returned <code> Response </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.ResponseList getResponses()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
