//
// org.osid.inquiry.batch.InquiryBatchAdminSession
//
//     The OSID Java specification for org.osid.inquiry.batch.InquiryBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Inquiries </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Inquiry, </code> an <code> InquiryForm </code> is requested using 
 *  <code> getInquiryFormsForCreate() </code> specifying the desired queues, 
 *  resources, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> InquiryForms </code> 
 *  will indicate that it is to be used with a create operation and can be 
 *  used to examine metdata or validate data prior to creation. Once an <code> 
 *  InquiryForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> InquiryForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> The <code> InquiryForms </code> returned from <code> 
 *  getInquiryFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> InquiryForm. 
 *  </code> In the case where there may be duplicates, any <code> InquiryForm 
 *  </code> of the same peer <code> Ids </code> may be used for a create 
 *  operation. </p> 
 *  
 *  <p> Once a batch of <code> InquiryForms </code> are submitted for create, 
 *  a <code> CreateResponse </code> is returned for each <code> InquiryForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createInquiry(), 
 *  </code> errors specific to an individual <code> InquiryForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> 
 *  InquiryForm </code> through the <code> InquiryForm </code> <code> Id 
 *  </code> . </p> 
 *  
 *  <p> For updates, <code> InquiryForms </code> are requested to the <code> 
 *  Inquiry </code> <code> Id </code> that is to be updated using <code> 
 *  getInquiryFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> InquiryForm </code> may be used to link the request. 
 *  Similarly, the <code> InquiryForm </code> has metadata about the data that 
 *  can be updated and it can perform validation before submitting the update. 
 *  The <code> InquiryForm </code> can only be used once for a successful 
 *  update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> InquiryForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> InquiryForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateInquiries(), 
 *  </code> errors specific to an individual <code> InquiryForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> 
 *  InquiryForm </code> through the <code> InquiryForm </code> <code> Id. 
 *  </code> </p> 
 *  
 *  <p> The delete operations delete <code> Inquiries </code> in bulk. To 
 *  unmap an <code> Inquiry </code> from the current <code> Inquest, </code> 
 *  the <code> InquiryInquestAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Inquiry </code> itself thus 
 *  removing it from all known <code> Inquest </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface InquiryBatchAdminSession
    extends org.osid.inquiry.InquiryAdminSession {


    /**
     *  Gets the inquiry forms for creating a bunch of new inquiries. An 
     *  inquiry form is returned for each audit. 
     *
     *  @param  auditIds a list of audit <code> Ids </code> 
     *  @param  inquiryRecordTypes array of inquiry record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the inquiry forms 
     *  @throws org.osid.NotFoundException an <code> auditId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> auditIds </code> or 
     *          <code> inquiryRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.batch.InquiryBatchFormList getInquiryFormsForCreate(org.osid.id.IdList auditIds, 
                                                                                org.osid.type.Type[] inquiryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Inquiries. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  inquiryForms the inquiry forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> inquiryForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createInquiries(org.osid.inquiry.batch.InquiryBatchFormList inquiryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the inquiry forms for updating an existing set of inquiries. A 
     *  new inquiry form should be requested for each update transaction. 
     *
     *  @param  inquiryIds the <code> Ids </code> of the <code> Inquiries 
     *          </code> 
     *  @return the inquiry forms 
     *  @throws org.osid.NotFoundException an <code> inquiryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquiryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.batch.InquiryBatchFormList getInquiryFormsForUpdate(org.osid.id.IdList inquiryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing inquiries. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  inquiryForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> inquiryForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateInquiries(org.osid.inquiry.batch.InquiryBatchFormList inquiryForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Inquiries </code> in this <code> Inquests. </code> 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllInquiries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes inquiries for the given <code> Ids. </code> 
     *
     *  @param  inquiryIds the <code> Ids </code> of the inquiries to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> inquiryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteInquiries(org.osid.id.IdList inquiryIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes inquiries for the given audit. 
     *
     *  @param  auditId the <code> Id </code> of an audit 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> auditId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteInquiriesForAudit(org.osid.id.Id auditId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to an <code> Inquiry </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Inquiry </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another inquiry, it is reassigned to the given inquiry 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasInquiries(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
