/**
 * <p>The Open Service Interface Definitions for the org.osid.inquiry
 * service.</p>
 * 
 * <p>The Inquiry OSID provides a means for managing a series of inquiries and 
 * acknowledgements. An example use of the Inquiry OSID is to capture an 
 * acknowledgement from a user before proceeding with some action. </p> 
 * <h4> Inquiries </h4> 
 * 
 * <p> An <code> Inquiry </code> is a question or statement posed to a user. A 
 * simple inquiry requires a yes/no response that can be recorded. An <code> 
 * Inquiry </code> may require the user perform some external action where the 
 * results of the action are recorded and evaluated in this service. <code> 
 * Inquiries </code> may be informational or may require <code> Responses. 
 * </code> </p> 
 * <h4> Audits </h4> 
 * 
 * <p> An <code> Audit </code> is a set of Inquiries that can be ordered. </p> 
 * <h4> Responses </h4> 
 * 
 * <p> A <code> Response </code> captures the user result of an Inquiry. 
 * Typically, a <code> Response </code> may simply represent a yes/no 
 * confirmation but may also be extended to capture other input data that can 
 * be evaluated. </p> 
 * <h4> Inquiry Workflow </h4> 
 * 
 * <p> The Inquiry OSID can be used as part of a workflow in which a complex 
 * series of actions and checks must be performed. The Rules Check OSID 
 * provides a means for checking <code> Audits </code> in which its <code> 
 * Inquiries </code> require positive acknowledgements in the form of <code> 
 * Responses </code> in order to proceed. </p> 
 * <h4> Inquest Cataloging </h4> 
 * 
 * <p> All <code> Inquiries, </code> <code> Responses </code> , and <code> 
 * Audits </code> may be organized into federateable <code> OsidCatalogs 
 * </code> called <code> Inquests. </code> </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Inquiry OSID includes an Inquiry Rules OSID for managing the 
 * applicability of <code> Inquiries </code> and an Inquiry Batch OSID for 
 * managing <code> Inquiries, </code> <code> Audits, </code> and <code> 
 * Responses </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2013 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
 * WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.inquiry;
