//
// org.osid.inquiry.rules.AuditEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.inquiry.rules.AuditEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session provides methods to apply <code> AuditEnablers </code> to 
 *  <code> Audits. </code> An <code> Audit </code> with multiple <code> 
 *  AuditEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Audit. </code> </p>
 */

public interface AuditEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter audit enabler/audit mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignAuditEnablers();


    /**
     *  Adds an existing <code> AuditEnabler </code> to an <code> Audit. 
     *  </code> 
     *
     *  @param  auditEnablerId the <code> Id </code> of the <code> 
     *          AuditEnabler </code> 
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> 
     *  @throws org.osid.AlreadyExistsException <code> auditEnablerId </code> 
     *          already applied to <code> auditId </code> 
     *  @throws org.osid.NotFoundException <code> auditEnablerId </code> or 
     *          <code> auditId </code> not found 
     *  @throws org.osid.NullArgumentException <code> auditEnablerId </code> 
     *          or <code> auditId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignAuditEnablerToAudit(org.osid.id.Id auditEnablerId, 
                                          org.osid.id.Id auditId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> AuditEnabler </code> from an <code> Audit. </code> 
     *
     *  @param  auditEnablerId the <code> Id </code> of the <code> 
     *          AuditEnabler </code> 
     *  @param  auditId the <code> Id </code> of the <code> Audit </code> 
     *  @throws org.osid.NotFoundException <code> auditEnablerId </code> or 
     *          <code> auditId </code> not found or <code> auditEnablerId 
     *          </code> not applied to <code> auditId </code> 
     *  @throws org.osid.NullArgumentException <code> auditEnablerId </code> 
     *          or <code> auditId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignAuditEnablerFromAudit(org.osid.id.Id auditEnablerId, 
                                              org.osid.id.Id auditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> AuditEnablers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> AuditEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceAuditEnablers();


    /**
     *  Reorders audit enablers for an audit by moving the specified audit 
     *  enabler in front of a reference audit enabler. 
     *
     *  @param  auditEnablerId the <code> Id </code> of an <code> AuditEnabler 
     *          </code> 
     *  @param  auditId the <code> Id </code> of an <code> Audit </code> 
     *  @param  referenceId the reference audit enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> auditEnablerId, auditId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          auditEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> auditId </code> 
     *  @throws org.osid.NullArgumentException <code> auditEnablerId, auditId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuditEnablerAhead(org.osid.id.Id auditEnablerId, 
                                      org.osid.id.Id auditId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders audit enablers for an inquiry by moving the specified audit 
     *  enabler behind a reference audit enabler. 
     *
     *  @param  auditEnablerId the <code> Id </code> of an <code> AuditEnabler 
     *          </code> 
     *  @param  auditId the <code> Id </code> of an <code> Audit </code> 
     *  @param  referenceId the reference audit enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> auditEnablerId, auditId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          auditEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> auditId </code> 
     *  @throws org.osid.NullArgumentException <code> auditEnablerId, auditId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAuditEnablerBehind(org.osid.id.Id auditEnablerId, 
                                       org.osid.id.Id auditId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of audit enablers for an audit. 
     *
     *  @param  auditEnablerIds the <code> Ids </code> for a set of <code> 
     *          AuditEnablers </code> 
     *  @param  auditId the <code> Id </code> of an <code> Audit </code> 
     *  @throws org.osid.NotFoundException <code> inquiryConstraienrId </code> 
     *          not found or, an <code> auditEnablerId </code> not related to 
     *          <code> auditId </code> 
     *  @throws org.osid.NullArgumentException <code> auditEnablerIds </code> 
     *          or <code> auditId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAuditEnablers(org.osid.id.Id[] auditEnablerIds, 
                                   org.osid.id.Id auditId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
