//
// org.osid.inquiry.rules.InquiryEnablerAdminSession
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryEnablerAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session creates and removes inquiry enablers. The data for create 
 *  and update is provided via the <code> InquiryEnablerForm. </code> </p>
 */

public interface InquiryEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create inquiry enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating an <code> InquiryEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> InquiryEnabler </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInquiryEnabler();


    /**
     *  Tests if this user can create a single <code> InquiryEnabler </code> 
     *  using the desired record types. While <code> 
     *  InquiryRulesManager.getInquiryEnablerRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> InquiryEnabler. 
     *  </code> Providing an empty array tests if an <code> InquiryEnabler 
     *  </code> can be created with no records. 
     *
     *  @param  inquiryEnablerRecordTypes array of inquiry enabler record 
     *          types 
     *  @return <code> true </code> if <code> InquiryEnabler </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          inquiryEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInquiryEnablerWithRecordTypes(org.osid.type.Type[] inquiryEnablerRecordTypes);


    /**
     *  Gets the inquiry enabler form for creating new inquiry enablers. A new 
     *  form should be requested for each create transinquiry. 
     *
     *  @param  inquiryEnablerRecordTypes array of inquiry enabler record 
     *          types 
     *  @return the inquiry enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          inquiryEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerForm getInquiryEnablerFormForCreate(org.osid.type.Type[] inquiryEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> InquiryEnabler. </code> 
     *
     *  @param  inquiryEnablerForm the form for this <code> InquiryEnabler 
     *          </code> 
     *  @return the new <code> InquiryEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> inquiryEnablerForm 
     *          </code> already used in a create transinquiry 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inquiryEnablerForm did 
     *          not originate from getInquiryEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnabler createInquiryEnabler(org.osid.inquiry.rules.InquiryEnablerForm inquiryEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update inquiry enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating an <code> InquiryEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> InquiryEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateInquiryEnablers();


    /**
     *  Gets the inquiry enabler form for updating an existing inquiry 
     *  enabler. A new inquiry enabler form should be requested for each 
     *  update transinquiry. 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of the <code> 
     *          InquiryEnabler </code> 
     *  @return the inquiry enabler form 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.InquiryEnablerForm getInquiryEnablerFormForUpdate(org.osid.id.Id inquiryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing inquiry enabler. 
     *
     *  @param  inquiryEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> inquiryEnablerForm 
     *          </code> already used in an update transinquiry 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> inquiryEnablerForm 
     *          </code> did not originate from <code> 
     *          getInquiryEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateInquiryEnabler(org.osid.inquiry.rules.InquiryEnablerForm inquiryEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete inquiry enablers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting an <code> InquiryEnabler </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> InquiryEnabler </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteInquiryEnablers();


    /**
     *  Deletes an <code> InquiryEnabler. </code> 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of the <code> 
     *          InquiryEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteInquiryEnabler(org.osid.id.Id inquiryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for inquiry 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> InquiryEnabler </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageInquiryEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> InquiryEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> InquiryEnabler </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another inquiry enabler. it is 
     *  reassigned to the given inquiry enabler <code> Id. </code> 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of an <code> 
     *          InquiryEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasInquiryEnabler(org.osid.id.Id inquiryEnablerId, 
                                    org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
