//
// org.osid.inquiry.rules.InquiryEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>This session provides methods to apply <code> InquiryEnablers </code> 
 *  to <code> Inquiries. </code> An <code> Inquiry </code> with multiple 
 *  <code> InquiryEnablers </code> means any positive rule evaluation across 
 *  the enablers result in an active <code> Inquiry. </code> </p>
 */

public interface InquiryEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Inquest </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Inquest Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInquestId();


    /**
     *  Gets the <code> Inquest </code> associated with this session. 
     *
     *  @return the inquest 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.Inquest getInquest()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter inquiry enabler/inquiry mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignInquiryEnablers();


    /**
     *  Adds an existing <code> InquiryEnabler </code> to an <code> Inquiry. 
     *  </code> 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of the <code> 
     *          InquiryEnabler </code> 
     *  @param  inquiryId the <code> Id </code> of the <code> Inquiry </code> 
     *  @throws org.osid.AlreadyExistsException <code> inquiryEnablerId 
     *          </code> already applied to <code> inquiryId </code> 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> or 
     *          <code> inquiryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          or <code> inquiryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignInquiryEnablerToInquiry(org.osid.id.Id inquiryEnablerId, 
                                              org.osid.id.Id inquiryId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> InquiryEnabler </code> from an <code> Inquiry. 
     *  </code> 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of the <code> 
     *          InquiryEnabler </code> 
     *  @param  inquiryId the <code> Id </code> of the <code> Inquiry </code> 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId </code> or 
     *          <code> inquiryId </code> not found or <code> inquiryEnablerId 
     *          </code> not applied to <code> inquiryId </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId </code> 
     *          or <code> inquiryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignInquiryEnablerFromInquiry(org.osid.id.Id inquiryEnablerId, 
                                                  org.osid.id.Id inquiryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> InquiryEnablers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> InquiryEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceInquiryEnablers();


    /**
     *  Reorders inquiry enablers for an inquiry by moving the specified 
     *  inquiry enabler in front of a reference inquiry enabler. 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of an <code> 
     *          InquiryEnabler </code> 
     *  @param  inquiryId the <code> Id </code> of an <code> Inquiry </code> 
     *  @param  referenceId the reference inquiry enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId, inquiryId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          inquiryEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> inquiryId </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId, 
     *          inquiryId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveInquiryEnablerAhead(org.osid.id.Id inquiryEnablerId, 
                                        org.osid.id.Id inquiryId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders inquiry enablers for an inquiry by moving the specified 
     *  inquiry enabler behind a reference inquiry enabler. 
     *
     *  @param  inquiryEnablerId the <code> Id </code> of an <code> 
     *          InquiryEnabler </code> 
     *  @param  inquiryId the <code> Id </code> of an <code> Inquiry </code> 
     *  @param  referenceId the reference inquiry enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> inquiryEnablerId, inquiryId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          inquiryEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> inquiryId </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerId, 
     *          inquiryId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveInquiryEnablerBehind(org.osid.id.Id inquiryEnablerId, 
                                         org.osid.id.Id inquiryId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of inquiry enablers for an inquiry. 
     *
     *  @param  inquiryEnablerIds the <code> Ids </code> for a set of <code> 
     *          InquiryEnablers </code> 
     *  @param  inquiryId the <code> Id </code> of an <code> Inquiry </code> 
     *  @throws org.osid.NotFoundException <code> inquiryConstraienrId </code> 
     *          not found or, an <code> inquiryEnablerId </code> not related 
     *          to <code> inquiryId </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerIds 
     *          </code> or <code> inquiryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderInquiryEnablers(org.osid.id.Id[] inquiryEnablerIds, 
                                     org.osid.id.Id inquiryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
