//
// org.osid.inquiry.rules.InquiryEnablerSearch
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryEnablerSearch.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>The search interface for governing inquiry enabler searches. </p>
 */

public interface InquiryEnablerSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of inquiry enablers. 
     *
     *  @param  inquiryEnablerIds list of inquiry enablers 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerIds 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongInquiryEnablers(org.osid.id.IdList inquiryEnablerIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  inquiryEnablerSearchOrder inquiry enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          inquiryEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> inquiryEnablerSearchOrder 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderInquiryEnablerResults(org.osid.inquiry.rules.InquiryEnablerSearchOrder inquiryEnablerSearchOrder);


    /**
     *  Gets the inquiry enabler search record corresponding to the given 
     *  inquiry enabler search record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. 
     *
     *  @param  inquiryEnablerSearchRecordType an inquiry enabler search 
     *          record type 
     *  @return the inquiry enabler search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          inquiryEnablerSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(inquiryEnablerSearchRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.rules.records.InquiryEnablerSearchRecord getInquiryEnablerSearchRecord(org.osid.type.Type inquiryEnablerSearchRecordType)
        throws org.osid.OperationFailedException;
}
