//
// org.osid.inquiry.rules.InquiryRulesProxyManager
//
//     The OSID Java specification for org.osid.inquiry.rules.InquiryRulesProxyManager.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INQUIRY OF CONTRACT, TORT OR OTHERWISE, 
//     ARISING FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inquiry.rules;


/**
 *  <p>The inquiry rules proxy manager provides access to inquiry rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> InquiryEnablerLookupSession: </code> a session to retrieve 
 *      inquiry enablers </li> 
 *      <li> <code> InquiryEnablerQuerySession: </code> a session to query for 
 *      inquiry enablers </li> 
 *      <li> <code> InquiryEnablerSearchSession: </code> a session to search 
 *      for inquiry enablers </li> 
 *      <li> <code> InquiryEnablerAdminSession: </code> a session to create 
 *      and delete inquiry enablers </li> 
 *      <li> <code> InquiryEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to inquiry enabler changes </li> 
 *      <li> <code> InquiryEnablerInquestSession: </code> a session to look up 
 *      inquiry enabler inquest mappings </li> 
 *      <li> <code> InquiryEnablerInquestAssignmentSession: </code> a session 
 *      to manage inquiry enabler to inquest mappings </li> 
 *      <li> <code> InquiryEnablerSmartInquestSession: </code> a session to 
 *      manage dynamic inquests of inquiry enablers </li> 
 *      <li> <code> InquiryEnablerRuleLookupSession: </code> a session to look 
 *      up inquiry enabler mappings </li> 
 *      <li> <code> InquiryEnablerRuleApplicationSession: </code> a session to 
 *      apply inquiry enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AuditEnablerLookupSession: </code> a session to retrieve 
 *      audit enablers </li> 
 *      <li> <code> AuditEnablerQuerySession: </code> a session to query for 
 *      audit enablers </li> 
 *      <li> <code> AuditEnablerSearchSession: </code> a session to search for 
 *      audit enablers </li> 
 *      <li> <code> AuditEnablerAdminSession: </code> a session to create and 
 *      delete audit enablers </li> 
 *      <li> <code> AuditEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to audit enabler changes </li> 
 *      <li> <code> AuditEnablerInquestSession: </code> a session to look up 
 *      audit enabler inquest mappings </li> 
 *      <li> <code> AuditEnablerInquestAssignmentSession: </code> a session to 
 *      manage audit enabler to inquest mappings </li> 
 *      <li> <code> AuditEnablerSmartInquestSession: </code> a session to 
 *      manage dynamic inquests of audit enablers </li> 
 *      <li> <code> AuditEnableRuleLookupSession: </code> a session to look up 
 *      audit enabler mappings </li> 
 *      <li> <code> AuditEnablerRuleApplicationSession: </code> a session to 
 *      apply audit enablers </li> 
 *  </ul>
 *  
 */

public interface InquiryRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.inquiry.rules.InquiryRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerLookupSession getInquiryEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler lookup service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerLookupSession getInquiryEnablerLookupSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerQuerySession getInquiryEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler query service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerQuerySession getInquiryEnablerQuerySessionForInquest(org.osid.id.Id inquestId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerSearchSession getInquiryEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enablers earch service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerSearchSession getInquiryEnablerSearchSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerAdminSession getInquiryEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler administration service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerAdminSession getInquiryEnablerAdminSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler notification service. 
     *
     *  @param  inquiryEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerNotificationSession getInquiryEnablerNotificationSession(org.osid.inquiry.rules.InquiryEnablerReceiver inquiryEnablerReceiver, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler notification service for the given inquest. 
     *
     *  @param  inquiryEnablerReceiver the notification callback 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquiryEnablerReceiver, 
     *          inquestId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerNotificationSession getInquiryEnablerNotificationSessionForInquest(org.osid.inquiry.rules.InquiryEnablerReceiver inquiryEnablerReceiver, 
                                                                                                                   org.osid.id.Id inquestId, 
                                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup inquiry enabler/inquest 
     *  mappings for inquiry enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerInquestSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerInquest() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerInquest() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerInquestSession getInquiryEnablerInquestSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning inquiry 
     *  enablers to inquests. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerInquestAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerInquestAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerInquestAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerInquestAssignmentSession getInquiryEnablerInquestAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage inquiry enabler smart 
     *  inquests. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerSmartInquestSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerSmartInquest() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerSmartInquest() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerSmartInquestSession getInquiryEnablerSmartInquestSession(org.osid.id.Id inquestId, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerRuleLookupSession getInquiryEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler mapping lookup service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerRuleLookupSession getInquiryEnablerRuleLookupSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerRuleApplicationSession getInquiryEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inquiry 
     *  enabler assignment service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> InquiryEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.InquiryEnablerRuleApplicationSession getInquiryEnablerRuleApplicationSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerLookupSession getAuditEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  lookup service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerLookupSession getAuditEnablerLookupSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerQuerySession getAuditEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  query service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerQuerySession getAuditEnablerQuerySessionForInquest(org.osid.id.Id inquestId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerSearchSession getAuditEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enablers 
     *  earch service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerSearchSession getAuditEnablerSearchSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerAdminSession getAuditEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  administration service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerAdminSession getAuditEnablerAdminSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  notification service. 
     *
     *  @param  auditEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> auditEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerNotificationSession getAuditEnablerNotificationSession(org.osid.inquiry.rules.AuditEnablerReceiver auditEnablerReceiver, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  notification service for the given inquest. 
     *
     *  @param  auditEnablerReceiver the notification callback 
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no inquest found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> auditEnablerReceiver, 
     *          inquestId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerNotificationSession getAuditEnablerNotificationSessionForInquest(org.osid.inquiry.rules.AuditEnablerReceiver auditEnablerReceiver, 
                                                                                                               org.osid.id.Id inquestId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup audit enabler/inquest 
     *  mappings for audit enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerInquestSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerInquest() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerInquest() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerInquestSession getAuditEnablerInquestSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning audit 
     *  enablers to inquests. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerInquestAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerInquestAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerInquestAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerInquestAssignmentSession getAuditEnablerInquestAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage audit enabler smart 
     *  inquests. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerSmartInquestSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerSmartInquest() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerSmartInquest() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerSmartInquestSession getAuditEnablerSmartInquestSession(org.osid.id.Id inquestId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerRuleLookupSession getAuditEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  mapping lookup service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerRuleLookupSession getAuditEnablerRuleLookupSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerRuleApplicationSession getAuditEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the audit enabler 
     *  assignment service for the given inquest. 
     *
     *  @param  inquestId the <code> Id </code> of the <code> Inquest </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AuditEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inquest </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inquestId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAuditEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAuditEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.rules.AuditEnablerRuleApplicationSession getAuditEnablerRuleApplicationSessionForInquest(org.osid.id.Id inquestId, 
                                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
