//
// org.osid.installation.DepotQuery
//
//     The OSID Java specification for org.osid.installation.DepotQuery.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This is the query for searching depots. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface DepotQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the package <code> Id </code> for this query. 
     *
     *  @param  packageId a package <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPackageId(org.osid.id.Id packageId, boolean match);


    /**
     *  Clears the package <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPackageIdTerms();


    /**
     *  Tests if a <code> PackageQuery </code> is available. 
     *
     *  @return <code> true </code> if a package query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPackageQuery();


    /**
     *  Gets the query for a package. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the package query 
     *  @throws org.osid.UnimplementedException <code> supportsPackageQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageQuery getPackageQuery();


    /**
     *  Matches depots that have any package. 
     *
     *  @param  match <code> true </code> to match depots with any packages, 
     *          <code> false </code> to match depots with no packages 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPackage(boolean match);


    /**
     *  Clears the package query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPackageTerms();


    /**
     *  Sets the depot <code> Id </code> for this query to match depots that 
     *  have the specified depot as an ancestor. 
     *
     *  @param  depotId a depot <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> depotId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorDepotId(org.osid.id.Id depotId, boolean match);


    /**
     *  Clears the ancestor depot <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorDepotIdTerms();


    /**
     *  Tests if a <code> DepotQuery </code> is available. 
     *
     *  @return <code> true </code> if a depot query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorDepotQuery();


    /**
     *  Gets the query for a Depot. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the depot query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorDepotQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorDepotQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.DepotQuery getAncestorDepotQuery();


    /**
     *  Matches depots with any ancestor. 
     *
     *  @param  match <code> true </code> to match depots with any ancestor, 
     *          <code> false </code> to match root depots 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorDepot(boolean match);


    /**
     *  Clears the ancestor depot query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorDepotTerms();


    /**
     *  Sets the depot <code> Id </code> for this query to match depots that 
     *  have the specified depot as a descendant. 
     *
     *  @param  depotId a depot <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> depotId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantDepotId(org.osid.id.Id depotId, boolean match);


    /**
     *  Clears the descendant depot <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantDepotIdTerms();


    /**
     *  Tests if a <code> DepotQuery </code> is available. 
     *
     *  @return <code> true </code> if a depot query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantDepotQuery();


    /**
     *  Gets the query for a Depot. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the depot query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantDepotQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantDepotQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.DepotQuery getDescendantDepotQuery();


    /**
     *  Matches depots with any descendant. 
     *
     *  @param  match <code> true </code> to match depots with any descendant, 
     *          <code> false </code> to match leaf depots 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantDepot(boolean match);


    /**
     *  Clears the descendant depot query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantDepotTerms();


    /**
     *  Gets the depot query record corresponding to the given <code> Depot 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  depotRecordType a depot record type 
     *  @return the depot query record 
     *  @throws org.osid.NullArgumentException <code> depotRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(depotRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.DepotQueryRecord getDepotQueryRecord(org.osid.type.Type depotRecordType)
        throws org.osid.OperationFailedException;
}
