//
// org.osid.installation.Installation
//
//     The OSID Java specification for org.osid.installation.Installation.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>A <code> Installation </code> represents a <code> Package </code> 
 *  installed on a <code> Site. </code> </p>
 */

public interface Installation
    extends org.osid.OsidObject {


    /**
     *  Gets the <code> Site Id </code> in which this installation is 
     *  installed. 
     *
     *  @return the site <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSiteId();


    /**
     *  Gets the <code> Site </code> in which this installation is installed. 
     *
     *  @return the package site 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Site getSite()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the package <code> Id </code> of this installation. 
     *
     *  @return the package <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPackageId();


    /**
     *  Gets the package. 
     *
     *  @return the package 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Package getPackage()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of depot from which the package was 
     *  installed. 
     *
     *  @return the depot <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDepotId();


    /**
     *  Gets the depot from which the package was installed. 
     *
     *  @return the depot 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Depot getDepot()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date the package was installed. 
     *
     *  @return the installation date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getInstallDate();


    /**
     *  Gets the <code> Id </code> of the agent who installed this package. 
     *
     *  @return the agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAgentId();


    /**
     *  Gets the agent who installed this package. 
     *
     *  @return the agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the date the installation was last checked for updates. 
     *
     *  @return the last check date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getLastCheckDate();


    /**
     *  Gets the installation record corresponding to the given <code> 
     *  Installation </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  installationRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(installationRecordType) </code> is <code> true </code> . 
     *
     *  @param  installationRecordType the type of the record to retrieve 
     *  @return the installation record 
     *  @throws org.osid.NullArgumentException <code> installationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(installationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.InstallationRecord getInstallationRecord(org.osid.type.Type installationRecordType)
        throws org.osid.OperationFailedException;
}
