//
// org.osid.installation.InstallationContentQuery
//
//     The OSID Java specification for org.osid.installation.InstallationContentQuery.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This is the query for searching installation contents. Each method 
 *  match request produces an <code> AND </code> term while multiple 
 *  invocations of a method produces a nested <code> OR. </code> </p>
 */

public interface InstallationContentQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Matches content whose length of the data in bytes are inclusive of the 
     *  given range. 
     *
     *  @param  low low range 
     *  @param  high high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDataLength(long low, long high, boolean match);


    /**
     *  Matches content that has any data length. 
     *
     *  @param  match <code> true </code> to match content with any data 
     *          length, <code> false </code> to match content with no data 
     *          length 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDataLength(boolean match);


    /**
     *  Clears the data length terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDataLengthTerms();


    /**
     *  Matches data in this content. 
     *
     *  @param  data list of matching strings 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @param  partial <code> true </code> for a partial match, <code> false 
     *          </code> for a complete match 
     *  @throws org.osid.NullArgumentException <code> data </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchData(byte[] data, boolean match, boolean partial);


    /**
     *  Matches content that has any data. 
     *
     *  @param  match <code> true </code> to match content with any data, 
     *          <code> false </code> to match content with no data 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyData(boolean match);


    /**
     *  Clears the data terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDataTerms();


    /**
     *  Gets the installation content query record corresponding to the given 
     *  <code> InstallationContent </code> record <code> Type. </code> 
     *  Multiple retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  installationContentRecordType an installation content query 
     *          record type 
     *  @return the installation content query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          installationContentRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(installationContentRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.InstallationContentQueryRecord getInstallationContentQueryRecord(org.osid.type.Type installationContentRecordType)
        throws org.osid.OperationFailedException;
}
