//
// org.osid.installation.InstallationLookupSession
//
//     The OSID Java specification for org.osid.installation.InstallationLookupSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>The session defines methods for retrieving <code> Installations </code> 
 *  from installation <code> Sites. </code> An <code> Installation </code> 
 *  represents a <code> Package </code> installed on a <code> Site. </code> 
 *  </p> 
 *  
 *  <p> Two views are defined in this session: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> normalized version view: multiple versions of the same package 
 *      are suppressed </li> 
 *      <li> denormalized version vew: all versions of an installation are 
 *      returned </li> 
 *  </ul>
 *  
 *  
 *  <p> Installations may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Installation. </code> </p>
 */

public interface InstallationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Site </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Site Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSiteId();


    /**
     *  Gets the <code> Site </code> associated with this session. 
     *
     *  @return the <code> Site </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Site getSite()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Installation </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupInstallations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInstallationView();


    /**
     *  A complete view of the <code> Installation </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInstallationView();


    /**
     *  The returns from the lookup methods may omit multiple versions of the 
     *  same installation. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useNormalizedVersionView();


    /**
     *  All versions of the same installation are returned. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useDenormalizedVersionView();


    /**
     *  Gets the <code> Installation </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Installation </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Installation </code> and retained for 
     *  compatibility. 
     *
     *  @param  installationId <code> Id </code> of the <code> Installation 
     *          </code> 
     *  @return the installation 
     *  @throws org.osid.NotFoundException <code> installationId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> installationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.installation.Installation getInstallation(org.osid.id.Id installationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstallationList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the installations specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> Installations </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  installationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Installation </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> installationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationList getInstallationsByIds(org.osid.id.IdList installationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstallationList </code> corresponding to the given 
     *  installation genus <code> Type </code> which does not include 
     *  installations of genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  installations or an error results. Otherwise, the returned list may 
     *  contain only those installations that are accessible through this 
     *  session. 
     *
     *  @param  installationGenusType an installation genus type 
     *  @return the returned <code> Installation </code> list 
     *  @throws org.osid.NullArgumentException <code> installationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationList getInstallationsByGenusType(org.osid.type.Type installationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstallationList </code> corresponding to the given 
     *  installation genus <code> Type </code> and include any additional 
     *  installations with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  installations or an error results. Otherwise, the returned list may 
     *  contain only those installations that are accessible through this 
     *  session. 
     *
     *  @param  installationGenusType an installation genus type 
     *  @return the returned <code> Installation </code> list 
     *  @throws org.osid.NullArgumentException <code> installationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationList getInstallationsByParentGenusType(org.osid.type.Type installationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstallationList </code> containing the given 
     *  installation record <code> Type. </code> In plenary mode, the returned 
     *  list contains all known installations or an error results. Otherwise, 
     *  the returned list may contain only those installations that are 
     *  accessible through this session. 
     *
     *  @param  installationRecordType an installation record type 
     *  @return the returned <code> Installation </code> list 
     *  @throws org.osid.NullArgumentException <code> installationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationList getInstallationsByRecordType(org.osid.type.Type installationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InstallationList </code> corresponding to the given 
     *  <code> Package. </code> In plenary mode, the returned list contains 
     *  all of the installations for the specified package, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Installations </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  packageId <code> Id </code> of a <code> Package </code> 
     *  @return the returned <code> Installation </code> list 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationList getInstallationsByPackage(org.osid.id.Id packageId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Installations. </code> In plenary mode, the returned 
     *  list contains all known installations or an error results. Otherwise, 
     *  the returned list may contain only those installations that are 
     *  accessible through this session. In both cases, the order of the set 
     *  is not specified. 
     *
     *  @return an <code> InstallationList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationList getInstallations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
