//
// org.osid.installation.InstallationProxyManager
//
//     The OSID Java specification for org.osid.installation.InstallationProxyManager.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>The installation manager provides access to package installation 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager accept a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> InstallationLookupSession: </code> a session to look up 
 *      local installations </li> 
 *      <li> <code> InstallationQuerySession: </code> a session to query local 
 *      installations <code> </code> </li> 
 *      <li> <code> InstallationSearchSession: </code> a session to search 
 *      local installations </li> 
 *      <li> <code> InstallationManagementSession: </code> a session to 
 *      install and remove packages <code> </code> </li> 
 *      <li> <code> InstallationUpdateSession: </code> a session to get 
 *      package updates </li> 
 *      <li> <code> InstallationNotificationSession </code> a session for 
 *      subscribing to new or deleted installations </li> 
 *      <li> <code> SiteLookupSession: </code> a session for listing 
 *      installation sites </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PackageLookupSession: </code> a session to look up 
 *      packages <code> </code> </li> 
 *      <li> <code> PackageQuerySession: </code> a session to query packages 
 *      </li> 
 *      <li> <code> PackageSearchSession: </code> a session to search packages 
 *      </li> 
 *      <li> <code> PackageAdminSession: </code> a session to create, modify 
 *      and delete packages <code> </code> </li> 
 *      <li> <code> PackageNotificationSession: a </code> session to receive 
 *      messages pertaining to package <code> </code> changes </li> 
 *      <li> <code> PackageDepotSession: </code> a session for retrieving 
 *      package and depot mappings </li> 
 *      <li> <code> PackageDepotAssignmentSession: </code> a session for 
 *      managing package and depot mappings </li> 
 *      <li> <code> PackageSmartDepotSession: </code> a session for managing 
 *      smart depots of packages </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> DepotLookupSession: </code> a session to lookup depots 
 *      </li> 
 *      <li> <code> DepotQuerySession: </code> a session to query depots </li> 
 *      <li> <code> DepotSearchSession </code> : a session to search depots 
 *      </li> 
 *      <li> <code> DepotAdminSession </code> : a session to create, modify 
 *      and delete depots </li> 
 *      <li> <code> DepotNotificationSession </code> : a session to receive 
 *      messages pertaining to depot changes </li> 
 *      <li> <code> DepotHierarchySession: </code> a session to traverse the 
 *      depot hierarchy </li> 
 *      <li> <code> DepotHierarchyDesignSession: </code> a session to manage 
 *      the depot hierarchy </li> 
 *  </ul>
 *  
 */

public interface InstallationProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.installation.InstallationProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InstallationLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationLookupSession getInstallationLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  lookup service for the given site. 
     *
     *  @param  siteId the <code> Id </code> of the site 
     *  @param  proxy a proxy 
     *  @return <code> an InstallationLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> siteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> siteId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationLookupSession getInstallationLookupSessionForSite(org.osid.id.Id siteId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InstallationQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationQuerySession[] getInstallationQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  query service for the given site. 
     *
     *  @param  siteId the <code> Id </code> of the site 
     *  @param  proxy a proxy 
     *  @return <code> an InstallationQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> siteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> siteId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationQuerySession[] getInstallationQuerySessionForSite(org.osid.id.Id siteId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InstallationSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationSearchSession getInstallationSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  search service for the given site. 
     *
     *  @param  siteId the <code> Id </code> of the site 
     *  @param  proxy a proxy 
     *  @return <code> an InstallationSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> siteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> siteId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationSearchSession getInstallationSearchSessionForSite(org.osid.id.Id siteId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  management service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InstallationAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationManagement() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationManagement() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationManagementSession getInstallationManagementSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  management service for the given site. 
     *
     *  @param  siteId the <code> Id </code> of the site 
     *  @param  proxy a proxy 
     *  @return <code> an InstallationAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> siteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> siteId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationManagement() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationManagement() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationManagementSession getInstallationManagementSessionForSite(org.osid.id.Id siteId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  update service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> InstallationAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationUpdate() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationUpdate() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationUpdateSession getInstallationUpdateSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  update service for the given site. 
     *
     *  @param  siteId the <code> Id </code> of the site 
     *  @param  proxy a proxy 
     *  @return <code> an InstallationUpdateSession </code> 
     *  @throws org.osid.NotFoundException <code> siteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> siteId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationUpdate() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationUpdate() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationUpdateSession getInstallationUpdateSessionForSite(org.osid.id.Id siteId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  installation changes. 
     *
     *  @param  installationReceiver the installation receiver 
     *  @param  proxy a proxy 
     *  @return an <code> InstallationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> installationReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationNotificationSession getInstallationNotificationSession(org.osid.installation.InstallationReceiver installationReceiver, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the installation 
     *  notification service for the given site. 
     *
     *  @param  installationReceiver the installation receiver 
     *  @param  siteId the <code> Id </code> of the site 
     *  @param  proxy a proxy 
     *  @return <code> an InstallationNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> siteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> installationReceiver, 
     *          siteId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationNotificationSession getInstallationNotificationSessionForSite(org.osid.installation.InstallationReceiver installationReceiver, 
                                                                                                           org.osid.id.Id siteId, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the site lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SiteLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSiteLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSiteLookup() </code> is <code> true. </code> 
     */

    public org.osid.installation.SiteLookupSession getSiteLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PackageLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPackageLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageLookup() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageLookupSession getPackageLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package lookup 
     *  service for the given depot. 
     *
     *  @param  depotId the <code> Id </code> of the depot 
     *  @param  proxy a proxy 
     *  @return <code> a PackageLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> depotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> depotId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsPackageLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageLookupSession getPackageLookupSessionForDepot(org.osid.id.Id depotId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PackageQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPackageQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageQuerySession getPackageQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package query 
     *  service for the given depot. 
     *
     *  @param  depotId the <code> Id </code> of the <code> Depot </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PackageQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Depot </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> depotId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPackageQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.installation.PackageQuerySession getPackageQuerySessionForDepot(org.osid.id.Id depotId, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PackageSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPackageSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageSearch() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageSearchSession getPackageSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package search 
     *  service for the given depot. 
     *
     *  @param  depotId the <code> Id </code> of the depot 
     *  @param  proxy a proxy 
     *  @return <code> a PackageSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> depotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> depotId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsPackageSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageSearchSession getPackageSearchSessionForDepot(org.osid.id.Id depotId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PackageAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPackageAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageAdmin() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageAdminSession getPackageAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package admin 
     *  service for the given depot. 
     *
     *  @param  depotId the <code> Id </code> of the depot 
     *  @param  proxy a proxy 
     *  @return <code> a PackageAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> depotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> depotId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsPackageAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageAdminSession getPackageAdminSessionForDepot(org.osid.id.Id depotId, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to package 
     *  changes. 
     *
     *  @param  packageReceiver the package receiver 
     *  @param  proxy a proxy 
     *  @return a <code> PackageNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> packageReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPackageNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageNotificationSession getPackageNotificationSession(org.osid.installation.PackageReceiver packageReceiver, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the package 
     *  notification service for the given depot. 
     *
     *  @param  packageReceiver the package receiver 
     *  @param  depotId the <code> Id </code> of the depot 
     *  @param  proxy a proxy 
     *  @return <code> a PackageNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> depotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> packageReceiver, depotId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPackageNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageNotificationSession getPackageNotificationSessionForDepot(org.osid.installation.PackageReceiver packageReceiver, 
                                                                                                  org.osid.id.Id depotId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving package to depot mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PackageDepotSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPackageDepot() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageDepot() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageDepotSession getPackageDepotSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning package to depot mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PackageDepotAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPackageDepotAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageDepotAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageDepotSession getPackageDepotAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic package depot. 
     *
     *  @param  depotId the <code> Id </code> of the depot 
     *  @param  proxy a proxy 
     *  @return a <code> PackageSmartDepotSession </code> 
     *  @throws org.osid.NotFoundException <code> depotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> depotId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPackageSmartDepot() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPackageSmartDepot() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.PackageSmartDepotSession getPackageSmartDepotSession(org.osid.id.Id depotId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the depot lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DepotLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDepotLookup() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotLookup() </code> is true. 
     */

    public org.osid.installation.DepotLookupSession getDepotLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the depot query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DepotQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDepotQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.DepotQuerySession getDepotQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the depot search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DepotSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDepotSearch() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotSearch() </code> is true. 
     */

    public org.osid.installation.DepotSearchSession getDepotSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the OsidSession associated with the depot administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DepotAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDepotAdmin() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotAdmin() </code> is true. 
     */

    public org.osid.installation.DepotAdminSession getDepotAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to depot 
     *  service changes. 
     *
     *  @param  depotReceiver the depot receiver 
     *  @param  proxy a proxy 
     *  @return a <code> DepotNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> depotReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDepotNotification() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotNotification() </code> is true. 
     */

    public org.osid.installation.DepotNotificationSession getDepotNotificationSession(org.osid.installation.DepotReceiver depotReceiver, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session traversing depot hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DepotHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDepotHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotHierarchy() </code> is true. 
     */

    public org.osid.installation.DepotHierarchySession getDepotHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session designing depot hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> DepotHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDepotHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotHierarchyDesign() </code> is true. 
     */

    public org.osid.installation.DepotHierarchyDesignSession getDepotHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> InstallationBatchProxyManager. </code> 
     *
     *  @return an <code> InstallationBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationBatch() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationBatch() </code> is true. 
     */

    public org.osid.installation.batch.InstallationBatchProxyManager getInstallationBatchProxyManager()
        throws org.osid.OperationFailedException;
}
