//
// org.osid.installation.InstallationQuerySession
//
//     The OSID Java specification for org.osid.installation.InstallationQuerySession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session provides methods for searching <code> Installations. 
 *  </code> The search query is constructed using the <code> 
 *  InstallationQuery. </code> The installation record <code> Type </code> 
 *  also specifies the record for the installation query. </p> 
 *  
 *  <p> Installations may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  InstallationQuery. </code> </p>
 */

public interface InstallationQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Site </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Site Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSiteId();


    /**
     *  Gets the <code> Site </code> associated with this session. 
     *
     *  @return the <code> Site </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Site getSite()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Installation </code> searches. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchInstallations();


    /**
     *  The returns from the lookup methods may omit multiple versions of the 
     *  same installation. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useNormalizedVersionView();


    /**
     *  All versions of the same installation are returned. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useDenormalizedVersionView();


    /**
     *  A normalized view uses a single <code> Installation </code> to 
     *  represent a set of package dependencies. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useNormalizedDependencyView();


    /**
     *  A denormalized view returns all dependencies. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useDenormalizedDependencyView();


    /**
     *  Gets an installation query. 
     *
     *  @return the installation query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationQuery getInstallationQuery();


    /**
     *  Gets a list of <code> Installations </code> matching the given 
     *  installation query. 
     *
     *  @param  installationQuery the installation query 
     *  @return the returned <code> InstallationList </code> 
     *  @throws org.osid.NullArgumentException <code> installationQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> installationQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationList getInstallationsByQuery(org.osid.installation.InstallationQuery installationQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
