//
// org.osid.installation.InstallationSearchSession
//
//     The OSID Java specification for org.osid.installation.InstallationSearchSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session provides methods for searching <code> Installations. 
 *  </code> The search query is constructed using the <code> 
 *  InstallationQuery. </code> The installation record <code> Type </code> 
 *  also specifies the record for the installation query. </p> 
 *  
 *  <p> <code> getInstallationsByQuery() </code> is the basic search method 
 *  and returns a list of <code> Installations. </code> A more advanced search 
 *  may be performed with <code> getInstallationsBySearch(). </code> It 
 *  accepts an <code> InstallationSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getInstallationsBySearch() </code> returns an 
 *  <code> InstallationSearchResults </code> that can be used to access the 
 *  resulting <code> InstallationList </code> or be used to perform a search 
 *  within the result set through <code> InstallationSearch. </code> </p> 
 *  
 *  <p> Installations may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  InstallationQuery. </code> </p>
 */

public interface InstallationSearchSession
    extends org.osid.installation.InstallationQuerySession {


    /**
     *  Gets an installation search. 
     *
     *  @return the installation search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationSearch getInstallationSearch();


    /**
     *  Gets an installation search order. The <code> InstallationSearchOrder 
     *  </code> is supplied to an <code> InstallationSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the installation search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationSearchOrder getInstallationSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  installationQuery the installation query 
     *  @param  installationSearch the installation search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> installationQuery 
     *          </code> or <code> installationSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> installationSearch 
     *          </code> or <code> installationQuery </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationSearchResults getInstallationsBySearch(org.osid.installation.InstallationQuery installationQuery, 
                                                                                    org.osid.installation.InstallationSearch installationSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a installation query from an inspector. The inspector is 
     *  available from a <code> InstallationSearchResults. </code> 
     *
     *  @param  installatonQueryInspector a installation query inspector 
     *  @return the installaton query 
     *  @throws org.osid.NullArgumentException <code> 
     *          installationQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          installationQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationQuery getInstallationsQueryFromInspector(org.osid.installation.InstallationQueryInspector installatonQueryInspector);
}
