//
// org.osid.installation.Package
//
//     The OSID Java specification for org.osid.installation.Package.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>A <code> Package </code> represents an installation bundle in a depot. 
 *  </p>
 */

public interface Package
    extends org.osid.OsidObject,
            org.osid.Sourceable {


    /**
     *  Gets the version of this package. 
     *
     *  @return the package version 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Version getVersion();


    /**
     *  Gets the copyright of this package. 
     *
     *  @return the copyright 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getCopyright();


    /**
     *  Tests if the provider requests acknowledgement of the license. 
     *
     *  @return <code> true </code> if the consumer should acknowledge the 
     *          terms in the license, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requestsLicenseAcknowledgement();


    /**
     *  Gets the creator or author of this package. 
     *
     *  @return the creator <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCreatorId();


    /**
     *  Gets the creator <code> Id </code> of this package. 
     *
     *  @return the creator 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getCreator()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the release date of this package. 
     *
     *  @return the timestamp of this package 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getReleaseDate();


    /**
     *  Gets the package <code> Ids </code> on which this package directly 
     *  depends. 
     *
     *  @return the package dependency <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getDependencyIds();


    /**
     *  Gets the packages on which this package directly depends. 
     *
     *  @return the package dependencies 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageList getDependencies()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a url for this package. The url may point to an external project 
     *  or product site. If no url is available an empty string is returned. 
     *
     *  @return the url for this package 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getURL();


    /**
     *  Gets the installation content <code> Ids. </code> 
     *
     *  @return the installation content <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getInstallationContentIds()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the installation contents. 
     *
     *  @return the installation contents 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationContentList getInstallationContents()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the package record corresponding to the given <code> Package 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> packageRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(packageRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  packageRecordType the type of the record to retrieve 
     *  @return the package record 
     *  @throws org.osid.NullArgumentException <code> packageRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(packageRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.PackageRecord getPackageRecord(org.osid.type.Type packageRecordType)
        throws org.osid.OperationFailedException;
}
