//
// org.osid.installation.PackageAdminSession
//
//     The OSID Java specification for org.osid.installation.PackageAdminSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session creates, updates, and deletes <code> Packages. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Package, </code> a <code> PackagetForm </code> is requested using <code> 
 *  getPackageFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> PackageForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> PackageForm </code> is submiited 
 *  to a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> PackageForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> PackageForms </code> are requested to the <code> 
 *  Package </code> <code> Id </code> that is to be updated using <code> 
 *  getPackageFormForUpdate(). </code> Similarly, the <code> PackageForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> PackageForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Packages. </code> To unmap a 
 *  <code> Package </code> from the current <code> Depot, </code> the <code> 
 *  PackageDepotAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Package </code> itself thus 
 *  removing it from all known <code> Depot </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface PackageAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Depot </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Depot Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDepotId();


    /**
     *  Gets the <code> Depot </code> associated with this session. 
     *
     *  @return the <code> Depot </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Depot getDepot()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Packages. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Package </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Package </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePackages();


    /**
     *  Tests if this user can create a single <code> Package </code> using 
     *  the desired record types. While <code> 
     *  InstallationManager.getPackageRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Package. </code> Providing 
     *  an empty array tests if a <code> Package </code> can be created with 
     *  no records. 
     *
     *  @param  packageRecordTypes array of package record types 
     *  @return <code> true </code> if <code> Package </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> packageRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePackageWithRecordTypes(org.osid.type.Type[] packageRecordTypes);


    /**
     *  Gets the package form for creating new packages. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  packageRecordTypes array of package record types 
     *  @return the package form 
     *  @throws org.osid.NullArgumentException <code> packageRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageForm getPackageFormForCreate(org.osid.type.Type[] packageRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Package. </code> 
     *
     *  @param  packageForm the form for this <code> Package </code> 
     *  @return the new <code> Package </code> 
     *  @throws org.osid.IllegalStateException <code> packageForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> packageForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> packageForm </code> did 
     *          not originate from <code> getPackageFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Package createPackage(org.osid.installation.PackageForm packageForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Packages. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Package </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if package modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdatePackages();


    /**
     *  Tests if this user can update a specified package. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating the package will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer an update operation to an 
     *  unauthorized user for this function. 
     *
     *  @param  packageId the <code> Id </code> of the <code> Package </code> 
     *  @return <code> false </code> if package modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> packageId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of an update 
     *          available. 
     */

    public boolean canUpdatePackage(org.osid.id.Id packageId);


    /**
     *  Gets the package form for updating an existing package. A new package 
     *  form should be requested for each update transaction. 
     *
     *  @param  packageId the <code> Id </code> of the <code> Package </code> 
     *  @return the package form 
     *  @throws org.osid.NotFoundException <code> packageId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageForm getPackageFormForUpdate(org.osid.id.Id packageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing package. 
     *
     *  @param  packageForm the form containing the elements to be updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> packageForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> packageForm </code> did 
     *          not originate from <code> getPackageFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updatePackage(org.osid.installation.PackageForm packageForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Packages. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Package </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Package </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeletePackages();


    /**
     *  Tests if this user can delete a specified <code> Package. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting the <code> Package 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer a 
     *  delete operation to an unauthorized user for this function. 
     *
     *  @param  packageId the <code> Id </code> of the <code> Package </code> 
     *  @return <code> false </code> if <code> Package </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> packageId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of a delete 
     *          available. 
     */

    public boolean canDeletePackage(org.osid.id.Id packageId);


    /**
     *  Deletes the <code> Package </code> identified by the given <code> Id. 
     *  </code> 
     *
     *  @param  packageId the <code> Id </code> of the <code> Package </code> 
     *          to delete 
     *  @throws org.osid.NotFoundException a <code> Package </code> was not 
     *          found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletePackage(org.osid.id.Id packageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Packages. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Package </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManagePackageAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Package </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Package </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another package it is reassigned to the given 
     *  package <code> Id. </code> 
     *
     *  @param  packageId the <code> Id </code> of a <code> Package </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> packageId </code> not found 
     *  @throws org.osid.NullArgumentException <code> packageId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasPackage(org.osid.id.Id packageId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create content for <code> Packages. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating an <code> 
     *  InstallationContent </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer create operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> installation </code> content 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInstallationContent();


    /**
     *  Tests if this user can create an <code> InstallationContent </code> 
     *  using the desired record types. While <code> 
     *  InstallationManager.getInstallationContentRecordTypes() </code> can be 
     *  used to test which records are supported, this method tests which 
     *  records are required for creating a specific <code> 
     *  InstallationContent. </code> Providing an empty array tests if an 
     *  <code> InstallationContent </code> can be created with no records. 
     *
     *  @param  installationContentRecordTypes array of installation content 
     *          record types 
     *  @return <code> true </code> if <code> InstallationContent </code> 
     *          creation using the specified <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          installationContentRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateInstallationContentWithRecordTypes(org.osid.type.Type[] installationContentRecordTypes);


    /**
     *  Gets an installation content form for creating new installation 
     *  contents. 
     *
     *  @param  packageId the <code> Id </code> of a <code> Package </code> 
     *  @param  installationContentRecordTypes array of installation content 
     *          record types 
     *  @return the installation content form 
     *  @throws org.osid.NotFoundException <code> packageId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> packageId </code> or 
     *          <code> installationContentRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationContentForm getInstallationContentFormForCreate(org.osid.id.Id packageId, 
                                                                                             org.osid.type.Type[] installationContentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates new <code> InstallationContent </code> for a given package. 
     *
     *  @param  installationContentForm the form for this <code> 
     *          InstallationContent </code> 
     *  @return the new <code> InstallationContent </code> 
     *  @throws org.osid.IllegalStateException <code> installationContentForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> installationContentForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> installationContentForm 
     *          </code> did not originate from <code> 
     *          getInstallationContentFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationContent createInstallationContent(org.osid.installation.InstallationContentForm installationContentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> InstallationContent. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating an <code> 
     *  InstallationContent </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer update operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> InstallationContent </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateInstallationContents();


    /**
     *  Gets the installation content form for updating an existing 
     *  installation content. A new installation content form should be 
     *  requested for each update transaction. 
     *
     *  @param  installationContentId the <code> Id </code> of the <code> 
     *          InstallationContent </code> 
     *  @return the v content form 
     *  @throws org.osid.NotFoundException <code> installationContentId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> installationContentId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.InstallationContentForm getInstallationContentFormForUpdate(org.osid.id.Id installationContentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing installation content. 
     *
     *  @param  installationContentForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> installationContentForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> installationForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> installationContentForm 
     *          </code> did not originate from <code> 
     *          getInstallationContentFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateInstallationContent(org.osid.installation.InstallationContentForm installationContentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> InstallationContents. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting an <code> 
     *  InstallationContent </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer delete operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> InstallationContent </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteInstallationContents();


    /**
     *  Deletes content from a package. 
     *
     *  @param  installationContentId the <code> Id </code> of the <code> 
     *          InstallationContent </code> 
     *  @throws org.osid.NotFoundException <code> installationContentId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> installationContentId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteInstallationContent(org.osid.id.Id installationContentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage package versions. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known version methods will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if package versioning is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManagePackageVersions();


    /**
     *  Sets the given package to be the next version of another package. 
     *
     *  @param  packageId the <code> Id </code> of a <code> Package </code> 
     *  @param  nextPackageId the <code> Id </code> of the net package version 
     *  @throws org.osid.AlreadyExistsException <code> nextPackageId </code> 
     *          or <code> packageId </code> already part of a version chain 
     *  @throws org.osid.NotFoundException <code> packageId </code> or <code> 
     *          nextPackageId </code> not found 
     *  @throws org.osid.NullArgumentException <code> packageId </code> or 
     *          <code> nextPackageId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addPackageVersion(org.osid.id.Id packageId, 
                                  org.osid.id.Id nextPackageId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a package from being the next version of another package. 
     *
     *  @param  packageId the <code> Id </code> of a <code> Package </code> 
     *  @param  nextPackageId the <code> Id </code> of the net package version 
     *  @throws org.osid.NotFoundException <code> nextPackageId </code> does 
     *          not follow <code> packageId </code> 
     *  @throws org.osid.NullArgumentException <code> packageId </code> or 
     *          <code> dependencyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removePackageVersion(org.osid.id.Id packageId, 
                                     org.osid.id.Id nextPackageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
