//
// org.osid.installation.PackageDepotAssignmentSession
//
//     The OSID Java specification for org.osid.installation.PackageDepotAssignmentSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session provides methods to re-assign <code> Packages </code> to 
 *  <code> Depots. </code> A <code> Package </code> may map to multiple <code> 
 *  Depots </code> and removing the last reference to an <code> Package 
 *  </code> is the equivalent of deleting it. Each <code> Depot </code> may 
 *  have its own authorizations governing who is allowed to operate on it. 
 *  </p> 
 *  
 *  <p> Moving or adding a reference of a <code> Package </code> to another 
 *  <code> Depot </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface PackageDepotAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter package/depot mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPackages();


    /**
     *  Tests if this user can alter package/depot mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  depotId the <code> Id </code> of the <code> Depot </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> depotId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPackagesToDepot(org.osid.id.Id depotId);


    /**
     *  Gets a list of depot including and under the given depot node in which 
     *  any package can be assigned. 
     *
     *  @param  depotId the <code> Id </code> of the <code> Depot </code> 
     *  @return list of assignable depot <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> depotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableDepotIds(org.osid.id.Id depotId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of depot including and under the given depot node in which 
     *  a specific package can be assigned. 
     *
     *  @param  depotId the <code> Id </code> of the <code> Depot </code> 
     *  @param  packageId the <code> Id </code> of the <code> Package </code> 
     *  @return list of assignable depot <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> depotId </code> or 
     *          <code> packageId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableDepotIdsForPackage(org.osid.id.Id depotId, 
                                                              org.osid.id.Id packageId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Package </code> to a <code> Depot. </code> 
     *
     *  @param  packageId the <code> Id </code> of the <code> Package </code> 
     *  @param  depotId the <code> Id </code> of the <code> Depot </code> 
     *  @throws org.osid.AlreadyExistsException <code> packageId </code> is 
     *          already assigned to <code> depotId </code> 
     *  @throws org.osid.NotFoundException <code> packageId </code> or <code> 
     *          depotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> packageId </code> or 
     *          <code> depotId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPackageToDepot(org.osid.id.Id packageId, 
                                     org.osid.id.Id depotId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Package </code> from a <code> Depot. </code> 
     *
     *  @param  packageId the <code> Id </code> of the <code> Package </code> 
     *  @param  depotId the <code> Id </code> of the <code> Depot </code> 
     *  @throws org.osid.NotFoundException <code> packageId </code> or <code> 
     *          depotId </code> not found or <code> packageId </code> not 
     *          assigned to <code> depotId </code> 
     *  @throws org.osid.NullArgumentException <code> packageId </code> or 
     *          <code> depotId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPackageFromDepot(org.osid.id.Id packageId, 
                                         org.osid.id.Id depotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
