//
// org.osid.installation.PackageDepotSession
//
//     The OSID Java specification for org.osid.installation.PackageDepotSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session provides methods to retrieve <code> Package </code> to 
 *  <code> Depot </code> mappings. A <code> Package </code> may appear in 
 *  multiple <code> Depots. </code> Each <code> Depot </code> may have its own 
 *  authorizations governing who is allowed to look at it. </p> 
 *  
 *  <p> This lookup session defines two views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface PackageDepotSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of package/depot mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known lookup methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPackageDepotMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeDepotView();


    /**
     *  A complete view of the <code> Package </code> and <code> Depot </code> 
     *  returns is desired. Methods will return what is requested or result in 
     *  an error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryDepotView();


    /**
     *  The returns from the lookup methods may omit multiple versions of the 
     *  same package. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useNormalizedVersionView();


    /**
     *  All versions of the same package are returned. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useDenormalizedVersionView();


    /**
     *  A normalized view uses a single <code> Package </code> to represent a 
     *  set of package dependencies. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useNormalizedDependencyView();


    /**
     *  A denormalized view returns all dependencies. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useDenormalizedDependencyView();


    /**
     *  Gets the list of <code> Package </code> <code> Ids </code> associated 
     *  with a <code> Depot. </code> 
     *
     *  @param  depotId <code> Id </code> of the <code> Depot </code> 
     *  @return list of related package <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> depotId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> depotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPackageIdsByDepot(org.osid.id.Id depotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Packages </code> associated with a <code> 
     *  Depot. </code> 
     *
     *  @param  depotId <code> Id </code> of the <code> Depot </code> 
     *  @return list of related packages 
     *  @throws org.osid.NotFoundException <code> depotId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> depotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageList getPackagesByDepot(org.osid.id.Id depotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Package Ids </code> corresponding to a list of 
     *  <code> Depots. </code> 
     *
     *  @param  depotIds list of depot <code> Ids </code> 
     *  @return list of package <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> depotIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPackageIdsByDepots(org.osid.id.IdList depotIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Packages </code> corresponding to a list of 
     *  <code> Depots. </code> 
     *
     *  @param  depotIds list of depot <code> Ids </code> 
     *  @return list of packages 
     *  @throws org.osid.NullArgumentException <code> depotIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageList getPackagesByDepots(org.osid.id.IdList depotIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Depot </code> <code> Ids </code> mapped to a 
     *  <code> Package. </code> 
     *
     *  @param  packageId <code> Id </code> of a <code> Package </code> 
     *  @return list of depot <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> packageId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getDepotIdsByPackage(org.osid.id.Id packageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Depots </code> mapped to a <code> Package. 
     *  </code> 
     *
     *  @param  packageId <code> Id </code> of a <code> Package </code> 
     *  @return list of depots 
     *  @throws org.osid.NotFoundException <code> packageId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.DepotList getDepotsByPackage(org.osid.id.Id packageId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
