//
// org.osid.installation.PackageForm
//
//     The OSID Java specification for org.osid.installation.PackageForm.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This is the form for creating and updating <code> Packages. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  PackageAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface PackageForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidSourceableForm {


    /**
     *  Gets the metadata for a version. 
     *
     *  @return metadata for the version 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getVersionMetadata();


    /**
     *  Sets the version. 
     *
     *  @param  version the new version 
     *  @throws org.osid.InvalidArgumentException <code> version </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> version </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setVersion(org.osid.installation.Version version);


    /**
     *  Clears the version. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersion();


    /**
     *  Gets the metadata for a copyright. 
     *
     *  @return metadata for the copyright 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCopyrightMetadata();


    /**
     *  Sets the copyright. 
     *
     *  @param  copyright the new copyright 
     *  @throws org.osid.InvalidArgumentException <code> copyright </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> copyright </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCopyright(String copyright);


    /**
     *  Clears the version. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCopyright();


    /**
     *  Gets the metadata for the requires license acknowledgement flag. 
     *
     *  @return metadata for the acknowledgement flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRequiresLicenseAcknowledgementMetadata();


    /**
     *  Sets the requires license acknowledgement flag. 
     *
     *  @param  requiresLicenseAcknowledgement the new ackknowledgement flag 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          requiresLicenseAcknowledgement </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRequiresLicenseAcknowledgement(boolean requiresLicenseAcknowledgement);


    /**
     *  Clears the acknowledgement flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiresLicenseAcknowledgement();


    /**
     *  Gets the metadata for a creator resource. 
     *
     *  @return metadata for the creator resource 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCreatorMetadata();


    /**
     *  Sets the creator resource. 
     *
     *  @param  resourceId the new creator resource 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCreator(org.osid.id.Id resourceId);


    /**
     *  Clears the creator. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreator();


    /**
     *  Gets the metadata for the release date. 
     *
     *  @return metadata for the release date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getReleaseDateMetadata();


    /**
     *  Sets the publisher release date. 
     *
     *  @param  releaseDate the new release date 
     *  @throws org.osid.InvalidArgumentException <code> releaseDate </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> releaseDate </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setReleaseDate(org.osid.calendaring.DateTime releaseDate);


    /**
     *  Clears the release date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReleaseDate();


    /**
     *  Gets the metadata for the package dependencies. 
     *
     *  @return metadata for the package dependencies 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDependenciesMetadata();


    /**
     *  Sets the dependencies. 
     *
     *  @param  packageIds the new package dependencies 
     *  @throws org.osid.InvalidArgumentException <code> packageIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> packageIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDependencies(org.osid.id.Id[] packageIds);


    /**
     *  Clears the package dependencies. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependencies();


    /**
     *  Gets the metadata for the url. 
     *
     *  @return metadata for the url 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getURLMetadata();


    /**
     *  Sets the url. 
     *
     *  @param  url the new url 
     *  @throws org.osid.InvalidArgumentException <code> url </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> url </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setURL(String url);


    /**
     *  Clears the url. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearURL();


    /**
     *  Gets the <code> PackageFormRecord </code> corresponding to the given 
     *  package record <code> Type. </code> 
     *
     *  @param  packageRecordType the package record type 
     *  @return the package form record 
     *  @throws org.osid.NullArgumentException <code> packageRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(packageRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.PackageFormRecord getPackageFormRecord(org.osid.type.Type packageRecordType)
        throws org.osid.OperationFailedException;
}
