//
// org.osid.installation.PackageQuery
//
//     The OSID Java specification for org.osid.installation.PackageQuery.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This is the query for searching packages. Each method match request 
 *  produces an <code> AND </code> term while multiple invocations of a method 
 *  produces a nested <code> OR. </code> </p>
 */

public interface PackageQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSourceableQuery {


    /**
     *  Matches a version. 
     *
     *  @param  version the version 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> version </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException version type not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVersion(org.osid.installation.Version version, 
                             boolean match);


    /**
     *  Matches packages with any version. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyVersion(boolean match);


    /**
     *  Clears the version query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersionTerms();


    /**
     *  Matches packages with versions including and more recent than the 
     *  given version. 
     *
     *  @param  version the version 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> version </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException version type not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVersionSince(org.osid.installation.Version version, 
                                  boolean match);


    /**
     *  Clears the version since query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersionSinceTerms();


    /**
     *  Matches the copyright. 
     *
     *  @param  copyright copyright string 
     *  @param  stringMatchType string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> copyright </code> is 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> copyright </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCopyright(String copyright, 
                               org.osid.type.Type stringMatchType, 
                               boolean match);


    /**
     *  Matches packages with any copyright. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCopyright(boolean match);


    /**
     *  Clears the copyright query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCopyrightTerms();


    /**
     *  Matches packages that require license acknowledgement. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequiresLicenseAcknowledgement(boolean match);


    /**
     *  Matches packages that have any acknowledgement value. 
     *
     *  @param  match <code> true </code> to match packages that have any 
     *          acknowledgement value, <code> false </code> for to match 
     *          packages that have no value 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequiresLicenseAcknowledgement(boolean match);


    /**
     *  Clears the license acknowledgement query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiresLicenseAcknowledgementTerms();


    /**
     *  Sets the creator resource <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreatorId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the creator <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatorIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for querying 
     *  creators. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCreatorQuery();


    /**
     *  Gets the query for a creator resource. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the creator resource query 
     *  @throws org.osid.UnimplementedException <code> supportsCreatorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCreatorQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getCreatorQuery();


    /**
     *  Matches packages with any creator. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreator(boolean match);


    /**
     *  Clears the creator query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatorTerms();


    /**
     *  Matches the release date between the given times inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is <code> 
     *          less than from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchReleaseDate(org.osid.calendaring.DateTime from, 
                                 org.osid.calendaring.DateTime to, 
                                 boolean match);


    /**
     *  Matches packages that have any release date. 
     *
     *  @param  match <code> true </code> to match packages with any release 
     *          date, <code> false </code> to match packages with no release 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyReleaseDate(boolean match);


    /**
     *  Clears the release date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearReleaseDateTerms();


    /**
     *  Sets the package <code> Id </code> to match packages on which a 
     *  package depends. 
     *
     *  @param  packageId a state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDependencyId(org.osid.id.Id packageId, boolean match);


    /**
     *  Clears the dependency <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependencyIdTerms();


    /**
     *  Tests if a <code> PackageQuery </code> is available. 
     *
     *  @return <code> true </code> if a package query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDependencyQuery();


    /**
     *  Gets the query for a dependency. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the package query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDependencyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDependencyQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageQuery getDependencyQuery();


    /**
     *  Matches packages that have any dependency. 
     *
     *  @param  match <code> true </code> to match packages with any 
     *          dependency, <code> false </code> to match packages with no 
     *          dependencies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDependency(boolean match);


    /**
     *  Clears the dependency query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependencyTerms();


    /**
     *  Sets the url for this query. Supplying multiple strings behaves like a 
     *  boolean <code> OR </code> among the elements each which must 
     *  correspond to the <code> stringMatchType. </code> 
     *
     *  @param  url url string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> url </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> url </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(url) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchURL(String url, org.osid.type.Type stringMatchType, 
                         boolean match);


    /**
     *  Matches packages that have any url. 
     *
     *  @param  match <code> true </code> to match packages with any url, 
     *          <code> false </code> to match packages with no url 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyURL(boolean match);


    /**
     *  Clears the url query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearURLTerms();


    /**
     *  Sets the installation <code> Id </code> for this query. 
     *
     *  @param  installationId an installation <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> installationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstallationId(org.osid.id.Id installationId, 
                                    boolean match);


    /**
     *  Clears the installation <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstallationIdTerms();


    /**
     *  Tests if an <code> InstallationQuery </code> is available. 
     *
     *  @return <code> true </code> if an installation query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationQuery();


    /**
     *  Gets the query for an installation. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the installation query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationQuery getInstallationQuery();


    /**
     *  Matches any packages that are installed. 
     *
     *  @param  match <code> true </code> to match installed packages, <code> 
     *          false </code> for uninstalled packages 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInstallation(boolean match);


    /**
     *  Clears the installation query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstallationTerms();


    /**
     *  Sets the package <code> Id </code> to match packages on which other 
     *  packages depend. 
     *
     *  @param  packageId a package <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDependentId(org.osid.id.Id packageId, boolean match);


    /**
     *  Clears the dependent <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependentIdTerms();


    /**
     *  Tests if a <code> PackageQuery </code> is available. 
     *
     *  @return <code> true </code> if a package query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDependentQuery();


    /**
     *  Gets the query for a dependent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the package query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDependentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDependentQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageQuery getDependentQuery();


    /**
     *  Matches packages that have any depenents. 
     *
     *  @param  match <code> true </code> to match packages with any 
     *          dependents, <code> false </code> to match packages with no 
     *          dependents 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDependent(boolean match);


    /**
     *  Clears the dependent query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDependentTerms();


    /**
     *  Sets the package <code> Id </code> to match packages in the version 
     *  chain. 
     *
     *  @param  packageId a state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> packageId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchVersionedPackageId(org.osid.id.Id packageId, 
                                        boolean match);


    /**
     *  Clears the versioned package <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersionedPackageIdTerms();


    /**
     *  Tests if a <code> PackageQuery </code> is available. 
     *
     *  @return <code> true </code> if a package query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVersionedPackageQuery();


    /**
     *  Gets the query for a version chain. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the package query 
     *  @throws org.osid.UnimplementedException <code> supportsVersionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVersionQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.PackageQuery getVersionedPackageQuery();


    /**
     *  Matches packages that have any versions. 
     *
     *  @param  match <code> true </code> to match packages with any versions, 
     *          <code> false </code> to match packages with no versions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyVersionedPackage(boolean match);


    /**
     *  Clears the versioned package query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearVersionedPackageTerms();


    /**
     *  Sets the installation content <code> Id </code> for this query. 
     *
     *  @param  installationContentId the installation content <code> Id 
     *          </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> installationContentId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstallationContentId(org.osid.id.Id installationContentId, 
                                           boolean match);


    /**
     *  Clears the installation content <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstallationContentIdTerms();


    /**
     *  Tests if an <code> InstallationContentQuery </code> is available. 
     *
     *  @return <code> true </code> if an installation content query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationContentQuery();


    /**
     *  Gets the query for the installation content. Multiple queries can be 
     *  retrieved for a nested <code> OR </code> term. 
     *
     *  @return the installation content query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstallationContentQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstallationContentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.installation.InstallationContentQuery getInstallationContentQuery();


    /**
     *  Matches packages with any content. 
     *
     *  @param  match <code> true </code> to match packages with any content, 
     *          <code> false </code> to match packages with no content 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInstallationContent(boolean match);


    /**
     *  Clears the installation content terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstallationContentTerms();


    /**
     *  Sets the depot <code> Id </code> for this query. 
     *
     *  @param  depotId a depot <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> depotId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDepotId(org.osid.id.Id depotId, boolean match);


    /**
     *  Clears the depot <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDepotIdTerms();


    /**
     *  Tests if a <code> DepotQuery </code> is available for querying 
     *  resources. 
     *
     *  @return <code> true </code> if a depot query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDepotQuery();


    /**
     *  Gets the query for a depot. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the depot query 
     *  @throws org.osid.UnimplementedException <code> supportsDepotQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDepotQuery() </code> is <code> true. </code> 
     */

    public org.osid.installation.DepotQuery getDepotQuery();


    /**
     *  Clears the depot query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDepotTerms();


    /**
     *  Gets the package query record corresponding to the given <code> 
     *  Package </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  packageRecordType a package query record type 
     *  @return the package query record 
     *  @throws org.osid.NullArgumentException <code> packageRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(packageRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.records.PackageQueryRecord getPackageQueryRecord(org.osid.type.Type packageRecordType)
        throws org.osid.OperationFailedException;
}
