//
// org.osid.installation.PackageSearchSession
//
//     The OSID Java specification for org.osid.installation.PackageSearchSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session provides methods for searching <code> Package </code> 
 *  objects. The search query is constructed using the <code> PackageQuery. 
 *  </code> The package record <code> Type </code> also specifies the record 
 *  for the package query. </p> 
 *  
 *  <p> <code> getPackagesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Packages. </code> A more advanced search may be 
 *  performed with <code> getPackagesBySearch(). </code> It accepts a <code> 
 *  PackageSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getPackagesBySearch() </code> returns a <code> 
 *  PackageSearchResults </code> that can be used to access the resulting 
 *  <code> PackageList </code> or be used to perform a search within the 
 *  result set through <code> PackageSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated depot view: searches include packages in depots of 
 *      which this depot is a ancestor in the depot hierarchy </li> 
 *      <li> isolated depot view: searches are restricted to packages in this 
 *      depot </li> 
 *      <li> normalized version view: multiple versions of the same package 
 *      are suppressed </li> 
 *      <li> denormalized version vew: all versions of an installation are 
 *      returned </li> 
 *      <li> normalized dependency view: supporting installations upon which 
 *      other installations depend are suppressed </li> 
 *      <li> denormalized dependency view: all dependencies are returned </li> 
 *  </ul>
 *  
 *  
 *  <p> Packages may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PackageQuery. </code> 
 *  </p>
 */

public interface PackageSearchSession
    extends org.osid.installation.PackageQuerySession {


    /**
     *  Gets a package search. 
     *
     *  @return the package search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageSearch getPackageSearch();


    /**
     *  Gets a package search order. The <code> PackageSearchOrder </code> is 
     *  supplied to a <code> PackageSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the package search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageSearchOrder getPackageSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  packageQuery the package query 
     *  @param  packageSearch the package search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> packageQuery </code> or 
     *          <code> packageSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> packageSearch </code> or 
     *          <code> packageQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageSearchResults getPackagesBySearch(org.osid.installation.PackageQuery packageQuery, 
                                                                          org.osid.installation.PackageSearch packageSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a package query from an inspector. The inspector is available 
     *  from a <code> PackageeSearchResults. </code> 
     *
     *  @param  packageQueryInspector a package query inspector 
     *  @return the package query 
     *  @throws org.osid.NullArgumentException <code> packageQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> packageQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageQuery getPackageQueryFromInspector(org.osid.installation.PackageQueryInspector packageQueryInspector);
}
