//
// org.osid.installation.PackageSmartDepotSession
//
//     The OSID Java specification for org.osid.installation.PackageSmartDepotSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2009-2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.installation;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> PackageQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Depot </code> to create a virtual collection of 
 *  <code> Packages. </code> The packages may be sequenced using the <code> 
 *  PackageSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Depot </code> has a default query that matches any package 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using a <code> PackageQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to a <code> PackageQuery. 
 *  </code> </p>
 */

public interface PackageSmartDepotSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Depot </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Depot Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDepotId();


    /**
     *  Gets the <code> Depot </code> associated with this session. 
     *
     *  @return the <code> Depot </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.Depot getDepot()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart depot. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart depot management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartDepot();


    /**
     *  Gets a package query. 
     *
     *  @return the package query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageQuery getPackageQuery();


    /**
     *  Gets a package search order. 
     *
     *  @return the package search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageSearchOrder getPackageSearchOrder();


    /**
     *  Applies a package query to this depot. 
     *
     *  @param  packageQuery the package query 
     *  @throws org.osid.NullArgumentException <code> packageQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> packageQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPackageQuery(org.osid.installation.PackageQuery packageQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a package query inspector for this depot. 
     *
     *  @return the package query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageQueryInspector inspectPackageQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a package search order to this depot. 
     *
     *  @param  packageSearchOrder the package search order 
     *  @throws org.osid.NullArgumentException <code> packageSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> packageSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPackageSequencing(org.osid.installation.PackageSearchOrder packageSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a package query from an inspector. 
     *
     *  @param  packageQueryInspector a package query inspector 
     *  @return the package query 
     *  @throws org.osid.NullArgumentException <code> packageQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> packageQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.installation.PackageQuery getPackageQueryFromInspector(org.osid.installation.PackageQueryInspector packageQueryInspector);
}
