//
// org.osid.inventory.InventoryLookupSession
//
//     The OSID Java specification for org.osid.inventory.InventoryLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session provides methods for retrieving <code> Inventory </code> 
 *  objects. The <code> Inventory </code> represents a collection of items and 
 *  models. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated warehouse view: All inventory methods in this session 
 *      operate, retrieve and pertain to inventories defined explicitly in the 
 *      current warehouse. Using an isolated view is useful for managing 
 *      <code> Inventories </code> with the <code> InventoryAdminSession. 
 *      </code> </li> 
 *      <li> federated warehouse view: All inventory methods in this session 
 *      operate, retrieve and pertain to all inventories defined in this 
 *      warehouse and any other inventories implicitly available in this 
 *      warehouse through warehouse inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedWarehouseView() </code> and <code> 
 *  useIsolatedWarehouseView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface InventoryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Warehouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Warehouse Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWarehouseId();


    /**
     *  Gets the <code> Warehouse </code> associated with this session. 
     *
     *  @return the warehouse 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse getWarehouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Inventory </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupInventories();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeInventoryView();


    /**
     *  A complete view of the <code> Inventory </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryInventoryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include inventories in warehouses which are children of this warehouse 
     *  in the warehouse hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedWarehouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this warehouse only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedWarehouseView();


    /**
     *  Gets the <code> Inventory </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Inventory 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to an <code> 
     *  Inventory </code> and retained for compatibility. 
     *
     *  @param  inventoryId <code> Id </code> of the <code> Inventory </code> 
     *  @return the inventory 
     *  @throws org.osid.NotFoundException <code> inventoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> inventoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.inventory.Inventory getInventory(org.osid.id.Id inventoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InventoryList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  inventories specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Inventories </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  inventoryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> inventoryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventoriesByIds(org.osid.id.IdList inventoryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InventoryList </code> corresponding to the given 
     *  inventory genus <code> Type </code> which does not include inventories 
     *  of genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known inventories or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  inventories that are accessible through this session. 
     *
     *  @param  inventoryGenusType an inventory genus type 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.NullArgumentException <code> inventoryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventoriesByGenusType(org.osid.type.Type inventoryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InventoryList </code> corresponding to the given 
     *  inventory genus <code> Type </code> and include any additional 
     *  inventories with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  inventories or an error results. Otherwise, the returned list may 
     *  contain only those inventories that are accessible through this 
     *  session. 
     *
     *  @param  inventoryGenusType an inventory genus type 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.NullArgumentException <code> inventoryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventoriesByParentGenusType(org.osid.type.Type inventoryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> InventoryList </code> containing the given inventory 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known inventories or an error results. Otherwise, the 
     *  returned list may contain only those inventories that are accessible 
     *  through this session. 
     *
     *  @param  inventoryRecordType an inventory record type 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.NullArgumentException <code> inventoryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventoriesByRecordType(org.osid.type.Type inventoryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the most recent <code> Inventories. </code> In plenary mode, the 
     *  returned list contains all known inventories or an error results. 
     *  Otherwise, the returned list may contain only those inventories that 
     *  are accessible through this session. 
     *
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getRecentInventories()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets <code> Inventories </code> between the given date range inclusive 
     *  <code> . </code> In plenary mode, the returned list contains all known 
     *  inventories or an error results. Otherwise, the returned list may 
     *  contain only those inventories that are accessible through this 
     *  session. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventoriesByDate(org.osid.calendaring.DateTime from, 
                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Inventories </code> for the given <code> Stock. 
     *  </code> In plenary mode, the returned list contains all known 
     *  inventories or an error results. Otherwise, the returned list may 
     *  contain only those inventories that are accessible through this 
     *  session. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventoriesForStock(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the most recent <code> Inventories </code> for with the given 
     *  <code> Stock. </code> In plenary mode, the returned list contains all 
     *  known inventories or an error results. Otherwise, the returned list 
     *  may contain only those inventories that are accessible through this 
     *  session. 
     *
     *  @param  stockId an inventory <code> Id </code> 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getRecentInventoriesForStock(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets <code> Inventories </code> between the given date range inclusive 
     *  for the given stock <code> . </code> In plenary mode, the returned 
     *  list contains all known inventories or an error results. Otherwise, 
     *  the returned list may contain only those inventories that are 
     *  accessible through this session. 
     *
     *  @param  stockId an inventory <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Inventory </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> stockid, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventoriesByDateForStock(org.osid.id.Id stockId, 
                                                                         org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Inventories. </code> In plenary mode, the returned 
     *  list contains all known inventories or an error results. Otherwise, 
     *  the returned list may contain only those inventories that are 
     *  accessible through this session. 
     *
     *  @return a list of <code> Inventories </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.InventoryList getInventories()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
