//
// org.osid.inventory.InventoryProxyManager
//
//     The OSID Java specification for org.osid.inventory.InventoryProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>The inventory manager provides access to inventory sessions and 
 *  provides interoperability tests for various aspects of this service. 
 *  Methods in this manager support the passing of a <code> Proxy </code> 
 *  interface for passing information from server environments. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ItemLookupSession: </code> a session to retrieve items 
 *      </li> 
 *      <li> <code> ItemQuerySession: </code> a session to query items </li> 
 *      <li> <code> ItemSearchSession: </code> a session to search for items 
 *      </li> 
 *      <li> <code> ItemAdminSession: </code> a session to create and delete 
 *      items </li> 
 *      <li> <code> ItemNotificationSession: </code> a session to receive 
 *      notifications pertaining to item changes </li> 
 *      <li> <code> ItemWarehouseSession: </code> a session to look up item to 
 *      warehouse mappings </li> 
 *      <li> <code> ItemWarehouseAssignmentSession: </code> a session to 
 *      manage item to warehouse mappings </li> 
 *      <li> <code> ItemSmartWarehouseSession: </code> a session to manage 
 *      dynamic warehouses of items </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> StockLookupSession: </code> a session to retrieve stocks 
 *      </li> 
 *      <li> <code> StockQuerySession: </code> a session to query stocks </li> 
 *      <li> <code> StockSearchSession: </code> a session to search for stocks 
 *      </li> 
 *      <li> <code> StockAdminSession: </code> a session to create and delete 
 *      stocks </li> 
 *      <li> <code> StockNotificationSession: </code> a session to receive 
 *      notifications pertaining to stock changes </li> 
 *      <li> <code> StockWarehouseSession: </code> a session to look up stock 
 *      to warehouse mappings </li> 
 *      <li> <code> StockWarehouseSession: </code> a session to look up stock 
 *      to warehouse mappings </li> 
 *      <li> <code> StockWarehouseAssignmentSession: </code> a session to 
 *      manage stock to warehouse mappings </li> 
 *      <li> <code> StockSmartWarehouseSession: </code> a session to manage 
 *      dynamic warehouses of stocks </li> 
 *      <li> <code> StockHierarchySession: </code> a session to traverse a 
 *      hierarchy of stocks </li> 
 *      <li> <code> StockHierarchyDesignSession: </code> a session to manage a 
 *      stock hierarchy </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ModelLookupSession: </code> a session to retrieve models 
 *      </li> 
 *      <li> <code> ModelQuerySession: </code> a session to query models </li> 
 *      <li> <code> ModelSearchSession: </code> a session to search for models 
 *      </li> 
 *      <li> <code> ModelAdminSession: </code> a session to create and delete 
 *      models </li> 
 *      <li> <code> ModelNotificationSession: </code> a session to receive 
 *      notifications pertaining to model changes </li> 
 *      <li> <code> ModelWarehouseSession: </code> a session to look up model 
 *      to warehouse mappings </li> 
 *      <li> <code> ModelWarehouseSession: </code> a session to look up model 
 *      to warehouse mappings </li> 
 *      <li> <code> ModelWarehouseAssignmentSession: </code> a session to 
 *      manage model to warehouse mappings </li> 
 *      <li> <code> ModelSmartWarehouseSession: </code> a session to manage 
 *      dynamic warehouses of models </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> InventoryLookupSession: </code> a session to retrieve 
 *      inventories </li> 
 *      <li> <code> InventoryLookupSession: </code> a session to query 
 *      inventories </li> 
 *      <li> <code> InventorySearchSession: </code> a session to search for 
 *      inventories </li> 
 *      <li> <code> InventoryAdminSession: </code> a session to create and 
 *      delete inventories </li> 
 *      <li> <code> InventoryNotificationSession: </code> a session to receive 
 *      notifications pertaining to inventory changes </li> 
 *      <li> <code> InventoryWarehouseSession: </code> a session to look up 
 *      inventory to warehouse mappings </li> 
 *      <li> <code> InventoryWarehouseAssignmentSession: </code> a session to 
 *      manage inventory to warehouse mappings </li> 
 *      <li> <code> InventorySmartWarehouseAssignmentSession: </code> a 
 *      session to manage dynamic warehouses of inventories </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> WarehouseLookupSession: </code> a session to retrieve 
 *      warehouses </li> 
 *      <li> <code> WarehouseQuerySession: </code> a session to query 
 *      warehouses </li> 
 *      <li> <code> WarehousesearchSession: </code> a session to search for 
 *      warehouses </li> 
 *      <li> <code> WarehouseAdminSession: </code> a session to create and 
 *      delete warehouses </li> 
 *      <li> <code> WarehouseNotificationSession: </code> a session to receive 
 *      notifications pertaining to warehouse changes </li> 
 *      <li> <code> WarehouseHierarchySession: </code> a session to traverse a 
 *      hierarchy of warehouses </li> 
 *      <li> <code> WarehouseHierarchyDesignSession: </code> a session to 
 *      manage a warehouse hierarchy </li> 
 *  </ul>
 *  
 */

public interface InventoryProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.inventory.InventoryProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the item lookup 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return an <code> ItemLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemLookup() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemLookupSession getItemLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item lookup 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> ItemLookupSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ItemLookupSession getItemLookupSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item query 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return an <code> ItemQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemQuerySession getItemQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item query 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> ItemQuerySession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ItemQuerySession getItemQuerySessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item search 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return an <code> ItemSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemSearch() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemSearchSession getItemSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item search 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> ItemSearchSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ItemSearchSession getItemSearchSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item 
     *  administration service. 
     *
     *  @param  proxy proxy 
     *  @return an <code> ItemAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemAdminSession getItemAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item 
     *  administration service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> ItemAdminSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ItemAdminSession getItemAdminSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item 
     *  notification service. 
     *
     *  @param  itemReceiver the notification callback 
     *  @param  proxy proxy 
     *  @return an <code> ItemNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> itemReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemNotification() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemNotificationSession getItemNotificationSession(org.osid.inventory.ItemReceiver itemReceiver, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item 
     *  notification service for the given warehouse. 
     *
     *  @param  itemReceiver the notification callback 
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> ItemNotificationSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> itemReceiver, 
     *          warehouseId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ItemNotificationSession getItemNotificationSessionForWarehouse(org.osid.inventory.ItemReceiver itemReceiver, 
                                                                                             org.osid.id.Id warehouseId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup item/catalog mappings. 
     *
     *  @param  proxy proxy 
     *  @return an <code> ItemCatalogSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsItemCatalog() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemCatalog() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemWarehouseSession getItemWarehouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning items to 
     *  warehouses. 
     *
     *  @param  proxy proxy 
     *  @return an <code> ItemCatalogAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemCatalogAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemCatalogAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.ItemWarehouseAssignmentSession getItemWarehouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the item smart 
     *  warehouse service. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> ItemSmartWarehouseSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemSmartWarehouse() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemSmartWarehouse() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ItemSmartWarehouseSession getItemSmartWarehouseSession(org.osid.id.Id warehouseId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock lookup 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockLookup() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockLookupSession getStockLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock lookup 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the warehouse 
     *  @param  proxy proxy 
     *  @return a <code> StockLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Warehouse </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockLookupSession getStockLookupSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock query 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockQuerySession getStockQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock query 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> StockQuerySession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockQuerySession getStockQuerySessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock search 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockSearch() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockSearchSession getStockSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock search 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> StockSearchSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockSearchSession getStockSearchSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock 
     *  administration service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockAdminSession getStockAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock 
     *  administration service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> StockAdminSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStockAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockAdminSession getStockAdminSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock 
     *  notification service. 
     *
     *  @param  stockReceiver the notification callback 
     *  @param  proxy proxy 
     *  @return a <code> StockNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> stockReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.StockNotificationSession getStockNotificationSession(org.osid.inventory.StockReceiver stockReceiver, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock 
     *  notification service for the given warehouse. 
     *
     *  @param  stockReceiver the notification callback 
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> StockNotificationSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> stockReceiver, 
     *          warehouseId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockNotificationSession getStockNotificationSessionForWarehouse(org.osid.inventory.StockReceiver stockReceiver, 
                                                                                               org.osid.id.Id warehouseId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup stock/catalog mappings. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockWarehouseSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockWarehouse() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockWarehouse() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockWarehouseSession getStockWarehouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning stocks 
     *  to warehouses. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockWarehouseAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockWarehouseAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockWarehouseAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.StockWarehouseAssignmentSession getStockWarehouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the stock smart 
     *  warehouse service. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> StockSmartWarehouseSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockSmartWarehouse() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockSmartWarehouse() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockSmartWarehouseSession getStockSmartWarehouseSession(org.osid.id.Id warehouseId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the stock hierarchy traversal session. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockHierarchySession getStockHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the stock hierarchy traversal session for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> StockHierarchySession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockHierarchy() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockHierarchy() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockHierarchySession getStockHierarchySessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the stock hierarchy design session. 
     *
     *  @param  proxy proxy 
     *  @return a <code> StockHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.StockHierarchyDesignSession getStockHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the stock hierarchy design session for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> StockHierarchyDesignSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockHierarchyDesign() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockHierarchyDesign() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.StockHierarchyDesignSession getStockHierarchyDesignSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model lookup 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> ModelSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelLookup() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelLookupSession getModelLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model lookup 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the warehouse 
     *  @param  proxy proxy 
     *  @return a <code> ModelLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Warehouse </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ModelLookupSession getModelLookupSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model query 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> ModelQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelQuerySession getModelQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model query 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> ModelQuerySession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ModelQuerySession getModelQuerySessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model search 
     *  service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> ModelSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelSearch() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelSearchSession getModelSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model search 
     *  service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> ModelSearchSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ModelSearchSession getModelSearchSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model 
     *  administration service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> ModelAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelAdminSession getModelAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model 
     *  administration service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> ModelAdminSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsModelAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ModelAdminSession getModelAdminSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model 
     *  notification service. 
     *
     *  @param  modelReceiver the notification callback 
     *  @param  proxy proxy 
     *  @return a <code> ModelNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> modelReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModelNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.ModelNotificationSession getModelNotificationSession(org.osid.inventory.ModelReceiver modelReceiver, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model 
     *  notification service for the given warehouse. 
     *
     *  @param  modelReceiver the notification callback 
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> ModelNotificationSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> modelReceiver, 
     *          warehouseId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModelNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ModelNotificationSession getModelNotificationSessionForWarehouse(org.osid.inventory.ModelReceiver modelReceiver, 
                                                                                               org.osid.id.Id warehouseId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup model/catalog mappings. 
     *
     *  @param  proxy proxy 
     *  @return a <code> ModelWarehouseSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModelWarehouse() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelWarehouse() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelWarehouseSession getModelWarehouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning models 
     *  to warehouses. 
     *
     *  @param  proxy proxy 
     *  @return a <code> ModelWarehouseAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModelWarehouseAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelWarehouseAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.ModelWarehouseAssignmentSession getModelWarehouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the model smart 
     *  warehouse service. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> ModelSmartWarehouseSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModelSmartWarehouse() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelSmartWarehouse() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.ModelSmartWarehouseSession getModelSmartWarehouseSession(org.osid.id.Id warehouseId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  lookup service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> InventoryLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryLookup() </code> is <code> true. </code> 
     */

    public org.osid.inventory.InventoryLookupSession getInventoryLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  lookup service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> InventoryLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Warehouse </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.InventoryLookupSession getInventoryLookupSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  query service. 
     *
     *  @param  proxy proxy 
     *  @return an <code> InventoryQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.InventoryQuerySession getInventoryQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  query service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> InventoryQuerySession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.InventoryQuerySession getInventoryQuerySessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  search service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> InventorySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventorySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventorySearch() </code> is <code> true. </code> 
     */

    public org.osid.inventory.InventorySearchSession getInventorySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  search service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> InventorySearchSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventorySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventorySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.InventorySearchSession getInventorySearchSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  administration service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> InventoryAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.InventoryAdminSession getInventoryAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  administration service for the given warehouse. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> InventoryAdminSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> or <code> 
     *          warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.InventoryAdminSession getInventoryAdminSessionForWarehouse(org.osid.id.Id warehouseId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  notification service. 
     *
     *  @param  inventoryReceiver the notification callback 
     *  @param  proxy proxy 
     *  @return a <code> InventoryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> inventoryReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.InventoryNotificationSession getInventoryNotificationSession(org.osid.inventory.InventoryReceiver inventoryReceiver, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  notification service for the given warehouse. 
     *
     *  @param  inventoryReceiver the notification callback 
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return a <code> InventoryNotificationSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inventoryReceiver, 
     *          warehouseId, </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.InventoryNotificationSession getInventoryNotificationSessionForWarehouse(org.osid.inventory.InventoryReceiver inventoryReceiver, 
                                                                                                       org.osid.id.Id warehouseId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup inventory/catalog 
     *  mappings. 
     *
     *  @param  proxy proxy 
     *  @return a <code> InventoryCatalogSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryCatalog() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryCatalog() </code> is <code> true. </code> 
     */

    public org.osid.inventory.InventoryWarehouseSession getInventoryWarehouseSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  inventories to warehouses. 
     *
     *  @param  proxy proxy 
     *  @return a <code> InventoryCatalogAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryCatalogAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryCatalogAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.inventory.InventoryWarehouseAssignmentSession getInventoryWarehouseAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the inventory 
     *  smart warehouse service. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  proxy proxy 
     *  @return an <code> InventorySmartWarehouseSession </code> 
     *  @throws org.osid.NotFoundException no warehouse found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventorySmartWarehouse() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventorySmartWarehouse() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.InventorySmartWarehouseSession getInventorySmartWarehouseSession(org.osid.id.Id warehouseId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the warehouse 
     *  lookup service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> WarehouseLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseLookup() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseLookupSession getWarehouseLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the warehouse 
     *  query service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> WarehouseQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseQuerySession getWarehouseQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the warehouse 
     *  search service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> WarehouseSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseSearch() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseSearchSession getWarehouseSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the warehouse 
     *  administrative service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> WarehouseAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseAdminSession getWarehouseAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the warehouse 
     *  notification service. 
     *
     *  @param  warehouseReceiver the notification callback 
     *  @param  proxy proxy 
     *  @return a <code> WarehouseNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.WarehouseNotificationSession getWarehouseNotificationSession(org.osid.inventory.WarehouseReceiver warehouseReceiver, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the warehouse 
     *  hierarchy service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> WarehouseHierarchySession </code> for warehouses 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.WarehouseHierarchySession getWarehouseHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the warehouse 
     *  hierarchy design service. 
     *
     *  @param  proxy proxy 
     *  @return a <code> HierarchyDesignSession </code> for warehouses 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.WarehouseHierarchyDesignSession getWarehouseHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> InventoryBatchProxyManager. </code> 
     *
     *  @return a <code> InventoryBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryBatch() </code> is <code> true. </code> 
     */

    public org.osid.inventory.batch.InventoryBatchProxyManager getInventoryBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> InventoryShipmentProxyManager. </code> 
     *
     *  @return a <code> InventoryShipmentProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryShipment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryShipment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.shipment.InventoryShipmentProxyManager getInventoryShipmentProxyManager()
        throws org.osid.OperationFailedException;
}
