//
// org.osid.inventory.ItemSearchSession
//
//     The OSID Java specification for org.osid.inventory.ItemSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session provides methods for searching among <code> Item </code> 
 *  objects. The search query is constructed using the <code> ItemQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getItemsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Items. </code> A more advanced search may be 
 *  performed with <code> getItemsBySearch(). </code> It accepts an <code> 
 *  ItemSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getItemsBySearch() </code> returns an <code> ItemSearchResults </code> 
 *  that can be used to access the resulting <code> ItemList </code> or be 
 *  used to perform a search within the result set through <code> ItemSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated warehouse view: searches include items in warehouses of 
 *      which this warehouse is an ancestor in the warehouse hierarchy </li> 
 *      <li> isolated warehouse view: searches are restricted to items in this 
 *      warehouse </li> 
 *  </ul>
 *  
 *  
 *  <p> Items may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ItemQuery. </code> </p>
 */

public interface ItemSearchSession
    extends org.osid.inventory.ItemQuerySession {


    /**
     *  Gets an item search. 
     *
     *  @return the item search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemSearch getItemSearch();


    /**
     *  Gets an inventory search order. The <code> ItemSearchOrder </code> is 
     *  supplied to an <code> ItemSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the item search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemSearchOrder getItemSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  itemQuery the item query 
     *  @param  itemSearch the item search 
     *  @return the item search results 
     *  @throws org.osid.NullArgumentException <code> itemQuery </code> or 
     *          <code> itemSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> itemQuery </code> or 
     *          <code> itemSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemSearchResults getItemsBySearch(org.osid.inventory.ItemQuery itemQuery, 
                                                                 org.osid.inventory.ItemSearch itemSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an item query from an inspector. The inspector is available from 
     *  an <code> ItemSearchResults. </code> 
     *
     *  @param  itemQueryInspector an item query inspector 
     *  @return the item query 
     *  @throws org.osid.NullArgumentException <code> itemQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> itemQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.ItemQuery getItemQueryFromInspector(org.osid.assessment.ItemQueryInspector itemQueryInspector);
}
