//
// org.osid.inventory.ModelQuery
//
//     The OSID Java specification for org.osid.inventory.ModelQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This is the query for searching models. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ModelQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the inventory <code> Id </code> for this query to match models 
     *  that have a related manufacturer. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchManufacturerId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the manufacturer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearManufacturerIdTerms();


    /**
     *  Tests if a <code> ManufacturerQuery </code> is available for the 
     *  location. 
     *
     *  @return <code> true </code> if a manufacturer query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsManufacturerQuery();


    /**
     *  Gets the query for a manufacturer. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the manufacturer query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsManufacturerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsManufacturerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getManufacturerQuery();


    /**
     *  Matches any manufacturer. 
     *
     *  @param  match <code> true </code> to match models with any inventory, 
     *          <code> false </code> to match models with no inventories 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyManufacturer(boolean match);


    /**
     *  Clears the manufacturer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearManufacturerTerms();


    /**
     *  Matches an archetype. 
     *
     *  @param  archetype an archetype for the model 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> archetype </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchArchetype(String archetype, 
                               org.osid.type.Type stringMatchType, 
                               boolean match);


    /**
     *  Matches items that have any archetype. 
     *
     *  @param  match <code> true </code> to match items with any archetype, 
     *          <code> false </code> to match items with no archetype 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyArchetype(boolean match);


    /**
     *  Clears the archetype terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearArchetypeTerms();


    /**
     *  Matches a model number. 
     *
     *  @param  number a model number 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> number </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNumber(String number, org.osid.type.Type stringMatchType, 
                            boolean match);


    /**
     *  Matches items that have any model number. 
     *
     *  @param  match <code> true </code> to match items with any model 
     *          number, <code> false </code> to match items with no model 
     *          number 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNumber(boolean match);


    /**
     *  Clears the model number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumberTerms();


    /**
     *  Sets the warehouse <code> Id </code> for this query to match models 
     *  assigned to warehouses. 
     *
     *  @param  warehouseId the warehouse <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWarehouseId(org.osid.id.Id warehouseId, boolean match);


    /**
     *  Clears the warehouse <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseIdTerms();


    /**
     *  Tests if a <code> WarehouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a warehouse query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWarehouseQuery();


    /**
     *  Gets the query for a warehouse. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the warehouse query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWarehouseQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWarehouseQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.WarehouseQuery getWarehouseQuery();


    /**
     *  Clears the warehouse terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarehouseTerms();


    /**
     *  Gets the model query record corresponding to the given <code> Model 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  modelRecordType a model record type 
     *  @return the model query record 
     *  @throws org.osid.NullArgumentException <code> modelRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(modelRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.ModelQueryRecord getModelQueryRecord(org.osid.type.Type modelRecordType)
        throws org.osid.OperationFailedException;
}
