//
// org.osid.inventory.StockForm
//
//     The OSID Java specification for org.osid.inventory.StockForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This is the form for creating and updating <code> Stocks. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> StockAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface StockForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidFederateableForm {


    /**
     *  Gets the metadata for sku. 
     *
     *  @return metadata for the sku 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSKUMetadata();


    /**
     *  Sets the SKU. 
     *
     *  @param  sku the new SKU 
     *  @throws org.osid.InvalidArgumentException <code> sku </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> sku </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSKU(String sku);


    /**
     *  Removes the SKU. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSKU();


    /**
     *  Gets the metadata for models in this stock. 
     *
     *  @return metadata for the models 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getModelsMetadata();


    /**
     *  Sets the models. 
     *
     *  @param  models the new models 
     *  @throws org.osid.InvalidArgumentException <code> models </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> models </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setModels(org.osid.id.Id[] models);


    /**
     *  Removes the models. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModels();


    /**
     *  Gets the metadata for location string. 
     *
     *  @return metadata for the location string 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLocationDescriptionMetadata();


    /**
     *  Sets the location string. 
     *
     *  @param  location the new location description 
     *  @throws org.osid.InvalidArgumentException <code> location </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> location </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocationDescription(String location);


    /**
     *  Removes the location description. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationDescription();


    /**
     *  Gets the metadata for locations in this stock. 
     *
     *  @return metadata for the locations 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLocationsMetadata();


    /**
     *  Sets the locations. 
     *
     *  @param  locations the new locations 
     *  @throws org.osid.InvalidArgumentException <code> locations </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> locations </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLocations(org.osid.id.Id[] locations);


    /**
     *  Removes the locations. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocations();


    /**
     *  Gets the <code> StockFormRecord </code> corresponding to the given 
     *  stock record <code> Type. </code> 
     *
     *  @param  stockRecordType a stock record type 
     *  @return the stock form record 
     *  @throws org.osid.NullArgumentException <code> stockRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(stockRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.StockFormRecord getStockFormRecord(org.osid.type.Type stockRecordType)
        throws org.osid.OperationFailedException;
}
