//
// org.osid.inventory.StockNotificationSession
//
//     The OSID Java specification for org.osid.inventory.StockNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Stock </code> objects in this <code> Warehouse. </code> This 
 *  also includes existing stocks that may appear or disappear due to changes 
 *  in the <code> Warehouse </code> hierarchy, This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> StockLookupSession. </code> </p>
 */

public interface StockNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Warehouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Warehouse Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWarehouseId();


    /**
     *  Gets the <code> Warehouse </code> associated with this session. 
     *
     *  @return the warehouse 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse getWarehouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Stock </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForStockNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include stocks in catalogs which are children of this catalog in the 
     *  warehouse hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedWarehouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this warehouse only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedWarehouseView();


    /**
     *  Register for notifications of new stocks. <code> 
     *  StockReceiver.newStocks() </code> is invoked when a new <code> Stock 
     *  </code> appears in this warehouse. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewStocks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is added to the specified 
     *  stock in the stock hierarchy. <code> StockReceiver.newAncestorStock() 
     *  </code> is invoked when the specified stock experiences an addition in 
     *  ancestry. 
     *
     *  @param  stockId the <code> Id </code> of the stock to monitor 
     *  @throws org.osid.NullArgumentException <code> stockId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewStockAncestors(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is added to the specified 
     *  stock in the stock hierarchy. <code> 
     *  StockReceiver.newStockDescendant() </code> is invoked when the 
     *  specified stock experiences an addition in descendants. 
     *
     *  @param  warehouseId the <code> Id </code> of the stock to monitor 
     *  @throws org.osid.NullArgumentException <code> stockId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewStockDescendants(org.osid.id.Id warehouseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated stocks. <code> 
     *  StockReceiver.changedStocks() </code> is invoked when a stock in this 
     *  warehouse is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedStocks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated stock. <code> 
     *  StockReceiver.changedStocks() </code> is invoked when the specified 
     *  stock in this warehouse is changed. 
     *
     *  @param  stockId the <code> Id </code> of the <code> Stock </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedStock(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted stocks. <code> 
     *  StockReceiver.deletedStocks() </code> is invoked when a stock is 
     *  deleted or removed from this warehouse. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedStocks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted stock. <code> 
     *  StockReceiver.deletedStocks() </code> is invoked when the specified 
     *  stock is deleted or removed from this warehouse. 
     *
     *  @param  stockId the <code> Id </code> of the <code> Stock </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedStock(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if an ancestor is removed from the 
     *  specified stock in the stock hierarchy. <code> 
     *  StockReceiver.newAncestorStock() </code> is invoked when the specified 
     *  stock experiences a removal in ancestry. 
     *
     *  @param  stockId the <code> Id </code> of the stock to monitor 
     *  @throws org.osid.NullArgumentException <code> stockId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedStockAncestors(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification if a descendant is removed from the 
     *  specified stock in the stock hierarchy. <code> 
     *  StockReceiver.newStockDescendant() </code> is invoked when the 
     *  specified stock experiences a removal in descendants. 
     *
     *  @param  warehouseId the <code> Id </code> of the stock to monitor 
     *  @throws org.osid.NullArgumentException <code> stockId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedStockDescendants(org.osid.id.Id warehouseId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
