//
// org.osid.inventory.StockReceiver
//
//     The OSID Java specification for org.osid.inventory.StockReceiver.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>The stock receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted stock objects. </p>
 */

public interface StockReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new stocks. 
     *
     *  @param  stockIds the <code> Ids </code> of the new <code> Stocks 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newStocks(org.osid.id.IdList stockIds);


    /**
     *  The callback for notifications of new stock ancestors. 
     *
     *  @param  stockId the <code> Id </code> of the <code> Stock </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Stock 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorStock(org.osid.id.Id stockId, 
                                 org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new stock descendants. 
     *
     *  @param  stockId the <code> Id </code> of the <code> Stock </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Stock 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantStock(org.osid.id.Id stockId, 
                                   org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated stocks. 
     *
     *  @param  stockIds the <code> Ids </code> of the updated <code> Stocks 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedStocks(org.osid.id.IdList stockIds);


    /**
     *  The callback for notification of deleted stocks. 
     *
     *  @param  stockIds the <code> Ids </code> of the deleted <code> Stocks 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedStocks(org.osid.id.IdList stockIds);


    /**
     *  The callback for notifications of deleted stock ancestors. 
     *
     *  @param  stockId the <code> Id </code> of the <code> Stock </code> 
     *  @param  ancestorId the <code> Id </code> of the removed <code> Stock 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorStock(org.osid.id.Id stockId, 
                                     org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted stock descendants. 
     *
     *  @param  stockId the <code> Id </code> of the <code> Stock </code> 
     *  @param  descendantId the <code> Id </code> of the removed <code> Stock 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantStock(org.osid.id.Id stockId, 
                                       org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a stock hierarchy where 
     *  the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredStockHierarchy();
}
