//
// org.osid.inventory.StockSearchSession
//
//     The OSID Java specification for org.osid.inventory.StockSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session provides methods for searching among <code> Stock </code> 
 *  objects. The search query is constructed using the <code> StockQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getStocksByQuery() </code> is the basic search method and 
 *  returns a list of <code> Stocks. </code> A more advanced search may be 
 *  performed with <code> getStocksBySearch(). </code> It accepts a <code> 
 *  StockSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getStocksBySearch() </code> returns a <code> StockSearchResults </code> 
 *  that can be used to access the resulting <code> StockList </code> or be 
 *  used to perform a search within the result set through <code> StockSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated warehouse view: searches include stocks in warehouses 
 *      of which this warehouse is an ancestor in the warehouse hierarchy 
 *      </li> 
 *      <li> isolated warehouse view: searches are restricted to stocks in 
 *      this warehouse </li> 
 *  </ul>
 *  
 *  
 *  <p> Stocks may have a query record indicated by their respective record 
 *  types. The queryrecord is accessed via the <code> StockQuery. </code> </p>
 */

public interface StockSearchSession
    extends org.osid.inventory.StockQuerySession {


    /**
     *  Gets a stock search. 
     *
     *  @return the stock search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.StockSearch getStockSearch();


    /**
     *  Gets a stock search order. The <code> StockSearchOrder </code> is 
     *  supplied to a <code> StockSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the stock search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.StockSearchOrder getStockSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  stockQuery the stock query 
     *  @param  stockSearch the stock search 
     *  @return the stock search results 
     *  @throws org.osid.NullArgumentException <code> stockQuery </code> or 
     *          <code> stockSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stockQuery </code> or 
     *          <code> stockSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.StockSearchResults getStocksBySearch(org.osid.inventory.StockQuery stockQuery, 
                                                                   org.osid.inventory.StockSearch stockSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a stock query from an inspector. The inspector is available from 
     *  a <code> StockSearchResults. </code> 
     *
     *  @param  stockQueryInspector a stock query inspector 
     *  @return the stock query 
     *  @throws org.osid.NullArgumentException <code> stockQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> stockQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.StockQuery getStockQueryFromInspector(org.osid.assessment.ItemQueryInspector stockQueryInspector);
}
