//
// org.osid.inventory.WarehouseQuery
//
//     The OSID Java specification for org.osid.inventory.WarehouseQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This is the query for searching warehouses. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface WarehouseQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the item <code> Id </code> for this query. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears the item <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if an <code> ItemQuery </code> is available. 
     *
     *  @return <code> true </code> if an item query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for an item. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the item query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ItemQuery getItemQuery();


    /**
     *  Matches warehouses that have any item. 
     *
     *  @param  match <code> true </code> to match warehouses with any item, 
     *          <code> false </code> to match warehouses with no items 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears the item query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Sets the catalog <code> Id </code> for this query. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStockId(org.osid.id.Id stockId, boolean match);


    /**
     *  Clears the stock <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockIdTerms();


    /**
     *  Tests if a <code> StockQuery </code> is available. 
     *
     *  @return <code> true </code> if a stock query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStockQuery();


    /**
     *  Gets the query for a stock. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the stock query 
     *  @throws org.osid.UnimplementedException <code> supportsStockQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.StockQuery getStockQuery();


    /**
     *  Matches warehouses that have any stock. 
     *
     *  @param  match <code> true </code> to match courses with any stock, 
     *          <code> false </code> to match courses with no stock 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyStock(boolean match);


    /**
     *  Clears the stock query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStockTerms();


    /**
     *  Sets the model <code> Id </code> for this query. 
     *
     *  @param  modelId a model <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> modelId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchModelId(org.osid.id.Id modelId, boolean match);


    /**
     *  Clears the model <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelIdTerms();


    /**
     *  Tests if a <code> ModelQuery </code> is available. 
     *
     *  @return <code> true </code> if a model query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsModelQuery();


    /**
     *  Gets the query for an inventory. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the model query 
     *  @throws org.osid.UnimplementedException <code> supportsModelQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.ModelQuery getModelQuery();


    /**
     *  Matches any related model. 
     *
     *  @param  match <code> true </code> to match warehouses with any model, 
     *          <code> false </code> to match warehouses with no models 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyModel(boolean match);


    /**
     *  Clears the model terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearModelTerms();


    /**
     *  Sets the inventory <code> Id </code> for this query. 
     *
     *  @param  itemId an inventory <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> inventoryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInventoryId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears the inventory <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInventoryIdTerms();


    /**
     *  Tests if an <code> InventoryQuery </code> is available. 
     *
     *  @return <code> true </code> if an inventory query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryQuery();


    /**
     *  Gets the query for an inventory. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the inventory query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryQuery() </code> is <code> true. </code> 
     */

    public org.osid.inventory.InventoryQuery getInventoryQuery();


    /**
     *  Matches warehouses that have any inventory. 
     *
     *  @param  match <code> true </code> to match warehouses with any 
     *          inventory, <code> false </code> to match warehouses with no 
     *          inventories 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInventory(boolean match);


    /**
     *  Clears the inventory query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInventoryTerms();


    /**
     *  Sets the warehouse <code> Id </code> for this query to match 
     *  warehouses that have the specified warehouse as an ancestor. 
     *
     *  @param  warehouseId a warehouse <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorWarehouseId(org.osid.id.Id warehouseId, 
                                         boolean match);


    /**
     *  Clears the ancestor warehouse <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorWarehouseIdTerms();


    /**
     *  Tests if a <code> WarehouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a warehouse query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorWarehouseQuery();


    /**
     *  Gets the query for a warehouse. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the warehouse query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorWarehouseQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorWarehouseQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.WarehouseQuery getAncestorWarehouseQuery();


    /**
     *  Matches warehouses with any warehouse ancestor. 
     *
     *  @param  match <code> true </code> to match warehouses with any 
     *          ancestor, <code> false </code> to match root warehouses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorWarehouse(boolean match);


    /**
     *  Clears the ancestor warehouse query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorWarehouseTerms();


    /**
     *  Sets the warehouse <code> Id </code> for this query to match 
     *  warehouses that have the specified warehouse as an descendant. 
     *
     *  @param  warehouseId a warehouse <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantWarehouseId(org.osid.id.Id warehouseId, 
                                           boolean match);


    /**
     *  Clears the descendant warehouse <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantWarehouseIdTerms();


    /**
     *  Tests if a <code> WarehouseQuery </code> is available. 
     *
     *  @return <code> true </code> if a warehouse query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantWarehouseQuery();


    /**
     *  Gets the query for a warehouse. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the warehouse query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantWarehouseQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantWarehouseQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.WarehouseQuery getDescendantWarehouseQuery();


    /**
     *  Matches warehouses with any descendant warehouse. 
     *
     *  @param  match <code> true </code> to match warehouses with any 
     *          descendant, <code> false </code> to match leaf warehouses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantWarehouse(boolean match);


    /**
     *  Clears the descendant warehouse query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantWarehouseTerms();


    /**
     *  Gets the warehouse query record corresponding to the given <code> 
     *  Warehouse </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  warehouseRecordType a warehouse record type 
     *  @return the warehouse query record 
     *  @throws org.osid.NullArgumentException <code> warehouseRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(warehouseRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.records.WarehouseQueryRecord getWarehouseQueryRecord(org.osid.type.Type warehouseRecordType)
        throws org.osid.OperationFailedException;
}
