//
// org.osid.inventory.WarehouseSearchSession
//
//     The OSID Java specification for org.osid.inventory.WarehouseSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory;


/**
 *  <p>This session provides methods for searching among <code> Warehouse 
 *  </code> objects. The search query is constructed using the <code> 
 *  WarehouseQuery. </code> </p> 
 *  
 *  <p> <code> getWarehousesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Warehouses. </code> A more advanced search may be 
 *  performed with <code> getWarehousesBySearch(). </code> It accepts a <code> 
 *  WarehouseSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getWarehousesBySearch() </code> returns a <code> 
 *  WarehouseSearchResults </code> that can be used to access the resulting 
 *  <code> WarehouseList </code> or be used to perform a search within the 
 *  result set through <code> Warehousesearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated warehouse view: searches include warehouses in 
 *      warehouses of which this warehouse is an ancestor in the warehouse 
 *      hierarchy </li> 
 *      <li> isolated warehouse view: searches are restricted to warehouses in 
 *      this warehouse </li> 
 *  </ul>
 *  
 *  
 *  <p> warehouses may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> WarehouseQuery. 
 *  </code> </p>
 */

public interface WarehouseSearchSession
    extends org.osid.inventory.WarehouseQuerySession {


    /**
     *  Gets a warehouse search. 
     *
     *  @return the warehouse search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseSearch getWarehouseSearch();


    /**
     *  Gets a warehouse search order. The <code> WarehouseSearchOrder </code> 
     *  is supplied to a <code> WarehouseSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the warehouse search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseSearchOrder getWarehouseSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  warehouseQuery the warehouse query 
     *  @param  warehouseSearch the warehouse search 
     *  @return the warehouse search results 
     *  @throws org.osid.NullArgumentException <code> warehouseQuery </code> 
     *          or <code> warehouseSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> warehouseQuery </code> or 
     *          <code> warehouseSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseSearchResults getWarehousesBySearch(org.osid.inventory.WarehouseQuery warehouseQuery, 
                                                                           org.osid.inventory.WarehouseSearch warehouseSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a warehouse query from an inspector. The inspector is available 
     *  from a <code> WarehousesearchResults. </code> 
     *
     *  @param  warehouseQueryInspector a warehouse query inspector 
     *  @return the warehouse query 
     *  @throws org.osid.NullArgumentException <code> warehouseQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> warehouseQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.WarehouseQuery getWarehouseQueryFromInspector(org.osid.inventory.WarehouseQueryInspector warehouseQueryInspector);
}
