//
// org.osid.inventory.batch.InventoryBatchManager
//
//     The OSID Java specification for org.osid.inventory.batch.InventoryBatchManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.batch;


/**
 *  <p>The inventory batch manager provides access to inventory batch sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ItemBatchAdminSession: </code> a session to create, modify 
 *      and delete items in bulk </li> 
 *      <li> <code> StockBatchSession: </code> a session to create, modify and 
 *      delete stocks in bulk </li> 
 *      <li> <code> ModelBatchAdminSession: </code> a session to create, 
 *      modify and delete models in bulk </li> 
 *      <li> <code> InventoryBatchAdminSession: </code> a session to create, 
 *      modify and delete inventories in bulk </li> 
 *  </ul>
 *  
 */

public interface InventoryBatchManager
    extends org.osid.OsidManager,
            org.osid.inventory.batch.InventoryBatchProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk item 
     *  administration service. 
     *
     *  @return an <code> ItemBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.batch.ItemBatchAdminSession getItemBatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk item 
     *  administration service for the given inventory. 
     *
     *  @param  inventoryId the <code> Id </code> of the <code> Inventory 
     *          </code> 
     *  @return an <code> ItemBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inventory </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inventoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsItemBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.batch.ItemBatchAdminSession getItemBatchAdminSessionForInventory(org.osid.id.Id inventoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk stock 
     *  administration service. 
     *
     *  @return a <code> StockBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.batch.StockBatchAdminSession getStockBatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk stock 
     *  administration service for the given inventory. 
     *
     *  @param  inventoryId the <code> Id </code> of the <code> Inventory 
     *          </code> 
     *  @return a <code> StockBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inventory </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inventoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStockBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStockBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.batch.StockBatchAdminSession getStockBatchAdminSessionForInventory(org.osid.id.Id inventoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk model 
     *  administration service. 
     *
     *  @return an <code> ModelBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModelBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.inventory.batch.ModelBatchAdminSession getModelBatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk model 
     *  administration service for the given inventory. 
     *
     *  @param  inventoryId the <code> Id </code> of the <code> Inventory 
     *          </code> 
     *  @return an <code> ModelBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Inventory </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> inventoryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsModelBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsModelBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.inventory.batch.ModelBatchAdminSession getModelBatchAdminSessionForInventory(org.osid.id.Id inventoryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk inventory 
     *  administration service. 
     *
     *  @return an <code> InventoryBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInventoryBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInventoryBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inventory.batch.InventoryBatchAdminSession getInventoryBatchAdminSession()
        throws org.osid.OperationFailedException;
}
