//
// org.osid.inventory.batch.ModelBatchAdminSession
//
//     The OSID Java specification for org.osid.inventory.batch.ModelBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Models </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Model, </code> a <code> ModelForm </code> is requested using <code> 
 *  getModelFormsForCreate() </code> specifying the desired stock, resource, 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> ModelForms </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> ModelForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ModelForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ModelForms </code> returned from <code> 
 *  getModelFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> ModelForm. </code> In 
 *  the case where there may be duplicates, any <code> ModelForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ModelForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> ModelForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createModels(), 
 *  </code> errors specific to an individual <code> ModelForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> ModelForm 
 *  </code> through the <code> ModelForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ModelForms </code> are requested to the <code> 
 *  Model </code> <code> Id </code> that is to be updated using <code> 
 *  getModelFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> ModelForm </code> may be used to link the request. Similarly, 
 *  the <code> ModelForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> ModelForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ModelForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> ModelForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateModels(), 
 *  </code> errors specific to an individual <code> ModelForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> ModelForm 
 *  </code> through the <code> ModelForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Models </code> in bulk. To unmap a 
 *  <code> Model </code> from the current <code> Inventory, </code> the <code> 
 *  ModelInventoryAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Model </code> itself thus removing 
 *  it from all known <code> Inventory </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface ModelBatchAdminSession
    extends org.osid.inventory.ModelAdminSession {


    /**
     *  Gets the model forms for creating a bunch of new models. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  modelRecordTypes array of model record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the model forms 
     *  @throws org.osid.NullArgumentException <code> modelRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.batch.ModelBatchFormList getModelFormsForCreate(long number, 
                                                                              org.osid.type.Type[] modelRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Models. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  modelForms the model forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> modelForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createModels(org.osid.inventory.batch.ModelBatchFormList modelForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the model forms for updating an existing set of models. A new 
     *  model form should be requested for each update transaction. 
     *
     *  @param  modelIds the <code> Ids </code> of the <code> Model </code> 
     *  @return the model form 
     *  @throws org.osid.NotFoundException a <code> modelId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> modelIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.batch.ModelBatchFormList getModelFormsForUpdate(org.osid.id.IdList modelIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing models. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  modelForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> modelForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateModels(org.osid.inventory.batch.ModelBatchFormList modelForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Models </code> in this <code> Inventory </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllModels()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes models for the given <code> Ids. </code> 
     *
     *  @param  modelIds the <code> Ids </code> of the models to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> modelIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteModels(org.osid.id.IdList modelIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes models for the given resource. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteModelsForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes models for the given stock. 
     *
     *  @param  stockId an <code> Id </code> of a stock 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteModelsForStock(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes models expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveModelsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Model </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Model </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another model, it is reassigned to the given model <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasModels(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
