//
// org.osid.inventory.batch.StockBatchAdminSession
//
//     The OSID Java specification for org.osid.inventory.batch.StockBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Stocks </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Stock, </code> a <code> StockForm </code> is requested using <code> 
 *  getStockFormsForCreate() </code> specifying the desired work, resource, 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. Each of the returned <code> StockForms </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> StockForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> StockForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> StockForms </code> returned from <code> 
 *  getStockFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> StockForm. </code> In 
 *  the case where there may be duplicates, any <code> StockForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> StockForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> StockForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createStocks(), 
 *  </code> errors specific to an individual <code> StockForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> StockForm 
 *  </code> through the <code> StockForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> StockForms </code> are requested to the <code> 
 *  Stock </code> <code> Id </code> that is to be updated using <code> 
 *  getStockFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> StockForm </code> may be used to link the request. Similarly, 
 *  the <code> StockForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> StockForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> StockForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> StockForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateStocks(), 
 *  </code> errors specific to an individual <code> StockForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> StockForm 
 *  </code> through the <code> StockForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Stocks </code> in bulk. To unmap a 
 *  <code> Stock </code> from the current <code> Inventory, </code> the <code> 
 *  StockInventoryAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Stock </code> itself thus removing 
 *  it from all known <code> Inventory </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface StockBatchAdminSession
    extends org.osid.inventory.StockAdminSession {


    /**
     *  Gets the stock forms for creating a bunch of new stocks. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  stockRecordTypes array of stock record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the stock forms 
     *  @throws org.osid.NullArgumentException <code> stockRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.batch.StockBatchFormList getStockFormsForCreate(long number, 
                                                                              org.osid.type.Type[] stockRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Stocks. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  stockForms the stock forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> stockForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createStocks(org.osid.inventory.batch.StockBatchFormList stockForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the stock forms for updating an existing set of stocks. A new 
     *  stock form should be requested for each update transaction. 
     *
     *  @param  stockIds the <code> Ids </code> of the <code> Stock </code> 
     *  @return the stock form 
     *  @throws org.osid.NotFoundException a <code> stockId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> stockIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.batch.StockBatchFormList getStockFormsForUpdate(org.osid.id.IdList stockIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing stocks. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  stockForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> stockForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateStocks(org.osid.inventory.batch.StockBatchFormList stockForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Stocks </code> in this <code> Inventory </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllStocks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes stocks for the given <code> Ids. </code> 
     *
     *  @param  stockIds the <code> Ids </code> of the stocks to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> stockIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteStocks(org.osid.id.IdList stockIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Stock </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Stock </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another stock, it is reassigned to the given stock <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasStocks(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
