//
// org.osid.inventory.shipment.ShipmentForm
//
//     The OSID Java specification for org.osid.inventory.shipment.ShipmentForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment;


/**
 *  <p>This is the form for creating and updating <code> Shipments. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ShipmentAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ShipmentForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidAggregateableForm {


    /**
     *  Gets the metadata for a source. 
     *
     *  @return metadata for the source 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSourceMetadata();


    /**
     *  Sets the source. 
     *
     *  @param  resourceId the new source 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSource(org.osid.id.Id resourceId);


    /**
     *  Removes the source. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSource();


    /**
     *  Gets the metadata for an odrer. 
     *
     *  @return metadata for the order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOrderMetadata();


    /**
     *  Sets the order. 
     *
     *  @param  orderId the new order 
     *  @throws org.osid.InvalidArgumentException <code> orderId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> orderId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOrder(org.osid.id.Id orderId);


    /**
     *  Removes the order. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrder();


    /**
     *  Gets the metadata for the shipment date. 
     *
     *  @return metadata for the date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDateMetadata();


    /**
     *  Sets the date. 
     *
     *  @param  date the new date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDate();


    /**
     *  Gets the <code> ShipmentFormRecord </code> corresponding to the given 
     *  shipment record <code> Type. </code> 
     *
     *  @param  shipmentRecordType a shipment record type 
     *  @return the shipment form record 
     *  @throws org.osid.NullArgumentException <code> shipmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(shipmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.records.ShipmentFormRecord getShipmentFormRecord(org.osid.type.Type shipmentRecordType)
        throws org.osid.OperationFailedException;
}
