//
// org.osid.inventory.shipment.ShipmentLookupSession
//
//     The OSID Java specification for org.osid.inventory.shipment.ShipmentLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment;


/**
 *  <p>This session defines methods for retrieving shipments. A <code> 
 *  Shipment </code> is a <code> Resource </code> related to the billing 
 *  system. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated warehouse view: All shipment methods in this session 
 *      operate, retrieve and pertain to shipments defined explicitly in the 
 *      current warehouse. Using an isolated view is useful for managing 
 *      <code> Shipments </code> with the <code> ShipmentAdminSession. </code> 
 *      </li> 
 *      <li> federated warehouse view: All shipment lookup methods in this 
 *      session operate, retrieve and pertain to all shipments defined in this 
 *      warehouse and any other shipments implicitly available in this 
 *      warehouse through warehouse inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedWarehouseView() </code> and <code> 
 *  useIsolatedWarehouseView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Shipments may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Shipment. </code> </p>
 */

public interface ShipmentLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Warehouse </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Warehouse Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWarehouseId();


    /**
     *  Gets the <code> Warehouse </code> associated with this session. 
     *
     *  @return the warehouse 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.Warehouse getWarehouse()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Shipment </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupShipments();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeShipmentView();


    /**
     *  A complete view of the <code> Shipment </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryShipmentView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include shipments in catalogs which are children of this catalog in 
     *  the warehouse hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedWarehouseView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this warehouse only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedWarehouseView();


    /**
     *  Gets the <code> Shipment </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Shipment </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Shipment </code> and retained for compatibility. 
     *
     *  @param  shipmentId the <code> Id </code> of the <code> Shipment 
     *          </code> to retrieve 
     *  @return the returned <code> Shipment </code> 
     *  @throws org.osid.NotFoundException no <code> Shipment </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> shipmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.Shipment getShipment(org.osid.id.Id shipmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  shipments specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Shipments </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  shipmentIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> shipmentIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsByIds(org.osid.id.IdList shipmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> corresponding to the given shipment 
     *  genus <code> Type </code> which does not include shipments of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  shipments or an error results. Otherwise, the returned list may 
     *  contain only those shipments that are accessible through this session. 
     *
     *  @param  shipmentGenusType a shipment genus type 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.NullArgumentException <code> shipmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsByGenusType(org.osid.type.Type shipmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> corresponding to the given shipment 
     *  genus <code> Type </code> and include any additional shipments with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  shipments or an error results. Otherwise, the returned list may 
     *  contain only those shipments that are accessible through this session. 
     *  
     *  In effective mode, shipments are returned that are currently 
     *  effective. In any effective mode, effective shipments and those 
     *  currently expired are returned. 
     *
     *  @param  shipmentGenusType a shipment genus type 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.NullArgumentException <code> shipmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsByParentGenusType(org.osid.type.Type shipmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> containing the given shipment 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known shipments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  shipments that are accessible through this session. 
     *
     *  @param  shipmentRecordType a shipment record type 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.NullArgumentException <code> shipmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsByRecordType(org.osid.type.Type shipmentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> received between the given date 
     *  range inclusive. 
     *  
     *  In plenary mode, the returned list contains all known shipments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  shipments that are accessible through this session. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsOnDate(org.osid.calendaring.DateTime from, 
                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> for to the given stock. 
     *  
     *  In plenary mode, the returned list contains all known shipments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  shipments that are accessible through this session. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.NullArgumentException <code> stockId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsForStock(org.osid.id.Id stockId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> for the given stock and received 
     *  between the given date range inclusive . 
     *  
     *  In plenary mode, the returned list contains all known shipments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  shipments that are accessible through this session. 
     *
     *  @param  stockId a stock <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> stockId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsForStockOnDate(org.osid.id.Id stockId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> from to the given source. 
     *  
     *  In plenary mode, the returned list contains all known shipments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  shipments that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsBySource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ShipmentList </code> from the given source and received 
     *  between the given date range inclusive . 
     *  
     *  In plenary mode, the returned list contains all known shipments or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  shipments that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> ShipmentList </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipmentsBySourceOnDate(org.osid.id.Id resourceId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Shipments. </code> In plenary mode, the returned list 
     *  contains all known shipments or an error results. Otherwise, the 
     *  returned list may contain only those shipments that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Shipments </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inventory.shipment.ShipmentList getShipments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
