//
// org.osid.inventory.shipment.ShipmentWarehouseAssignmentSession
//
//     The OSID Java specification for org.osid.inventory.shipment.ShipmentWarehouseAssignmentSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.inventory.shipment;


/**
 *  <p>This session provides methods to re-assign <code> Shipments </code> to 
 *  <code> Warehouse </code> objects A <code> Shipment </code> may appear in 
 *  multiple <code> Warehouse </code> objects and removing the last reference 
 *  to a <code> Shipment </code> is the equivalent of deleting it. Each <code> 
 *  Warehouse </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Shipment </code> to another <code> 
 *  Warehouse </code> is not a copy operation (eg: does not change its <code> 
 *  Id </code> ). </p>
 */

public interface ShipmentWarehouseAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter shipment/warehouse mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignShipments();


    /**
     *  Tests if this user can alter shipment/warehouse mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignShipmentToWarehouse(org.osid.id.Id warehouseId);


    /**
     *  Gets a list of warehouses including and under the given warehouse node 
     *  in which any shipment can be assigned. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @return list of assignable warehouse <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableWarehouseIds(org.osid.id.Id warehouseId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of warehouses including and under the given warehouse node 
     *  in which a specific shipment can be assigned. 
     *
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @param  shipmentId the <code> Id </code> of the <code> Shipment 
     *          </code> 
     *  @return list of assignable warehouse <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> warehouseId </code> or 
     *          <code> shipmentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableWarehouseIdsForShipment(org.osid.id.Id warehouseId, 
                                                                   org.osid.id.Id shipmentId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Shipment </code> to a <code> Warehouse. 
     *  </code> 
     *
     *  @param  shipmentId the <code> Id </code> of the <code> Shipment 
     *          </code> 
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> shipmentId </code> is 
     *          already assigned to <code> warehouseId </code> 
     *  @throws org.osid.NotFoundException <code> shipmentId </code> or <code> 
     *          warehouseId </code> not found 
     *  @throws org.osid.NullArgumentException <code> shipmentId </code> or 
     *          <code> warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignShipmentToWarehouse(org.osid.id.Id shipmentId, 
                                          org.osid.id.Id warehouseId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Shipment </code> from a <code> Warehouse. </code> 
     *
     *  @param  shipmentId the <code> Id </code> of the <code> Shipment 
     *          </code> 
     *  @param  warehouseId the <code> Id </code> of the <code> Warehouse 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> shipmentId </code> or <code> 
     *          warehouseId </code> not found or <code> shipmentId </code> not 
     *          assigned to <code> warehouseId </code> 
     *  @throws org.osid.NullArgumentException <code> shipmentId </code> or 
     *          <code> warehouseId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignShipmentFromWarehouse(org.osid.id.Id shipmentId, 
                                              org.osid.id.Id warehouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> Shipment </code> from one <code> Warehouse </code> to 
     *  another. Mappings to other <code> Warehouses </code> are unaffected. 
     *
     *  @param  shipmentId the <code> Id </code> of the <code> Shipment 
     *          </code> 
     *  @param  fromWarehouseId the <code> Id </code> of the current <code> 
     *          Warehouse </code> 
     *  @param  toWarehouseId the <code> Id </code> of the destination <code> 
     *          Warehouse </code> 
     *  @throws org.osid.NotFoundException <code> shipmentId, fromWarehouseId, 
     *          </code> or <code> toWarehouseId </code> not found or <code> 
     *          shipmentId </code> not mapped to <code> fromWarehouseId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> shipmentId, 
     *          fromWarehouseId, </code> or <code> toWarehouseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignShipmentToWarehouse(org.osid.id.Id shipmentId, 
                                            org.osid.id.Id fromWarehouseId, 
                                            org.osid.id.Id toWarehouseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
