//
// org.osid.journaling.BranchAdminSession
//
//     The OSID Java specification for org.osid.journaling.BranchAdminSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session creates, updates, and deletes <code> Branches. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Branch, </code> a <code> BranchForm </code> is requested using <code> 
 *  getBranchFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> BranchForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> BranchForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> BranchForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> BranchForms </code> are requested to the <code> 
 *  Branch </code> <code> Id </code> that is to be updated using <code> 
 *  getBranchFormForUpdate(). </code> Similarly, the <code> BranchForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> BranchForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Branches. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface BranchAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Journal </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Journal Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJournalId();


    /**
     *  Gets the <code> Journal </code> associated with this session. 
     *
     *  @return the journal 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Journal getJournal()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can branch a version chain. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known branching will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may not wish 
     *  to offer create operations to unauthorized users. 
     *
     *  @return <code> false </code> if journal branching is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBranches();


    /**
     *  Tests if this user can branch a specified <code> JournalEntry. </code> 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known branching the <code> JournalEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not wish to offer update 
     *  operations to unauthorized users. 
     *
     *  @param  journalEntryId the <code> Id </code> of the <code> 
     *          JournalEntry </code> 
     *  @return <code> false </code> if branching is not authorized, <code> 
     *          true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> journalEntryId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of branching 
     *          available. 
     */

    public boolean canCreateBranch(org.osid.id.Id journalEntryId);


    /**
     *  Tests if this user can create a single <code> Branch </code> using the 
     *  desired record types. While <code> 
     *  JournalingManager.getBranchRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Branch. </code> Providing 
     *  an empty array tests if a <code> Branch </code> can be created with no 
     *  records. 
     *
     *  @param  branchRecordTypes array of branch record types 
     *  @return <code> true </code> if <code> Branch </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> branchyRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBranchWithRecordTypes(org.osid.type.Type[] branchRecordTypes);


    /**
     *  Gets the branch form for creating new entries. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  journalEntryId the <code> Id </code> of the <code> 
     *          JournalEntry </code> 
     *  @param  branchRecordTypes array of branch record types 
     *  @return the branch form 
     *  @throws org.osid.NotFoundException <code> journalEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          or <code> branchRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchForm getBranchFormForCreate(org.osid.id.Id journalEntryId, 
                                                                 org.osid.type.Type[] branchRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a branch. 
     *
     *  @param  branchForm the branch form 
     *  @return a the new branch 
     *  @throws org.osid.IllegalStateException <code> branchForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> branchForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> branchForm </code> did 
     *          not originate from <code> getBranchFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Branch createBranch(org.osid.journaling.BranchForm branchForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update branches. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Branch </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Branch </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateBranches();


    /**
     *  Gets the branch form for updating an existing branch. A new journal 
     *  entry form should be requested for each update transaction. 
     *
     *  @param  branchId the <code> Id </code> of the <code> Branch </code> 
     *  @return the branch form 
     *  @throws org.osid.NotFoundException <code> branchId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.BranchForm getBranchFormForUpdate(org.osid.id.Id branchId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing branch. 
     *
     *  @param  branchForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> branchForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> branchForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> branchForm </code> did 
     *          not originate from <code> getBranchFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateBranch(org.osid.journaling.BranchForm branchForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can merge branches. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known merging <code> Branches </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer merging operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Branch </code> merging is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canMergeBranches();


    /**
     *  Merges the source branch into the destination branch. A new journal 
     *  entry is created to join the two branches. 
     *
     *  @param  srcBranchId the <code> Id </code> of the <code> Branch </code> 
     *          to merge from 
     *  @param  dstBranchId the <code> Id </code> of the <code> Branch </code> 
     *          to merge into 
     *  @return a the new journal entry 
     *  @throws org.osid.NotFoundException <code> branchId </code> not found 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntry mergeBranches(org.osid.id.Id srcBranchId, 
                                                          org.osid.id.Id dstBranchId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can supersede branches. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known merging <code> Branches </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer superseding operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Branch </code> superseding is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSupersedeBranches();


    /**
     *  Joins the source branch to the destination branch by creating a new 
     *  journal entry. The most recent version of the source branch supsrsedes 
     *  the most recent versiuon of the desitination branch. 
     *
     *  @param  srcBranchId the <code> Id </code> of the superseding <code> 
     *          Branch </code> 
     *  @param  dstBranchId the <code> Id </code> of the <code> Branch </code> 
     *          to override 
     *  @return a the new journal entry 
     *  @throws org.osid.NotFoundException <code> branchId </code> not found 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntry supersedeBranch(org.osid.id.Id srcBranchId, 
                                                            org.osid.id.Id dstBranchId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete branches. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> Branch </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Branch </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteBranches();


    /**
     *  Deletes a branch and all associated versions. 
     *
     *  @param  branchId the <code> Id </code> of the <code> Branch </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> branchId </code> not found 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteBranch(org.osid.id.Id branchId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for branches. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known changing an alias will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Branch </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageBranchAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Branch </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Branch </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another branch it is reassigned to the given 
     *  branch <code> Id. </code> 
     *
     *  @param  branchId the <code> Id </code> of a <code> Branch </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> branchId </code> not found 
     *  @throws org.osid.NullArgumentException <code> branchId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasBranch(org.osid.id.Id branchId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
