//
// org.osid.journaling.BranchQueryInspector
//
//     The OSID Java specification for org.osid.journaling.BranchQueryInspector.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This is the query inspector for examining branch queries. </p>
 */

public interface BranchQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidOperableQueryInspector {


    /**
     *  Gets the origin journal entry <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getOriginJournalEntryIdTerms();


    /**
     *  Gets the origin journal entry query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryQueryInspector[] getOriginJournalEntryTerms();


    /**
     *  Gets the latest journal entry <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLatestJournalEntryIdTerms();


    /**
     *  Gets the latest journal entry query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryQueryInspector[] getLatestJournalEntryTerms();


    /**
     *  Gets the branch query inspector record corresponding to the given 
     *  <code> Branch </code> record <code> Type. </code> 
     *
     *  @param  branchRecordType a branch record type 
     *  @return the branch query inspector record 
     *  @throws org.osid.NullArgumentException <code> branchRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(branchRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.records.BranchQueryInspectorRecord getBranchQueryInspectorRecord(org.osid.type.Type branchRecordType)
        throws org.osid.OperationFailedException;
}
