//
// org.osid.journaling.JournalEntryLookupSession
//
//     The OSID Java specification for org.osid.journaling.JournalEntryLookupSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session defines methods for retrieving journal entries. A <code> 
 *  JournalEntry </code> is a version entry for an OSID <code> Id. </code> 
 *  </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated journal view: All journal entry methods in this session 
 *      operate, retrieve and pertain to journal entries defined explicitly in 
 *      the current journal. Using an isolated view is useful for managing 
 *      journal entries with the <code> JournalEntryAdminSession. </code> 
 *      </li> 
 *      <li> federated journal view: All journal entry lookup methods in this 
 *      session operate, retrieve and pertain to all journal entries defined 
 *      in this journal and any other journals implicitly available in this 
 *      journal through journal inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedJournalView() </code> and <code> 
 *  useIsolatedJournalView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface JournalEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Journal </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Journal Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJournalId();


    /**
     *  Gets the <code> Journal </code> associated with this session. 
     *
     *  @return the journal 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Journal getJournal()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this journal. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if journal reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canReadJournal();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeJournalEntryView();


    /**
     *  A complete view of the <code> JournalEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryJournalEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in journals which are children of this journal in the 
     *  journal hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedJournalView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this journal only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedJournalView();


    /**
     *  Gets the <code> JournalEntry </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  JournalEntry </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> JournalEntry </code> and retained for 
     *  compatibility. 
     *
     *  @param  journalEntryId the <code> Id </code> of the <code> 
     *          JournalEntry </code> to retrieve 
     *  @return the returned <code> JournalEntry </code> 
     *  @throws org.osid.NotFoundException no <code> JournalEntry </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntry getJournalEntry(org.osid.id.Id journalEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JournalEntryList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the entries specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible entries may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  journalEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> JournalEntry list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> journalEntryIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByIds(org.osid.id.IdList journalEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JournalEntryList </code> corresponding to the given 
     *  journal entry genus <code> Type </code> which does not include journal 
     *  entries of genus types derived from the specified <code> Type. </code> 
     *  In plenary mode, the returned list contains all known journal entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those journal entries that are accessible through this session. 
     *
     *  @param  journalEntryGenusType a journal entry genus type 
     *  @return the returned <code> JournalEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> journalEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByGenusType(org.osid.type.Type journalEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JournalEntryList </code> corresponding to the given 
     *  journal entry genus <code> Type </code> and include any additional 
     *  journal entries with genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  journal entries or an error results. Otherwise, the returned list may 
     *  contain only those journal entries that are accessible through this 
     *  session. 
     *
     *  @param  journalEntryGenusType a journal entry genus type 
     *  @return the returned <code> JournalEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> journalEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByParentGenusType(org.osid.type.Type journalEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> JournalEntryList </code> containing the given journal 
     *  entry record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known journal entries or an error results. Otherwise, the 
     *  returned list may contain only those journal entries that are 
     *  accessible through this session. 
     *
     *  @param  journalEntryRecordType a journal entry record type 
     *  @return the returned <code> JournalEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> journalEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByRecordType(org.osid.type.Type journalEntryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a branch <code> Id. 
     *  </code> In plenary mode, the returned list contains all known journal 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those journal entries that are accessible through this session. 
     *
     *  @param  branchId the <code> Id </code> of the branch 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesForBranch(org.osid.id.Id branchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the journal entry corresponding to a resource <code> Id </code> 
     *  and date. The entries returned have a date equal to or more recent 
     *  than the requested date. In plenary mode, the returned list contains 
     *  all known journal entries or an error results. Otherwise, the returned 
     *  list may contain only those journal entries that are accessible 
     *  through this session. 
     *
     *  @param  branchId the <code> Id </code> of the branch 
     *  @param  date from date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> branchId </code> or 
     *          <code> date </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateForBranch(org.osid.id.Id branchId, 
                                                                                 org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a branch <code> Id 
     *  </code> and date range. Entries are returned with dates that fall 
     *  between the requested dates inclusive. In plenary mode, the returned 
     *  list contains all known journal entries or an error results. 
     *  Otherwise, the returned list may contain only those journal entries 
     *  that are accessible through this session. 
     *
     *  @param  branchId the <code> Id </code> of the branch 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> branchId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateRangeForBranch(org.osid.id.Id branchId, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a source <code> Id. 
     *  </code> A source <code> Id </code> of any version may be requested. In 
     *  plenary mode, the returned list contains all known journal entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  journal entries that are accessible through this session. 
     *
     *  @param  sourceId the <code> Id </code> of the source 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the journal entry corresponding to a source <code> Id </code> and 
     *  date. The entry returned has a date equal to or more recent than the 
     *  requested date. The <code> sourceId </code> may correspond to any 
     *  version. In plenary mode, the returned list contains all known journal 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those journal entries that are accessible through this session. 
     *
     *  @param  sourceId a source <code> Id </code> 
     *  @param  date from date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateForSource(org.osid.id.Id sourceId, 
                                                                                 org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a source <code> Id 
     *  </code> and date range. Entries are returned with dates that fall 
     *  between the requested dates inclusive. The <code> sourceId </code> may 
     *  correspond to any version. In plenary mode, the returned list contains 
     *  all known journal entries or an error results. Otherwise, the returned 
     *  list may contain only those journal entries that are accessible 
     *  through this session. 
     *
     *  @param  sourceId a source <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> sourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateRangeForSource(org.osid.id.Id sourceId, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a branch and source 
     *  <code> Id. </code> A source <code> Id </code> of any version may be 
     *  requested. <code> </code> In plenary mode, the returned list contains 
     *  all known journal entries or an error results. Otherwise, the returned 
     *  list may contain only those journal entries that are accessible 
     *  through this session. 
     *
     *  @param  branchId the <code> Id </code> of the branch 
     *  @param  sourceId the <code> Id </code> of the source 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> branchId </code> or 
     *          <code> sourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesForBranchAndSource(org.osid.id.Id branchId, 
                                                                                    org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the journal entry corresponding to a branch and source <code> Id 
     *  </code> and date. The entry returned has a date equal to or more 
     *  recent than the requested date. The <code> sourceId </code> may 
     *  correspond to any version. In plenary mode, the returned list contains 
     *  all known journal entries or an error results. Otherwise, the returned 
     *  list may contain only those journal entries that are accessible 
     *  through this session. 
     *
     *  @param  branchId a branch <code> Id </code> 
     *  @param  sourceId the <code> Id </code> of the source 
     *  @param  date from date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> branchId, sourceId 
     *          </code> or <code> date </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateForBranchAndSource(org.osid.id.Id branchId, 
                                                                                          org.osid.id.Id sourceId, 
                                                                                          org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a branch and source 
     *  <code> Id </code> and date range. Entries are returned with dates that 
     *  fall between the requested dates inclusive. The <code> sourceId 
     *  </code> may correspond to any version In plenary mode, the returned 
     *  list contains all known journal entries or an error results. 
     *  Otherwise, the returned list may contain only those journal entries 
     *  that are accessible through this session. 
     *
     *  @param  branchId a branch <code> Id </code> 
     *  @param  sourceId the <code> Id </code> of the source 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> branchId, sourceId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateRangeForBranchAndSource(org.osid.id.Id branchId, 
                                                                                               org.osid.id.Id sourceId, 
                                                                                               org.osid.calendaring.DateTime from, 
                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a resource <code> Id. 
     *  </code> In plenary mode, the returned list contains all known journal 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those journal entries that are accessible through this session. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the journal entry corresponding to a resource <code> Id </code> 
     *  and date. The entry returned has a date equal to or more recent than 
     *  the requested date. In plenary mode, the returned list contains all 
     *  known journal entries or an error results. Otherwise, the returned 
     *  list may contain only those journal entries that are accessible 
     *  through this session. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  date from date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> date </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateForResource(org.osid.id.Id resourceId, 
                                                                                   org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of journal entries corresponding to a resource <code> Id 
     *  </code> and date range. Entries are returned with dates that fall 
     *  between the requested dates inclusive. In plenary mode, the returned 
     *  list contains all known journal entries or an error results. 
     *  Otherwise, the returned list may contain only those journal entries 
     *  that are accessible through this session. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> JournalEntryList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntriesByDateRangeForResource(org.osid.id.Id resourceId, 
                                                                                        org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all journal entries. In plenary mode, the returned list contains 
     *  all known entries or an error results. Otherwise, the returned list 
     *  may contain only those entries that are accessible through this 
     *  session. In both cases, the order of the set is not specifed. In 
     *  plenary mode, the returned list contains all known journal entries or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  journal entries that are accessible through this session. 
     *
     *  @return a list of journal entries 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryList getJournalEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
