//
// org.osid.journaling.JournalEntryNotificationSession
//
//     The OSID Java specification for org.osid.journaling.JournalEntryNotificationSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> JournalEntry </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p>
 */

public interface JournalEntryNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Journal </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Journal Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJournalId();


    /**
     *  Gets the <code> Journal </code> associated with this session. 
     *
     *  @return the journal 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.Journal getJournal()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> JournalEntry </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForJournalEntryNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for entries in journals which are children of 
     *  this journal in the journal hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedJournalView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this journal only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedJournalView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeJournalEntryNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableJournalEntryNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableJournalEntryNotifications();


    /**
     *  Acknowledge a journal entry notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeJournalEntryNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new journal entries. <code> 
     *  JournalEntryReceiver.newJournalEntries() </code> is invoked when a new 
     *  <code> JournalEntry </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewJournalEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new journal entries for the given branch 
     *  <code> Id. </code> <code> JournalEntryReceiver.newJournalEntries() 
     *  </code> is invoked when a new <code> JournalEntry </code> is created. 
     *
     *  @param  branchId the <code> Id </code> of the branch to monitor 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewJournalEntriesForBranch(org.osid.id.Id branchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new journal entries for the given source 
     *  <code> Id. </code> <code> JournalEntryReceiver.newJournalEntries() 
     *  </code> is invoked when a new <code> JournalEntry </code> is created. 
     *
     *  @param  sourceId the <code> Id </code> of the source to monitor 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewJournalEntriesForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new journal entries for the given 
     *  resource <code> Id. </code> <code> 
     *  JournalEntryReceiver.newJournalEntries() </code> is invoked when a new 
     *  <code> JournalEntry </code> is created. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewJournalEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated journal entries. <code> 
     *  JournalEntryReceiver.changedJournalEntries() </code> is invoked when a 
     *  journal entry is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedJournalEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed journal entries for the given 
     *  branch <code> Id. </code> <code> 
     *  JournalEntryReceiver.changedJournalEntries() </code> is invoked when a 
     *  <code> JournalEntry </code> for the branch is changed. 
     *
     *  @param  branchId the <code> Id </code> of the branch to monitor 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedJournalEntriesForBranch(org.osid.id.Id branchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed journal entries for the given 
     *  source <code> Id. </code> <code> 
     *  JournalEntryReceiver.changedJournalEntries() </code> is invoked when a 
     *  <code> JournalEntry </code> for the source is changed. 
     *
     *  @param  sourceId the <code> Id </code> of the source to monitor 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedJournalEntriesForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed journal entries for the given 
     *  resource <code> Id. </code> <code> 
     *  JournalEntryReceiver.changedJournalEntries() </code> is invoked when a 
     *  <code> JournalEntry </code> for the source is changed. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedJournalEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated journal entry. <code> 
     *  JournalEntryReceiver.changedJournalEntries() </code> is invoked when 
     *  the specified journal entry is changed. 
     *
     *  @param  journalEntryId the <code> Id </code> of the <code> 
     *          JournalEntry </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedJournalEntry(org.osid.id.Id journalEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted journal entries. <code> 
     *  JournalEntryReceiver.deletedJournalEntries() </code> is invoked when a 
     *  journal entry is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedJournalEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted journal entries for the given 
     *  source <code> Id. </code> <code> 
     *  JournalEntryReceiver.deletedJournalEntries() </code> is invoked when a 
     *  <code> JournalEntry </code> for the branch is deleted. 
     *
     *  @param  branchId the <code> Id </code> of the branch to monitor 
     *  @throws org.osid.NullArgumentException <code> branchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedJournalEntriesForBranch(org.osid.id.Id branchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted journal entries for the given 
     *  source <code> Id. </code> <code> 
     *  JournalEntryReceiver.deletedJournalEntries() </code> is invoked when a 
     *  <code> JournalEntry </code> for the source is deleted. 
     *
     *  @param  sourceId the <code> Id </code> of the source to monitor 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedJournalEntriesForSource(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted journal entries for the given 
     *  resource <code> Id. </code> <code> 
     *  JournalEntryReceiver.deletedJournalEntries() </code> is invoked when a 
     *  <code> JournalEntry </code> for the source is deleted. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedJournalEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted journal entry. <code> 
     *  JournalEntryReceiver.deletedJournalEntries() </code> is invoked when 
     *  the specified journal entry is deleted. 
     *
     *  @param  journalEntryId the <code> Id </code> of the <code> 
     *          JournalEntry </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> journalEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedJournalEntry(org.osid.id.Id journalEntryId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
