//
// org.osid.journaling.JournalEntrySearchSession
//
//     The OSID Java specification for org.osid.journaling.JournalEntrySearchSession.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>This session provides methods for searching <code> JournalEntry </code> 
 *  objects. The search query is constructed using the <code> 
 *  JournalEntryQuery. </code> The journal record <code> Type </code> also 
 *  specifies the record for the journal query. </p> 
 *  
 *  <p> <code> getJournalEntriesByQuery() </code> is the basic search method 
 *  and returns a list of <code> Journal </code> elements. A more advanced 
 *  search may be performed with <code> getJournalEntriesBySearch(). </code> 
 *  It accepts a <code> JournalEntrySearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getJournalEntriesBySearch() </code> 
 *  returns a <code> JournalEntrySearchResults </code> that can be used to 
 *  access the resulting <code> JournalEntryList </code> or be used to perform 
 *  a search within the result set through <code> JournalEntrySearch. </code> 
 *  </p> 
 *  
 *  <p> Journal entries may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  JournalEntryQuery. </code> The returns in this session may not be cast 
 *  directly to these interfaces. </p>
 */

public interface JournalEntrySearchSession
    extends org.osid.journaling.JournalEntryQuerySession {


    /**
     *  Gets a journal entry search. 
     *
     *  @return the journal entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntrySearch getJournalEntrySearch();


    /**
     *  Gets a journal entry search order. The <code> JournalEntrySearchOrder 
     *  </code> is supplied to a <code> JournalEntrySearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the journal entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntrySearchOrder getJournalEntrySearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  journalEntryQuery the journal entry query 
     *  @param  journalEntrySearch the journal entry search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> journalEntryQuery 
     *          </code> or <code> journalEntrySearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> journalEntryQuery </code> 
     *          or <code> journalEntrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntrySearchResults getJournalEntriesBySearch(org.osid.journaling.JournalEntryQuery journalEntryQuery, 
                                                                                   org.osid.journaling.JournalEntrySearch journalEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a journal entry query from an inspector. The inspector is 
     *  available from a <code> JournalEntrySearchResults. </code> 
     *
     *  @param  journalEntryQueryInspector a journal entry query inspector 
     *  @return the journal entry query 
     *  @throws org.osid.NullArgumentException <code> 
     *          journalEntryQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          journalEntryQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.journaling.JournalEntryQuery getJournalEntryQueryFromInspector(org.osid.journaling.JournalEntryQueryInspector journalEntryQueryInspector);
}
