//
// org.osid.journaling.JournalingManager
//
//     The OSID Java specification for org.osid.journaling.JournalingManager.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>The journaling manager provides access to journaling sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> JournalEntryLookupSession: </code> a session to lookup 
 *      journal entries </li> 
 *      <li> <code> JournalEntryQuerySession: </code> a session to query 
 *      journal entries </li> 
 *      <li> <code> JournalEntrySearchSession: </code> a session to search 
 *      journal entries </li> 
 *      <li> <code> JournalEntryAdminSession: </code> a session to manage 
 *      journal entries </li> 
 *      <li> <code> JournalEntryNotificationSession: </code> a session to 
 *      subscribe to notifications of journal entry changes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BranchLookupSession: </code> a session to retrieve 
 *      branches </li> 
 *      <li> <code> BranchQuerySession: </code> a session to query branches 
 *      </li> 
 *      <li> <code> BranchSearchSession: </code> a session to search for 
 *      branches </li> 
 *      <li> <code> BranchAdminSession: </code> a session to create and delete 
 *      brancehs </li> 
 *      <li> <code> BranchNotificationSession: </code> a session to receive 
 *      notifications pertaining to branch changes </li> 
 *      <li> <code> BranchSmartJournalSession: </code> a session to manage 
 *      smart branch journals </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> JournalLookupSession: </code> a session to retrieve 
 *      journals </li> 
 *      <li> <code> JournalQuerySession </code> : a session to query journals 
 *      </li> 
 *      <li> <code> JournalSearchSession: </code> a session to search for 
 *      journals </li> 
 *      <li> <code> JournalAdminSession: </code> a session to create, update 
 *      and delete journals </li> 
 *      <li> <code> JournalNotificationSession: </code> a session to receive 
 *      notifications for changes in journals </li> 
 *      <li> <code> JournalHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of journals </li> 
 *      <li> <code> JournalHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of journals </li> 
 *  </ul>
 *  
 *  
 *  <p> The journaling manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface JournalingManager
    extends org.osid.OsidManager,
            org.osid.journaling.JournalingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  lookup service. 
     *
     *  @return a <code> JournalEntryLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryLookupSession getJournalEntryLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  lookup service for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the <code> Journal </code> 
     *  @return a <code> JournalEntryLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Journal </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryLookupSession getJournalEntryLookupSessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  query service. 
     *
     *  @return a <code> JournalEntryQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryQuerySession getJournalEntryQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  query service for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the <code> Journal </code> 
     *  @return a <code> JournalEntryQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Journal </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryQuerySession getJournalEntryQuerySessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  search service. 
     *
     *  @return a <code> JournalEntrySearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntrySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntrySearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntrySearchSession getJournalEntrySearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  search service for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the <code> Journal </code> 
     *  @return a <code> JournalEntrySearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Journal </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntrySearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntrySearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.journaling.JournalEntrySearchSession getJournalEntrySearchSessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  administration service. 
     *
     *  @return a <code> JournalEntryAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryAdminSession getJournalEntryAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  administration service for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the <code> Journal </code> 
     *  @return a <code> JournalEntryAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Journal </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryAdminSession getJournalEntryAdminSessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  notification service. 
     *
     *  @param  journalEntryReceiver the receiver 
     *  @return a <code> JournalEntryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> journalEntryReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryNotificationSession getJournalEntryNotificationSession(org.osid.journaling.JournalEntryReceiver journalEntryReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal entry 
     *  notification service for the given journal. 
     *
     *  @param  journalEntryReceiver the receiver 
     *  @param  journalId the <code> Id </code> of the <code> Journal </code> 
     *  @return a <code> JournalEntryNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Journal </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> journalEntryReceiver 
     *          </code> or <code> journalId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalEntryNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalEntryNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.journaling.JournalEntryNotificationSession getJournalEntryNotificationSessionForJournal(org.osid.journaling.JournalEntryReceiver journalEntryReceiver, 
                                                                                                            org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the branch lookup 
     *  service. 
     *
     *  @return <code> a BranchLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBranchLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchLookup() </code> is <code> true. </code> 
     */

    public org.osid.journaling.BranchLookupSession getBranchLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the branch lookup 
     *  service for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the journal 
     *  @return <code> a BranchLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> journalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsBranchLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.journaling.BranchLookupSession getBranchLookupSessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a branch query session. 
     *
     *  @return <code> a BranchQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBranchQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchQuery() </code> is <code> true. </code> 
     */

    public org.osid.journaling.BranchQuerySession getBranchQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a branch query session for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the journal 
     *  @return <code> a BranchQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> journalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsBranchQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.journaling.BranchQuerySession getBranchQuerySessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a branch search session. 
     *
     *  @return <code> a BranchSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBranchSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchSearch() </code> is <code> true. </code> 
     */

    public org.osid.journaling.BranchSearchSession getBranchSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a branch search session for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the journal 
     *  @return <code> a BranchSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> journalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsBranchSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.journaling.BranchSearchSession getBranchSearchSessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a branch administration session for creating, updating and 
     *  deleting branches. 
     *
     *  @return <code> a BranchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBranchAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.journaling.BranchAdminSession getBranchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a branch administration session for the given journal. 
     *
     *  @param  journalId the <code> Id </code> of the journal 
     *  @return <code> a BranchAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> journalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBranchAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.journaling.BranchAdminSession getBranchAdminSessionForJournal(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to branch 
     *  changes. 
     *
     *  @param  branchReceiver the notification callback 
     *  @return <code> a BranchNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> branchReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBranchNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.BranchNotificationSession getBranchNotificationSession(org.osid.journaling.BranchReceiver branchReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the branch notification session for the given journal. 
     *
     *  @param  branchReceiver the notification callback 
     *  @param  journalId the <code> Id </code> of the journal 
     *  @return <code> a BranchNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> journalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> branchReceiver </code> 
     *          or <code> journalId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBranchNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.journaling.BranchNotificationSession getBranchNotificationSessionForJournal(org.osid.journaling.BranchReceiver branchReceiver, 
                                                                                                org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic branch journals. 
     *
     *  @param  journalId the <code> Id </code> of the journal 
     *  @return a <code> BranchSmartJournalSession </code> 
     *  @throws org.osid.NotFoundException <code> journalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> journalId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBranchSmartJournal() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBranchSmartJournal() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.BranchSmartJournalSession getBranchSmartJournalSession(org.osid.id.Id journalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal lookup 
     *  service. 
     *
     *  @return a <code> JournalLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsJournalLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalLookup() </code> is <code> true. </code> 
     */

    public org.osid.journaling.JournalLookupSession getJournalLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal query 
     *  service. 
     *
     *  @return a <code> JournalQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsJournalQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalQuery() </code> is <code> true. </code> 
     */

    public org.osid.journaling.JournalQuerySession getJournalQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal search 
     *  service. 
     *
     *  @return a <code> JournalSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsJournalSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalSearch() </code> is <code> true. </code> 
     */

    public org.osid.journaling.JournalSearchSession getJournalSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal 
     *  administrative service. 
     *
     *  @return a <code> JournalAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsJournalAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalAdmin() </code> is <code> true. </code> 
     */

    public org.osid.journaling.JournalAdminSession getJournalAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal 
     *  notification service. 
     *
     *  @param  journalReceiver the receiver 
     *  @return a <code> JournalNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> journalReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalNotificationSession getJournalNotificationSession(org.osid.journaling.JournalReceiver journalReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal 
     *  hierarchy service. 
     *
     *  @return a <code> JournalHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.journaling.JournalHierarchySession getJournalHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the journal 
     *  hierarchy design service. 
     *
     *  @return a <code> JournalHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.journaling.JournalHierarchyDesignSession getJournalHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> JournalingBatchManager. </code> 
     *
     *  @return a <code> JournalingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsJournalingBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJournalingBatch() </code> is <code> true. </code> 
     */

    public org.osid.journaling.batch.JournalingBatchManager getJournalingBatchManager()
        throws org.osid.OperationFailedException;
}
