//
// org.osid.journaling.JournalingProfile
//
//     The OSID Java specification for org.osid.journaling.JournalingProfile.
//
// Copyright (C) 2009, 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.journaling;


/**
 *  <p>The journaling profile describes the interoperability among journaling 
 *  services. </p>
 */

public interface JournalingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any journal federation is exposed. Federation is exposed when 
     *  a specific journal may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  journals appears as a single journal. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a journal entry lookup service. 
     *
     *  @return <code> true </code> if journal entry lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntryLookup();


    /**
     *  Tests if querying journal entries is available. 
     *
     *  @return <code> true </code> if journal entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntryQuery();


    /**
     *  Tests if searching for journal entries is available. 
     *
     *  @return <code> true </code> if journal entry search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntrySearch();


    /**
     *  Tests if searching for journal entries is available. 
     *
     *  @return <code> true </code> if journal entry search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntryAdmin();


    /**
     *  Tests if journal entry notification is available. 
     *
     *  @return <code> true </code> if journal entry notification is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntryNotification();


    /**
     *  Tests if branch lookup is supported. 
     *
     *  @return <code> true </code> if branch lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchLookup();


    /**
     *  Tests if branch query is supported. 
     *
     *  @return <code> true </code> if branch query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchQuery();


    /**
     *  Tests if branch search is supported. 
     *
     *  @return <code> true </code> if branch search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchSearch();


    /**
     *  Tests if branch administration is supported. 
     *
     *  @return <code> true </code> if branch administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchAdmin();


    /**
     *  Tests if branch notification is supported. Messages may be sent when 
     *  branches are created, modified, or deleted. 
     *
     *  @return <code> true </code> if branch notification is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchNotification();


    /**
     *  Tests if branch smart journals are available. 
     *
     *  @return <code> true </code> if branch smart journals are supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchSmartJournal();


    /**
     *  Tests for the availability of an journal lookup service. 
     *
     *  @return <code> true </code> if journal lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalLookup();


    /**
     *  Tests if querying journals is available. 
     *
     *  @return <code> true </code> if journal query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalQuery();


    /**
     *  Tests if searching for journals is available. 
     *
     *  @return <code> true </code> if journal search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalSearch();


    /**
     *  Tests for the availability of a journal administrative service for 
     *  creating and deleting journals. 
     *
     *  @return <code> true </code> if journal administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalAdmin();


    /**
     *  Tests for the availability of a journal notification service. 
     *
     *  @return <code> true </code> if journal notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsJournalNotification();


    /**
     *  Tests for the availability of a journal hierarchy traversal service. 
     *
     *  @return <code> true </code> if journal hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalHierarchy();


    /**
     *  Tests for the availability of a journal hierarchy design service. 
     *
     *  @return <code> true </code> if journal hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsJournalHierarchyDesign();


    /**
     *  Tests for the availability of a journaling batch service. 
     *
     *  @return <code> true </code> if journaling batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsJournalngBatch();


    /**
     *  Gets the supported <code> JournalEntry </code> record types. 
     *
     *  @return a list containing the supported journal entry record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJournalEntryRecordTypes();


    /**
     *  Tests if the given <code> JournalEntry </code> record type is 
     *  supported. 
     *
     *  @param  journalEntryRecordType a <code> Type </code> indicating a 
     *          <code> JournalEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> journalEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntryRecordType(org.osid.type.Type journalEntryRecordType);


    /**
     *  Gets the supported journal entry search record types. 
     *
     *  @return a list containing the supported journal entry search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJournalEntrySearchRecordTypes();


    /**
     *  Tests if the given journal entry search record type is supported. 
     *
     *  @param  journalEntrySearchRecordType a <code> Type </code> indicating 
     *          a journal entry record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          journalEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalEntrySearchRecordType(org.osid.type.Type journalEntrySearchRecordType);


    /**
     *  Gets all the branch record types supported. 
     *
     *  @return the list of supported branch record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBranchRecordTypes();


    /**
     *  Tests if a given branch record type is supported. 
     *
     *  @param  branchRecordType the branch type 
     *  @return <code> true </code> if the branch record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> branchRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchRecordType(org.osid.type.Type branchRecordType);


    /**
     *  Gets all the branch search record types supported. 
     *
     *  @return the list of supported branch search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBranchSearchRecordTypes();


    /**
     *  Tests if a given branch search type is supported. 
     *
     *  @param  branchSearchRecordType the branch search type 
     *  @return <code> true </code> if the branch search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> branchSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBranchSearchRecordType(org.osid.type.Type branchSearchRecordType);


    /**
     *  Gets the supported <code> Journal </code> record types. 
     *
     *  @return a list containing the supported journal record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJournalRecordTypes();


    /**
     *  Tests if the given <code> Journal </code> record type is supported. 
     *
     *  @param  journalRecordType a <code> Type </code> indicating a <code> 
     *          Journal </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> journalRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalRecordType(org.osid.type.Type journalRecordType);


    /**
     *  Gets the supported journal search record types. 
     *
     *  @return a list containing the supported journal search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJournalSearchRecordTypes();


    /**
     *  Tests if the given journal search record type is supported. 
     *
     *  @param  journalSearchRecordType a <code> Type </code> indicating a 
     *          journal record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          journalEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalSearchRecordType(org.osid.type.Type journalSearchRecordType);
}
