//
// org.osid.learning.Activity
//
//     The OSID Java specification for org.osid.learning.Activity.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>An <code> Activity </code> represents learning material or other 
 *  learning activities to meet an objective. An Activity has may relate to a 
 *  set of <code> Asssts </code> for self learning, recommended <code> Courses 
 *  </code> to take, or a learning <code> Assessment. </code> The learning 
 *  <code> Assessment </code> differs from the <code> Objective </code> <code> 
 *  Assessment </code> in that the latter used to test for proficiency in the 
 *  <code> Objective. </code> </p> 
 *  
 *  <p> Generally, an <code> Activity </code> should focus on one of assets, 
 *  courses, assessments, or some other specific activity related to the 
 *  objective described or related in the <code> ActivityRecord. </code> </p>
 */

public interface Activity
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the related objective. 
     *
     *  @return the objective <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveId();


    /**
     *  Gets the related objective. 
     *
     *  @return the related objective 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.Objective getObjective()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this is an asset based activity. 
     *
     *  @return <code> true </code> if this activity is based on assets, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAssetBasedActivity();


    /**
     *  Gets the <code> Ids </code> of any assets associated with this 
     *  activity. 
     *
     *  @return list of asset <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isAssetBasedActivity() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssetIds();


    /**
     *  Gets any assets associated with this activity. 
     *
     *  @return list of assets 
     *  @throws org.osid.IllegalStateException <code> isAssetBasedActivity() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetList getAssets()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this is a course based activity. 
     *
     *  @return <code> true </code> if this activity is based on courses, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isCourseBasedActivity();


    /**
     *  Gets the <code> Ids </code> of any courses associated with this 
     *  activity. 
     *
     *  @return list of course <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isCourseBasedActivity() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCourseIds();


    /**
     *  Gets any courses associated with this activity. 
     *
     *  @return list of courses 
     *  @throws org.osid.IllegalStateException <code> isCourseBasedActivity() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseList getCourses()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this is an assessment based activity. These assessments are 
     *  for learning the objective and not for assessing prodiciency in the 
     *  objective. 
     *
     *  @return <code> true </code> if this activity is based on assessments, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAssessmentBasedActivity();


    /**
     *  Gets the <code> Ids </code> of any assessments associated with this 
     *  activity. 
     *
     *  @return list of assessment <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          isAssessmentBasedActivity() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssessmentIds();


    /**
     *  Gets any assessments associated with this activity. 
     *
     *  @return list of assessments 
     *  @throws org.osid.IllegalStateException <code> 
     *          isAssessmentBasedActivity() </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentList getAssessments()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the activity record corresponding to the given <code> Activity 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  activityRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(activityRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  activityRecordType the type of the record to retrieve 
     *  @return the activity record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ActivityRecord getActivityRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
