//
// org.osid.learning.ActivityLookupSession
//
//     The OSID Java specification for org.osid.learning.ActivityLookupSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods for retrieving <code> Activity </code> 
 *  objects. The <code> Activity </code> represents something to perform in 
 *  order to achieve a learning objective. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated objective bank view: All activity methods in this 
 *      session operate, retrieve and pertain to activities defined explicitly 
 *      in the current objective bank. Using an isolated view is useful for 
 *      managing activities with the <code> ActivityAdminSession. </code> 
 *      </li> 
 *      <li> federated objective bank view: All activity methods in this 
 *      session operate, retrieve and pertain to all activities defined in 
 *      this objective bank and any other objective banks implicitly available 
 *      in this objective bank through objective bank inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Activities may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Activity. </code> </p>
 */

public interface ActivityLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the <code> ObjectiveBank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Activity </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupActivities();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeActivityView();


    /**
     *  A complete view of the <code> Activity </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryActivityView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include activities in objective banks which are children of this 
     *  objective bank in the objective bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedObjectiveBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this objective bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedObjectiveBankView();


    /**
     *  Gets the <code> Activity </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Activity 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Activity </code> and retained for compatibility. 
     *
     *  @param  activityId <code> Id </code> of the <code> Activity </code> 
     *  @return the activity 
     *  @throws org.osid.NotFoundException <code> activityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.learning.Activity getActivity(org.osid.id.Id activityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  activities specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Activities </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  activityIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Activity </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> activityIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesByIds(org.osid.id.IdList activityIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityList </code> corresponding to the given 
     *  activity genus <code> Type </code> which does not include activities 
     *  of genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known activities or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  activities that are accessible through this session. 
     *
     *  @param  activityGenusType an activity genus type 
     *  @return the returned <code> Activity </code> list 
     *  @throws org.osid.NullArgumentException <code> activityGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesByGenusType(org.osid.type.Type activityGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ActivityList </code> corresponding to the given 
     *  activity genus <code> Type </code> and include any additional activity 
     *  with genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known activities or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  activities that are accessible through this session. 
     *
     *  @param  activityGenusType an activity genus type 
     *  @return the returned <code> Activity </code> list 
     *  @throws org.osid.NullArgumentException <code> activityGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesByParentGenusType(org.osid.type.Type activityGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ActivityList </code> containing the given activity 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known activities or an error results. Otherwise, the 
     *  returned list may contain only those activities that are accessible 
     *  through this session. 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the returned <code> Activity </code> list 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesByRecordType(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the activities for the given objective. In plenary mode, the 
     *  returned list contains all of the activities mapped to the objective 
     *  <code> Id </code> or an error results if an Id in the supplied list is 
     *  not found or inaccessible. Otherwise, inaccessible <code> Activities 
     *  </code> may be omitted from the list and may present the elements in 
     *  any order including returning a unique set. 
     *
     *  @param  objectiveId <code> Id </code> of the <code> Objective </code> 
     *  @return list of enrollments 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesForObjective(org.osid.id.Id objectiveId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the activities for the given objectives. In plenary mode, the 
     *  returned list contains all of the activities specified in the 
     *  objective <code> Id </code> list, in the order of the list, including 
     *  duplicates, or an error results if a course offering <code> Id </code> 
     *  in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Activities </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  objectiveIds list of objective <code> Ids </code> 
     *  @return list of activities 
     *  @throws org.osid.NotFoundException an <code> objectiveId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveIdList </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesForObjectives(org.osid.id.IdList objectiveIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the activities for the given asset. In plenary mode, the returned 
     *  list contains all of the activities mapped to the asset <code> Id 
     *  </code> or an error results if an <code> Id </code> in the supplied 
     *  list is not found or inaccessible. Otherwise, inaccessible <code> 
     *  Activities </code> may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  assetId <code> Id </code> of an <code> Asset </code> 
     *  @return list of activities 
     *  @throws org.osid.NotFoundException <code> assetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assetId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesByAsset(org.osid.id.Id assetId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the activities for the given asset. In plenary mode, the returned 
     *  list contains all of the activities mapped to the asset <code> Id 
     *  </code> or an error results if an <code> Id </code> in the supplied 
     *  list is not found or inaccessible. Otherwise, inaccessible <code> 
     *  Activities </code> may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *
     *  @param  assetIds <code> Ids </code> of <code> Assets </code> 
     *  @return list of activities 
     *  @throws org.osid.NotFoundException an <code> assetId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assetIdList </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.learning.ActivityList getActivitiesByAssets(org.osid.id.IdList assetIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Activities. </code> In plenary mode, the returned list 
     *  contains all known activites or an error results. Otherwise, the 
     *  returned list may contain only those activities that are accessible 
     *  through this session. 
     *
     *  @return a <code> ActivityList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityList getActivities()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
