//
// org.osid.learning.ActivityQueryInspector
//
//     The OSID Java specification for org.osid.learning.ActivityQueryInspector.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This is the query inspector for examining activity queries. </p>
 */

public interface ActivityQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the objective <code> Id </code> query terms. 
     *
     *  @return the objective <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getObjectiveIdTerms();


    /**
     *  Gets the objective query terms. 
     *
     *  @return the objective terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getObjectiveTerms();


    /**
     *  Gets the asset <code> Id </code> query terms. 
     *
     *  @return the asset <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssetIdTerms();


    /**
     *  Gets the asset query terms. 
     *
     *  @return the asset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetQueryInspector[] getAssetTerms();


    /**
     *  Gets the course <code> Id </code> query terms. 
     *
     *  @return the course <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCourseIdTerms();


    /**
     *  Gets the course query terms. 
     *
     *  @return the course terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.course.CourseQueryInspector[] getCourseTerms();


    /**
     *  Gets the assessment <code> Id </code> query terms. 
     *
     *  @return the assessment <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssessmentIdTerms();


    /**
     *  Gets the assessment query terms. 
     *
     *  @return the assessment terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.assessment.AssessmentQueryInspector[] getAssessmentTerms();


    /**
     *  Gets the objective bank <code> Id </code> query terms. 
     *
     *  @return the objective bank <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getObjectiveBankIdTerms();


    /**
     *  Gets the objective bank query terms. 
     *
     *  @return the objective bank terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankQueryInspector[] getObjectiveBankTerms();


    /**
     *  Gets the activity query inspector record corresponding to the given 
     *  <code> Activity </code> record <code> Type. </code> 
     *
     *  @param  activityRecordType an activity record type 
     *  @return the activity query inspector record 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(activityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ActivityQueryInspectorRecord getActivityQueryInspectorRecord(org.osid.type.Type activityRecordType)
        throws org.osid.OperationFailedException;
}
