//
// org.osid.learning.ActivitySmartObjectiveBankSession
//
//     The OSID Java specification for org.osid.learning.ActivitySmartObjectiveBankSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> ActivityQuery </code> can be retrieved from this 
 *  session and mapped to this <code> ObjectiveBank </code> to create a 
 *  virtual collection of activities. The activities may be sequenced using 
 *  the <code> ActivitySearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> ObjectiveBank </code> has a default query that matches any 
 *  activity and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> ActivityQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to an <code> 
 *  ActivityQuery. </code> </p>
 */

public interface ActivitySmartObjectiveBankSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the <code> ObjectiveBank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart objective banks. A return of true 
     *  does not guarantee successful assessment. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart objective bank management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartObjectiveBanks();


    /**
     *  Gets an activity query. 
     *
     *  @return the activity query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityQuery getActivityQuery();


    /**
     *  Gets an activity search order. 
     *
     *  @return the activity search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivitySearchOrder getActivitySearchOrder();


    /**
     *  Applies an activity query to this bank. 
     *
     *  @param  activityQuery the activity query 
     *  @throws org.osid.NullArgumentException <code> activityQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> activityQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyActivityQuery(org.osid.learning.ActivityQuery activityQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an activity query inspector for this objective bank. 
     *
     *  @return the activity query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityQueryInspector inspectActivityQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an activity search order to this objective bank. 
     *
     *  @param  activitySearchOrder the activity search order 
     *  @throws org.osid.NullArgumentException <code> activitySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> activitySearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyActivitySequencing(org.osid.learning.ActivitySearchOrder activitySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an activity query from an inspector. 
     *
     *  @param  activityQueryInspector an activity query inspector 
     *  @return the activity query 
     *  @throws org.osid.NullArgumentException <code> activityQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> activityQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityQuery getActivityQueryFromInspector(org.osid.learning.ActivityQueryInspector activityQueryInspector);
}
