//
// org.osid.learning.LearningPathSession
//
//     The OSID Java specification for org.osid.learning.LearningPathSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session defines methods for finding learning paths through an 
 *  objective hierarchy based on proficiencies. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated objective bank view: All methods in this session 
 *      operate, retrieve and pertain to objectives defined explicitly in the 
 *      current objective bank. </li> 
 *      <li> federated objective bank view: All methods in this session 
 *      operate, retrieve and pertain to all obtecives defined in this 
 *      objective bank and any other objectives implicitly available in this 
 *      objective bank through objective bank inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedObjectiveBankView() </code> and <code> 
 *  useIsolatedObjectiveBankView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p>
 */

public interface LearningPathSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the obective bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform learning path lookups. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupLearningPaths();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProficiencyView();


    /**
     *  A complete view of the <code> Proficiency </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProficiencyView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include proficiencies in objective banks which are children of this 
     *  objective bank in the obective bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedObjectiveBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this objective bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedObjectiveBankView();


    /**
     *  Gets the shortest path to an objective. The path is a list of 
     *  objectives for which the resource has a deficient proficiency. 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> to reach 
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @return the returned list of objectives 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList findPathForResource(org.osid.id.Id objectiveId, 
                                                               org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the shortest path to an objective. The path is a list of 
     *  objectives for which the resource has a proficiency less than the 
     *  given proficiency. 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> to reach 
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @param  gradeId the <code> Id </code> of a proficiency level 
     *  @return the returned list of objectives 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> proficiencyId, 
     *          resourceId </code> or <code> gradeId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList findPathForResourceAtProficiency(org.osid.id.Id objectiveId, 
                                                                            org.osid.id.Id resourceId, 
                                                                            org.osid.id.Id gradeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of objectives for a resource that have a minimum 
     *  completion. 
     *
     *  @param  objectiveId the <code> Id </code> of the <code> Objective 
     *          </code> to reach 
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @param  completion the minimum completion as a percentage number 
     *  @return the returned list of objectives 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> or 
     *          <code> resourceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getObjectivesForResourceByCompletion(org.osid.id.Id objectiveId, 
                                                                                org.osid.id.Id resourceId, 
                                                                                long completion)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
