//
// org.osid.learning.LearningProfile
//
//     The OSID Java specification for org.osid.learning.LearningProfile.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>The <code> LearningProfile </code> describes the interoperability among 
 *  learning services. </p>
 */

public interface LearningProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if an objective lookup service is supported. An objective lookup 
     *  service defines methods to access objectives. 
     *
     *  @return true if objective lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveLookup();


    /**
     *  Tests if an objective query service is supported. 
     *
     *  @return <code> true </code> if objective query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveQuery();


    /**
     *  Tests if an objective search service is supported. 
     *
     *  @return <code> true </code> if objective search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveSearch();


    /**
     *  Tests if an objective administrative service is supported. 
     *
     *  @return <code> true </code> if objective admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveAdmin();


    /**
     *  Tests if objective notification is supported. Messages may be sent 
     *  when objectives are created, modified, or deleted. 
     *
     *  @return <code> true </code> if objective notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveNotification();


    /**
     *  Tests if an objective hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if an objective hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveHierarchy();


    /**
     *  Tests if an objective hierarchy design is supported. 
     *
     *  @return <code> true </code> if an objective hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveHierarchyDesign();


    /**
     *  Tests if an objective sequencing design is supported. 
     *
     *  @return <code> true </code> if objective sequencing is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveSequencing();


    /**
     *  Tests if an objective to objective bank lookup session is available. 
     *
     *  @return <code> true </code> if objective objective bank lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveObjectiveBank();


    /**
     *  Tests if an objective to objective bank assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if objective objective bank assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveObjectiveBankAssignment();


    /**
     *  Tests if an objective smart objective bank cataloging service is 
     *  supported. 
     *
     *  @return <code> true </code> if objective smart objective banks are 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveSmartObjectiveBank();


    /**
     *  Tests if an objective requisite service is supported. 
     *
     *  @return <code> true </code> if objective requisite service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveRequisite();


    /**
     *  Tests if an objective requisite assignment service is supported. 
     *
     *  @return <code> true </code> if objective requisite assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveRequisiteAssignment();


    /**
     *  Tests if an activity lookup service is supported. 
     *
     *  @return <code> true </code> if activity lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityLookup();


    /**
     *  Tests if an activity query service is supported. 
     *
     *  @return <code> true </code> if activity query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityQuery();


    /**
     *  Tests if an activity search service is supported. 
     *
     *  @return <code> true </code> if activity search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySearch();


    /**
     *  Tests if an activity administrative service is supported. 
     *
     *  @return <code> true </code> if activity admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityAdmin();


    /**
     *  Tests if activity notification is supported. Messages may be sent when 
     *  activities are created, modified, or deleted. 
     *
     *  @return <code> true </code> if activity notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityNotification();


    /**
     *  Tests if an activity to objective bank lookup session is available. 
     *
     *  @return <code> true </code> if activity objective bank lookup session 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityObjectiveBank();


    /**
     *  Tests if an activity to objective bank assignment session is 
     *  available. 
     *
     *  @return <code> true </code> if activity objective bank assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityObjectiveBankAssignment();


    /**
     *  Tests if an activity smart objective bank cataloging service is 
     *  supported. 
     *
     *  @return <code> true </code> if activity smart objective banks are 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySmartObjectiveBank();


    /**
     *  Tests if looking up proficiencies is supported. 
     *
     *  @return <code> true </code> if proficiency lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencyLookup();


    /**
     *  Tests if querying proficiencies is supported. 
     *
     *  @return <code> true </code> if proficiency query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencyQuery();


    /**
     *  Tests if searching proficiencies is supported. 
     *
     *  @return <code> true </code> if proficiency search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencySearch();


    /**
     *  Tests if proficiency <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if proficiency administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencyAdmin();


    /**
     *  Tests if a proficiency <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if proficiency notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencyNotification();


    /**
     *  Tests if a proficiency objective bank mapping lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a proficiency objective bank lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencyObjectiveBank();


    /**
     *  Tests if a proficiency objective bank mapping service is supported. 
     *
     *  @return <code> true </code> if proficiency to objective bank mapping 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencyObjectiveBankAssignment();


    /**
     *  Tests if a proficiency smart objective bank cataloging service is 
     *  supported. 
     *
     *  @return <code> true </code> if proficiency smart objective banks are 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencySmartObjectiveBank();


    /**
     *  Tests if a learning path service is supported for the authenticated 
     *  agent. 
     *
     *  @return <code> true </code> if learning path is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyLearningPath();


    /**
     *  Tests if a learning path service is supported. 
     *
     *  @return <code> true </code> if learning path is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningPath();


    /**
     *  Tests if an objective bank lookup service is supported. 
     *
     *  @return <code> true </code> if objective bank lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankLookup();


    /**
     *  Tests if an objective bank query service is supported. 
     *
     *  @return <code> true </code> if objective bank query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankQuery();


    /**
     *  Tests if an objective bank search service is supported. 
     *
     *  @return <code> true </code> if objective bank search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankSearch();


    /**
     *  Tests if an objective bank administrative service is supported. 
     *
     *  @return <code> true </code> if objective bank admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankAdmin();


    /**
     *  Tests if objective bank notification is supported. Messages may be 
     *  sent when objective banks are created, modified, or deleted. 
     *
     *  @return <code> true </code> if objective bank notification is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankNotification();


    /**
     *  Tests if an objective bank hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if an objective bank hierarchy traversal 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankHierarchy();


    /**
     *  Tests if objective bank hierarchy design is supported. 
     *
     *  @return <code> true </code> if an objective bank hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankHierarchyDesign();


    /**
     *  Tests if a learning batch service is supported. 
     *
     *  @return <code> true </code> if a learning batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningBatch();


    /**
     *  Gets the supported <code> Objective </code> record types. 
     *
     *  @return a list containing the supported <code> Objective </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObjectiveRecordTypes();


    /**
     *  Tests if the given <code> Objective </code> record type is supported. 
     *
     *  @param  objectiveRecordType a <code> Type </code> indicating an <code> 
     *          Objective </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> objectiveRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveRecordType(org.osid.type.Type objectiveRecordType);


    /**
     *  Gets the supported <code> Objective </code> search record types. 
     *
     *  @return a list containing the supported <code> Objective </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObjectiveSearchRecordTypes();


    /**
     *  Tests if the given <code> Objective </code> search record type is 
     *  supported. 
     *
     *  @param  objectiveSearchRecordType a <code> Type </code> indicating an 
     *          <code> Objective </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          objectiveSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveSearchRecordType(org.osid.type.Type objectiveSearchRecordType);


    /**
     *  Gets the supported <code> Activity </code> record types. 
     *
     *  @return a list containing the supported <code> Activity </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivityRecordTypes();


    /**
     *  Tests if the given <code> Activity </code> record type is supported. 
     *
     *  @param  activityRecordType a <code> Type </code> indicating a <code> 
     *          Activity </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activityRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivityRecordType(org.osid.type.Type activityRecordType);


    /**
     *  Gets the supported <code> Activity </code> search record types. 
     *
     *  @return a list containing the supported <code> Activity </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getActivitySearchRecordTypes();


    /**
     *  Tests if the given <code> Activity </code> search record type is 
     *  supported. 
     *
     *  @param  activitySearchRecordType a <code> Type </code> indicating a 
     *          <code> Activity </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> activitySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsActivitySearchRecordType(org.osid.type.Type activitySearchRecordType);


    /**
     *  Gets the supported <code> Proficiency </code> record types. 
     *
     *  @return a list containing the supported <code> Proficiency </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProficiencyRecordTypes();


    /**
     *  Tests if the given <code> Proficiency </code> record type is 
     *  supported. 
     *
     *  @param  proficiencyRecordType a <code> Type </code> indicating a 
     *          <code> Proficiency </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> proficiencyRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencyRecordType(org.osid.type.Type proficiencyRecordType);


    /**
     *  Gets the supported <code> Proficiency </code> search types. 
     *
     *  @return a list containing the supported <code> Proficiency </code> 
     *          search types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProficiencySearchRecordTypes();


    /**
     *  Tests if the given <code> Proficiency </code> search type is 
     *  supported. 
     *
     *  @param  proficiencySearchRecordType a <code> Type </code> indicating a 
     *          <code> Proficiency </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          proficiencySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProficiencySearchRecordType(org.osid.type.Type proficiencySearchRecordType);


    /**
     *  Gets the supported <code> ObjectiveBank </code> record types. 
     *
     *  @return a list containing the supported <code> ObjectiveBank </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObjectiveBankRecordTypes();


    /**
     *  Tests if the given <code> ObjectiveBank </code> record type is 
     *  supported. 
     *
     *  @param  objectiveBankRecordType a <code> Type </code> indicating an 
     *          <code> ObjectiveBank </code> type 
     *  @return <code> true </code> if the given objective bank record <code> 
     *          Type </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> objectiveBankRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankRecordType(org.osid.type.Type objectiveBankRecordType);


    /**
     *  Gets the supported objective bank search record types. 
     *
     *  @return a list containing the supported <code> ObjectiveBank </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObjectiveBankSearchRecordTypes();


    /**
     *  Tests if the given objective bank search record type is supported. 
     *
     *  @param  objectiveBankSearchRecordType a <code> Type </code> indicating 
     *          an <code> ObjectiveBank </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          objectiveBankSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObjectiveBankSearchRecordType(org.osid.type.Type objectiveBankSearchRecordType);
}
