//
// org.osid.learning.ObjectiveBankAdminSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveBankAdminSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session creates, updates, and deletes <code> ObjectiveBanks. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> ObjectiveBank, </code> an <code> ObjectiveBankForm </code> is 
 *  requested using <code> getObjectiveBankFormForCreate() </code> specifying 
 *  the desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> ObjectiveBankForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  ObjectiveBankForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> ObjectiveBankForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ObjectiveBankForms </code> are requested to the 
 *  <code> ObjectiveBank </code> <code> Id </code> that is to be updated using 
 *  <code> getObjectiveBankFormForUpdate(). </code> Similarly, the <code> 
 *  ObjectiveBankForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ObjectiveBankForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ObjectiveBanks. </code> It is 
 *  safer to remove all mappings to the <code> ObjectiveBank </code> catalogs 
 *  before deletion. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ObjectiveBankAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> ObjectiveBanks. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> ObjectiveBank </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer create operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> ObjectiveBank </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateObjectiveBanks();


    /**
     *  Tests if this user can create a single <code> ObjectiveBank </code> 
     *  using the desired record types. While <code> 
     *  LearningManager.getObjectiveBankRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> ObjectiveBank. </code> 
     *  Providing an empty array tests if an <code> ObjectiveBank </code> can 
     *  be created with no records. 
     *
     *  @param  objectiveBankRecordTypes array of objective bank record types 
     *  @return <code> true </code> if <code> ObjectiveBank </code> creation 
     *          using the specified <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> objectiveBankRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateObjectiveBankWithRecordTypes(org.osid.type.Type[] objectiveBankRecordTypes);


    /**
     *  Gets the objective bank form for creating new objective banks. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  objectiveBankRecordTypes array of objective bank record types 
     *  @return the objective bank form 
     *  @throws org.osid.NullArgumentException <code> objectiveBankRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types. 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankForm getObjectiveBankFormForCreate(org.osid.type.Type[] objectiveBankRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ObjectiveBank. </code> 
     *
     *  @param  objectiveBankForm the form for this <code> ObjectiveBank 
     *          </code> 
     *  @return the new <code> ObjectiveBank </code> 
     *  @throws org.osid.IllegalStateException <code> objectiveBankForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> objectiveBankForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> objectiveBankForm </code> 
     *          did not originate from <code> getObjectiveBankFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank createObjectiveBank(org.osid.learning.ObjectiveBankForm objectiveBankForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ObjectiveBanks. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> ObjectiveBank </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer update operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> ObjectiveBank </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateObjectiveBanks();


    /**
     *  Gets the objective bank form for updating an existing objective bank. 
     *  A new objective bank form should be requested for each update 
     *  transaction. 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> 
     *  @return the objective bank form 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankForm getObjectiveBankFormForUpdate(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing objective bank. 
     *
     *  @param  objectiveBankForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> objectiveBankForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> objectiveBankForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> objectiveBankForm did not 
     *          originate from getObjectiveBankFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateObjectiveBank(org.osid.learning.ObjectiveBankForm objectiveBankForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete objective banks. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting an <code> ObjectiveBank </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> ObjectiveBank </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteObjectiveBanks();


    /**
     *  Deletes an <code> ObjectiveBank. </code> 
     *
     *  @param  objectiveBankId the <code> Id </code> of the <code> 
     *          ObjectiveBank </code> to remove 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ObjectiveBanks. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ObjectiveBank </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageObjectiveBankAliases();


    /**
     *  Adds an <code> Id </code> to an <code> ObjectiveBank </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ObjectiveBank </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another objective bank, it is 
     *  reassigned to the given objective bank <code> Id. </code> 
     *
     *  @param  objectiveBankId the <code> Id </code> of an <code> 
     *          ObjectiveBank </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasObjectiveBank(org.osid.id.Id objectiveBankId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
