//
// org.osid.learning.ObjectiveBankLookupSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveBankLookupSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods for retrieving <code> ObjectiveBank 
 *  </code> objects. The <code> ObjectiveBank </code> represents a collection 
 *  of <code> Objectives Activities </code> , and <code> Proficiencies. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. For 
 *  example, a browsing application may only need to examine the <code> 
 *  ObjectiveBanks </code> it can access, without breaking execution. However, 
 *  an administrative application may require all <code> ObjectiveBank </code> 
 *  elements to be available. </p> 
 *  
 *  <p> <code> ObjectiveBanks </code> may have an additional records indicated 
 *  by their respective record types. The record may not be accessed through a 
 *  cast of the <code> ObjectiveBank. </code> </p>
 */

public interface ObjectiveBankLookupSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform <code> ObjectiveBank </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupObjectiveBanks();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeObjectiveBankView();


    /**
     *  A complete view of the <code> ObjectiveBank </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryObjectiveBankView();


    /**
     *  Gets the <code> ObjectiveBank </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ObjectiveBank </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> ObjectiveBank </code> and retained for 
     *  compatility. 
     *
     *  @param  objectiveBankId <code> Id </code> of the <code> ObjectiveBank 
     *          </code> 
     *  @return the objective bank 
     *  @throws org.osid.NotFoundException <code> objectiveBankId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank(org.osid.id.Id objectiveBankId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ObjectiveBankList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the objective banks specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> ObjectiveBank </code> objects may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *
     *  @param  objectiveBankIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ObjectiveBank </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> objectiveBankIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankList getObjectiveBanksByIds(org.osid.id.IdList objectiveBankIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ObjectiveBankList </code> corresponding to the given 
     *  objective bank genus <code> Type </code> which does not include 
     *  objective banks of types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  objective banks or an error results. Otherwise, the returned list may 
     *  contain only those objective banks that are accessible through this 
     *  session. 
     *
     *  @param  objectiveBankGenusType an objective bank genus type 
     *  @return the returned <code> ObjectiveBank </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveBankGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankList getObjectiveBanksByGenusType(org.osid.type.Type objectiveBankGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ObjectiveBankList </code> corresponding to the given 
     *  objective bank genus <code> Type </code> and include any additional 
     *  objective banks with genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  objective banks or an error results. Otherwise, the returned list may 
     *  contain only those objective banks that are accessible through this 
     *  session. 
     *
     *  @param  objectiveBankGenusType an objective bank genus type 
     *  @return the returned <code> ObjectiveBank </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveBankGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankList getObjectiveBanksByParentGenusType(org.osid.type.Type objectiveBankGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ObjectiveBankList </code> containing the given objective 
     *  bank record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known objective banks or an error results. Otherwise, the 
     *  returned list may contain only those objective banks that are 
     *  accessible through this session. 
     *
     *  @param  objectiveBankRecordType an objective bank record type 
     *  @return the returned <code> ObjectiveBank </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveBankRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankList getObjectiveBanksByRecordType(org.osid.type.Type objectiveBankRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ObjectiveBankList </code> for the given provider. <code> 
     *  </code> In plenary mode, the returned list contains all known 
     *  objective banks or an error results. Otherwise, the returned list may 
     *  contain only those objective banks that are accessible through this 
     *  session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> ObjectiveBank </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankList getObjectiveBanksByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ObjectiveBanks. </code> In plenary mode, the returned 
     *  list contains all known objective banks or an error results. 
     *  Otherwise, the returned list may contain only those objective banks 
     *  that are accessible through this session. 
     *
     *  @return a <code> ObjectiveBankList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankList getObjectiveBanks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
