//
// org.osid.learning.ObjectiveBankQueryInspector
//
//     The OSID Java specification for org.osid.learning.ObjectiveBankQueryInspector.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This is the query inspector for examining objective bank queries. </p>
 */

public interface ObjectiveBankQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the objective <code> Id </code> query terms. 
     *
     *  @return the objective <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getObjectiveIdTerms();


    /**
     *  Gets the objective query terms. 
     *
     *  @return the objective terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getObjectiveTerms();


    /**
     *  Gets the activity <code> Id </code> query terms. 
     *
     *  @return the activity <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityIdTerms();


    /**
     *  Gets the activity query terms. 
     *
     *  @return the activity terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityQueryInspector[] getActivityTerms();


    /**
     *  Gets the ancestor objective bank <code> Id </code> query terms. 
     *
     *  @return the ancestor objective bank <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorObjectiveBankIdTerms();


    /**
     *  Gets the ancestor objective bank query terms. 
     *
     *  @return the ancestor objective bank terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankQueryInspector[] getAncestorObjectiveBankTerms();


    /**
     *  Gets the descendant objective bank <code> Id </code> query terms. 
     *
     *  @return the descendant objective bank <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantObjectiveBankIdTerms();


    /**
     *  Gets the descendant objective bank query terms. 
     *
     *  @return the descendant objective bank terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankQueryInspector[] getDescendantObjectiveBankTerms();


    /**
     *  Gets the objective bank query inspector record corresponding to the 
     *  given <code> ObjectiveBank </code> record <code> Type. </code> 
     *
     *  @param  objectiveBankRecordType an objective bank record type 
     *  @return the objective bank query inspector record 
     *  @throws org.osid.NullArgumentException <code> objectiveBankRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(objectiveBankRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ObjectiveBankQueryInspectorRecord getObjectiveBankQueryInspectorRecord(org.osid.type.Type objectiveBankRecordType)
        throws org.osid.OperationFailedException;
}
