//
// org.osid.learning.ObjectiveBankSearchSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveBankSearchSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods for searching among <code> ObjectiveBank 
 *  </code> objects. The search query is constructed using the <code> 
 *  ObjectiveBankQuery. </code> </p> 
 *  
 *  <p> <code> getObjectiveBanksByQuery() </code> is the basic search method 
 *  and returns a list of <code> ObjectiveBank </code> objects.A more advanced 
 *  search may be performed with <code> getObjectiveBanksBySearch(). </code> 
 *  It accepts a <code> ObjectiveBankSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getObjectiveBanksBySearch() </code> 
 *  returns a <code> ObjectiveBankSearchResults </code> that can be used to 
 *  access the resulting <code> ObjectiveBankList </code> or be used to 
 *  perform a search within the result set through <code> ObjectiveBankSearch. 
 *  </code> </p> 
 *  
 *  <p> <code> ObjectiveBanks </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  ObjectiveBankQuery. </code> </p>
 */

public interface ObjectiveBankSearchSession
    extends org.osid.learning.ObjectiveBankQuerySession {


    /**
     *  Gets an objective bank search. 
     *
     *  @return an objective bank search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankSearch getObjectiveBankSearch();


    /**
     *  Gets an objective bank search order. The <code> 
     *  ObjectiveBankSearchOrder </code> is supplied to a <code> 
     *  ObjectiveBankSearch </code> to specify the ordering of results. 
     *
     *  @return the objective bank search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankSearchOrder getObjectiveBankSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  objectiveBankQuery the objective bank query 
     *  @param  objectiveBankSearch the objective bank search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> objectiveBankQuery 
     *          </code> or <code> objectiveBankSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> objectiveBankQuery 
     *          </code> or <code> objectiveBankSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankSearchResults getObjectiveBanksBySearch(org.osid.learning.ObjectiveBankQuery objectiveBankQuery, 
                                                                                  org.osid.learning.ObjectiveBankSearch objectiveBankSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an objective bank query from an inspector. The inspector is 
     *  available from an <code> ObjectiveBankSearchResults. </code> 
     *
     *  @param  objectiveBankQueryInspector an objective bank query inspector 
     *  @return the objective bank query 
     *  @throws org.osid.NullArgumentException <code> 
     *          objectiveBankQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          objectiveBankQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankQuery getObjectiveBankQueryFromInspector(org.osid.learning.ObjectiveBankQueryInspector objectiveBankQueryInspector);
}
