//
// org.osid.learning.ObjectiveLookupSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveLookupSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session provides methods for retrieving <code> Objective </code> 
 *  s. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated objective bank view: All objective methods in this 
 *      session operate, retrieve and pertain to objectives defined explicitly 
 *      in the current objective bank. Using an isolated view is useful for 
 *      managing objectives with the <code> ObjectiveAdminSession. </code> 
 *      </li> 
 *      <li> federated objective bank view: All objective methods in this 
 *      session operate, retrieve and pertain to all objectives defined in 
 *      this objective bank and any other objective banks implicitly available 
 *      in this objective bank through objective bank inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Objectives may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Objective. </code> </p>
 */

public interface ObjectiveLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the <code> ObjectiveBank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Objective </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupObjectives();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeObjectiveView();


    /**
     *  A complete view of the <code> Objective </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryObjectiveView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include objectives in objective banks which are children of this 
     *  objective bank in the objective bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedObjectiveBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this objective bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedObjectiveBankView();


    /**
     *  Gets the <code> Objective </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Objective 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to an <code> 
     *  Objective </code> and retained for compatibility. 
     *
     *  @param  objectiveId <code> Id </code> of the <code> Objective </code> 
     *  @return the objective 
     *  @throws org.osid.NotFoundException <code> objectiveId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.learning.Objective getObjective(org.osid.id.Id objectiveId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObjectiveList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  objectives specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Objectives </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  objectiveIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Objective </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> objectiveIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getObjectivesByIds(org.osid.id.IdList objectiveIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObjectiveList </code> corresponding to the given 
     *  objective genus <code> Type </code> which does not include objectives 
     *  of genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known objectives or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  objectives that are accessible through this session. 
     *
     *  @param  objectiveGenusType an objective genus type 
     *  @return the returned <code> Objective </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getObjectivesByGenusType(org.osid.type.Type objectiveGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObjectiveList </code> corresponding to the given 
     *  objective genus <code> Type </code> and include any additional 
     *  objective with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  objectives or an error results. Otherwise, the returned list may 
     *  contain only those objectives that are accessible through this session 
     *
     *  @param  objectiveGenusType an objective genus type 
     *  @return the returned <code> Objective </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getObjectivesByParentGenusType(org.osid.type.Type objectiveGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObjectiveList </code> containing the given objective 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known objectives or an error results. Otherwise, the 
     *  returned list may contain only those objectives that are accessible 
     *  through this session. 
     *
     *  @param  objectiveRecordType an objective record type 
     *  @return the returned <code> Objective </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getObjectivesByRecordType(org.osid.type.Type objectiveRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Objectives. </code> In plenary mode, the returned list 
     *  contains all known objectives or an error results. Otherwise, the 
     *  returned list may contain only those objectives that are accessible 
     *  through this session. 
     *
     *  @return an <code> ObjectiveList </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getObjectives()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
