//
// org.osid.learning.ObjectiveQueryInspector
//
//     The OSID Java specification for org.osid.learning.ObjectiveQueryInspector.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This is the query inspector for examining objective queries. </p>
 */

public interface ObjectiveQueryInspector
    extends org.osid.OsidObjectQueryInspector,
            org.osid.OsidFederateableQueryInspector {


    /**
     *  Gets the asset <code> Id </code> query terms. 
     *
     *  @return the asset <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAssessmentIdTerms();


    /**
     *  Gets the asset query terms. 
     *
     *  @return the asset terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetQueryInspector[] getAssessmentTerms();


    /**
     *  Gets the knowledge category <code> Id </code> query terms. 
     *
     *  @return the knowledge category <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getKnowledgeCategoryIdTerms();


    /**
     *  Gets the knowledge category query terms. 
     *
     *  @return the knowledge category terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getKnowledgeCategoryTerms();


    /**
     *  Gets the cognitive process <code> Id </code> query terms. 
     *
     *  @return the cognitive process <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getCognitiveProcessIdTerms();


    /**
     *  Gets the cognitive process query terms. 
     *
     *  @return the cognitive process terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeQueryInspector[] getCognitiveProcessTerms();


    /**
     *  Gets the requisite objective <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRequisiteObjectiveIdTerms();


    /**
     *  Gets the requisite objective query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getRequisiteObjectiveTerms();


    /**
     *  Gets the requisite objective <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDependentObjectiveIdTerms();


    /**
     *  Gets the requisite objective query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getDependentObjectiveTerms();


    /**
     *  Gets the equivalent objective <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getEquivalentObjectiveIdTerms();


    /**
     *  Gets the equivalent objective query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getEquivalentObjectiveTerms();


    /**
     *  Gets the ancestor objective <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorObjectiveIdTerms();


    /**
     *  Gets the ancestor objective query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getAncestorObjectiveTerms();


    /**
     *  Gets the descendant objective <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantObjectiveIdTerms();


    /**
     *  Gets the descendant objective query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector[] getDescendantObjectiveTerms();


    /**
     *  Gets the activity <code> Id </code> query terms. 
     *
     *  @return the activity <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getActivityIdTerms();


    /**
     *  Gets the activity query terms. 
     *
     *  @return the activity terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ActivityQueryInspector[] getActivityTerms();


    /**
     *  Gets the objective bank <code> Id </code> query terms. 
     *
     *  @return the objective bank <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getObjectiveBankIdTerms();


    /**
     *  Gets the objective bank query terms. 
     *
     *  @return the objective bank terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBankQueryInspector[] getObjectiveBankTerms();


    /**
     *  Gets the objective query inspector record corresponding to the given 
     *  <code> Objective </code> record <code> Type. </code> 
     *
     *  @param  objectiveRecordType an objective record type 
     *  @return the objective query inspector record 
     *  @throws org.osid.NullArgumentException <code> objectiveRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(objectiveRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ObjectiveQueryInspectorRecord getObjectiveQueryInspectorRecord(org.osid.type.Type objectiveRecordType)
        throws org.osid.OperationFailedException;
}
