//
// org.osid.learning.ObjectiveSearchOrder
//
//     The OSID Java specification for org.osid.learning.ObjectiveSearchOrder.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface ObjectiveSearchOrder
    extends org.osid.OsidObjectSearchOrder,
            org.osid.OsidFederateableSearchOrder {


    /**
     *  Specified a preference for ordering results by the assessment. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAssessment(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an <code> AssessmentSearchOrder </code> is available. 
     *
     *  @return <code> true </code> if an assessment search order is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentSearchOrder();


    /**
     *  Gets the search order for an assessment. 
     *
     *  @return the assessment search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssessmentSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssessmentSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.assessment.AssessmentSearchOrder getAssessmentSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the knowledge 
     *  category. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByKnowledgeCategory(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a grade search order is available. 
     *
     *  @return <code> true </code> if a grade search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsKnowledgeCategorySearchOrder();


    /**
     *  Gets a grade search order to order on knolwgedge category. 
     *
     *  @return a grade search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsKnowledgeCategorySearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsKnowledgeCategorySearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradeSearchOrder getKnowledgeCategorySearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the cognitive 
     *  process. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCognitiveProcess(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a grade search order is available. 
     *
     *  @return <code> true </code> if a grade search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCognitiveProcessSearchOrder();


    /**
     *  Gets a grade search order to order on cognitive process. 
     *
     *  @return a grade search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCognitiveProcessSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCognitiveProcessSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.grading.GradeSearchOrder getCognitiveProcessSearchOrder();


    /**
     *  Gets the objective search order record corresponding to the given 
     *  objective record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  objectiveRecordType an objective record type 
     *  @return the objective search order record 
     *  @throws org.osid.NullArgumentException <code> objectiveRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(objectiveRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.records.ObjectiveSearchOrderRecord getObjectiveSearchOrderRecord(org.osid.type.Type objectiveRecordType)
        throws org.osid.OperationFailedException;
}
