//
// org.osid.learning.ObjectiveSmartObjectiveBankSession
//
//     The OSID Java specification for org.osid.learning.ObjectiveSmartObjectiveBankSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> ObjectiveQuery </code> can be retrieved from this 
 *  session and mapped to this <code> ObjectiveBank </code> to create a 
 *  virtual collection of <code> Objectives. </code> The objectives may be 
 *  sequenced using the <code> ObjectiveSearchOrder </code> from this session. 
 *  </p> 
 *  
 *  <p> This <code> ObjectiveBank </code> has a default query that matches any 
 *  objective and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> ObjectiveQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to an <code> 
 *  ObjectiveQuery. </code> </p>
 */

public interface ObjectiveSmartObjectiveBankSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the <code> ObjectiveBank </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart objective banks. A return of true 
     *  does not guarantee successful assessment. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart objective bank management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartObjectiveBanks();


    /**
     *  Gets an objective query. 
     *
     *  @return the objective query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQuery getObjectiveQuery();


    /**
     *  Gets an objective search order. 
     *
     *  @return the objective search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveSearchOrder getObjectiveSearchOrder();


    /**
     *  Applies an objective query to this bank. 
     *
     *  @param  objectiveQuery the objective query 
     *  @throws org.osid.NullArgumentException <code> objectiveQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> objectiveQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyObjectiveQuery(org.osid.learning.ObjectiveQuery objectiveQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an objective query inspector for this objective bank. 
     *
     *  @return the objective query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQueryInspector inspectObjectiveQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an objective search order to this objective bank. 
     *
     *  @param  objectiveSearchOrder the objective search order 
     *  @throws org.osid.NullArgumentException <code> objectiveSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> objectiveSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyObjectiveSequencing(org.osid.learning.ObjectiveSearchOrder objectiveSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an objective query from an inspector. 
     *
     *  @param  objectiveQueryInspector a query inspector 
     *  @return the objective query 
     *  @throws org.osid.NullArgumentException <code> objectiveQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> objectiveQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveQuery getObjectiveQueryFromInspector(org.osid.learning.ObjectiveQueryInspector objectiveQueryInspector);
}
