//
// org.osid.learning.ProficiencyLookupSession
//
//     The OSID Java specification for org.osid.learning.ProficiencyLookupSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session defines methods for retrieving proficiencies. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated objective bank view: All proficiency methods in this 
 *      session operate, retrieve and pertain to proficiencies defined 
 *      explicitly in the current objective bank. Using an isolated view is 
 *      useful for managing <code> Proficiencies </code> with the <code> 
 *      ProficiencyAdminSession. </code> </li> 
 *      <li> federated objective bank view: All proficiency lookup methods in 
 *      this session operate, retrieve and pertain to all proficiencies 
 *      defined in this objective bank and any other proficiencies implicitly 
 *      available in this objective bank through objective bank inheritence. 
 *      </li> 
 *      <li> effective proficiency view: All proficiency lookup methods return 
 *      proficiencies where the current date falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any proficiency view: Proficiencies of any effective date are 
 *      returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedObjectiveBankView() </code> and <code> 
 *  useIsolatedObjectiveBankView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Proficiencies may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Proficiencies. </code> </p>
 */

public interface ProficiencyLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> ObjectiveBank </code> <code> Id </code> associated 
     *  with this session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the obective bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Proficiency </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProficiencies();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProficiencyView();


    /**
     *  A complete view of the <code> Proficiency </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProficiencyView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include proficiencies in objective banks which are children of this 
     *  objective bank in the obective bank hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedObjectiveBankView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this objective bank only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedObjectiveBankView();


    /**
     *  Only proficiencies whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveProficiencyView();


    /**
     *  All proficienies of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveProficiencyView();


    /**
     *  Gets the <code> Proficiency </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Proficiency </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Proficiency </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  proficiencyId the <code> Id </code> of the <code> Proficiency 
     *          </code> to retrieve 
     *  @return the returned <code> Proficiency </code> 
     *  @throws org.osid.NotFoundException no <code> Proficiency </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> proficiencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.Proficiency getProficiency(org.osid.id.Id proficiencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  proficiencies specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Proficiencies </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  proficiencyIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> proficiencyIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByIds(org.osid.id.IdList proficiencyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> corresponding to the given 
     *  proficiency genus <code> Type </code> which does not include 
     *  proficiencies of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  proficiencies or an error results. Otherwise, the returned list may 
     *  contain only those proficiencies that are accessible through this 
     *  session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> proficiencyGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusType(org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> corresponding to the given 
     *  proficiency genus <code> Type </code> and include any additional 
     *  proficiencies with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  proficiencies or an error results. Otherwise, the returned list may 
     *  contain only those proficiencies that are accessible through this 
     *  session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> proficiencyGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByParentGenusType(org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> containing the given proficiency 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  proficiencyRecordType a proficiency record type 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> proficiencyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByRecordType(org.osid.type.Type proficiencyRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> effecyive during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesOnDate(org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> of the given proficiency genus 
     *  type effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> proficiencyGenusType, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusTypeOnDate(org.osid.type.Type proficiencyGenusType, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given objective. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForObjective(org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given objective 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForObjectiveOnDate(org.osid.id.Id objectiveId, 
                                                                                org.osid.calendaring.DateTime from, 
                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given objective 
     *  and proficiency genus <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> proficiencyGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusTypeForObjective(org.osid.id.Id objectiveId, 
                                                                                     org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> of the given proficiency genus 
     *  type relating to the given objective effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId, 
     *          proficiencyGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusTypeForObjectiveOnDate(org.osid.id.Id objectiveId, 
                                                                                           org.osid.type.Type proficiencyGenusType, 
                                                                                           org.osid.calendaring.DateTime from, 
                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given 
     *  objectives. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveIds the objective <code> Ids </code> 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForObjectives(org.osid.id.IdList objectiveIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given resource. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given resource 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForResourceOnDate(org.osid.id.Id resourceId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given resource 
     *  and proficiency genus <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> proficiencyGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusTypeForResource(org.osid.id.Id resourceId, 
                                                                                    org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> of the given proficiency genus 
     *  type relating to the given resource effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          proficiencyGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusTypeForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                          org.osid.type.Type proficiencyGenusType, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given resources. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  resourceIds the resource <code> Ids </code> 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForResources(org.osid.id.IdList resourceIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given objective 
     *  and resource <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> or 
     *          <code> resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForObjectiveAndResource(org.osid.id.Id objectiveId, 
                                                                                     org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> relating to the given resource 
     *  and objective effective during the entire given date range inclusive 
     *  but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId, resourceId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesForObjectiveAndResourceOnDate(org.osid.id.Id objectiveId, 
                                                                                           org.osid.id.Id resourceId, 
                                                                                           org.osid.calendaring.DateTime from, 
                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> of the given genus type relating 
     *  to the given objective and resource <code> . </code> 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.NullArgumentException <code> objectiveId, resourceId 
     *          </code> or <code> proficiencyGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusTypeForObjectiveAndResource(org.osid.id.Id objectiveId, 
                                                                                                org.osid.id.Id resourceId, 
                                                                                                org.osid.type.Type proficiencyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProficiencyList </code> of the given genus type relating 
     *  to the given resource and objective effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @param  objectiveId an objective <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  proficiencyGenusType a proficiency genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Proficiency </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveId, resourceId, 
     *          proficiencyGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficienciesByGenusTypeForObjectiveAndResourceOnDate(org.osid.id.Id objectiveId, 
                                                                                                      org.osid.id.Id resourceId, 
                                                                                                      org.osid.type.Type proficiencyGenusType, 
                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Proficiencies. </code> 
     *  
     *  In plenary mode, the returned list contains all known proficiencies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  proficiencies that are accessible through this session. 
     *  
     *  In effective mode, proficiencies are returned that are currently 
     *  effective. In any effective mode, effective proficiencies and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Proficiencies </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyList getProficiencies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
