//
// org.osid.learning.ProficiencySmartObjectiveBankSession
//
//     The OSID Java specification for org.osid.learning.ProficiencySmartObjectiveBankSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ProficiencyQuery </code> can be retrieved from this 
 *  session and mapped to this <code> ObjectiveBank </code> to create a 
 *  virtual collection of <code> Proficiencies. </code> The proficiencies may 
 *  be sequenced using the <code> ProficiencySearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> ObjectiveBank </code> has a default query that matches any 
 *  proficiency and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> ProficiencyQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  ProficiencyQuery. </code> </p>
 */

public interface ProficiencySmartObjectiveBankSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Familt </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> ObjectiveBank Id </code> associated with this 
     *          session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getObjectiveBankId();


    /**
     *  Gets the <code> ObjectiveBank </code> associated with this session. 
     *
     *  @return the obective bank 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveBank getObjectiveBank()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart objective banks. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart objective bank methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartObjectiveBanks();


    /**
     *  Gets a proficiency query. 
     *
     *  @return the proficiency query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyQuery getProficiencyQuery();


    /**
     *  Gets a proficiency search order. 
     *
     *  @return the proficiency search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencySearchOrder getProficiencySearchOrder();


    /**
     *  Applies a proficiency query to this objective bank. 
     *
     *  @param  proficiencyQuery the proficiency query 
     *  @throws org.osid.NullArgumentException <code> proficiencyQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> proficiencyQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyProficiencyQuery(org.osid.learning.ProficiencyQuery proficiencyQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a proficiency query inspector for this objective bank. 
     *
     *  @return the proficiency query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyQueryInspector inspectProficiencyQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a proficiency search order to this objective bank. 
     *
     *  @param  proficiencySearchOrder the proficiency search order 
     *  @throws org.osid.NullArgumentException <code> proficiencySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> proficiencySearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyProficiencySequencing(org.osid.learning.ProficiencySearchOrder proficiencySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a proficiency query from an inspector. 
     *
     *  @param  proficiencyQueryInspector a proficiency query inspector 
     *  @return the proficiency query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relatinshipQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> proficiencyQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ProficiencyQuery getProficiencyQueryFromInspector(org.osid.learning.ProficiencyQueryInspector proficiencyQueryInspector);
}
