//
// org.osid.learning.batch.ProficiencyBatchAdminSession
//
//     The OSID Java specification for org.osid.learning.batch.ProficiencyBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.learning.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Proficiencies </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Proficiency, </code> a <code> ProficiencyForm </code> is requested using 
 *  <code> getProficiencyFormsForCreate() </code> specifying the desired 
 *  objective, resource, and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  ProficiencyForms </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once a <code> ProficiencyForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> ProficiencyForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ProficiencyForms </code> returned from <code> 
 *  getProficiencyFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> ProficiencyForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  ProficiencyForm </code> of the same peer <code> Ids </code> may be used 
 *  for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ProficiencyForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ProficiencyForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createProficiencies(), </code> errors specific to an individual <code> 
 *  ProficiencyForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> ProficiencyForm </code> through the <code> 
 *  ProficiencyForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ProficiencyForms </code> are requested to the 
 *  <code> Proficiency </code> <code> Id </code> that is to be updated using 
 *  <code> getProficiencyFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> ProficiencyForm </code> may be used to link the 
 *  request. Similarly, the <code> ProficiencyForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ProficiencyForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ProficiencyForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ProficiencyForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateProficiencies(), </code> errors specific to an individual <code> 
 *  ProficiencyForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> ProficiencyForm </code> through the <code> 
 *  ProficiencyForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Proficiencies </code> in bulk. To 
 *  unmap a <code> Proficiency </code> from the current <code> ObjectiveBank, 
 *  </code> the <code> ProficiencyObjectiveBankAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  Proficiency </code> itself thus removing it from all known <code> 
 *  ObjectiveBank </code> catalogs. Bulk delete operations return the results 
 *  in <code> DeleteResponses. </code> </p>
 */

public interface ProficiencyBatchAdminSession
    extends org.osid.learning.ProficiencyAdminSession {


    /**
     *  Gets the proficiency forms for creating a bunch of new proficiencies. 
     *  A form is returned for each supplied objective and resource peer. 
     *
     *  @param  peers the proficiency peers 
     *  @param  proficiencyRecordTypes array of proficiency record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the proficiency forms 
     *  @throws org.osid.NotFoundException an <code> objectiveId </code> or 
     *          <code> resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          proficiencyRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.batch.ProficiencyBatchFormList getProficiencyFormsForCreate(org.osid.learning.batch.ProficiencyPeerList peers, 
                                                                                         org.osid.type.Type[] proficiencyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Proficiencies. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  proficiencyForms the proficiency forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> proficiencyForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createProficiencies(org.osid.learning.batch.ProficiencyBatchFormList proficiencyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the proficiency forms for updating an existing set of 
     *  proficiencies. A new proficiency form should be requested for each 
     *  update transaction. 
     *
     *  @param  proficiencyIds the <code> Ids </code> of the <code> 
     *          Proficiency </code> 
     *  @return the proficiency form 
     *  @throws org.osid.NotFoundException a <code> proficiencyId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> proficiencyIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.batch.ProficiencyBatchFormList getProficiencyFormsForUpdate(org.osid.id.IdList proficiencyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing proficiencies. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  proficiencyForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> proficiencyForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateProficiencies(org.osid.learning.batch.ProficiencyBatchFormList proficiencyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Proficiencies </code> in this <code> ObjectiveBank 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllProficiencies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes proficiencies for the given <code> Ids. </code> 
     *
     *  @param  proficiencyIds the <code> Ids </code> of the proficiencies to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> proficiencyIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProficiencies(org.osid.id.IdList proficiencyIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes proficiencies for the given objective. 
     *
     *  @param  objectiveId the <code> Id </code> of an objective 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> objectiveId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProficienciesForObjective(org.osid.id.Id objectiveId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes proficiencies for the given resource. 
     *
     *  @param  resourceId the <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProficienciesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes proficiencies expired befoe the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveProficienciesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Proficiency </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Proficiency </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another proficiency, it is reassigned to the 
     *  given entry <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasProficiencies(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
