/**
 * <p>The Open Service Interface Definitions for the org.osid.learning
 * service.</p>
 * 
 * <p>The Learning OSID manages learning objectives. A learning <code> 
 * Objective </code> describes measurable learning goals. </p> 
 * <h4> Objectives </h4> 
 * 
 * <p> <code> Objectives </code> describe measurable learning goals. A 
 * learning objective may be measured by a related <code> Assesment. </code> 
 * <code> Objectives </code> may be mapped to levels, A level is represented 
 * by a <code> Grade </code> which is used to indicate a grade level or level 
 * of difficulty. </p> 
 * 
 * <p> <code> Objectives </code> are hierarchical. An <code> Objective </code> 
 * with children represents an objective that is inclusive of all its 
 * children. For example, an <code> Objective </code> that represents learning 
 * in arithmetic may be composed of objectives that represent learning in both 
 * addition and subtraction. </p> 
 * 
 * <p> <code> Objectives </code> may also have requisites. A requisite 
 * objective is one that should be achieved before an objective is attempted. 
 * </p> 
 * <h4> Activities </h4> 
 * 
 * <p> An <code> Activity </code> describes actions that one can do to meet a 
 * learning objective. An <code> Activity </code> includes a list of <code> 
 * Assets </code> to read or watch, or a list of <code> Courses </code> to 
 * take, or a list of learning <code> Assessments </code> to practice. An 
 * <code> Activity </code> may also represent other learning activities such 
 * as taking a course or practicing an instrument. An <code> Activity </code> 
 * is specific to an <code> Objective </code> where the reusability is 
 * achieved based on what the <code> Activity </code> relates. </p> 
 * <h4> Proficiencies </h4> 
 * 
 * <p> A <code> Proficiency </code> is an <code> OsidRelationship </code> 
 * measuring the competence of a <code> Resource </code> with respect to an 
 * Objective. </p> 
 * <h4> Objective Bank Cataloging </h4> 
 * 
 * <p> <code> Objectives, Activities, </code> and <code> Proficiencies </code> 
 * can be organized into hierarchical <code> ObjectiveBanks </code> for the 
 * purposes of categorization and federation. </p> 
 * <h4> Concept Mapping </h4> 
 * 
 * <p> A concept can be modeled as a learning <code> Objective </code> without 
 * any related <code> Assessment </code> or <code> Activities. </code> In this 
 * scenario, an <code> Objective </code> looks much like the simpler <code> 
 * Subject </code> in the Ontology OSID. The Ontology OSID is constrained to 
 * qualifying concepts while the relations found in an <code> Objective 
 * </code> allow for the quantification of the learning concept and providing 
 * paths to self-learning. </p> 
 * 
 * <p> The Topology OSID may also be used to construct and view a concept map. 
 * While a Topology OSID Provider may be adapted from a Learning OSID or an 
 * Ontology OSID, the topology for either would be interpreted from a 
 * multi-parented hierarchy of the <code> Objectives </code> and <code> 
 * Subjects </code> respectively. </p> 
 * <h4> Courses </h4> 
 * 
 * <p> The Learning OSID may be used in conjunction with the Course OSID to 
 * identify dsired learning oitcomes from a course or to align the course 
 * activities and syllabus with stated learning objectives. The Course OSID 
 * describes learning from a structured curriculum management point of view 
 * where the Learning OSID and allows for various objectives to be combined 
 * and related without any regard to a prescribed curriculum. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Learning OSID contains a Learning Batch OSID for bulk management of 
 * <code> Objectives, </code> <code> Activities, </code> and <code> 
 * Proficiencies </code> . </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2009 Massachusetts Institute of Technology. </p> 
 * 
 * <p> Copyright &copy; 2011 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.learning;
