//
// org.osid.locale.CalendarConversionSession
//
//     The OSID Java specification for org.osid.locale.CalendarConversionSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This session defines methods to convert dates across calendar systems. 
 *  </p>
 */

public interface CalendarConversionSession
    extends org.osid.OsidSession {


    /**
     *  Gets the source calendar type used in this session. 
     *
     *  @return the source calendar type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getSourceCalendarType();


    /**
     *  Gets the source time type used in this session. 
     *
     *  @return the source time type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getSourceTimeType();


    /**
     *  Gets the target calendar type used in this session. 
     *
     *  @return the target calendar 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTargetCalendarType();


    /**
     *  Gets the target time type used in this session. 
     *
     *  @return the target time type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTargetTimeType();


    /**
     *  Tests if this user can perform calendar conversions. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if conversion methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canConvertCalendars();


    /**
     *  Converts a date. 
     *
     *  @param  sourceDate the date to convert 
     *  @return the resulting date 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          sourceDate.getCalendarType() != getSourceCalendarType() 
     *          </code> or <code> sourceDate.getTimeType() != 
     *          getSourceTimeType() </code> 
     *  @throws org.osid.NullArgumentException <code> sourceDate </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime convertCalendar(org.osid.calendaring.DateTime sourceDate)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Converts dates. 
     *
     *  @param  sourceDateList the dates to convert 
     *  @return the resulting dates 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          sourceDate.getCalendarType() != getSourceCalendarType() 
     *          </code> or <code> sourceDate.getTimeType() != 
     *          getSourceTimeType() </code> 
     *  @throws org.osid.NullArgumentException <code> sourceDateList </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTimeList convertCalendars(org.osid.calendaring.DateTimeList sourceDateList)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
