//
// org.osid.locale.CalendarInfo
//
//     The OSID Java specification for org.osid.locale.CalendarInfo.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This interface defines methods to examine a calendar. A calendar is 
 *  organized into "years," "months," and "days." A calendar system may offer 
 *  a diffreent designation for these divisions which may or may not vary in 
 *  duration. </p>
 */

public interface CalendarInfo {


    /**
     *  Gets the calendar type. 
     *
     *  @return the calendar type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCalendarType();


    /**
     *  Gets the display name for this calendar. 
     *
     *  @return the display name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayName();


    /**
     *  Gets a description of this calendar. 
     *
     *  @return the description 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDescription();


    /**
     *  Gets the string for the common era in which years are positive. 
     *
     *  @return the common era label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getCommonEraName();


    /**
     *  Gets the abbreviation for the common era in which years are positive. 
     *
     *  @return the common era label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getCommonEraAbbrev();


    /**
     *  Gets the string for before the common era in which years are negative. 
     *
     *  @return the before common era label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getBeforeCommonEraName();


    /**
     *  Gets the abbreviation for before the common era in which years are 
     *  negative. 
     *
     *  @return the before common era label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getBeforeCommonEraAbbrev();


    /**
     *  Gets the year number for the first year. 
     *
     *  @return the first year 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getFirstYearInCommonEra();


    /**
     *  Gets the year number for the year before the common era. 
     *
     *  @return the last bce year 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getLastYearBeforeCommonEra();


    /**
     *  Gets the display name for a calendar "year." 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getYearName();


    /**
     *  Gets the display name for a calendar "month." 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMonthName();


    /**
     *  Tests if this calendar has a variable number of months in a year. 
     *
     *  @return <code> true </code> if the number of months varies, <code> 
     *          false </code> if the number of months is constant 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasVariableMonths();


    /**
     *  Gets the number of months of the year. For a variable month calendar, 
     *  the number of all defined months are returned. If there are no 
     *  "months" in this calendar system then this value may be zero. 
     *
     *  @return the number of months 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumMonths();


    /**
     *  Gets the number of months in the given year. 
     *
     *  @param  year a year 
     *  @return the number of months 
     *  @throws org.osid.IllegalStateException <code> year </code> is greater 
     *          than <code> getLastYearBeforeCommonEra() </code> and less then 
     *          <code> getFirstYearInCommonEra() </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumMonthsForYear(long year)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the months of the year in order of the calendar. For a variable 
     *  month calendar, all defined months are returned. If there are no 
     *  "months" in this calendar system then the list may be empty. 
     *
     *  @return the months 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.CalendarUnit[] getMonths();


    /**
     *  Gets the months of the year in order of the calendar. 
     *
     *  @param  year a year 
     *  @return the months 
     *  @throws org.osid.IllegalStateException <code> year </code> is greater 
     *          than <code> getLastYearBeforeCommonEra() </code> and less then 
     *          <code> getFirstYearInCommonEra() </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.CalendarUnit[] getMonthsForYear(long year)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the display name for a calendar "day." 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDayName();


    /**
     *  Tests if this calendar has a variable number of days in a month. 
     *
     *  @return <code> true </code> if the number of days per month varies, 
     *          <code> false </code> if the number of days is constant 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasVariableDays();


    /**
     *  Gets the number of days in a year. For a variable day calendar, the 
     *  number of all defined days are returned. If there are no "days" in 
     *  this calendar system then this value may be zero. If there are no 
     *  "months" defined then the number of days is the number of days in a 
     *  year. 
     *
     *  @return the number of days 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumDays();


    /**
     *  Gets the number of days in the given month. 
     *
     *  @param  year a year 
     *  @param  month a <code> DateTime </code> month code 
     *  @return the number of days 
     *  @throws org.osid.IllegalStateException <code> year </code> is greater 
     *          than <code> getLastYearBeforeCommonEra() </code> and less then 
     *          <code> getFirstYearInCommonEra() </code> , or <code> month 
     *          </code> is greater than <code> getMonthsForYear(year) </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumDaysForMonth(long year, long month)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the days of the month in order of the calendar. For a variable 
     *  day calendar, all defined days are returned. If there are no "days" in 
     *  this time system then this value may be zero. If there are no "months" 
     *  defined then the number of days applies to the entire year. 
     *
     *  @return the days 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.CalendarUnit[] getDays();


    /**
     *  Gets the days of the given month in order of the calendar. 
     *
     *  @param  year a year 
     *  @param  month a <code> DateTime </code> month code 
     *  @return the days 
     *  @throws org.osid.IllegalStateException <code> year </code> is greater 
     *          than <code> getLastYearBeforeCommonEra() </code> and less then 
     *          <code> getFirstYearInCommonEra() </code> , or <code> month 
     *          </code> is greater than or equal to than <code> 
     *          getMonthsForYear(year) </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.CalendarUnit[] getDaysForMonth(long year, 
                                                          long month)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the first day of the calendar year. 
     *
     *  @return the first day of the year 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getFirstDayOfYear();


    /**
     *  Gets the display name for the end of the calendar. 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getEndOfDaysName();


    /**
     *  Gets the start of the "common era" for this calendar. 
     *
     *  @return start of the calendar 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getOrigin();


    /**
     *  Gets the end of the world as specified by this calendar. 
     *
     *  @return end of days 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getEndOfDays();


    /**
     *  Gets the days of the week in order of the calendar. 
     *
     *  @return the week days 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.CalendarUnit[] getWeekdays();
}
