//
// org.osid.locale.Locale
//
//     The OSID Java specification for org.osid.locale.Locale.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>A locale is a collection of types. <code> Locale </code> defines a set 
 *  of types that together define the formatting, language, calendaring, and 
 *  currency for a locale or culture. </p>
 */

public interface Locale {


    /**
     *  Gets the language <code> Type. </code> 
     *
     *  @return the language type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getLanguageType();


    /**
     *  Gets the script <code> Type. </code> 
     *
     *  @return the script type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getScriptType();


    /**
     *  Gets the calendar <code> Type. </code> 
     *
     *  @return the calendar type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCalendarType();


    /**
     *  Gets the time <code> Type. </code> 
     *
     *  @return the time type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTimeType();


    /**
     *  Gets the currency <code> Type. </code> 
     *
     *  @return the currency type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCurrencyType();


    /**
     *  Gets the unit system <code> Type. </code> 
     *
     *  @return the unit system type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getUnitSystemType();


    /**
     *  Gets the numeric format <code> Type. </code> 
     *
     *  @return the numeric format type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getNumericFormatType();


    /**
     *  Gets the calendar format <code> Type. </code> 
     *
     *  @return the calendar format type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCalendarFormatType();


    /**
     *  Gets the time format <code> Type. </code> 
     *
     *  @return the time format type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTimeFormatType();


    /**
     *  Gets the currency format <code> Type. </code> 
     *
     *  @return the currency format type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCurrencyFormatType();


    /**
     *  Gets the coordinate format <code> Type. </code> 
     *
     *  @return the coordinate format type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCoordinateFormatType();
}
