//
// org.osid.locale.LocaleManager
//
//     The OSID Java specification for org.osid.locale.LocaleManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>The locale manager provides access to locale sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> TranslationSession: </code> a session translate strings 
 *      </li> 
 *      <li> <code> TranslationAdminSession: a </code> session to update the 
 *      string translations for a locale </li> 
 *      <li> <code> NumericFormattingSession: </code> a session for formatting 
 *      and parsing numbers </li> 
 *      <li> <code> CalendarFormattingSession: </code> a session for 
 *      formatting and parsing dates and times </li> 
 *      <li> <code> CurrencyFormattingSession </code> : a session for 
 *      formatting and parsing currency amounts </li> 
 *      <li> <code> CoordinateFormattingSession: </code> a session for 
 *      formatting and parsing coordinates </li> 
 *      <li> <code> UnitConversionSession: </code> a session to convert 
 *      measurement units <code> </code> </li> 
 *      <li> <code> CurrencyConversionSession: </code> a session to convert 
 *      currency </li> 
 *      <li> <code> CalendarConversionSession: </code> a session to convert 
 *      dates across calendars </li> 
 *      <li> <code> CoordinateConversionSession: </code> a session to convert 
 *      coordinate systems </li> 
 *      <li> <code> SpatialUnitConversionSession: </code> a session to convert 
 *      spatial units </li> 
 *      <li> <code> FormatConversionSession: </code> a session to convert text 
 *      formats </li> 
 *      <li> <code> CalendarInfoSession: </code> a session for examining 
 *      calendaring and time systems </li> 
 *  </ul>
 *  
 */

public interface LocaleManager
    extends org.osid.OsidManager,
            org.osid.locale.LocaleProfile {


    /**
     *  Gets an <code> OsidSession </code> associated with the language 
     *  translation service. 
     *
     *  @return a <code> TranslationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTranslation() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTranslation() </code> is <code> true. </code> 
     */

    public org.osid.locale.TranslationSession getTranslationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the language 
     *  translation service and the given language and script types. 
     *
     *  @param  sourceLanguageType the type of the source language 
     *  @param  sourceScriptType the type of the source script 
     *  @param  targetLanguageType the type of the target language 
     *  @param  targetScriptType the type of the target script 
     *  @return a <code> TranslationSession </code> 
     *  @throws org.osid.NullArgumentException <code> sourceLanguageType, 
     *          sourceScriptType, targetLanguageType </code> or <code> 
     *          targetScriptType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTranslation() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsLanguageTypesForTranslation(sourceLanguageType, 
     *          sourceScriptType, targetLanguageType, targetScriptType) 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTranslation() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.TranslationSession getTranslationSessionForType(org.osid.type.Type sourceLanguageType, 
                                                                           org.osid.type.Type sourceScriptType, 
                                                                           org.osid.type.Type targetLanguageType, 
                                                                           org.osid.type.Type targetScriptType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a language translation administration service for updating a 
     *  locale dictionary. 
     *
     *  @return a <code> TranslationAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTranslationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTranslationAdmin() </code> is <code> true. </code> 
     */

    public org.osid.locale.TranslationAdminSession getTranslationAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a language trabslation administration service for updating a 
     *  locale dictionary using the given language and script types. 
     *
     *  @param  sourceLanguageType the type of the source language 
     *  @param  sourceScriptType the type of the source script 
     *  @param  targetLanguageType the type of the target language 
     *  @param  targetScriptType the type of the target script 
     *  @return a <code> TranslationAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> sourceLanguageType, 
     *          sourceScriptType, targetLanguageType </code> or <code> 
     *          targetScriptType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTranslationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsLanguageTypesForTranslation(sourceLanguageType, 
     *          sourceScriptType, targetLanguageType, targetScriptType) 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTranslationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.TranslationAdminSession getTranslationAdminSessionForType(org.osid.type.Type sourceLanguageType, 
                                                                                     org.osid.type.Type sourceScriptType, 
                                                                                     org.osid.type.Type targetLanguageType, 
                                                                                     org.osid.type.Type targetScriptType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the numeric 
     *  formatting service. 
     *
     *  @return a <code> NumericFormattingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNumericFormatting() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNumericFormatting() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.NumericFormattingSession getNumericFormattingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the numeric 
     *  formatting service and the given numeric format type. 
     *
     *  @param  numericFormatType the type of the numeric format 
     *  @return a <code> NumericFormattingSession </code> 
     *  @throws org.osid.NullArgumentException <code> numericFormatType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNumericFormatting() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsNumericFormatType(numericFormatType) </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNumericFormatting() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.NumericFormattingSession getNumericFormattingSessionForType(org.osid.type.Type numericFormatType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the calendar 
     *  formatting service. 
     *
     *  @return a <code> CalendarFormattingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarFormatting() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarFormatting() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.CalendarFormattingSession getCalendarFormattingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the calendar 
     *  formatting service and the given calendar and time types. 
     *
     *  @param  calendarType the type of the calendar 
     *  @param  calendarFormatType the type of the calendar format 
     *  @param  timeType the type of the time system 
     *  @param  timeFormatType the type of the time format 
     *  @return a <code> CalendarFormattingSession </code> 
     *  @throws org.osid.NullArgumentException <code> calendarType, 
     *          calendarFormatType, timeType </code> or <code> timeFormatType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarFormatting() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsCalendarTypesForFormattinge(calendarType, 
     *          calendarFormatType, timeType, timeFormatType) </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarFormatting() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.CalendarFormattingSession getCalendarFormattingSessionForType(org.osid.type.Type calendarType, 
                                                                                         org.osid.type.Type calendarFormatType, 
                                                                                         org.osid.type.Type timeType, 
                                                                                         org.osid.type.Type timeFormatType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the currency 
     *  formatting service. 
     *
     *  @return a <code> CurrencyFormattingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCurrencyFormatting() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCurrencyFormatting() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.CurrencyFormattingSession getCurrencyFormattingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the currency 
     *  formatting service and the given currency and numeric format types. 
     *
     *  @param  currencyType the type of the currency 
     *  @param  numericFormatType the type of the numeric format 
     *  @return a <code> CurrencyFormattingSession </code> 
     *  @throws org.osid.NullArgumentException <code> currencyType </code> or 
     *          <code> numericFormatType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCurrencyFormatting() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsCurrencyTypesForFomatting(currencyType, 
     *          numericFormatType) </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCurrencyFormatting() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.CurrencyFormattingSession getCurrencyFormattingSessionForType(org.osid.type.Type currencyType, 
                                                                                         org.osid.type.Type numericFormatType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the coordinate 
     *  formatting service. 
     *
     *  @return a <code> CoordinateFormattingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCoordinateFormatting() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCoordinateFormatting() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.CoordinateFormattingSession getCoordinateFormattingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the coordinate 
     *  formatting service and the given coordinate and format types. 
     *
     *  @param  coordinateType the type of the coordinate 
     *  @param  coordinateFormatType the type of the coordinate format 
     *  @return a <code> CoordinateFormattingSession </code> 
     *  @throws org.osid.NullArgumentException <code> coordinateType </code> 
     *          or <code> coordinateFormatType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCoordinateFormatting() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsCoordinateTypesForFomatting(coordinateType, 
     *          coordinateFormatType) </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCoordinateFormatting() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.CoordinateFormattingSession getCoordinateFormattingSessionForType(org.osid.type.Type coordinateType, 
                                                                                             org.osid.type.Type coordinateFormatType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a unit conversion session. 
     *
     *  @return a <code> UnitConversionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsUnitConversion() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsUnitConversion() </code> is <code> true. </code> 
     */

    public org.osid.locale.UnitConversionSession getUnitConversionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a currency conversion session. 
     *
     *  @return a <code> CurrencyConversionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCurrencyConversion() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCurrencyConversion() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.CurrencyConversionSession getCurrencyConversionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the currency 
     *  conversion service and the given currency types. 
     *
     *  @param  sourceCurrencyType the type of the source currency 
     *  @param  targetCurrencyType the type of the target currency 
     *  @return a <code> CurrencyConversionSession </code> 
     *  @throws org.osid.NullArgumentException <code> sourceCurrencyType 
     *          </code> or <code> targetCurrencyType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCurrencyConversion() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsCurrencyTypesForConversion(sourceCurrencyType, 
     *          targetCurrencyType) </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCurrencyConversion() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.CurrencyConversionSession getCurrencyConversionSessionForType(org.osid.type.Type sourceCurrencyType, 
                                                                                         org.osid.type.Type targetCurrencyType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a calendar conversion session. 
     *
     *  @return a <code> CalendarConversionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarConversion() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarConversion() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.CalendarConversionSession getCalendarConversionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the calendar 
     *  conversion service and the given calendar types. 
     *
     *  @param  sourceCalendarType the type of the source calendar 
     *  @param  sourceTimeType the type of the source time 
     *  @param  targetCalendarType the type of the target calendar 
     *  @param  targetTimeType the type of the target time 
     *  @return a <code> CalendarConversionSession </code> 
     *  @throws org.osid.NullArgumentException <code> sourceCalendarType, 
     *          sourceTimeType, </code> <code> targetCalendarType </code> or 
     *          <code> targetTimeType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCalendarConversion() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsCalendarTypesForConversion(sourceCalendarType, 
     *          targetCalendarType) </code> or <code> 
     *          supportsTimeTypesForConversion(sourceTimeType, targetTimeType) 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarConversion() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.CalendarConversionSession getCalendarConversionSessionForType(org.osid.type.Type sourceCalendarType, 
                                                                                         org.osid.type.Type sourceTimeType, 
                                                                                         org.osid.type.Type targetCalendarType, 
                                                                                         org.osid.type.Type targetTimeType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a coordinate conversion session. 
     *
     *  @return a <code> CoordinateConversionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCoordinateConversion() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCoordinateConversion() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.CoordinateConversionSession getCoordinateConversionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the coordinate 
     *  conversion service and the given coordinate types. 
     *
     *  @param  sourceCoordinateType the type of the source coordinate 
     *  @param  targetCoordinateType the type of the target coordinate 
     *  @return a <code> CoordinateConversionSession </code> 
     *  @throws org.osid.NullArgumentException <code> sourceCoordinateType 
     *          </code> or <code> targetCoordinateType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCoordinateConversion() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsCoordinateRecordTypesForConversion(sourceCoordinateType, 
     *          targetCoordinateType) </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCoordinateConversion() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.CoordinateConversionSession getCoordinateConversionSessionForType(org.osid.type.Type sourceCoordinateType, 
                                                                                             org.osid.type.Type targetCoordinateType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a spatial unit conversion session. 
     *
     *  @return a <code> SpatialUnitConversionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpatialUnitConversion() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpatialUnitConversion() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.locale.SpatialUnitConversionSession getSpatialUnitConversionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the spatial unit 
     *  conversion service and the given spatial unit record types. 
     *
     *  @param  sourceSpatialUnitRecordType the type of the source spatial 
     *          unit record 
     *  @param  targetSpatialUnitRecordType the type of the target spatial 
     *          unit record 
     *  @return a <code> SpatialUnitConversionSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          sourceSpatialUnitRecordType </code> or <code> 
     *          targetSpatialUnitRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpatialUnitConversion() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsSpatialUnitRecordTypesForConversion(sourceSpatialUnitRecordType, 
     *          targetSpatialUnitRecordType) </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpatialUnitConversion() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.SpatialUnitConversionSession getSpatialUnitConversionSessionForType(org.osid.type.Type sourceSpatialUnitRecordType, 
                                                                                               org.osid.type.Type targetSpatialUnitRecordType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a text format conversion session. 
     *
     *  @return a <code> FormatConversionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFormatConversion() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFormatConversion() </code> is <code> true. </code> 
     */

    public org.osid.locale.FormatConversionSession getFormatConversionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the text format 
     *  conversion service and the given format types. 
     *
     *  @param  sourceFormatType the type of the text format 
     *  @param  targetFormatType the type of the text format 
     *  @return a <code> FormatConversionSession </code> 
     *  @throws org.osid.NullArgumentException <code> sourceFormatType </code> 
     *          or <code> targetFormatType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFormatConversion() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsFormatTypesForConversion(sourceFormatType, 
     *          targetFormatRecordType) </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFormatConversion() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.FormatConversionSession getFormatConversionSessionForType(org.osid.type.Type sourceFormatType, 
                                                                                     org.osid.type.Type targetFormatType)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a calendar informational session session. 
     *
     *  @return a <code> CalendarInfoSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarInfo() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarInfo() </code> is <code> true. </code> 
     */

    public org.osid.locale.CalendarInfoSession getCalendarInfoSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets an <code> OsidSession </code> associated with the calendar 
     *  informational service and the given calendar and time types. 
     *
     *  @param  calendarType the type of the calendar 
     *  @param  timeType the type of the time system 
     *  @return a <code> CalendarInfoSession </code> 
     *  @throws org.osid.NullArgumentException <code> calendarType </code> or 
     *          <code> timeType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCalendarType() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsCalendarTimeTypes(calendarType, timeType) </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCalendarInfo() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.locale.CalendarInfoSession getCalendarInfoSessionForType(org.osid.type.Type calendarType, 
                                                                             org.osid.type.Type timeType)
        throws org.osid.OperationFailedException;
}
