//
// org.osid.locale.TimeInfo
//
//     The OSID Java specification for org.osid.locale.TimeInfo.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This interface defines methods to examine a time. Time is organized 
 *  intro "hours," "minutes," and "seconds." A time system may offer a 
 *  different designation for these divisions which may or may not vary in 
 *  duration. </p>
 */

public interface TimeInfo {


    /**
     *  Gets the time type. 
     *
     *  @return the time type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTimeType();


    /**
     *  Gets the display name for this time system. 
     *
     *  @return the display name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayName();


    /**
     *  Gets a short label for this time system. 
     *
     *  @return the label 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDisplayLabel();


    /**
     *  Gets a description of this time system. 
     *
     *  @return the description 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getDescription();


    /**
     *  Gets the display name for "hours." 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getHourName();


    /**
     *  Gets the abbreviation for "hours." 
     *
     *  @return the abbreviation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getHourAbbrev();


    /**
     *  Gets the initial for "hours." 
     *
     *  @return the initial 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getHourInitial();


    /**
     *  Tests if this time system has a variable number of hours in a day. 
     *
     *  @return <code> true </code> if the number of hours per day varies, 
     *          <code> false </code> if the number of hours per day is 
     *          constant 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasVariableHours();


    /**
     *  Gets the number of hours in a day. For a variable hour time system, 
     *  the number of hours defined is returned. If there are no "hours" in 
     *  this time system then this value may be zero. 
     *
     *  @return the number of hours 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumHours();


    /**
     *  Gets the number of hours for a given day. 
     *
     *  @param  year a year 
     *  @param  month a <code> DateTime </code> month code 
     *  @param  day a <code> DateTime </code> day code 
     *  @return the number of hours 
     *  @throws org.osid.IllegalStateException <code> year </code> is greater 
     *          than <code> CalendarInfo.getLastYearBeforeCommonEra() </code> 
     *          and less then <code> CalendarInfo.getFirstYearInCommonEra() 
     *          </code> , or <code> month </code> is greater than or equal to 
     *          <code> CalendarInfo.getNumMonthsForYear(year) </code> , or 
     *          <code> day </code> is greater than or equal to <code> 
     *          CalendarInfo.getDaysInMonth(year, month) </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumHoursForDay(long year, long month, long day)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the display name for "minutes." 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMinuteName();


    /**
     *  Gets the abbreviation for "minutes." 
     *
     *  @return the abbreviation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMinuteAbbrev();


    /**
     *  Gets the initial for "minutes." 
     *
     *  @return the initial 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMinuteInitial();


    /**
     *  Tests if this time system has a variable number of minutes in an hour. 
     *
     *  @return <code> true </code> if the number of minutes per hour varies, 
     *          <code> false </code> if the number of minutes per hour is 
     *          constant 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasVariableMinutes();


    /**
     *  Gets the number of minutes in an hour. For a variable minute time 
     *  system, the number of minutes defined is returned. If there are no 
     *  "minutes" in this time system then this value may be zero. If there 
     *  are no "hours" defined then the number of minutes is the number of 
     *  minutes in a day. 
     *
     *  @return the number of minutes 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumMinutes();


    /**
     *  Gets the minutes for a given hour. 
     *
     *  @param  year a year 
     *  @param  month a <code> DateTime </code> month code 
     *  @param  day a <code> DateTime </code> day code 
     *  @param  hour an hour 
     *  @return the number of minutes 
     *  @throws org.osid.IllegalStateException <code> year </code> is greater 
     *          than <code> CalendarInfo.getLastYearBeforeCommonEra() </code> 
     *          and less then <code> CalendarInfo.getFirstYearInCommonEra(), 
     *          </code> or <code> month </code> is greater than or equal to 
     *          <code> CalendarInfo.getNumMonthsForYear(year) </code> , or 
     *          <code> day </code> is greater than or equal to <code> 
     *          CalendarInfo.getDaysInMonth(year, month) </code> , or <code> 
     *          hour </code> is greater than or equal to <code> 
     *          getNumHoursInDay(year, month, day) </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumMinutesForHour(long year, long month, long day, 
                                     long hour)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the display name for "seconds." 
     *
     *  @return the name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSecondName();


    /**
     *  Gets the abbreviation for "seconds." 
     *
     *  @return the abbreviation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSecondAbbrev();


    /**
     *  Gets the initial for "seconds." 
     *
     *  @return the initial 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getSecondInitial();


    /**
     *  Tests if this time system has a variable number of seconds in a 
     *  minute. 
     *
     *  @return <code> true </code> if the number of seconds per minute 
     *          varies, <code> false </code> if the number of seconds per 
     *          minute is constant 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasVariableSeconds();


    /**
     *  Gets the number of seconds in a minute. For a variable second time 
     *  system, the number of seconds defined is returned. If there are no 
     *  "seconds" in this time system then this value may be zero. If there 
     *  are no "minutes" defined then the number of seconds is the number of 
     *  seconds in an hour. 
     *
     *  @return the number of seconds 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumSeconds();


    /**
     *  Gets the seconds for a given minute. 
     *
     *  @param  year a year 
     *  @param  month a <code> DateTime </code> month code 
     *  @param  day a <code> DateTime </code> day code 
     *  @param  hour an hour 
     *  @param  minute a minute 
     *  @return the number of seconds 
     *  @throws org.osid.IllegalStateException <code> year </code> is greater 
     *          than <code> getLastYearBeforeCommonEra() </code> and less then 
     *          <code> getFirstYearInCommonEra() </code> , or <code> month 
     *          </code> is greater than or equal to <code> 
     *          CalendarInfo.getNumMonthsForYear(year) </code> , or <code> day 
     *          </code> is greater than or equal to <code> 
     *          CalendarInfo.getDaysInMonth(year, month) </code> , or <code> 
     *          hour </code> is greater than or equal to <code> 
     *          getNumHoursInDay(year, month, day) </code> , or <code> minute 
     *          </code> is greater than or equal to <code> 
     *          getNumMinutesInhour(year, month, day, hour) </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getNumSecondsForMinute(long year, long month, long day, 
                                       long hour, long minute)
        throws org.osid.OperationFailedException;
}
