//
// org.osid.locale.TranslationAdminSession
//
//     The OSID Java specification for org.osid.locale.TranslationAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.locale;


/**
 *  <p>This session defines methods to translate and format text between a 
 *  source and target locale. </p>
 */

public interface TranslationAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the source language used in this session. 
     *
     *  @return the source language 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getSourceLanguageType();


    /**
     *  Gets the source script used in this session. 
     *
     *  @return the source script 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getSourceScriptType();


    /**
     *  Gets the target language used in this session. 
     *
     *  @return the target language 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTargetLanguageType();


    /**
     *  Gets the target script used in this session. 
     *
     *  @return the target script 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getTargetScriptType();


    /**
     *  Tests if this user can update localization strings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer notification operations. 
     *
     *  @return <code> false </code> if changing translation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateTranslation();


    /**
     *  Adds or updates a string translation. 
     *
     *  @param  sourceText the source <code> string </code> 
     *  @param  targetText the translated string 
     *  @throws org.osid.NullArgumentException <code> sourceText </code> or 
     *          <code> targetText </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addTranslation(String sourceText, String targetText)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a translation. 
     *
     *  @param  sourceText the source <code> string </code> 
     *  @throws org.osid.NullArgumentException <code> sourceText </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeTranslation(String sourceText)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
