/**
 * <p>The Open Service Interface Definitions for the org.osid.locale
 * service.</p>
 * 
 * <p>The Locale OSID provides the service of localizing applications defining 
 * interfaces for string translation, measurement unit conversion, calendar 
 * conversion, spatial conversion, and currency conversion. </p> 
 * <h4> String Translation </h4> 
 * 
 * <p> The Locale OSID can access and manage string translations using the 
 * <code> TranslationSession </code> and <code> TranslationAdminSession 
 * </code> respectively. Translations map a pair of strings with language and 
 * script Types. The translation services provide a simple means for an OSID 
 * Consumer to localize known display strings for an application. </p> 
 * <h4> Numeric Formatting </h4> 
 * 
 * <p> The <code> NumericFormattingSession </code> provides the service of 
 * converting numbers to display strings and parsing display strings into 
 * numbers. The format of the display string is identified by a numeric format 
 * <code> Type. </code> It supports the various numeric types defined among 
 * OSID Primitives such as integers, decimals, and cardinal numbers. </p> 
 * <h4> Calendar Formatting </h4> 
 * 
 * <p> The <code> CalendarFormattingSession </code> converts <code> DateTime 
 * </code> and <code> Time </code> OSID Primitives to display strings and 
 * parses display strings back into <code> DateTimes </code> and <code> Times. 
 * </code> The display string formats are specified by a date format <code> 
 * Type </code> and time format <code> Type </code> respectively. The 
 * calendaring and time systems implemented by <code> DateTime </code> and 
 * <code> Time </code> are specified by a calendar <code> Type </code> and 
 * time <code> Type. </code> Conversions among calendaring systems are 
 * performed using the <code> CalendarConversionSession. </code> </p> 
 * <h4> Currency Formatting </h4> 
 * 
 * <p> The <code> CurrencyFormattingSession </code> converts currency amounts 
 * to display strings and parses display strings into currency amounts. The 
 * format of the display string is identified by both a currency and a numeric 
 * format <code> Type. </code> Conversions among currencies are performed 
 * using the <code> CurrencyConversionSession. </code> </p> 
 * <h4> Coordinate Formatting </h4> 
 * 
 * <p> The <code> CoordinateFormattingSession </code> converts <code> 
 * Coordinate </code> OSID Primitives to display strings and parses display 
 * strings back into <code> Coordinates. </code> The display string formats 
 * are specified by a coordinate format <code> Type. </code> The coordinate 
 * data is identified by the coordinate record <code> Type. </code> 
 * Conversions among calendaring systems are performed using the <code> 
 * CoordinateConversionSession. </code> </p> 
 * <h4> Unit Conversion </h4> 
 * 
 * <p> The <code> UnitConversionSession </code> converts units of measurement 
 * among unit types. The unit types may represent different units within the 
 * same system of measurement or units among different measurement systems 
 * where a conversion exists. </p> 
 * <h4> Currency Conversion </h4> 
 * 
 * <p> The <code> CurrencyConversionSession </code> converts a currency amount 
 * from one currency system to another where a means for transforming the 
 * currency values exists. </p> 
 * <h4> Spatial Unit Conversion </h4> 
 * 
 * <p> The <code> SpatialUnitConversionSession </code> converts a spatial 
 * units from one spatial system to another where a means for transforming the 
 * spatial units exists. </p> 
 * <h4> Text Format Conversion </h4> 
 * 
 * <p> The <code> FormatConversionSession </code> converts text from one 
 * format to another. </p> 
 * 
 * <p> </p> 
 * <h4> Informational Objects </h4> 
 * 
 * <p> The Locale OSID includes a <code> CalendarInfo </code> and <code> 
 * TimeInfo </code> interfaces for inspecting the details of the respective 
 * <code> Types </code> to assist in displaying calendars and clocks without 
 * knowledge of the specific system. </p> 
 * 
 * <p> The <code> Locale </code> interface defines a set of types that 
 * together define the formatting, language, calendaring, and currency for a 
 * locale or culture. Locale is referenced in OsidSessions to convey the 
 * localization of the service. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.locale;
