//
// org.osid.logging.LogEntryAdminSession
//
//     The OSID Java specification for org.osid.logging.LogEntryAdminSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session creates, updates, and deletes <code> LogEntries. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  LogEntry, </code> a <code> LogEntryForm </code> is requested using <code> 
 *  getLogEntryFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> LogEntryForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> LogEntryForm </code> is submiited 
 *  to a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> LogEntryForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> LogEntryForms </code> are requested to the <code> 
 *  LogEntry </code> <code> Id </code> that is to be updated using <code> 
 *  getLogEntryFormForUpdate(). </code> Similarly, the <code> LogEntryForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> LogEntryForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> LogEntries. </code> To unmap a 
 *  <code> LogEntry </code> from the current <code> Log, </code> the <code> 
 *  LogEntryLogAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> LogEntry </code> itself thus 
 *  removing it from all known <code> Log </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface LogEntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Log </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Log Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLogId();


    /**
     *  Gets the <code> Log </code> associated with this session. 
     *
     *  @return the <code> Log </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.Log getLog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create log entries. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> LogEntry </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> LogEntry </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateLogEntries();


    /**
     *  Tests if this user can create a single <code> LogEntry </code> using 
     *  the desired record types. While <code> 
     *  LoggingManager.getLogEntryRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> LogEntry. </code> Providing an 
     *  empty array tests if a <code> LogEntry </code> can be created with no 
     *  records. 
     *
     *  @param  logEntryRecordTypes array of log entry record types 
     *  @return <code> true </code> if <code> LogEntry </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateLogEntryWithRecordTypes(org.osid.type.Type[] logEntryRecordTypes);


    /**
     *  Gets the log entry form for creating new log entries. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  logEntryRecordTypes array of log entry record types 
     *  @return the log entry form 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryForm getLogEntryFormForCreate(org.osid.type.Type[] logEntryRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> LogEntry. </code> 
     *
     *  @param  logEntryForm the form for this <code> LogEntry </code> 
     *  @return the new <code> LogEntry </code> 
     *  @throws org.osid.IllegalStateException <code> logEntryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> logEntryForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryForm </code> did 
     *          not originate from <code> getLogEntryFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntry createLogEntry(org.osid.logging.LogEntryForm logEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update log entries. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Log </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> LogEntry </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateLogEntries();


    /**
     *  Gets the log entry form for updating an existing log. A new log entry 
     *  form should be requested for each update transaction. 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> 
     *  @return the log entry form 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryForm getLogEntryFormForUpdate(org.osid.id.Id logEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing log entry. 
     *
     *  @param  logEntryForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> logEntryForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> logEntryForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryForm </code> did 
     *          not originate from <code> getLogEntryFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateLogEntry(org.osid.logging.LogEntryForm logEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete log entries. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> LogEntry </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> LogEntry </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteLogEntries();


    /**
     *  Deletes a <code> LogEntry. </code> 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> logEntryId 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteLogEntry(org.osid.id.Id logEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for log 
     *  entries. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known changing an alias will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer alias operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> LogEntry </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageLogEntryAliases();


    /**
     *  Adds an <code> Id </code> to a <code> LogEntry </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  LogEntry </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another log entry, it is reassigned to the given 
     *  log entry <code> Id. </code> 
     *
     *  @param  logEntryId the <code> Id </code> of a <code> LogEntry </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasLogEntry(org.osid.id.Id logEntryId, 
                              org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
