//
// org.osid.logging.LogEntryForm
//
//     The OSID Java specification for org.osid.logging.LogEntryForm.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This is the form for creating and updating log entries. <code> </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  LogEntryAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface LogEntryForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for a priority type. 
     *
     *  @return metadata for the priority 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPriorityMetadata();


    /**
     *  Sets the priority. 
     *
     *  @param  priority the new priority 
     *  @throws org.osid.InvalidArgumentException <code> priority </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> priority </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPriority(org.osid.type.Type priority);


    /**
     *  Removes the priority. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriority();


    /**
     *  Gets the metadata for a timestamp. 
     *
     *  @return metadata for the timestamp 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTimestampMetadata();


    /**
     *  Sets the timestamp. 
     *
     *  @param  timestamp the new timestamp 
     *  @throws org.osid.InvalidArgumentException <code> timestamp </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> timestamp </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimestamp(org.osid.calendaring.DateTime timestamp);


    /**
     *  Gets the metadata for the agent. 
     *
     *  @return metadata for the agent 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAgentMetadata();


    /**
     *  Sets the agent. 
     *
     *  @param  agentId the new agent 
     *  @throws org.osid.InvalidArgumentException <code> agentId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAgent(org.osid.id.Id agentId);


    /**
     *  Gets the <code> LogEntryFormRecord </code> corresponding to the given 
     *  log entry record <code> Type. </code> 
     *
     *  @param  logEntryRecordType the log entry record type 
     *  @return the log entry form record 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(logEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.records.LogEntryFormRecord getLogEntryFormRecord(org.osid.type.Type logEntryRecordType)
        throws org.osid.OperationFailedException;
}
