//
// org.osid.logging.LogEntryLookupSession
//
//     The OSID Java specification for org.osid.logging.LogEntryLookupSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session provides methods for retrieving <code> log entries. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> federated log view: searches include entries in logs of which 
 *      this log is an ancestor in the log hierarchy </li> 
 *      <li> isolated log view: searches are restricted to entries in this log 
 *      only </li> 
 *  </ul>
 *  
 */

public interface LogEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Log </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Log Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLogId();


    /**
     *  Gets the <code> Log </code> associated with this session. 
     *
     *  @return the log 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.Log getLog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can read the log. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer reading operations. 
     *
     *  @return <code> false </code> if reading methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canReadLog();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeLogEntryView();


    /**
     *  A complete view of the <code> LogEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryLogEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in logs which are children of this log in the log 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedLogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this log only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedLogView();


    /**
     *  Gets the <code> LogEntry </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> LogEntry 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  LogEntry </code> and retained for compatibility. 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> to retrieve 
     *  @return the returned <code> LogEntry </code> 
     *  @throws org.osid.NotFoundException no <code> LogEntry </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntry getLogEntry(org.osid.id.Id logEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  entries specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible logentries may be omitted from the list and may present 
     *  the elements in any order including returning a unique set. 
     *
     *  @param  logEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> LogEntry list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> logEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByIds(org.osid.id.IdList logEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given log 
     *  entry genus <code> Type </code> which doe snot include entries of 
     *  genus types derived form the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session 
     *
     *  @param  logEntryGenusType a log entry genus type 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> logEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByGenusType(org.osid.type.Type logEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given log 
     *  entry genus <code> Type </code> and include any additional entries 
     *  with genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session. 
     *
     *  @param  logEntryGenusType a log entry genus type 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> logEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByParentGenusType(org.osid.type.Type logEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> containing the given log entry 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known log entries or an error results. Otherwise, the 
     *  returned list may contain only those log entries that are accessible 
     *  through this session. 
     *
     *  @param  logEntryGenusType a log entry genus type 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> logEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByRecordType(org.osid.type.Type logEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> filtering the list to log entries 
     *  including and above the given priority <code> Type. </code> In plenary 
     *  mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session. 
     *
     *  @param  priorityType a log entry priority type 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByPriorityType(org.osid.type.Type priorityType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given time 
     *  interval inclusive. <code> </code> In plenary mode, the returned list 
     *  contains all known entries or an error results. Otherwise, the 
     *  returned list may contain only those entries that are accessible 
     *  through this session. 
     *
     *  @param  start a starting time 
     *  @param  end a starting time 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByDate(org.osid.calendaring.DateTime start, 
                                                             org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given time 
     *  interval inclusive filtering the list to log entries including and 
     *  above the given priority <code> Type. </code> In plenary mode, the 
     *  returned list contains all known entries or an error results. 
     *  Otherwise, the returned list may contain only those entries that are 
     *  accessible through this session. 
     *
     *  @param  priorityType a log entry priority type 
     *  @param  start a starting time 
     *  @param  end a starting time 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> priorityType, start 
     *          </code> or <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByPriorityTypeAndDate(org.osid.type.Type priorityType, 
                                                                            org.osid.calendaring.DateTime start, 
                                                                            org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> for an agent associated with the 
     *  given resource. In plenary mode, the returned list contains all known 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given time 
     *  interval inclusive for an agent associated with the given resource. 
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  start a starting time 
     *  @param  end a starting time 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, start 
     *          </code> or <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByDateForResource(org.osid.id.Id resourceId, 
                                                                        org.osid.calendaring.DateTime start, 
                                                                        org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given time 
     *  interval inclusive for an agent associated with the given resource 
     *  filtering the list to log entries including and above the given 
     *  priority <code> Type. </code> In plenary mode, the returned list 
     *  contains all known entries or an error results. Otherwise, the 
     *  returned list may contain only those entries that are accessible 
     *  through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  priorityType a log entry priority type 
     *  @param  start a starting time 
     *  @param  end a starting time 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          priorityType, start </code> or <code> end </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByPriorityTypeAndDateForResource(org.osid.id.Id resourceId, 
                                                                                       org.osid.type.Type priorityType, 
                                                                                       org.osid.calendaring.DateTime start, 
                                                                                       org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all log entries. In plenary mode, the returned list contains all 
     *  known entries or an error results. Otherwise, the returned list may 
     *  contain only those entries that are accessible through this session. 
     *
     *  @return a list of log entries 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
