//
// org.osid.logging.LogEntryQueryInspector
//
//     The OSID Java specification for org.osid.logging.LogEntryQueryInspector.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This is the query inspector for examining log entry queries. </p>
 */

public interface LogEntryQueryInspector
    extends org.osid.OsidObjectQueryInspector {


    /**
     *  Gets the prirority query terms. 
     *
     *  @return the priority terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getPriorityTerms();


    /**
     *  Gets the minimum prirority query terms. 
     *
     *  @return the minimum priority terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.TypeTerm[] getMinimumPriorityTerms();


    /**
     *  Gets the timestamp query terms. 
     *
     *  @return the timestamp terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getTimestampTerms();


    /**
     *  Gets the resource <code> Id </code> query terms. 
     *
     *  @return the resource <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getResourceIdTerms();


    /**
     *  Gets the resource query terms. 
     *
     *  @return the resource terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getResourceTerms();


    /**
     *  Gets the agent <code> Id </code> query terms. 
     *
     *  @return the agent <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAgentIdTerms();


    /**
     *  Gets the agent query terms. 
     *
     *  @return the agent terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.AgentQueryInspector[] getAgentTerms();


    /**
     *  Gets the log <code> Id </code> query terms. 
     *
     *  @return the log <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getLogIdTerms();


    /**
     *  Gets the log query terms. 
     *
     *  @return the log terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogQueryInspector[] getLogTerms();


    /**
     *  Gets the log entry query inspector corresponding to the given <code> 
     *  LogEntry </code> record <code> Type. </code> 
     *
     *  @param  logEntryRecordType a log entry record type 
     *  @return the log entry query record 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(logEntryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.records.LogEntryQueryInspectorRecord getLogEntryQueryInspectorRecord(org.osid.type.Type logEntryRecordType)
        throws org.osid.OperationFailedException;
}
