//
// org.osid.logging.LogEntryQuerySession
//
//     The OSID Java specification for org.osid.logging.LogEntryQuerySession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session provides methods for searching among log entries. The 
 *  search query is constructed using the <code> LogEntryQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated log view: searches include entries in logs of which 
 *      this log is an ancestor in the log hierarchy </li> 
 *      <li> isolated log view: searches are restricted to entries in this log 
 *      only </li> 
 *  </ul>
 *  
 */

public interface LogEntryQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Log </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Log Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLogId();


    /**
     *  Gets the <code> Log </code> associated with this session. 
     *
     *  @return the <code> Log </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.Log getLog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> LogEntry </code> searches. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchLogEntries();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in logs which are children of this log in the log 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedLogView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this log only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedLogView();


    /**
     *  Gets a log entry query 
     *
     *  @return the log entry query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryQuery getLogEntryQuery();


    /**
     *  Gets a list of log entries matching the given log entry query 
     *
     *  @param  logEntryQuery the log entry query 
     *  @return the returned <code> LogEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> logEntryQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryQuery </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryList getLogEntriesByQuery(org.osid.logging.LogEntryQuery logEntryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
