//
// org.osid.logging.LogEntrySearchSession
//
//     The OSID Java specification for org.osid.logging.LogEntrySearchSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session provides methods for searching among log entries. The 
 *  search query is constructed using the <code> LogEntryQuery. </code> </p> 
 *  
 *  <p> <code> getLogEntriesByQuery() </code> is the basic search method and 
 *  returns a list of log entries. A more advanced search may be performed 
 *  with <code> getLogEntriesBySearch(). </code> It accepts a <code> 
 *  LogEntrySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getLogEntriesBySearch() </code> returns a <code> 
 *  LogEntrySearchResults </code> that can be used to access the resulting 
 *  <code> LogEntryList </code> or be used to perform a search within the 
 *  result set through <code> LogEntrySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated log view: searches include entries in logs of which 
 *      this log is an ancestor in the log hierarchy </li> 
 *      <li> isolated log view: searches are restricted to entries in this log 
 *      only </li> 
 *  </ul>
 *  
 */

public interface LogEntrySearchSession
    extends org.osid.logging.LogEntryQuerySession {


    /**
     *  Gets a log entry search. 
     *
     *  @return the log entry search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntrySearch getLogEntrySearch();


    /**
     *  Gets a log entry search order. The <code> LogEntrySearchOrder </code> 
     *  is supplied to a <code> LogEntrySearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the log entry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntrySearchOrder getLogEntrySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  logEntryQuery the log entry query 
     *  @param  logEntrySearch the log entry search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> logEntryQuery </code> or 
     *          <code> logEntrySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryQuery </code> or 
     *          <code> logEntrySearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntrySearchResults getLogEntriesBySearch(org.osid.logging.LogEntryQuery logEntryQuery, 
                                                                        org.osid.logging.LogEntrySearch logEntrySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a log entry query from an inspector. The inspector is available 
     *  from a <code> LogEntrySearchResults. </code> 
     *
     *  @param  logEntryQueryInspector a log entry query inspector 
     *  @return the log entry query 
     *  @throws org.osid.NullArgumentException <code> logEntryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> logEntryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryQuery getLogEntryQueryFromInspector(org.osid.logging.LogQueryInspector logEntryQueryInspector);
}
