//
// org.osid.logging.LogEntrySmartLogSession
//
//     The OSID Java specification for org.osid.logging.LogEntrySmartLogSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> LogEntryQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Log </code> to create a virtual 
 *  collection of log entries. The log entries may be sequenced using the 
 *  <code> LogEntrySearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Log </code> has a default query that matches any log entry 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using a <code> LogEntryQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to a <code> LogEntryQuery. 
 *  </code> </p>
 */

public interface LogEntrySmartLogSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Log </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Log Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLogId();


    /**
     *  Gets the <code> Log </code> associated with this session. 
     *
     *  @return the <code> Log </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.Log getLog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart log. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart log management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartLog();


    /**
     *  Gets a logEntry query. 
     *
     *  @return the log entry query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryQuery getLogEntryQuery();


    /**
     *  Gets a logEntry search order. 
     *
     *  @return the logEntry search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntrySearchOrder getLogEntrySearchOrder();


    /**
     *  Applies a logEntry query to this log. 
     *
     *  @param  logEntryQuery the logEntry query 
     *  @throws org.osid.NullArgumentException <code> logEntryQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> logEntryQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyLogEntryQuery(org.osid.logging.LogEntryQuery logEntryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a logEntry query inspector for this log. 
     *
     *  @return the logEntry query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryQueryInspector inspectLogEntryQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a logEntry search order to this log. 
     *
     *  @param  logEntrySearchOrder the logEntry search order 
     *  @throws org.osid.NullArgumentException <code> logEntrySearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> logEntrySearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyLogEntrySequencing(org.osid.logging.LogEntrySearchOrder logEntrySearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a logEntry query from an inspector. 
     *
     *  @param  logEntryQueryInspector a resorce relationship query inspector 
     *  @return the logEntry query 
     *  @throws org.osid.NullArgumentException <code> logEntryQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> logEntryQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryQuery getLogEntryQueryFromInspector(org.osid.logging.LogEntryQueryInspector logEntryQueryInspector);
}
