//
// org.osid.logging.LogSearchSession
//
//     The OSID Java specification for org.osid.logging.LogSearchSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session provides methods for searching <code> Log </code> objects. 
 *  The search query is constructed using the <code> LogQuery </code> . The 
 *  log record <code> Type </code> also specifies the record for the log 
 *  query. </p> 
 *  
 *  <p> <code> getLogsByQuery() </code> is the basic search method and returns 
 *  a list of <code> Log </code> elements. A more advanced search may be 
 *  performed with <code> getLogsBySearch(). </code> It accepts a <code> 
 *  LogSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getLogsBySearch() </code> returns a <code> LogSearchResults </code> that 
 *  can be used to access the resulting <code> LogList </code> or be used to 
 *  perform a search within the result set through <code> LogSearch. </code> 
 *  </p> 
 *  
 *  <p> Logs may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> LogQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface LogSearchSession
    extends org.osid.logging.LogQuerySession {


    /**
     *  Gets a log search. 
     *
     *  @return the log search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogSearch getLogSearch();


    /**
     *  Gets a log search order. The <code> LogSearchOrder </code> is supplied 
     *  to a <code> LogSearch </code> to specify the ordering of results. 
     *
     *  @return the log search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogSearchOrder getLogSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  logQuery the log query 
     *  @param  logSearch the log search 
     *  @return the log search results 
     *  @throws org.osid.NullArgumentException <code> logQuery </code> or 
     *          <code> logSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logQuery </code> or 
     *          <code> logSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogSearchResults getLogsBySearch(org.osid.logging.LogQuery logQuery, 
                                                             org.osid.logging.LogSearch logSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a log query from an inspector. The inspector is available from a 
     *  <code> LogSearchResults. </code> 
     *
     *  @param  logQueryInspector a log query inspector 
     *  @return the log query 
     *  @throws org.osid.NullArgumentException <code> logQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> logQueryInspector </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogQuery getLogQueryFromInspector(org.osid.logging.LogQueryInspector logQueryInspector);
}
