//
// org.osid.logging.LoggingProfile
//
//     The OSID Java specification for org.osid.logging.LoggingProfile.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>The logging profile describes the interoperability among logging 
 *  services. </p>
 */

public interface LoggingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if visible federation is supported. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if logging is supported. 
     *
     *  @return <code> true </code> if logging is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogging();


    /**
     *  Tests if reading logs is supported. 
     *
     *  @return <code> true </code> if reading logs is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryLookup();


    /**
     *  Tests if querying log entries is supported. 
     *
     *  @return <code> true </code> if querying log entries is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryQuery();


    /**
     *  Tests if searching log entries is supported. 
     *
     *  @return <code> true </code> if searching log entries is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntrySearch();


    /**
     *  Tests if log entry notification is supported,. 
     *
     *  @return <code> true </code> if log entry notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryNotification();


    /**
     *  Tests if looking up log entry log mappings is supported. 
     *
     *  @return <code> true </code> if log entry logs is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryLog();


    /**
     *  Tests if managing log entry log mappings is supported. 
     *
     *  @return <code> true </code> if log entry logs mapping assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryLogAssignment();


    /**
     *  Tests if smart logs is supported. 
     *
     *  @return <code> true </code> if smart logs is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntrySmartLog();


    /**
     *  Tests for the availability of a log lookup service. 
     *
     *  @return <code> true </code> if log lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogLookup();


    /**
     *  Tests if querying logs is available. 
     *
     *  @return <code> true </code> if log query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogQuery();


    /**
     *  Tests if searching for logs is available. 
     *
     *  @return <code> true </code> if log search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogSearch();


    /**
     *  Tests for the availability of a log administrative service for 
     *  creating and deleting logs. 
     *
     *  @return <code> true </code> if log administration is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogAdmin();


    /**
     *  Tests for the availability of a log notification service. 
     *
     *  @return <code> true </code> if log notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsLogNotification();


    /**
     *  Tests for the availability of a log hierarchy traversal service. 
     *
     *  @return <code> true </code> if log hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogHierarchy();


    /**
     *  Tests for the availability of a log hierarchy design service. 
     *
     *  @return <code> true </code> if log hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsLogHierarchyDesign();


    /**
     *  Tests for the availability of a logging batch service. 
     *
     *  @return <code> true </code> if loggin batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsLoggingBatch();


    /**
     *  Gets the supported <code> Log </code> record types. 
     *
     *  @return a list containing the supported log record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLogEntryRecordTypes();


    /**
     *  Tests if the given <code> LogEntry </code> record type is supported. 
     *
     *  @param  logEntryRecordType a <code> Type </code> indicating a <code> 
     *          LogEntry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntryRecordType(org.osid.type.Type logEntryRecordType);


    /**
     *  Gets the supported log entry search record types. 
     *
     *  @return a list containing the supported log entry search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLogEntrySearchRecordTypes();


    /**
     *  Tests if the given log entry search record type is supported. 
     *
     *  @param  logEntrySearchRecordType a <code> Type </code> indicating a 
     *          log entry record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntrySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogEntrySearchRecordType(org.osid.type.Type logEntrySearchRecordType);


    /**
     *  Gets the supported <code> Log </code> record types. 
     *
     *  @return a list containing the supported log record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLogRecordTypes();


    /**
     *  Tests if the given <code> Log </code> record type is supported. 
     *
     *  @param  logRecordType a <code> Type </code> indicating a <code> Log 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logRecordType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogRecordType(org.osid.type.Type logRecordType);


    /**
     *  Gets the supported log search record types. 
     *
     *  @return a list containing the supported log search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLogSearchRecordTypes();


    /**
     *  Tests if the given log search record type is supported. 
     *
     *  @param  logSearchRecordType a <code> Type </code> indicating a log 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLogSearchRecordType(org.osid.type.Type logSearchRecordType);


    /**
     *  Gets the priority types supported, in ascending order of the priority 
     *  level. 
     *
     *  @return a list containing the supported priority types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPriorityTypes();


    /**
     *  Tests if the priority type is supported. 
     *
     *  @param  priorityType a <code> Type </code> indicating a priority type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priorityType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriorityType(org.osid.type.Type priorityType);


    /**
     *  Gets the content types supported. 
     *
     *  @return a list containing the supported content types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getContentTypes();


    /**
     *  Tests if the content type is supported. 
     *
     *  @param  contentType a <code> Type </code> indicating a content type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> contentType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContentType(org.osid.type.Type contentType);
}
