//
// org.osid.logging.LoggingSession
//
//     The OSID Java specification for org.osid.logging.LoggingSession.
//
// Copyright (C) 2002-2004, 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.logging;


/**
 *  <p>This session is used to log entries to a log. </p>
 */

public interface LoggingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Log </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Log Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLogId();


    /**
     *  Gets the <code> Log </code> associated with this session. 
     *
     *  @return the log 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.Log getLog()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can log. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  all methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer logging operations. 
     *
     *  @return <code> false </code> if logging methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLog();


    /**
     *  Logs an item. This method is a shortcut to <code> createLogEntry(). 
     *  </code> 
     *
     *  @param  content the entry to log 
     *  @param  contentType the type of this entry which must be one of the 
     *          types returned by <code> LoggingManager.getContentTypes() 
     *          </code> 
     *  @throws org.osid.InvalidArgumentException <code> content </code> is 
     *          not of <code> contentType </code> 
     *  @throws org.osid.NullArgumentException <code> content </code> or 
     *          <code> contentType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          LoggingManager.supportsContentType(contentType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void log(java.lang.Object content, org.osid.type.Type contentType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Logs an item. 
     *
     *  @param  priorityType the entry priority 
     *  @param  content the entry to log 
     *  @param  contentType the type of this entry which must be one of the 
     *          types returned by <code> LoggingManager.getContentTypes() 
     *          </code> 
     *  @throws org.osid.InvalidArgumentException <code> content </code> is 
     *          not of <code> contentType </code> 
     *  @throws org.osid.NullArgumentException <code> content </code> , <code> 
     *          contentType </code> or <code> priorityType </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          LoggingManager.supportsContentType(contentType) </code> is 
     *          <code> false </code> or <code> 
     *          LoggingManager.supportsPriorityType(priorityType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void logAtPriority(org.osid.type.Type priorityType, 
                              java.lang.Object content, 
                              org.osid.type.Type contentType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a log entry form for creating a log entry. 
     *
     *  @return the log entry form 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.logging.LogEntryForm getLogEntryForm();


    /**
     *  Logs an entry through the log entry form. 
     *
     *  @param  logEntryForm the log entry form 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> logEntryForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryForm </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void createLogEntry(org.osid.logging.LogEntryForm logEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
