//
// org.osid.mapping.Coordinate
//
//     The OSID Java specification for org.osid.mapping.Coordinate.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>A coordinate represents a position. </p>
 */

public interface Coordinate
    extends org.osid.OsidPrimitive,
            org.osid.binding.java.Coordinate {


    /**
     *  Gets the <code> Type </code> of this <code> Coordinate </code> which 
     *  indicates the format of the coordinate data. 
     *
     *  @return the coordinate type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getCoordinateType();


    /**
     *  Gets the number of dimensions available in this coordinate. 
     *
     *  @return the number of dimensions 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getDimensions();


    /**
     *  Gets the values of this coordinate. The size of the returned array 
     *  should equal <code> getDimensions(). </code> 
     *
     *  @return the coordinate values 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal[] getValues();


    /**
     *  Tests if uncertainty is defined for this heading. 
     *
     *  @return <code> true </code> if uncertainty is defined, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean definesUncertainty();


    /**
     *  Gets the uncertainty in the negtive direction for each value of this 
     *  coordinate. The size of the returned array is typically one less than 
     *  <code> getDimensions(). </code> 
     *
     *  @return the negative uncertainty values 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal[] getUncertaintyMinus();


    /**
     *  Gets the uncertainty in the positive direction for each value of this 
     *  coordinate. The size of the returned array is typically one less than 
     *  <code> getDimensions(). </code> 
     *
     *  @return the positive uncertainty values 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal[] getUncertaintyPlus();
}
