//
// org.osid.mapping.Location
//
//     The OSID Java specification for org.osid.mapping.Location.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>A <code> Location </code> represents a location in a <code> Map. 
 *  </code> </p>
 */

public interface Location
    extends org.osid.OsidObject,
            org.osid.Federateable {


    /**
     *  Tests if a spatial unit is available for this location. 
     *
     *  @return <code> true </code> if a spatial unit is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSpatialUnit();


    /**
     *  Gets the spatial unit corresponding to this location. 
     *
     *  @return the spatial unit for this location 
     *  @throws org.osid.IllegalStateException <code> hasSpatialUnit() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.SpatialUnit getSpatialUnit();


    /**
     *  Gets the location record corresponding to the given <code> Location 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  locationRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(locationRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  locationRecordType the type of location record to retrieve 
     *  @return the location record 
     *  @throws org.osid.NullArgumentException <code> locationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(locationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.records.LocationRecord getLocationRecord(org.osid.type.Type locationRecordType)
        throws org.osid.OperationFailedException;
}
