//
// org.osid.mapping.LocationQuery
//
//     The OSID Java specification for org.osid.mapping.LocationQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>This is the query for searching locations. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface LocationQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidFederateableQuery {


    /**
     *  Matches locations at the specified <code> Coordinate. </code> 
     *
     *  @param  coordinate a coordinate 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> coordinate </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCoordinate(org.osid.mapping.Coordinate coordinate, 
                                boolean match);


    /**
     *  Matches locations that have any coordinate assignment. 
     *
     *  @param  match <code> true </code> to match locations with any 
     *          coordinate, <code> false </code> to match locations with no 
     *          coordinates 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCoordinate(boolean match);


    /**
     *  Clears the coordinate query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCoordinateTerms();


    /**
     *  Matches locations containing the specified <code> SpatialUnit. </code> 
     *
     *  @param  spatialUnit a spatial unit 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContainedSpatialUnit(org.osid.mapping.SpatialUnit spatialUnit, 
                                          boolean match);


    /**
     *  Clears the spatial unit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainedSpatialUnitTerms();


    /**
     *  Matches locations overlapping with the specified <code> SpatialUnit. 
     *  </code> 
     *
     *  @param  spatialUnit a spatial unit 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverlappingSpatialUnit(org.osid.mapping.SpatialUnit spatialUnit, 
                                            boolean match);


    /**
     *  Clears the overlapping spatial unit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverlappingSpatialUnitTerms();


    /**
     *  Matches locations that have any spatial unit assignment. 
     *
     *  @param  match <code> true </code> to match locations with any 
     *          boundary, <code> false </code> to match locations with no 
     *          boundaries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySpatialUnit(boolean match);


    /**
     *  Clears the spatial unit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpatialUnitTerms();


    /**
     *  Sets the route <code> Id </code> for this query to match locations 
     *  along the given route. 
     *
     *  @param  routeId the route <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRouteId(org.osid.id.Id routeId, boolean match);


    /**
     *  Clears the route <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteIdTerms();


    /**
     *  Tests if a <code> RouteQuery </code> is available. 
     *
     *  @return <code> true </code> if a route query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteQuery();


    /**
     *  Gets the query for a route. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the route query 
     *  @throws org.osid.UnimplementedException <code> supportsRouteQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRouteQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.route.RouteQuery getRouteQuery();


    /**
     *  Matches locations that are used on any route. 
     *
     *  @param  match <code> true </code> to match locations on any route, 
     *          <code> false </code> to match locations on no routes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRoute(boolean match);


    /**
     *  Clears the route query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteTerms();


    /**
     *  Sets the path <code> Id </code> for this query to match locations 
     *  along the given path. 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPathId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the path <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathIdTerms();


    /**
     *  Tests if a <code> PathQuery </code> is available. 
     *
     *  @return <code> true </code> if a path query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathQuery();


    /**
     *  Gets the query for a path. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the path query 
     *  @throws org.osid.UnimplementedException <code> supportsPathQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPathQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.path.PathQuery getPathQuery();


    /**
     *  Matches locations that exist along any path. 
     *
     *  @param  match <code> true </code> to match locations on any path, 
     *          <code> false </code> to match locations on no path 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPath(boolean match);


    /**
     *  Clears the path query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathTerms();


    /**
     *  Sets the location <code> Id </code> for this query to match locations 
     *  contained within the given location. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContainingLocationId(org.osid.id.Id locationId, 
                                          boolean match);


    /**
     *  Clears the pcontaining location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainingLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContainingLocationQuery();


    /**
     *  Gets the query for a parent location. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContainingLocationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContainingLocationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationQuery getContainingLocationQuery();


    /**
     *  Matches locations that have any ancestor. 
     *
     *  @param  match <code> true </code> to match locations with any parent 
     *          location, <code> false </code> to match root locations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyContainingLocation(boolean match);


    /**
     *  Clears the containing location query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainingLocationTerms();


    /**
     *  Sets the location <code> Id </code> for this query to match locations 
     *  containing the given location. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContainedLocationId(org.osid.id.Id locationId, 
                                         boolean match);


    /**
     *  Clears the contained location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainedLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContainedLocationQuery();


    /**
     *  Gets the query for a contained location. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsContainedLocationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsContainedLocationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationQuery getContainedLocationQuery();


    /**
     *  Matches locations that have any children. 
     *
     *  @param  match <code> true </code> to match locations containing any 
     *          other location, <code> false </code> to match empty locations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyContainedLocation(boolean match);


    /**
     *  Clears the contained location query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContainedLocationTerms();


    /**
     *  Sets the map <code> Id </code> for this query. 
     *
     *  @param  mapId the map <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMapId(org.osid.id.Id mapId, boolean match);


    /**
     *  Clears the map <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapIdTerms();


    /**
     *  Tests if a <code> MapQuery </code> is available. 
     *
     *  @return <code> true </code> if a map query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapQuery();


    /**
     *  Gets the query for a map. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the map query 
     *  @throws org.osid.UnimplementedException <code> supportsMapQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMapQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.MapQuery getMapQuery();


    /**
     *  Clears the map query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapTerms();


    /**
     *  Gets the location query record corresponding to the given <code> 
     *  Location </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  locationRecordType a location record type 
     *  @return the location query record 
     *  @throws org.osid.NullArgumentException <code> locationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(locationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.records.LocationQueryRecord getLocationQueryRecord(org.osid.type.Type locationRecordType)
        throws org.osid.OperationFailedException;
}
