//
// org.osid.mapping.LocationSpatialSession
//
//     The OSID Java specification for org.osid.mapping.LocationSpatialSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>This session defines methods for retrieving locations through spatial 
 *  queries. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated map view: All location methods in this session operate, 
 *      retrieve and pertain to locations defined explicitly in the current 
 *      map. Using an isolated view is useful for managing <code> Locations 
 *      </code> with the <code> LocationAdminSession. </code> </li> 
 *      <li> federated map view: All location lookup methods in this session 
 *      operate, retrieve and pertain to all locations defined in this map and 
 *      any other locations implicitly available in this map through map 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Locations may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Locations. </code> </p>
 */

public interface LocationSpatialSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Location </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupLocations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeLocationView();


    /**
     *  A complete view of the <code> Location </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryLocationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include locations in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets the closest bounding location of the given coordinate. 
     *
     *  @param  coordinate a coordinate 
     *  @return the returned <code> Location </code> 
     *  @throws org.osid.NullArgumentException <code> coordinate </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException coordinate not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Location getLocationByCoordinate(org.osid.mapping.Coordinate coordinate)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the closest bounding locations in the given coordinate list. In 
     *  plenary mode, all locations are returned for each supplied coodrinate 
     *  or an error results. In comparative mode, the returned list may omit 
     *  inaccessible locations or reorder them. 
     *
     *  @param  coordinates a coordinate list 
     *  @return the returned <code> Locations </code> 
     *  @throws org.osid.NullArgumentException <code> coordinates </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException a coordinate is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationList getLocationsByCoordinates(org.osid.mapping.CoordinateList coordinates)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the locations that are included inside the given spatial unit. In 
     *  plenary mode, all locations are returned or an error results. 
     *
     *  @param  spatialUnit a spatial unit 
     *  @return the returned <code> Locations </code> 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException spatial unit not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationList getLocationsInSpatialUnit(org.osid.mapping.SpatialUnit spatialUnit)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the locations that are included inside or touch the given spatial 
     *  unit. In plenary mode, all locations are returned or an error results. 
     *
     *  @param  spatialUnit a spatial unit 
     *  @return the returned <code> Locations </code> 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException spatial unit not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.LocationList getLocationsOverlappingSpatialUnit(org.osid.mapping.SpatialUnit spatialUnit)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
