//
// org.osid.mapping.MapHierarchySession
//
//     The OSID Java specification for org.osid.mapping.MapHierarchySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> Map 
 *  </code> objects. Each node in the hierarchy is a unique <code> Map. 
 *  </code> The hierarchy may be traversed recursively to establish the tree 
 *  structure through <code> getParentMaps() </code> and <code> 
 *  getChildMaps(). </code> To relate these <code> Ids </code> to another 
 *  OSID, <code> getMapNodes() </code> can be used for retrievals that can be 
 *  used for bulk lookups in other OSIDs. Any <code> Map </code> available in 
 *  the Mapping OSID is known to this hierarchy but does not appear in the 
 *  hierarchy traversal until added as a root location or a child of another 
 *  location. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentMaps() </code> or <code> getChildMaps() </code> in lieu 
 *  of a <code> PERMISSION_DENIED </code> error that may disrupt the traversal 
 *  through authorized pathways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative map view: map elements may be silently omitted or 
 *      re-ordered </li> 
 *      <li> plenary map view: provides a complete set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface MapHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getMapHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessMapHierarchy();


    /**
     *  The returns from the map methods may omit or translate elements based 
     *  on this session, such as authorization, and not result in an error. 
     *  This view is used when greater interoperability is desired at the 
     *  expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeMapView();


    /**
     *  A complete view of the <code> Maps </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryMapView();


    /**
     *  Gets the root map <code> Ids </code> in this hierarchy. 
     *
     *  @return the root map <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootMapIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root map in the map hierarchy. A location with no parents is 
     *  an orphan. While all map <code> Ids </code> are known to the 
     *  hierarchy, an orphan does not appear in the hierarchy unless 
     *  explicitly added as a root location or child of another location. 
     *
     *  @return the root maps 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.MapList getRootMaps()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> Map </code> has any parents. 
     *
     *  @param  mapId a map <code> Id </code> 
     *  @return <code> true </code> if the map has parents, f <code> alse 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> mapId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentMaps(org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of map. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  mapId the <code> Id </code> of a map 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> mapId, </code> f <code> alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> mapId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          mapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfMap(org.osid.id.Id id, org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given map. 
     *
     *  @param  mapId a map <code> Id </code> 
     *  @return the parent <code> Ids </code> of the map 
     *  @throws org.osid.NotFoundException <code> mapId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentMapIds(org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given map. 
     *
     *  @param  mapId the <code> Id </code> to query 
     *  @return the parents of the map 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.MapList getParentMaps(org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of a map. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  mapId the <code> Id </code> of a map 
     *  @return <code> tru </code> e if this <code> id </code> is an ancestor 
     *          of <code> mapId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfMap(org.osid.id.Id id, org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a map has any children. 
     *
     *  @param  mapId a map <code> Id </code> 
     *  @return <code> true </code> if the <code> mapId </code> has children, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildMaps(org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a map is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  mapId the <code> Id </code> of a map 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> mapId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          mapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfMap(org.osid.id.Id id, org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given map. 
     *
     *  @param  mapId the <code> Id </code> to query 
     *  @return the children of the map 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildMapIds(org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given map. 
     *
     *  @param  mapId the <code> Id </code> to query 
     *  @return the children of the map 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.MapList getChildMaps(org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of a map. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  mapId the <code> Id </code> of a map 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> mapId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          mapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfMap(org.osid.id.Id id, org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given map. 
     *
     *  @param  mapId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the location. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the location. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given location, <code> false </code> to omit the siblings 
     *  @return a map node 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getMapNodeIds(org.osid.id.Id mapId, 
                                                 long ancestorLevels, 
                                                 long descendantLevels, 
                                                 boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given map. 
     *
     *  @param  mapId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the location. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the location. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given location, <code> false </code> to omit the siblings 
     *  @return a map node 
     *  @throws org.osid.NotFoundException <code> mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.MapNode getMapNodes(org.osid.id.Id mapId, 
                                                long ancestorLevels, 
                                                long descendantLevels, 
                                                boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
