//
// org.osid.mapping.MapQuery
//
//     The OSID Java specification for org.osid.mapping.MapQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>This is the query for searching maps. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface MapQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the location <code> Id </code> for this query to match maps that 
     *  have a related location. 
     *
     *  @param  locationId a location <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Gets the query for a location. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> supportsLocationQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.LocationQuery getLocationQuery();


    /**
     *  Matches maps that have any location. 
     *
     *  @param  match <code> true </code> to match maps with any location, 
     *          <code> false </code> to match maps with no location 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocation(boolean match);


    /**
     *  Clears the location query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationTerms();


    /**
     *  Sets the path <code> Id </code> for this query to match maps 
     *  containing paths. 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPathId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the path <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathIdTerms();


    /**
     *  Tests if a <code> PathQuery </code> is available. 
     *
     *  @return <code> true </code> if a path query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathQuery();


    /**
     *  Gets the query for a path. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the path query 
     *  @throws org.osid.UnimplementedException <code> supportsPathQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPathQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.path.PathQuery getPathQuery();


    /**
     *  Matches maps that have any path. 
     *
     *  @param  match <code> true </code> to match maps with any path, <code> 
     *          false </code> to match maps with no path 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPath(boolean match);


    /**
     *  Clears the path query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathTerms();


    /**
     *  Sets the path <code> Id </code> for this query to match maps 
     *  containing paths. 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRouteId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the route <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteIdTerms();


    /**
     *  Tests if a <code> RouteQuery </code> is available. 
     *
     *  @return <code> true </code> if a route query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteQuery();


    /**
     *  Gets the query for a route. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the route query 
     *  @throws org.osid.UnimplementedException <code> supportsRouteQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRouteQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.route.RouteQuery getRouteQuery();


    /**
     *  Matches maps that have any route. 
     *
     *  @param  match <code> true </code> to match maps with any route, <code> 
     *          false </code> to match maps with no route 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRoute(boolean match);


    /**
     *  Clears the route query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRouteTerms();


    /**
     *  Sets the map <code> Id </code> for this query to match maps that have 
     *  the specified map as an ancestor. 
     *
     *  @param  mapId a map <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorMapId(org.osid.id.Id mapId, boolean match);


    /**
     *  Clears the ancestor map <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorMapIdTerms();


    /**
     *  Tests if a <code> MapQuery </code> is available. 
     *
     *  @return <code> true </code> if a map query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorMapQuery();


    /**
     *  Gets the query for a map. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the map query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorMapQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorMapQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.MapQuery getAncestorMapQuery();


    /**
     *  Matches maps with any ancestor. 
     *
     *  @param  match <code> true </code> to match maps with any ancestor, 
     *          <code> false </code> to match root maps 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorMap(boolean match);


    /**
     *  Clears the ancestor map query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorMapTerms();


    /**
     *  Sets the map <code> Id </code> for this query to match maps that have 
     *  the specified map as a descendant. 
     *
     *  @param  mapId a map <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantMapId(org.osid.id.Id mapId, boolean match);


    /**
     *  Clears the descendant map <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantMapIdTerms();


    /**
     *  Tests if a <code> MapQuery </code> is available. 
     *
     *  @return <code> true </code> if a map query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantMapQuery();


    /**
     *  Gets the query for a map. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the map query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantMapQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantMapQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.MapQuery getDescendantMapQuery();


    /**
     *  Matches maps with any descendant. 
     *
     *  @param  match <code> true </code> to match maps with any descendant, 
     *          <code> false </code> to match leaf maps 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantMap(boolean match);


    /**
     *  Clears the descendant map query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantMapTerms();


    /**
     *  Gets the map query record corresponding to the given <code> Map 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  mapRecordType a map record type 
     *  @return the map query record 
     *  @throws org.osid.NullArgumentException <code> mapRecordType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(mapRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.records.MapQueryRecord getMapQueryRecord(org.osid.type.Type mapRecordType)
        throws org.osid.OperationFailedException;
}
