//
// org.osid.mapping.MapSearchSession
//
//     The OSID Java specification for org.osid.mapping.MapSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>This session provides methods for searching among <code> Map </code> 
 *  objects. The search query is constructed using the <code> MapQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getMapsByQuery() </code> is the basic search method and returns 
 *  a list of <code> Maps. </code> A more advanced search may be performed 
 *  with <code> getMapsBySearch(). </code> It accepts a <code> MapSearch 
 *  </code> in addition to the query for the purpose of specifying additional 
 *  options affecting the entire search, such as ordering. <code> 
 *  getMapsBySearch() </code> returns a <code> MapSearchResults </code> that 
 *  can be used to access the resulting <code> MapList </code> or be used to 
 *  perform a search within the result set through <code> MapSearch. </code> 
 *  </p> 
 *  
 *  <p> Maps may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> MapQuery. </code> </p>
 */

public interface MapSearchSession
    extends org.osid.mapping.MapQuerySession {


    /**
     *  Gets a map search. 
     *
     *  @return the map search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.MapSearch getMapSearch();


    /**
     *  Gets a map search order. The <code> MapSearchOrder </code> is supplied 
     *  to a <code> MapSearch </code> to specify the ordering of results. 
     *
     *  @return the map search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.MapSearchOrder getMapSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  mapQuery the map query 
     *  @param  mapSearch the map search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> mapQuery </code> or 
     *          <code> mapSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> mapQuery </code> or 
     *          <code> mapSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.MapSearchResults getMapsBySearch(org.osid.mapping.MapQuery mapQuery, 
                                                             org.osid.mapping.MapSearch mapSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a map query from an inspector. The inspector is available from a 
     *  <code> MapSearchResults. </code> 
     *
     *  @param  mapQueryInspector a map query inspector 
     *  @return the map query 
     *  @throws org.osid.NullArgumentException <code> mapQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> mapQueryInspector </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.MapQuery getMapQueryFromInspector(org.osid.mapping.MapQueryInspector mapQueryInspector);
}
