//
// org.osid.mapping.MappingProfile
//
//     The OSID Java specification for org.osid.mapping.MappingProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>The mapping profile describes the interoperability among mapping 
 *  services. </p>
 */

public interface MappingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any map federation is exposed. Federation is exposed when a 
     *  specific map may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of maps appears 
     *  as a single map. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up locations is supported. 
     *
     *  @return <code> true </code> if location lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationLookup();


    /**
     *  Tests if querying locations is supported. 
     *
     *  @return <code> true </code> if location query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Tests if searching locations is supported. 
     *
     *  @return <code> true </code> if location search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationSearch();


    /**
     *  Tests if location <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if location administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationAdmin();


    /**
     *  Tests if a location <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if location notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationNotification();


    /**
     *  Tests if a location <code> </code> hierarchy service is supported. 
     *
     *  @return <code> true </code> if location hierarchy is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationHierarchy();


    /**
     *  Tests if a location hierarchy design service is supported. 
     *
     *  @return <code> true </code> if location hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationHierarchyDesign();


    /**
     *  Tests if a location map lookup service is supported. 
     *
     *  @return <code> true </code> if a location map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationMap();


    /**
     *  Tests if a location map assignment service is supported. 
     *
     *  @return <code> true </code> if a location to map assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationMapAssignment();


    /**
     *  Tests if a location smart map service is supported. 
     *
     *  @return <code> true </code> if a location smart map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationSmartMap();


    /**
     *  Tests if a location adjacency service is supported. 
     *
     *  @return <code> true </code> if a location adjacency service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationAdjacency();


    /**
     *  Tests if a location spatial service is supported. 
     *
     *  @return <code> true </code> if a location spatial service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationSpatial();


    /**
     *  Tests if a resource location service is supported. 
     *
     *  @return <code> true </code> if a resource location service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceLocation();


    /**
     *  Tests if a resource location update service is supported. 
     *
     *  @return <code> true </code> if a resource location update service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceLocationUpdate();


    /**
     *  Tests if a resource location notification service is supported. 
     *
     *  @return <code> true </code> if a resource location notification 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceLocationNotification();


    /**
     *  Tests if a resource position notification service is supported. 
     *
     *  @return <code> true </code> if a resource position notification 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourcePositionNotification();


    /**
     *  Tests if a location service is supported for the current agent. 
     *
     *  @return <code> true </code> if my location is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyLocation();


    /**
     *  Tests if looking up maps is supported. 
     *
     *  @return <code> true </code> if map lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapLookup();


    /**
     *  Tests if querying maps is supported. 
     *
     *  @return <code> true </code> if a map query service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapQuery();


    /**
     *  Tests if searching maps is supported. 
     *
     *  @return <code> true </code> if map search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapSearch();


    /**
     *  Tests if map administrative service is supported. 
     *
     *  @return <code> true </code> if map administration is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapAdmin();


    /**
     *  Tests if a map <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if map notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapNotification();


    /**
     *  Tests for the availability of a map hierarchy traversal service. 
     *
     *  @return <code> true </code> if map hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsMapHierarchy();


    /**
     *  Tests for the availability of a map hierarchy design service. 
     *
     *  @return <code> true </code> if map hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapHierarchyDesign();


    /**
     *  Tests if the mapping batch service is supported. 
     *
     *  @return <code> true </code> if maping batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMappingBatch();


    /**
     *  Tests if the mapping path service is supported. 
     *
     *  @return <code> true </code> if maping path service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMappingPath();


    /**
     *  Tests if the mapping route service is supported. 
     *
     *  @return <code> true </code> if maping route service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMappingRoute();


    /**
     *  Gets the supported <code> Location </code> record types. 
     *
     *  @return a list containing the supported <code> Location </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLocationRecordTypes();


    /**
     *  Tests if the given <code> Location </code> record type is supported. 
     *
     *  @param  locationRecordType a <code> Type </code> indicating a <code> 
     *          Location </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> locationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationRecordType(org.osid.type.Type locationRecordType);


    /**
     *  Gets the supported <code> Location </code> search types. 
     *
     *  @return a list containing the supported <code> Location </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLocationSearchRecordTypes();


    /**
     *  Tests if the given <code> Location </code> search type is supported. 
     *
     *  @param  locationSearchRecordType a <code> Type </code> indicating a 
     *          <code> Location </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> locationSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationSearchRecordType(org.osid.type.Type locationSearchRecordType);


    /**
     *  Gets the supported <code> Map </code> record types. 
     *
     *  @return a list containing the supported <code> Map </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMapRecordTypes();


    /**
     *  Tests if the given <code> Map </code> record type is supported. 
     *
     *  @param  mapRecordType a <code> Type </code> indicating a <code> Map 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mapRecordType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapRecordType(org.osid.type.Type mapRecordType);


    /**
     *  Gets the supported <code> Map </code> search record types. 
     *
     *  @return a list containing the supported <code> Map </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMapSearchRecordTypes();


    /**
     *  Tests if the given <code> Map </code> search record type is supported. 
     *
     *  @param  mapSearchRecordType a <code> Type </code> indicating a <code> 
     *          Map </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mapSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapSearchRecordType(org.osid.type.Type mapSearchRecordType);


    /**
     *  Gets the supported <code> ResourceLocation </code> record types. 
     *
     *  @return a list containing the supported <code> ResourceLocation 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResourceLocationRecordTypes();


    /**
     *  Tests if the given <code> ResourceLocationRecord </code> record type 
     *  is supported. 
     *
     *  @param  resourceLocationRecordType a <code> Type </code> indicating a 
     *          <code> ResourceLocation </code> type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceLocationRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceLocationRecordType(org.osid.type.Type resourceLocationRecordType);


    /**
     *  Gets the supported <code> Coordinate </code> types. 
     *
     *  @return a list containing the supported <code> Coordinate </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCoordinateTypes();


    /**
     *  Tests if the given <code> Coordinate </code> type is supported. 
     *
     *  @param  coordinateType a <code> Type </code> indicating a <code> 
     *          Coordinate </code> type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> coordinateType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCoordinateType(org.osid.type.Type coordinateType);


    /**
     *  Gets the supported <code> Heading </code> types. 
     *
     *  @return a list containing the supported <code> Heading </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getHeadingTypes();


    /**
     *  Tests if the given <code> Heading </code> type is supported. 
     *
     *  @param  headingType a <code> Type </code> indicating a <code> Heading 
     *          </code> type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> headingType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHeadingType(org.osid.type.Type headingType);


    /**
     *  Gets the supported <code> SpatialUnit </code> record types. 
     *
     *  @return a list containing the supported <code> SpatialUnit </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpatialUnitRecordTypes();


    /**
     *  Tests if the given <code> SpatialUnit </code> record type is 
     *  supported. 
     *
     *  @param  spatialUnitRecordType a <code> Type </code> indicating a 
     *          <code> SpatialUnit </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> spatialUnitRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpatialUnitRecordType(org.osid.type.Type spatialUnitRecordType);
}
