//
// org.osid.mapping.ResourceLocation
//
//     The OSID Java specification for org.osid.mapping.ResourceLocation.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping;


/**
 *  <p>This interface defines a resource at a location. </p>
 */

public interface ResourceLocation
    extends org.osid.OsidCompendium {


    /**
     *  Gets the <code> Id </code> of the resource on the route. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the resource on the route. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this resource has a known location. 
     *
     *  @return <code> true </code> if a location is known, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasLocation();


    /**
     *  Gets the location <code> Id </code> of the resource. 
     *
     *  @return the location <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLocationId();


    /**
     *  Gets the location of the resource. 
     *
     *  @return the location 
     *  @throws org.osid.IllegalStateException <code> hasLocation() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Location getLocation()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this resource has a known coordinate. 
     *
     *  @return <code> true </code> if a coordinate is known, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasCoordinate();


    /**
     *  Gets the coordinate of the resource. 
     *
     *  @return the coordinate of the resource 
     *  @throws org.osid.IllegalStateException <code> hasCoordinate() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Coordinate getCoordinate();


    /**
     *  Gets the map record corresponding to the given <code> ResourceLocation 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  resourceLocationRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(resourceLocationRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  resourceLocationRecordType the type of resource location 
     *          record to retrieve 
     *  @return the resource location record 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceLocationRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(resourceLocationRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.records.ResourceLocationRecord getResourceLocationRecord(org.osid.type.Type resourceLocationRecordType)
        throws org.osid.OperationFailedException;
}
