/**
 * <p>The Open Service Interface Definitions for the org.osid.mapping
 * service.</p>
 * 
 * <p>The Mapping OSID provides a means for managing inventories of places and 
 * performing a variety of mapping operations. </p> 
 * <h4> Locations </h4> 
 * 
 * <p> One aspect of the Mapping OSID provides references to location places 
 * used in other OSIDs. A <code> Location </code> may include a spatial 
 * coordinate or defined boundary described in a <code> SpatialUnit. </code> 
 * Additional sessions provide a means to easily look up locations by <code> 
 * Coordinate </code> or arbitrary <code> SpatialUnit </code> as well as to 
 * traverse locations through lookups of adjacent <code> Locations. </code> 
 * </p> 
 * 
 * <p> <code> Locations </code> may be structured in hierarchies to convey 
 * hierarchical relationships. A room may be located inside a building, within 
 * a city within a state. </p> 
 * <h4> Primitives </h4> 
 * 
 * <p> The data interfaces for <code> Coordinates </code> and <code> 
 * SpatialUnits </code> are defined through their respective <code> Types 
 * </code> to allow for any kind of coordinate or spatial system. A definition 
 * for distance resolution is also provided to capture an extremely wide array 
 * of unit values. <code> Distance, </code> <code> Coordinate, </code> <code> 
 * Heading, </code> and <code> SpatialUnit </code> appear to the OSID as 
 * complex primitive interfaces which are constructed by the consumer in order 
 * to fulfill the interface contracts. It is required that the consumer and 
 * provider agree on the coordinate domain and spatial unit types through 
 * testing of the <code> Type </code> support. </p> 
 * <h4> Resource Tracking </h4> 
 * 
 * <p> <code> Resources </code> may be tracked spatially. Sessions are 
 * available to query and place <code> Resources </code> at specific <code> 
 * Locations </code> and <code> Coordinates, </code> and receive notifications 
 * to changes in their locations. </p> 
 * <h4> Map Cataloging </h4> 
 * 
 * <p> <code> Locations </code> may be organuzed in hierarchical <code> Maps 
 * </code> that offer a means of federation or layering of map data. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Mapping OSID includes a Mapping Route OSID for creating and 
 * navigating Routes, a Mapping Path OSID for querying and designing physical 
 * <code> Paths </code> and a Mapping Batch OSID for managing locations in 
 * bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.mapping;
