//
// org.osid.mapping.path.IntersectionLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.IntersectionLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods for retrieving <code> Intersections. 
 *  </code> The <code> Intersection </code> represents a crossing of two 
 *  <code> Paths. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated map view: All intersection methods in this session 
 *      operate, retrieve and pertain to intersections defined explicitly in 
 *      the current map. Using an isolated view is useful for managing <code> 
 *      Intersections </code> with the <code> IntersectionAdminSession. 
 *      </code> </li> 
 *      <li> federated map view: All intersections methods in this session 
 *      operate, retrieve and pertain to all intersections defined in this map 
 *      and any other paths implicitly available in this map through map 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface IntersectionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Intersection </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupIntersections();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeIntersectionView();


    /**
     *  A complete view of the <code> Intersection </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryIntersectionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include intersections in maps which are children of this map in the 
     *  map hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets the <code> Intersection </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Intersection </code> may have a different <code> Id </code> than 
     *  requested. 
     *
     *  @param  intersectionId <code> Id </code> of the <code> Intersection 
     *          </code> 
     *  @return the intersection 
     *  @throws org.osid.NotFoundException <code> intersectionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> intersectionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.path.Intersection getIntersection(org.osid.id.Id intersectionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IntersectionList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the intersections specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> Intersections </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  intersectionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Intersection </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> intersectionIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersectionsByIds(org.osid.id.IdList intersectionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IntersectionList </code> corresponding to the given 
     *  intersection genus <code> Type </code> which does not include 
     *  intersections of genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  intersections or an error results. Otherwise, the returned list may 
     *  contain only those intersections that are accessible through this 
     *  session. 
     *
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> pathGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersectionsByGenusType(org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IntersectionList </code> corresponding to the given 
     *  intersection genus <code> Type </code> and include any additional 
     *  intersections with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  intersections or an error results. Otherwise, the returned list may 
     *  contain only those intersections that are accessible through this 
     *  session. 
     *
     *  @param  intersectionGenusType an intersection genus type 
     *  @return the returned <code> Intersection </code> list 
     *  @throws org.osid.NullArgumentException <code> intersectionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersectionsByParentGenusType(org.osid.type.Type intersectionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IntersectionList </code> containing the given 
     *  intersection record <code> Type. </code> In plenary mode, the returned 
     *  list contains all known intersections or an error results. Otherwise, 
     *  the returned list may contain only those intersections that are 
     *  accessible through this session. 
     *
     *  @param  intersectionRecordType an intersection record type 
     *  @return the returned <code> Intersection </code> list 
     *  @throws org.osid.NullArgumentException <code> intersectionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersectionsByRecordType(org.osid.type.Type intersectionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IntersectionList </code> connected to the given <code> 
     *  Path. </code> In plenary mode, the returned list contains all of the 
     *  intersections, or an error results if an intersection along the path 
     *  is not found or inaccessible. Otherwise, inaccessible <code> 
     *  Intersections </code> may be omitted from the list. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @return the returned <code> Intersection </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersectionsForPath(org.osid.id.Id pathId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> IntersectionList </code> connected to the given <code> 
     *  Path </code> within a distance of a given coordinate. In plenary mode, 
     *  the returned list contains all of the paths, or an error results if a 
     *  path connected to the location is not found or inaccessible. 
     *  Otherwise, inaccessible <code> Paths </code> may be omitted from the 
     *  list. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @param  coordinate a coordinate 
     *  @param  distance a distance 
     *  @return the returned <code> Intersection </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate 
     *          </code> or <code> distance </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersectionsForPathAtCoordinate(org.osid.id.Id pathId, 
                                                                                      org.osid.mapping.Coordinate coordinate, 
                                                                                      org.osid.mapping.Distance distance)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Intersections </code> of both given paths. In plenary 
     *  mode, the returned list contains all of the intersections, or an error 
     *  results if an intersection along the path is not found or 
     *  inaccessible. Otherwise, inaccessible <code> Intersections </code> may 
     *  be omitted from the list. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @param  crossingPathId another path <code> Id </code> 
     *  @return the returned <code> Intersection </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId </code> or <code> 
     *          crossingPathId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersectionsForPaths(org.osid.id.Id pathId, 
                                                                           org.osid.id.Id crossingPathId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Intersection. </code> In plenary mode, the returned 
     *  list contains all of the intersections. or an error results if an 
     *  intersection is not found or inaccessible. Otherwise, inaccessible 
     *  <code> Intersections </code> may be omitted from the list. 
     *
     *  @return the returned <code> Intersection </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionList getIntersections()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
