//
// org.osid.mapping.path.IntersectionSearchSession
//
//     The OSID Java specification for org.osid.mapping.path.IntersectionSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods for searching among <code> Intersection 
 *  </code> objects. The search query is constructed using the <code> 
 *  IntersectionQuery. </code> </p> 
 *  
 *  <p> <code> getIntersectionsByQuery() </code> is the basic search method 
 *  and returns a list of <code> Intersections. </code> A more advanced search 
 *  may be performed with <code> getIntersectionsBySearch(). </code> It 
 *  accepts an <code> IntersectionSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getIntersectionsBySearch() </code> returns an 
 *  <code> IntersectionSearchResults </code> that can be used to access the 
 *  resulting <code> IntersectionList </code> or be used to perform a search 
 *  within the result set through <code> IntersectionSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include intersections in maps of 
 *      which this map is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to intersections in 
 *      this map </li> 
 *  </ul>
 *  
 *  
 *  <p> Intersections may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  IntersectionQuery. </code> </p>
 */

public interface IntersectionSearchSession
    extends org.osid.mapping.path.IntersectionQuerySession {


    /**
     *  Gets an intersection search. 
     *
     *  @return the intersection search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionSearch getIntersectionSearch();


    /**
     *  Gets an intersection search order. The <code> IntersectionSearchOrder 
     *  </code> is supplied to an <code> IntersectionSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the intersection search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionSearchOrder getIntersectionSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  intersectionQuery the intersection query 
     *  @param  intersectionSearch the intersection search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> intersectionQuery 
     *          </code> or <code> intersectionSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> intersectionQuery </code> 
     *          or <code> intersectionSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionSearchResults getIntersectionsBySearch(org.osid.mapping.path.IntersectionQuery intersectionQuery, 
                                                                                    org.osid.mapping.path.IntersectionSearch intersectionSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an intersection query from an inspector. The inspector is 
     *  available from an <code> IntersectionSearchResults. </code> 
     *
     *  @param  intersectionQueryInspector an intersection query inspector 
     *  @return the intersection query 
     *  @throws org.osid.NullArgumentException <code> 
     *          intersectionQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          intersectionQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.IntersectionQuery getIntersectionQueryFromInspector(org.osid.mapping.path.IntersectionQueryInspector intersectionQueryInspector);
}
