//
// org.osid.mapping.path.MappingPathProfile
//
//     The OSID Java specification for org.osid.mapping.path.MappingPathProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>The mapping profile describes the interoperability among mapping 
 *  services. </p>
 */

public interface MappingPathProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any map federation is exposed. Federation is exposed when a 
     *  specific map may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of maps appears 
     *  as a single map. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up paths is supported. 
     *
     *  @return <code> true </code> if path lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathLookup();


    /**
     *  Tests if querying paths is supported. 
     *
     *  @return <code> true </code> if path query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathQuery();


    /**
     *  Tests if searching paths is supported. 
     *
     *  @return <code> true </code> if path search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathSearch();


    /**
     *  Tests if path <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if path administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathAdmin();


    /**
     *  Tests if a path <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if path notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathNotification();


    /**
     *  Tests if a path map lookup service is supported. 
     *
     *  @return <code> true </code> if a path map lookup service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathMap();


    /**
     *  Tests if a path map service is supported. 
     *
     *  @return <code> true </code> if path to map assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathMapAssignment();


    /**
     *  Tests if a path smart map lookup service is supported. 
     *
     *  @return <code> true </code> if a path smart map service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathSmartMap();


    /**
     *  Tests if a path spatial lookup service is supported. 
     *
     *  @return <code> true </code> if a path spatial service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathSpatial();


    /**
     *  Tests if a path spatial design service is supported. 
     *
     *  @return <code> true </code> if a path spatial design service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathSpatialDesign();


    /**
     *  Tests if a path travel service is supported. 
     *
     *  @return <code> true </code> if a path travel service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathTravel();


    /**
     *  Tests if a resource path notification service is supported. 
     *
     *  @return <code> true </code> if a resource path notification service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourcePathNotification();


    /**
     *  Tests if a resource velocity service is supported. 
     *
     *  @return <code> true </code> if a resource velocity service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceVelocity();


    /**
     *  Tests if a resource velocity update service is supported. 
     *
     *  @return <code> true </code> if a resource velocity update service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceVelocityUpdate();


    /**
     *  Tests if a resource velocity notification service is supported. 
     *
     *  @return <code> true </code> if a resource velocity notification 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceVelocityNotification();


    /**
     *  Tests if a my path service is supported. 
     *
     *  @return <code> true </code> if a my path service is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyPath();


    /**
     *  Tests if an intersection lookup service is supported. 
     *
     *  @return <code> true </code> if an intersection lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionLookup();


    /**
     *  Tests if querying intersections is supported. 
     *
     *  @return <code> true </code> if intersection query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionQuery();


    /**
     *  Tests if searching intersections is supported. 
     *
     *  @return <code> true </code> if intersection search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionSearch();


    /**
     *  Tests if an intersection administrative service is supported. 
     *
     *  @return <code> true </code> if an intersection administrative service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionAdmin();


    /**
     *  Tests if an intersection <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if intersection notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionNotification();


    /**
     *  Tests if an intersection map lookup service is supported. 
     *
     *  @return <code> true </code> if an intersection map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionMap();


    /**
     *  Tests if an intersection map service is supported. 
     *
     *  @return <code> true </code> if intersection to map assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionMapAssignment();


    /**
     *  Tests if an intersection smart map lookup service is supported. 
     *
     *  @return <code> true </code> if an intersection smart map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionSmartMap();


    /**
     *  Tests if looking up speed zones is supported. 
     *
     *  @return <code> true </code> if speed zone lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneLookup();


    /**
     *  Tests if querying speed zones is supported. 
     *
     *  @return <code> true </code> if speed zone query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneQuery();


    /**
     *  Tests if searching speed zones is supported. 
     *
     *  @return <code> true </code> if speed zone search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneSearch();


    /**
     *  Tests if speed zone <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if speed zone administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneAdmin();


    /**
     *  Tests if a speed zone <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if speed zone notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneNotification();


    /**
     *  Tests if a speed zone map lookup service is supported. 
     *
     *  @return <code> true </code> if a speed zone map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneMap();


    /**
     *  Tests if a speed zone map assignment service is supported. 
     *
     *  @return <code> true </code> if a speed zone to map assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneMapAssignment();


    /**
     *  Tests if a speed zone smart map service is supported. 
     *
     *  @return <code> true </code> if a speed zone smart map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneSmartMap();


    /**
     *  Tests if looking up signals is supported. 
     *
     *  @return <code> true </code> if signal lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalLookup();


    /**
     *  Tests if querying signals is supported. 
     *
     *  @return <code> true </code> if signal query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalQuery();


    /**
     *  Tests if searching signals is supported. 
     *
     *  @return <code> true </code> if signal search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalSearch();


    /**
     *  Tests if signal <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if signal administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalAdmin();


    /**
     *  Tests if a signal <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if signal notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalNotification();


    /**
     *  Tests if a signal map lookup service is supported. 
     *
     *  @return <code> true </code> if a signal map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalMap();


    /**
     *  Tests if a signal map assignment service is supported. 
     *
     *  @return <code> true </code> if a signal to map assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalMapAssignment();


    /**
     *  Tests if a signal smart map service is supported. 
     *
     *  @return <code> true </code> if a signal smart map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalSmartMap();


    /**
     *  Tests if a resource signal notification service is supported. 
     *
     *  @return <code> true </code> if a resource signal notification service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceSignalNotification();


    /**
     *  Tests if looking up obstacles is supported. 
     *
     *  @return <code> true </code> if obstacle lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleLookup();


    /**
     *  Tests if querying obstacles is supported. 
     *
     *  @return <code> true </code> if obstacle query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleQuery();


    /**
     *  Tests if searching obstacles is supported. 
     *
     *  @return <code> true </code> if obstacle search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleSearch();


    /**
     *  Tests if obstacle administrative service is supported. 
     *
     *  @return <code> true </code> if obstacle administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleAdmin();


    /**
     *  Tests if an obstacle <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if obstacle notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleNotification();


    /**
     *  Tests if an obstacle <code> </code> hierarchy service is supported. 
     *
     *  @return <code> true </code> if obstacle hierarchy is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleHierarchy();


    /**
     *  Tests if an obstacle hierarchy design service is supported. 
     *
     *  @return <code> true </code> if obstacle hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleHierarchyDesign();


    /**
     *  Tests if an obstacle map lookup service is supported. 
     *
     *  @return <code> true </code> if an obstacle map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleMap();


    /**
     *  Tests if an obstacle map assignment service is supported. 
     *
     *  @return <code> true </code> if an obstacle to map assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleMapAssignment();


    /**
     *  Tests if an obstacle smart map service is supported. 
     *
     *  @return <code> true </code> if an obstacle smart map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleSmartMap();


    /**
     *  Tests if a batch mapping path service is supported. 
     *
     *  @return <code> true </code> if a mapping path batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMappingPathBatch();


    /**
     *  Tests if a mapping path rules service is supported. 
     *
     *  @return <code> true </code> if a mapping path rules service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMappingPathRules();


    /**
     *  Gets the supported <code> Path </code> record types. 
     *
     *  @return a list containing the supported <code> Path </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPathRecordTypes();


    /**
     *  Tests if the given <code> Path </code> record type is supported. 
     *
     *  @param  pathRecordType a <code> Type </code> indicating a <code> Path 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> pathRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathRecordType(org.osid.type.Type pathRecordType);


    /**
     *  Gets the supported <code> Path </code> search record types. 
     *
     *  @return a list containing the supported <code> Path </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPathSearchRecordTypes();


    /**
     *  Tests if the given <code> Path </code> search record type is 
     *  supported. 
     *
     *  @param  pathSearchRecordType a <code> Type </code> indicating a <code> 
     *          Path </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> pathSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathSearchRecordType(org.osid.type.Type pathSearchRecordType);


    /**
     *  Gets the supported <code> Intersection </code> record types. 
     *
     *  @return a list containing the supported <code> Intersection </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getIntersectionRecordTypes();


    /**
     *  Tests if the given <code> Intersection </code> record type is 
     *  supported. 
     *
     *  @param  intersectionRecordType a <code> Type </code> indicating an 
     *          <code> Intersection </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> intersectionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionRecordType(org.osid.type.Type intersectionRecordType);


    /**
     *  Gets the supported <code> Intersection </code> search record types. 
     *
     *  @return a list containing the supported <code> Intersection </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getIntersectionSearchRecordTypes();


    /**
     *  Tests if the given <code> Intersection </code> search record type is 
     *  supported. 
     *
     *  @param  intersectionSearchRecordType a <code> Type </code> indicating 
     *          an <code> Intersection </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          intersectionSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIntersectionSearchRecordType(org.osid.type.Type intersectionSearchRecordType);


    /**
     *  Gets the supported <code> SpeedZone </code> record types. 
     *
     *  @return a list containing the supported <code> SpeedZone </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpeedZoneRecordTypes();


    /**
     *  Tests if the given <code> SpeedZone </code> record type is supported. 
     *
     *  @param  speedZoneRecordType a <code> Type </code> indicating a <code> 
     *          SpeedZone </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> speedZoneRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneRecordType(org.osid.type.Type speedZoneRecordType);


    /**
     *  Gets the supported <code> SpeedZone </code> search types. 
     *
     *  @return a list containing the supported <code> SpeedZone </code> 
     *          search types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpeedZoneSearchRecordTypes();


    /**
     *  Tests if the given <code> SpeedZone </code> search type is supported. 
     *
     *  @param  speedZoneSearchRecordType a <code> Type </code> indicating a 
     *          <code> SpeedZone </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneSearchRecordType(org.osid.type.Type speedZoneSearchRecordType);


    /**
     *  Gets the supported <code> Signal </code> record types. 
     *
     *  @return a list containing the supported <code> Signal </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSignalRecordTypes();


    /**
     *  Tests if the given <code> Signal </code> record type is supported. 
     *
     *  @param  signalRecordType a <code> Type </code> indicating a <code> 
     *          Signal </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> signalRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalRecordType(org.osid.type.Type signalRecordType);


    /**
     *  Gets the supported <code> Signal </code> search types. 
     *
     *  @return a list containing the supported <code> Signal </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSignalSearchRecordTypes();


    /**
     *  Tests if the given <code> Signal </code> search type is supported. 
     *
     *  @param  signalSearchRecordType a <code> Type </code> indicating a 
     *          <code> Signal </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> signalSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalSearchRecordType(org.osid.type.Type signalSearchRecordType);


    /**
     *  Gets the supported <code> Obstacle </code> record types. 
     *
     *  @return a list containing the supported <code> Obstacle </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObstacleRecordTypes();


    /**
     *  Tests if the given <code> Obstacle </code> record type is supported. 
     *
     *  @param  obstacleRecordType a <code> Type </code> indicating an <code> 
     *          Obstacle </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> obstacleRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleRecordType(org.osid.type.Type obstacleRecordType);


    /**
     *  Gets the supported <code> Obstacle </code> search types. 
     *
     *  @return a list containing the supported <code> Obstacle </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObstacleSearchRecordTypes();


    /**
     *  Tests if the given <code> Obstacle </code> search type is supported. 
     *
     *  @param  obstacleSearchRecordType a <code> Type </code> indicating an 
     *          <code> Obstacle </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> obstacleSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleSearchRecordType(org.osid.type.Type obstacleSearchRecordType);


    /**
     *  Gets the supported <code> ResourceVelocity </code> record types. 
     *
     *  @return a list containing the supported <code> ResourceVelocity 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResourceVelocityRecordTypes();


    /**
     *  Tests if the given <code> ResourceVelocity </code> record type is 
     *  supported. 
     *
     *  @param  resourceVelocityRecordType a <code> Type </code> indicating a 
     *          <code> ResourceVelocity </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceVelocityRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceVelocityRecordType(org.osid.type.Type resourceVelocityRecordType);
}
