//
// org.osid.mapping.path.ObstacleForm
//
//     The OSID Java specification for org.osid.mapping.path.ObstacleForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This is the form for creating and updating <code> Obstacles. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ObstacleAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ObstacleForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidOperableForm {


    /**
     *  Gets the metadata for a starting coordinate. 
     *
     *  @return metadata for the starting coordinate 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStartingCoordinateMetadata();


    /**
     *  Sets the starting coordinate. 
     *
     *  @param  coordinate the new starting coordinate 
     *  @throws org.osid.InvalidArgumentException <code> coordinate </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> coordinate </code> is 
     *          <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> coordinate </code> type 
     *          is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStartingCoordinate(org.osid.mapping.Coordinate coordinate);


    /**
     *  Removes the starting coordinate. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingCoordinate();


    /**
     *  Gets the metadata for a ending coordinate. 
     *
     *  @return metadata for the ending coordinate 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEndingCoordinateMetadata();


    /**
     *  Sets the ending coordinate. 
     *
     *  @param  coordinate the new ending coordinate 
     *  @throws org.osid.InvalidArgumentException <code> coordinate </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> coordinate </code> is 
     *          <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> coordinate </code> type 
     *          is not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEndingCoordinate(org.osid.mapping.Coordinate coordinate);


    /**
     *  Removes the ending coordinate. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndingCoordinate();


    /**
     *  Gets the <code> ObstacleFormRecord </code> corresponding to the given 
     *  obstacle record <code> Type. </code> 
     *
     *  @param  obstacleRecordType an obstacle record type 
     *  @return the obstacle form record 
     *  @throws org.osid.NullArgumentException <code> obstacleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(obstacleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.records.ObstacleFormRecord getObstacleFormRecord(org.osid.type.Type obstacleRecordType)
        throws org.osid.OperationFailedException;
}
