//
// org.osid.mapping.path.ObstacleSearchSession
//
//     The OSID Java specification for org.osid.mapping.path.ObstacleSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods for searching among <code> Obstacle 
 *  </code> objects. The search query is constructed using the <code> 
 *  ObstacleQuery. </code> </p> 
 *  
 *  <p> <code> getObstaclesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Obstacles. </code> A more advanced search may be 
 *  performed with <code> getObstaclesBySearch(). </code> It accepts an <code> 
 *  ObstacleSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getObstaclesBySearch() </code> returns an <code> 
 *  ObstacleSearchResults </code> that can be used to access the resulting 
 *  <code> ObstacleList </code> or be used to perform a search within the 
 *  result set through <code> ObstacleSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include obstacle in maps of which 
 *      this map is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to obstacle in this 
 *      map </li> 
 *  </ul>
 *  
 *  
 *  <p> Obstacles may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> ObstacleQuery. </code> 
 *  </p>
 */

public interface ObstacleSearchSession
    extends org.osid.mapping.path.ObstacleQuerySession {


    /**
     *  Gets an obstacle search. 
     *
     *  @return the obstacle search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleSearch getObstacleSearch();


    /**
     *  Gets an obstacle search order. The <code> ObstacleSearchOrder </code> 
     *  is supplied to an <code> ObstacleSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the obstacle search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleSearchOrder getObstacleSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  obstacleQuery the obstacle query 
     *  @param  obstacleSearch the obstacle search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> obstacleQuery </code> or 
     *          <code> obstacleSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> obstacleQuery </code> or 
     *          <code> obstacleSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleSearchResults getObstaclesBySearch(org.osid.mapping.path.ObstacleQuery obstacleQuery, 
                                                                            org.osid.mapping.path.ObstacleSearch obstacleSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an obstacle query from an inspector. The inspector is available 
     *  from an <code> ObstacleSearchResults. </code> 
     *
     *  @param  obstacleQueryInspector an obstacle query inspector 
     *  @return the obstacle query 
     *  @throws org.osid.NullArgumentException <code> obstacleQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> obstacleQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleQuery getObstacleQueryFromInspector(org.osid.mapping.path.ObstacleQueryInspector obstacleQueryInspector);
}
