//
// org.osid.mapping.path.PathLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.PathLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods for retrieving <code> Path </code> 
 *  objects. The <code> Path </code> represents a fixed connection between two 
 *  <code> Locations. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated map view: All path methods in this session operate, 
 *      retrieve and pertain to paths defined explicitly in the current map. 
 *      Using an isolated view is useful for managing <code> Paths </code> 
 *      with the <code> PathAdminSession. </code> </li> 
 *      <li> federated map view: All path methods in this session operate, 
 *      retrieve and pertain to all paths defined in this map and any other 
 *      paths implicitly available in this map through map inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface PathLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Path </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPaths();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePathView();


    /**
     *  A complete view of the <code> Path </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPathView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include paths in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets the <code> Path </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Path </code> 
     *  may have a different <code> Id </code> than requested, such as the 
     *  case where a duplicate <code> Id </code> was assigned to a <code> Path 
     *  </code> and retained for compatibility. 
     *
     *  @param  pathId <code> Id </code> of the <code> Path </code> 
     *  @return the path 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.path.Path getPath(org.osid.id.Id pathId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  paths specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Paths </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  pathIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.PathList getPathsByIds(org.osid.id.IdList pathIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> corresponding to the given path genus 
     *  <code> Type </code> which does not include paths of genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known paths or an error results. Otherwise, 
     *  the returned list may contain only those paths that are accessible 
     *  through this session. 
     *
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> pathGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.PathList getPathsByGenusType(org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> corresponding to the given path genus 
     *  <code> Type </code> and include any additional paths with genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known paths or an error results. Otherwise, 
     *  the returned list may contain only those paths that are accessible 
     *  through this session. 
     *
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> pathGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.PathList getPathsByParentGenusType(org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> containing the given path record <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *
     *  @param  pathRecordType a path record type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> pathRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.PathList getPathsByRecordType(org.osid.type.Type pathRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> connected to all the given <code> 
     *  Locations. </code> In plenary mode, the returned list contains all of 
     *  the paths along the locations, or an error results if a path connected 
     *  to the location is not found or inaccessible. Otherwise, inaccessible 
     *  <code> Paths </code> may be omitted from the list. 
     *
     *  @param  locationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> locationIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.PathList getPathsAlongLocations(org.osid.id.IdList locationIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Paths. </code> In plenary mode, the returned list 
     *  contains all known paths or an error results. Otherwise, the returned 
     *  list may contain only those paths that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> Paths </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.PathList getPaths()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
