//
// org.osid.mapping.path.PathTravelSession
//
//     The OSID Java specification for org.osid.mapping.path.PathTravelSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods for examining <code> Path </code> travel. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated map view: All path methods in this session operate, 
 *      retrieve and pertain to paths defined explicitly in the current map. 
 *      </li> 
 *      <li> federated map view: All path methods in this session operate, 
 *      retrieve and pertain to all paths defined in this map and any other 
 *      paths implicitly available in this map through map inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface PathTravelSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Path </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPathTravel();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePathView();


    /**
     *  A complete view of the <code> Path </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPathView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include paths in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets an <code> ObstacleList </code> corresponding to the given <code> 
     *  Path </code> and coordinate range. In plenary mode, the returned list 
     *  contains all of the obstacles as defined. Otherwise, inaccessible 
     *  <code> Obstacles </code> may be omitted from the list or overlapping 
     *  obstacles may be reordered. 
     *
     *  @param  pathId <code> Id </code> of the <code> Path </code> 
     *  @param  coordinate starting coordinate 
     *  @param  distance a distance from coordinate 
     *  @return the obstacle list 
     *  @throws org.osid.InvalidArgumentException coordinate not on path 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate 
     *          </code> or <code> distance </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstacles(org.osid.id.Id pathId, 
                                                           org.osid.mapping.Coordinate coordinate, 
                                                           org.osid.mapping.Distance distance)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the expected average speed for a traveler along a path between 
     *  the given coordinates. If the path is blocked by an obstacle, then the 
     *  speed is zero. Some obstacles may have the effect of lowering the 
     *  expected speed. 
     *
     *  @param  pathId <code> Id </code> of the <code> Path </code> 
     *  @param  coordinate starting coordinate 
     *  @param  distance a distance from coordinate 
     *  @return the speed 
     *  @throws org.osid.InvalidArgumentException coordinate not on path 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate 
     *          </code> or <code> distance </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.Speed getAverageSpeed(org.osid.id.Id pathId, 
                                                  org.osid.mapping.Coordinate coordinate, 
                                                  org.osid.mapping.Distance distance)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> corresponding to the given <code> 
     *  Path </code> and coordinate range. In plenary mode, the returned list 
     *  contains all of the speed zones as defined. Otherwise, inaccessible 
     *  <code> SpeedZones </code> may be omitted from the list or overlapping 
     *  speed zones may be reordered. 
     *
     *  @param  pathId <code> Id </code> of the <code> Path </code> 
     *  @param  coordinate starting coordinate 
     *  @param  distance a distance from coordinate 
     *  @return the list of speed zones 
     *  @throws org.osid.InvalidArgumentException coordinate not on path 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate or 
     *          distance is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZones(org.osid.id.Id pathId, 
                                                             org.osid.mapping.Coordinate coordinate, 
                                                             org.osid.mapping.Distance distance)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> corresponding to the given <code> 
     *  Path </code> and coordinate range for a given resolution. 
     *
     *  @param  pathId <code> Id </code> of the <code> Path </code> 
     *  @param  coordinate starting coordinate 
     *  @param  distance a distance from coordinate 
     *  @param  resolution the resolution 
     *  @return the list of speed zones 
     *  @throws org.osid.InvalidArgumentException coordinate not on path 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate, 
     *          distance </code> or <code> resolution </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesAtResolution(org.osid.id.Id pathId, 
                                                                         org.osid.mapping.Coordinate coordinate, 
                                                                         org.osid.mapping.Distance distance, 
                                                                         org.osid.mapping.Distance resolution)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
