//
// org.osid.mapping.path.ResourceVelocity
//
//     The OSID Java specification for org.osid.mapping.path.ResourceVelocity.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>A <code> Velocity </code> for a <code> Resource. </code> </p>
 */

public interface ResourceVelocity
    extends org.osid.OsidCompendium {


    /**
     *  Gets the <code> Resource </code> <code> Id. </code> 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResourceId();


    /**
     *  Gets the <code> Resource. </code> 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the current speed. 
     *
     *  @return the current speed 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Speed getSpeed();


    /**
     *  Gets the current position. 
     *
     *  @return the current coordinate 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Coordinate getPosition();


    /**
     *  Gets the current heading. 
     *
     *  @return the current heading 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Heading getHeading();


    /**
     *  Tests if the resource is on a designated path. 
     *
     *  @return <code> true </code> if the resource is on a designated path, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOnPath();


    /**
     *  Gets the <code> Path </code> <code> Id. </code> 
     *
     *  @return the path <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isOnPath() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPathId();


    /**
     *  Gets the <code> Path. </code> 
     *
     *  @return the path 
     *  @throws org.osid.IllegalStateException <code> isOnPath() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Path getPath()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resource velocity record corresponding to the given <code> 
     *  ResourceVelocity </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> resourceVelocityRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(resourceVelocityRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  resourceVelocityRecordType the type of resource velocity 
     *          record to retrieve 
     *  @return the resource velocity record 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceVelocityRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(resourceVelocityRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.records.ResourceVelocityRecord getResourceVelocityRecord(org.osid.type.Type resourceVelocityRecordType)
        throws org.osid.OperationFailedException;
}
