//
// org.osid.mapping.path.ResourceVelocitySession
//
//     The OSID Java specification for org.osid.mapping.path.ResourceVelocitySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session defines methods to look up resources on paths. </p>
 */

public interface ResourceVelocitySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can access the velocities of resources. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer location operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if velocity methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessResourcePaths();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeResourcePathView();


    /**
     *  A complete view of the <code> Path </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryResourcePathView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include paths in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets the current velocity of the given resource. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the current velocity 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not on 
     *          map 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ResourceVelocity getResourceVelocity(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the current velocities of the given resources. In plenary mode, 
     *  the returned list contains all of the velocities of the supplied 
     *  resources or an error results. In comparative mode, inaccessible 
     *  resources may be omitted or duplicates suppressed or reordered. 
     *
     *  @param  resourceIds a resource list 
     *  @return the current velocities 
     *  @throws org.osid.NotFoundException a resource <code> Id </code> is not 
     *          on map 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ResourceVelocityList geResourceVelociiesForResource(org.osid.id.IdList resourceIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the current velocities for a resource genus type. In plenary 
     *  mode, the returned list contains all of the velocities of the supplied 
     *  resources or an error results. In comparative mode, inaccessible 
     *  resources may be omitted or duplicates suppressed or reordered. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @return the resource velocities 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ResourceVelocityList getResourceVelocitiesByGenusType(org.osid.id.Id pathId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the current resource velocities on a given path. In plenary mode, 
     *  the returned list contains all of the velocities of the supplied 
     *  resources or an error results. In comparative mode, inaccessible 
     *  resources may be omitted or duplicates suppressed or reordered. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @return the resource velocities 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ResourceVelocityList getResourceVelocitiesOnPath(org.osid.id.Id pathId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the current velocities on a given path for a resource genus type. 
     *  In plenary mode, the returned list contains all of the velocities of 
     *  the supplied resources or an error results. In comparative mode, 
     *  inaccessible resources may be omitted or duplicates suppressed or 
     *  reordered. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @param  resourceGenusType a resource genus type 
     *  @return the resource velocities 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId </code> or <code> 
     *          resourceGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ResourceVelocityList getResourceVelocitiesOnPathByGenusType(org.osid.id.Id pathId, 
                                                                                             org.osid.type.Type resourceGenusType)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the current velocities for given resources in the given spatial 
     *  unit. 
     *
     *  @param  spatialUnit a spatial unit 
     *  @return the current velocities 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException spatial unit not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ResourceVelocityList getResourceVelocitiesInSpatialUnit(org.osid.mapping.SpatialUnit spatialUnit)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the current velocities on a given path for a resource genus type. 
     *  In plenary mode, the returned list contains all of the velocities of 
     *  the supplied resources or an error results. In comparative mode, 
     *  inaccessible resources may be omitted or duplicates suppressed or 
     *  reordered. 
     *
     *  @param  spatialUnit a spatial unit 
     *  @param  resourceGenusType a resource genus type 
     *  @return the resource velocities 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> or 
     *          <code> resourceGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException spatial unit not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ResourceVelocityList getResourceVelocitiesInSpatialUnitByGenusType(org.osid.mapping.SpatialUnit spatialUnit, 
                                                                                                    org.osid.type.Type resourceGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
