//
// org.osid.mapping.path.SignalMapAssignmentSession
//
//     The OSID Java specification for org.osid.mapping.path.SignalMapAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session provides methods to re-assign <code> Signals </code> to 
 *  <code> Map </code> objects A <code> Signal </code> may appear in multiple 
 *  <code> Map </code> objects and removing the last reference to a <code> 
 *  Signal </code> is the equivalent of deleting it. Each <code> Map </code> 
 *  may have its own authorizations governing who is allowed to operate on it. 
 *  </p> 
 *  
 *  <p> Adding a reference of a <code> Signal </code> to another <code> Map 
 *  </code> is not a copy operation (eg: does not change its <code> Id </code> 
 *  ). </p>
 */

public interface SignalMapAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter signal/map mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known signal methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if signal is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSignals();


    /**
     *  Tests if this user can alter signal/map mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known signal methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSignalsToMap(org.osid.id.Id mapId);


    /**
     *  Gets a list of maps including and under the given map node in which 
     *  any signal can be assigned. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @return list of assignable map <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableMapIds(org.osid.id.Id mapId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of maps including and under the given map node in which a 
     *  specific signal can be assigned. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> 
     *  @return list of assignable map <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          signalId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableMapIdsForSignal(org.osid.id.Id mapId, 
                                                           org.osid.id.Id signalId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Signal </code> to a <code> Map. </code> 
     *
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> 
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @throws org.osid.AlreadyExistsException <code> signalId </code> is 
     *          already assigned to <code> mapId </code> 
     *  @throws org.osid.NotFoundException <code> signalId </code> or <code> 
     *          mapId </code> not found 
     *  @throws org.osid.NullArgumentException <code> signalId </code> or 
     *          <code> mapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignSignalToMap(org.osid.id.Id signalId, 
                                  org.osid.id.Id mapId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Signal </code> from a <code> Map. </code> 
     *
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> 
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @throws org.osid.NotFoundException <code> signalId </code> or <code> 
     *          mapId </code> not found or <code> signalId </code> not 
     *          assigned to <code> mapId </code> 
     *  @throws org.osid.NullArgumentException <code> signalId </code> or 
     *          <code> mapId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignSignalFromMap(org.osid.id.Id signalId, 
                                      org.osid.id.Id mapId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
