//
// org.osid.mapping.path.SpeedZone
//
//     The OSID Java specification for org.osid.mapping.path.SpeedZone.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>A <code> SpeedZone </code> represents a speed zone in a <code> Map. 
 *  </code> </p>
 */

public interface SpeedZone
    extends org.osid.OsidRule {


    /**
     *  Gets the path <code> Id </code> of this speed zone. 
     *
     *  @return the <code> Id </code> of the path 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPathId();


    /**
     *  Gets the path of this speed zone. 
     *
     *  @return the path 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.Path getPath()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the starting coordinate of the speed zone on the path. 
     *
     *  @return the start of the zone 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Coordinate getStartingCoordinate();


    /**
     *  Gets the ending coordinate of the speed zone on the path. 
     *
     *  @return the end of the zone 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Coordinate getEndingCoordinate();


    /**
     *  Tests if this speed zone is implicit. An implicit speed zone is 
     *  generated from other information such as an <code> Obstacle. </code> 
     *
     *  @return <code> true </code> if this speed zone is implicit, <code> 
     *          false </code> if explicitly managed 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isImplicit();


    /**
     *  Gets the speed limit in this zone. 
     *
     *  @return the speed limit 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Speed getSpeedLimit();


    /**
     *  Gets the speed zone record corresponding to the given <code> SpeedZone 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  speedZoneRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(speedZoneRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  speedZoneRecordType the type of speed zone record to retrieve 
     *  @return the speed zone record 
     *  @throws org.osid.NullArgumentException <code> speedZoneRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(speedZoneRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.records.SpeedZoneRecord getSpeedZoneRecord(org.osid.type.Type speedZoneRecordType)
        throws org.osid.OperationFailedException;
}
