//
// org.osid.mapping.path.SpeedZoneLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.SpeedZoneLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path;


/**
 *  <p>This session defines methods for retrieving speed zones. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated map view: All speed zone methods in this session 
 *      operate, retrieve and pertain to speed zones defined explicitly in the 
 *      current map. Using an isolated view is useful for managing <code> 
 *      SpeedZones </code> with the <code> SpeedZoneAdminSession. </code> 
 *      </li> 
 *      <li> federated map view: All speed zone lookup methods in this session 
 *      operate, retrieve and pertain to all speed zones defined in this map 
 *      and any other speed zones implicitly available in this map through map 
 *      inheritence. </li> 
 *      <li> active speed zone view: All speed zone lookup methods return 
 *      active speed zones. </li> 
 *      <li> any status speed zone view: Speed zones of any active or inactive 
 *      status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Speed zones may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> SpeedZones. </code> </p>
 */

public interface SpeedZoneLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> SpeedZone </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSpeedZones();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSpeedZoneView();


    /**
     *  A complete view of the <code> SpeedZone </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySpeedZoneView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include speed zones in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Only active speed zones are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveSpeedZoneView();


    /**
     *  All active and inactive speed zones are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusSpeedZoneView();


    /**
     *  Gets the <code> SpeedZone </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  SpeedZone </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> SpeedZone </code> and retained for compatibility. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @param  speedZoneId the <code> Id </code> of the <code> SpeedZone 
     *          </code> to retrieve 
     *  @return the returned <code> SpeedZone </code> 
     *  @throws org.osid.NotFoundException no <code> SpeedZone </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZone getSpeedZone(org.osid.id.Id speedZoneId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  speed zones specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> SpeedZones </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @param  speedZoneIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> SpeedZone </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesByIds(org.osid.id.IdList speedZoneIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> corresponding to the given speed 
     *  zone genus <code> Type </code> which does not include speed zones of 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  speed zones or an error results. Otherwise, the returned list may 
     *  contain only those speed zones that are accessible through this 
     *  session. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @param  speedZoneGenusType a speed zone genus type 
     *  @return the returned <code> SpeedZone </code> list 
     *  @throws org.osid.NullArgumentException <code> speedZoneGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesByGenusType(org.osid.type.Type speedZoneGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> corresponding to the given speed 
     *  zone genus <code> Type </code> and include any additional speed zones 
     *  with genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  speed zones or an error results. Otherwise, the returned list may 
     *  contain only those speed zones that are accessible through this 
     *  session. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @param  speedZoneGenusType a speed zone genus type 
     *  @return the returned <code> SpeedZone </code> list 
     *  @throws org.osid.NullArgumentException <code> speedZoneGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesByParentGenusType(org.osid.type.Type speedZoneGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> containing the given speed zone 
     *  record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known speed zones or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  speed zones that are accessible through this session. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @param  speedZoneRecordType a speed zone record type 
     *  @return the returned <code> SpeedZone </code> list 
     *  @throws org.osid.NullArgumentException <code> speedZoneRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesByRecordType(org.osid.type.Type speedZoneRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> containing the given path. 
     *  
     *  In plenary mode, the returned list contains all known spwed zones or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  speed zones that are accessible through this session. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @return the returned <code> SpeedZone </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesForPath(org.osid.id.Id pathId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneList </code> containing the given path between 
     *  the given coordinates inclusive. 
     *  
     *  In plenary mode, the returned list contains all known speed zones or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  speed zones that are accessible through this session. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @param  pathId a path <code> Id </code> 
     *  @param  coordinate starting coordinate 
     *  @param  distance a distance from coordinate 
     *  @return the returned <code> SpeedZone </code> list 
     *  @throws org.osid.NullArgumentException <code> pathId, coordinate 
     *          </code> or <code> distance </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZonesForPathAtCoordinate(org.osid.id.Id pathId, 
                                                                                org.osid.mapping.Coordinate coordinate, 
                                                                                org.osid.mapping.Distance distance)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> SpeedZones. </code> 
     *  
     *  In plenary mode, the returned list contains all known speed zones or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  speed zones that are accessible through this session. 
     *  
     *  In active mode, speed zones are returned that are currently active. In 
     *  any status mode, active and inactive speed zones are returned. 
     *
     *  @return a list of <code> SpeedZones </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.SpeedZoneList getSpeedZones()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
