/**
 * <p>The Open Service Interface Definitions for the org.osid.mapping.path
 * service.</p>
 * 
 * <p>The Mapping Path OSID provides a means for managing spatial paths. This 
 * service may be used to link routing information with geospatial information 
 * or to simulate or monitor physical traffic. </p> 
 * <h4> Path </h4> 
 * 
 * <p> A <code> Path </code> is any interconnection that may represent a road, 
 * hallway, or orbit. A <code> Path </code> is plotted along a series of 
 * <code> Coordinates </code> to describe its geometry or may include data to 
 * generate the path from an equation. </p> 
 * 
 * <p> A multi-lane road may be modeled as a series of individual paths along 
 * side each other. Each Path may have its own intersections, speed zones, 
 * obstacles, and signals. </p> 
 * <h4> Intersections </h4> 
 * 
 * <p> <code> Intersections </code> define a crossing of <code> Paths </code> 
 * where one can move from one <code> Path </code> to another. Different types 
 * of <code> Intersections </code> may exist including forks and rotaries. 
 * </p> 
 * <h4> Speed Zones </h4> 
 * 
 * <p> A <code> SpeedZone </code> specifies the speed limit between a set of 
 * <code> Coordinates </code> on a <code> Path. </code> <code> SpeedZones 
 * </code> may be manually created or automatically generated based on 
 * conditions along a <code> Path. </code> </p> 
 * <h4> Signals </h4> 
 * 
 * <p> A <code> Signal </code> represents some instruction to traffic along a 
 * <code> Path. </code> A Signal may be a traffic light, stop sign, or other 
 * control point in which to collect data about moving <code> Resources. 
 * </code> </p> 
 * <h4> Obstacles </h4> 
 * 
 * <p> <code> Obstacles </code> represent an obstruction that impacts the 
 * travel between a set of <code> Coordinates </code> along a <code> Path. 
 * </code> <code> Obstacles </code> may be used to generate implicit <code> 
 * SpeedZones </code> or completely block a <code> Path. </code> </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Mapping Path OSID contains a Mapping Path Rules OSID for managing 
 * the effectiveness of <code> SppedZones </code> and <code> Obstacles </code> 
 * as well as a Mapping Path Batch OSID for managing <code> Paths, </code> 
 * <code> Intersections, </code> <code> Signals, </code> and <code> Obstacles 
 * </code> in bulk. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.mapping.path;
