//
// org.osid.mapping.path.rules.MappingPathRulesProfile
//
//     The OSID Java specification for org.osid.mapping.path.rules.MappingPathRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>The mapping rules profile describes the interoperability among mapping 
 *  rules services. </p>
 */

public interface MappingPathRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up speed zone enablers is supported. 
     *
     *  @return <code> true </code> if speed zone enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerLookup();


    /**
     *  Tests if querying speed zone enablers is supported. 
     *
     *  @return <code> true </code> if speed zone enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerQuery();


    /**
     *  Tests if searching speed zone enablers is supported. 
     *
     *  @return <code> true </code> if speed zone enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerSearch();


    /**
     *  Tests if a speed zone enabler administrative service is supported. 
     *
     *  @return <code> true </code> if speed zone enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerAdmin();


    /**
     *  Tests if a speed zone enabler notification service is supported. 
     *
     *  @return <code> true </code> if speed zone enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerNotification();


    /**
     *  Tests if a speed zone enabler map lookup service is supported. 
     *
     *  @return <code> true </code> if a speed zone enabler map lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerMap();


    /**
     *  Tests if a speed zone enabler map service is supported. 
     *
     *  @return <code> true </code> if speed zone enabler map assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerMapAssignment();


    /**
     *  Tests if a speed zone enabler map lookup service is supported. 
     *
     *  @return <code> true </code> if a speed zone enabler map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerSmartMap();


    /**
     *  Tests if a speed zone enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a speed zone enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerRuleLookup();


    /**
     *  Tests if a speed zone enabler rule application service is supported. 
     *
     *  @return <code> true </code> if speed zone enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerRuleApplication();


    /**
     *  Tests if looking up signal enabler is supported. 
     *
     *  @return <code> true </code> if signal enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerLookup();


    /**
     *  Tests if querying signal enabler is supported. 
     *
     *  @return <code> true </code> if signal enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerQuery();


    /**
     *  Tests if searching signal enabler is supported. 
     *
     *  @return <code> true </code> if signal enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerSearch();


    /**
     *  Tests if a signal enabler administrative service is supported. 
     *
     *  @return <code> true </code> if signal enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerAdmin();


    /**
     *  Tests if a signal enabler notification service is supported. 
     *
     *  @return <code> true </code> if signal enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerNotification();


    /**
     *  Tests if a signal enabler map lookup service is supported. 
     *
     *  @return <code> true </code> if a signal enabler map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerMap();


    /**
     *  Tests if a signal enabler map service is supported. 
     *
     *  @return <code> true </code> if signal enabler map assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerMapAssignment();


    /**
     *  Tests if a signal enabler map lookup service is supported. 
     *
     *  @return <code> true </code> if a signal enabler map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerSmartMap();


    /**
     *  Tests if a signal enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a signal enabler rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerRuleLookup();


    /**
     *  Tests if a signal enabler rule application service is supported. 
     *
     *  @return <code> true </code> if a signal enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerRuleApplication();


    /**
     *  Tests if looking up obstacle enabler is supported. 
     *
     *  @return <code> true </code> if obstacle enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerLookup();


    /**
     *  Tests if querying obstacle enabler is supported. 
     *
     *  @return <code> true </code> if obstacle enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerQuery();


    /**
     *  Tests if searching obstacle enabler is supported. 
     *
     *  @return <code> true </code> if obstacle enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerSearch();


    /**
     *  Tests if an obstacle enabler administrative service is supported. 
     *
     *  @return <code> true </code> if obstacle enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerAdmin();


    /**
     *  Tests if an obstacle enabler notification service is supported. 
     *
     *  @return <code> true </code> if obstacle enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerNotification();


    /**
     *  Tests if an obstacle enabler map lookup service is supported. 
     *
     *  @return <code> true </code> if an obstacle enabler map lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerMap();


    /**
     *  Tests if an obstacle enabler map service is supported. 
     *
     *  @return <code> true </code> if obstacle enabler map assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerMapAssignment();


    /**
     *  Tests if an obstacle enabler map lookup service is supported. 
     *
     *  @return <code> true </code> if an obstacle enabler map service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerSmartMap();


    /**
     *  Tests if an obstacle enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an obstacle enabler rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerRuleLookup();


    /**
     *  Tests if an obstacle enabler rule application service is supported. 
     *
     *  @return <code> true </code> if an obstacle enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerRuleApplication();


    /**
     *  Gets the supported <code> SpeedZoneEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> SpeedZoneEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpeedZoneEnablerRecordTypes();


    /**
     *  Tests if the given <code> SpeedZoneEnabler </code> record type is 
     *  supported. 
     *
     *  @param  speedZoneEnablerRecordType a <code> Type </code> indicating a 
     *          <code> SpeedZoneEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerRecordType(org.osid.type.Type speedZoneEnablerRecordType);


    /**
     *  Gets the supported <code> SpeedZoneEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> SpeedZoneEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSpeedZoneEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> SpeedZoneEnabler </code> search record type 
     *  is supported. 
     *
     *  @param  speedZoneEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> SpeedZoneEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSpeedZoneEnablerSearchRecordType(org.osid.type.Type speedZoneEnablerSearchRecordType);


    /**
     *  Gets the supported <code> SignalEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> SignalEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSignalEnablerRecordTypes();


    /**
     *  Tests if the given <code> SignalEnabler </code> record type is 
     *  supported. 
     *
     *  @param  signalEnablerRecordType a <code> Type </code> indicating a 
     *          <code> SignalEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> signalEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerRecordType(org.osid.type.Type signalEnablerRecordType);


    /**
     *  Gets the supported <code> SignalEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> SignalEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSignalEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> SignalEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  signalEnablerSearchRecordType a <code> Type </code> indicating 
     *          a <code> SignalEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          signalEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSignalEnablerSearchRecordType(org.osid.type.Type signalEnablerSearchRecordType);


    /**
     *  Gets the supported <code> ObstacleEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> ObstacleEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObstacleEnablerRecordTypes();


    /**
     *  Tests if the given <code> ObstacleEnabler </code> record type is 
     *  supported. 
     *
     *  @param  obstacleEnablerRecordType a <code> Type </code> indicating an 
     *          <code> ObstacleEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerRecordType(org.osid.type.Type obstacleEnablerRecordType);


    /**
     *  Gets the supported <code> ObstacleEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> ObstacleEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getObstacleEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> ObstacleEnabler </code> search record type 
     *  is supported. 
     *
     *  @param  obstacleEnablerSearchRecordType a <code> Type </code> 
     *          indicating an <code> ObstacleEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsObstacleEnablerSearchRecordType(org.osid.type.Type obstacleEnablerSearchRecordType);
}
