//
// org.osid.mapping.path.rules.MappingPathRulesProxyManager
//
//     The OSID Java specification for org.osid.mapping.path.rules.MappingPathRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>The mapping rules proxy manager provides access to mapping rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> SpeedZoneEnablerLookupSession: </code> a session to 
 *      retrieve speed zone enablers </li> 
 *      <li> <code> SpeedZoneEnablerQuerySession: </code> a session to query 
 *      for speed zone enablers </li> 
 *      <li> <code> SpeedZoneEnablerSearchSession: </code> a session to search 
 *      for speed zone enablers </li> 
 *      <li> <code> SpeedZoneEnablerAdminSession: </code> a session to create 
 *      and delete speed zone enablers </li> 
 *      <li> <code> SpeedZoneEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to speed zone enabler changes </li> 
 *      <li> <code> SpeedZoneEnablerMapSession: </code> a session to look up 
 *      speed zone enabler map mappings </li> 
 *      <li> <code> SpeedZoneEnablerMapAssignmentSession: </code> a session to 
 *      manage speed zone enabler to map mappings </li> 
 *      <li> <code> SpeedZoneEnablerSmartMapSession: </code> a session to 
 *      manage dynamic map of speed zone enablers </li> 
 *      <li> <code> SpeedZoneEnableRuleLookupSession: </code> a session to 
 *      look up speed zone enabler mappings </li> 
 *      <li> <code> SpeedZoneEnablerRuleApplicationSession: </code> a session 
 *      to apply speed zone enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SpeedZoneProcessorEnablerLookupSession: </code> a session 
 *      to retrieve speed zone processor enablers </li> 
 *      <li> <code> SpeedZoneProcessorEnablerQuerySession: </code> a session 
 *      to query for speed zone processor enablers </li> 
 *      <li> <code> SpeedZoneProcessorEnablerSearchSession: </code> a session 
 *      to search for speed zone processor enablers </li> 
 *      <li> <code> SpeedZoneProcessorEnablerAdminSession: </code> a session 
 *      to create and delete speed zone processor enablers </li> 
 *      <li> <code> SpeedZoneProcessorEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to speed zone processor 
 *      enabler changes </li> 
 *      <li> <code> SpeedZoneProcessorEnablerMapSession: </code> a session to 
 *      look up speed zone processor enabler map mappings </li> 
 *      <li> <code> SpeedZoneProcessorEnablerMapAssignmentSession: </code> a 
 *      session to manage speed zone processor enabler to map mappings </li> 
 *      <li> <code> SpeedZoneProcessorEnablerSmartMapSession: </code> a 
 *      session to manage dynamic map of speed zone processor enablers </li> 
 *      <li> <code> SpeedZoneProcessorEnablerRuleLookupSession: </code> a 
 *      session to look up speed zone processor enabler mappings </li> 
 *      <li> <code> SpeedZoneProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply speed zone processor enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> SignalEnablerLookupSession: </code> a session to retrieve 
 *      signal enabler </li> 
 *      <li> <code> SignalEnablerQuerySession: </code> a session to query for 
 *      signal enabler </li> 
 *      <li> <code> SignalEnablerSearchSession: </code> a session to search 
 *      for signal enabler </li> 
 *      <li> <code> SignalEnablerAdminSession: </code> a session to create and 
 *      delete signal enabler </li> 
 *      <li> <code> SignalEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to signal enabler changes </li> 
 *      <li> <code> SignalEnablerMapSession: </code> a session to look up 
 *      signal enabler map mappings </li> 
 *      <li> <code> SignalEnablerMapAssignmentSession: </code> a session to 
 *      manage signal enabler to map mappings </li> 
 *      <li> <code> SignalEnablerSmartMapSession: </code> a session to manage 
 *      dynamic map of signal enabler </li> 
 *      <li> <code> SignalEnablerRuleLookupSession: </code> a session to look 
 *      up signal enabler to signal mappings </li> 
 *      <li> <code> SignalEnablerRuleApplicationSession: </code> a session to 
 *      apply signal enabler to signalss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ObstacleEnablerLookupSession: </code> a session to 
 *      retrieve obstacle enabler </li> 
 *      <li> <code> ObstacleEnablerQuerySession: </code> a session to query 
 *      for obstacle enabler </li> 
 *      <li> <code> ObstacleEnablerSearchSession: </code> a session to search 
 *      for obstacle enabler </li> 
 *      <li> <code> ObstacleEnablerAdminSession: </code> a session to create 
 *      and delete obstacle enabler </li> 
 *      <li> <code> ObstacleEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to obstacle enabler changes </li> 
 *      <li> <code> ObstacleEnablerMapSession: </code> a session to look up 
 *      obstacle enabler map mappings </li> 
 *      <li> <code> ObstacleEnablerMapAssignmentSession: </code> a session to 
 *      manage obstacle enabler to map mappings </li> 
 *      <li> <code> ObstacleEnablerSmartMapSession: </code> a session to 
 *      manage dynamic map of obstacle enabler </li> 
 *      <li> <code> ObstacleEnablerRuleLookupSession: </code> a session to 
 *      look up obstacle enabler to obstacle mappings </li> 
 *      <li> <code> ObstacleEnablerRuleApplicationSession: </code> a session 
 *      to apply obstacle enabler to obstacles </li> 
 *  </ul>
 *  
 */

public interface MappingPathRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.mapping.path.rules.MappingPathRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerLookupSession getSpeedZoneEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler lookup service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerLookupSession getSpeedZoneEnablerLookupSessionForMap(org.osid.id.Id mapId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerQuerySession getSpeedZoneEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler query service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerQuerySession getSpeedZoneEnablerQuerySessionForMap(org.osid.id.Id mapId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerSearchSession getSpeedZoneEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enablers earch service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerSearchSession getSpeedZoneEnablerSearchSessionForMap(org.osid.id.Id mapId, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerAdminSession getSpeedZoneEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler administration service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerAdminSession getSpeedZoneEnablerAdminSessionForMap(org.osid.id.Id mapId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler notification service. 
     *
     *  @param  speedZoneEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerNotificationSession getSpeedZoneEnablerNotificationSession(org.osid.mapping.path.rules.SpeedZoneEnablerReceiver speedZoneEnablerReceiver, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler notification service for the given map. 
     *
     *  @param  speedZoneEnablerReceiver the notification callback 
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no map found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerReceiver, mapId </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerNotificationSession getSpeedZoneEnablerNotificationSessionForMap(org.osid.mapping.path.rules.SpeedZoneEnablerReceiver speedZoneEnablerReceiver, 
                                                                                                                        org.osid.id.Id mapId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup speed zone enabler/map 
     *  mappings for speed zone enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerMapSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerMap() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerMap() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerMapSession getSpeedZoneEnablerMapSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning speed 
     *  zone enablers to map. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerMapAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerMapAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerMapAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerMapAssignmentSession getSpeedZoneEnablerMapAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage speed zone enabler smart 
     *  map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerSmartMapSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerSmartMap() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerSmartMap() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerSmartMapSession getSpeedZoneEnablerSmartMapSession(org.osid.id.Id mapId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerRuleLookupSession getSpeedZoneEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler mapping lookup service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerRuleLookupSession getSpeedZoneEnablerRuleLookupSessionForMap(org.osid.id.Id mapId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerRuleApplicationSession getSpeedZoneEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the speed zone 
     *  enabler assignment service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SpeedZoneEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSpeedZoneEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpeedZoneEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerRuleApplicationSession getSpeedZoneEnablerRuleApplicationSessionForMap(org.osid.id.Id mapId, 
                                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerLookupSession getSignalEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  lookup service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerLookupSession getSignalEnablerLookupSessionForMap(org.osid.id.Id mapId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerQuerySession getSignalEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  query service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerQuerySession getSignalEnablerQuerySessionForMap(org.osid.id.Id mapId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException a <code> 
     *          SignalEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerSearchSession getSignalEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  earch service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerSearchSession getSignalEnablerSearchSessionForMap(org.osid.id.Id mapId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerAdminSession getSignalEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  administration service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerAdminSession getSignalEnablerAdminSessionForMap(org.osid.id.Id mapId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  notification service. 
     *
     *  @param  signalEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> signalEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerNotificationSession getSignalEnablerNotificationSession(org.osid.mapping.path.rules.SignalEnablerReceiver signalEnablerReceiver, 
                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  notification service for the given map. 
     *
     *  @param  signalEnablerReceiver the notification callback 
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no map found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> signalEnablerReceiver, 
     *          mapId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerNotificationSession getSignalEnablerNotificationSessionForMap(org.osid.mapping.path.rules.SignalEnablerReceiver signalEnablerReceiver, 
                                                                                                                  org.osid.id.Id mapId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup signal enabler/map 
     *  mappings for signal enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerMapSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerMap() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerMap() </code> is <code> true. </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerMapSession getSignalEnablerMapSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning signal 
     *  enabler to map. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerMapAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerMapAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerMapAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerMapAssignmentSession getSignalEnablerMapAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage signal enabler smart 
     *  map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerSmartMapSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerSmartMap() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerSmartMap() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerSmartMapSession getSignalEnablerSmartMapSession(org.osid.id.Id mapId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  mapping lookup service for looking up the rules applied to a signal. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerRuleLookupSession getSignalEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  mapping lookup service for the given map for looking up rules applied 
     *  to a signal. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerRuleLookupSession getSignalEnablerRuleLookupSessionForMap(org.osid.id.Id mapId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  assignment service to apply to signals. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerRuleApplicationSession getSignalEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the signal enabler 
     *  assignment service for the given map to apply to signals. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SignalEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSignalEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSignalEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.SignalEnablerRuleApplicationSession getSignalEnablerRuleApplicationSessionForMap(org.osid.id.Id mapId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerLookupSession getObstacleEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler lookup service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerLookupSession getObstacleEnablerLookupSessionForMap(org.osid.id.Id mapId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerQuerySession getObstacleEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler query service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerQuerySession getObstacleEnablerQuerySessionForMap(org.osid.id.Id mapId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerSearchSession getObstacleEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler earch service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerSearchSession getObstacleEnablerSearchSessionForMap(org.osid.id.Id mapId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerAdminSession getObstacleEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler administration service for the given map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerAdminSession getObstacleEnablerAdminSessionForMap(org.osid.id.Id mapId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler notification service. 
     *
     *  @param  obstacleEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerNotificationSession getObstacleEnablerNotificationSession(org.osid.mapping.path.rules.ObstacleEnablerReceiver obstacleEnablerReceiver, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler notification service for the given map. 
     *
     *  @param  obstacleEnablerReceiver the notification callback 
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no map found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerReceiver, 
     *          mapId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerNotificationSession getObstacleEnablerNotificationSessionForMap(org.osid.mapping.path.rules.ObstacleEnablerReceiver obstacleEnablerReceiver, 
                                                                                                                      org.osid.id.Id mapId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup obstacle enabler/map 
     *  mappings for obstacle enablers. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerMapSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerMap() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerMap() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerMapSession getObstacleEnablerMapSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning obstacle 
     *  enabler to map. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerMapAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerMapAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerMapAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerMapAssignmentSession getObstacleEnablerMapAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage obstacle enabler smart 
     *  map. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerSmartMapSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerSmartMap() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerSmartMap() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerSmartMapSession getObstacleEnablerSmartMapSession(org.osid.id.Id mapId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler mapping lookup service for looking up the rules applied to an 
     *  obstacle. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerRuleLookupSession getObstacleEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler mapping lookup service for the given map for looking up rules 
     *  applied to an obstacle. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerRuleLookupSession getObstacleEnablerRuleLookupSessionForMap(org.osid.id.Id mapId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler assignment service to apply to obstacles. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerRuleApplicationSession getObstacleEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the obstacle 
     *  enabler assignment service for the given map to apply to obstacles. 
     *
     *  @param  mapId the <code> Id </code> of the <code> Map </code> 
     *  @param  proxy a proxy 
     *  @return an <code> ObstacleEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Map </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> mapId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsObstacleEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsObstacleEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerRuleApplicationSession getObstacleEnablerRuleApplicationSessionForMap(org.osid.id.Id mapId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
