//
// org.osid.mapping.path.rules.ObstacleEnablerLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.ObstacleEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods for retrieving <code> ObstacleEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated map view: All obstacle enabler methods in this session 
 *      operate, retrieve and pertain to obstacle enabler defined explicitly 
 *      in the current map. Using an isolated view is useful for managing 
 *      <code> ObstacleEnablers </code> with the <code> 
 *      ObstacleEnablerAdminSession. </code> </li> 
 *      <li> federated map view: All obstacle enabler methods in this session 
 *      operate, retrieve and pertain to all obstacle enabler defined in this 
 *      map and any other obstacle enabler implicitly available in this map 
 *      through map inheritence. </li> 
 *      <li> active obstacle enabler view: All obstacle enabler lookup methods 
 *      return active obstacle enablers. </li> 
 *      <li> any status obstacle enabler view: Obstacle enablers of any active 
 *      or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface ObstacleEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ObstacleEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupObstacleEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeObstacleEnablerView();


    /**
     *  A complete view of the <code> ObstacleEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryObstacleEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include obstacle enabler in map which are children of this map in the 
     *  map hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this maps only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Only active obstacle enablers are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveObstacleEnablerView();


    /**
     *  All active and inactive obstacle enablers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusObstacleEnablerView();


    /**
     *  Gets the <code> ObstacleEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ObstacleEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> ObstacleEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active. In any status mode, active and inactive obstacle enablers are 
     *  returned. 
     *
     *  @param  obstacleEnablerId <code> Id </code> of the <code> 
     *          ObstacleEnabler </code> 
     *  @return the obstacle enabler 
     *  @throws org.osid.NotFoundException <code> obstacleEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnabler getObstacleEnabler(org.osid.id.Id obstacleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  obstacle enabler specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> ObstacleEnablers </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active. In any status mode, active and inactive obstacle enablers are 
     *  returned. 
     *
     *  @param  obstacleEnablerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ObstacleEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablersByIds(org.osid.id.IdList obstacleEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleEnablerList </code> corresponding to the given 
     *  obstacle enabler genus <code> Type </code> which does not include 
     *  obstacle enabler of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  obstacle enabler or an error results. Otherwise, the returned list may 
     *  contain only those obstacle enabler that are accessible through this 
     *  session. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active. In any status mode, active and inactive obstacle enablers are 
     *  returned. 
     *
     *  @param  obstacleEnablerGenusType an obstacle enabler genus type 
     *  @return the returned <code> ObstacleEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablersByGenusType(org.osid.type.Type obstacleEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleEnablerList </code> corresponding to the given 
     *  obstacle enabler genus <code> Type </code> and include any additional 
     *  obstacle enabler with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  obstacle enabler or an error results. Otherwise, the returned list may 
     *  contain only those obstacle enabler that are accessible through this 
     *  session. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active. In any status mode, active and inactive obstacle enablers are 
     *  returned. 
     *
     *  @param  obstacleEnablerGenusType an obstacle enabler genus type 
     *  @return the returned <code> ObstacleEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablersByParentGenusType(org.osid.type.Type obstacleEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleEnablerList </code> containing the given 
     *  obstacle enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  obstacle enabler or an error results. Otherwise, the returned list may 
     *  contain only those obstacle enabler that are accessible through this 
     *  session. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active. In any status mode, active and inactive obstacle enablers are 
     *  returned. 
     *
     *  @param  obstacleEnablerRecordType an obstacle enabler record type 
     *  @return the returned <code> ObstacleEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablersByRecordType(org.osid.type.Type obstacleEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleEnablerList </code> that are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  for any agent. 
     *  
     *  In plenary mode, the returned list contains all known obstacle 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those obstacle enablers that are accessible through this session. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive obstacle enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ObstacleEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> ObstacleEnablerList </code> that are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  and evaluated against the given agent. 
     *  
     *  In plenary mode, the returned list contains all known obstacle 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those obstacle enablers that are accessible through this session. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive obstacle enablers are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ObstacleEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                              org.osid.calendaring.DateTime from, 
                                                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ObstacleEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known obstacle enabler 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those obstacle enabler that are accessible through this session. 
     *  
     *  In active mode, obstacle enablers are returned that are currently 
     *  active. In any status mode, active and inactive obstacle enablers are 
     *  returned. 
     *
     *  @return the returned <code> ObstacleEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
