//
// org.osid.mapping.path.rules.ObstacleEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.ObstacleEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods to retrieve <code> ObstacleEnabler 
 *  </code> to <code> Obstacle </code> mappings. An <code> Obstacle </code> 
 *  with multiple <code> ObstacleEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an enabled <code> Obstacle. 
 *  </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated map view: All methods in this session operate, retrieve 
 *      and pertain obstacle enabler defined explicitly in the current map 
 *      </li> 
 *      <li> federated map view: All methods in this session operate, retrieve 
 *      and pertain to all obstacle enabler defined in this map and any other 
 *      obstacle enabler implicitly available in this map through map 
 *      inheritence. </li> 
 *  </ul>
 *  
 */

public interface ObstacleEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of obstacle enabler/obstacle 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupObstacleEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeObstacleEnablerRuleView();


    /**
     *  A complete view of the <code> ObstacleEnabler </code> and <code> 
     *  Obstacle </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryObstacleEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include obstacle enabler in maps which are children of this map in the 
     *  map hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Gets the <code> ObstacleEnabler Id </code> associated with an <code> 
     *  Obstacle. </code> 
     *
     *  @param  obstacleId <code> Id </code> of the <code> Obstacle </code> 
     *  @return the obstacle enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> obstacleId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> obstacleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getObstacleEnablerIdsForObstacle(org.osid.id.Id obstacleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ObstacleEnabler </code> associated with an <code> 
     *  Obstacle. </code> 
     *
     *  @param  obstacleId <code> Id </code> of the <code> Obstacle </code> 
     *  @return the obstacle enablers 
     *  @throws org.osid.NotFoundException <code> obstacleId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> obstacleId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerList getObstacleEnablersForObstacle(org.osid.id.Id obstacleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Obstacle </code> <code> Ids </code> mapped to an 
     *  <code> ObstacleEnabler. </code> 
     *
     *  @param  obstacleEnablerId <code> Id </code> of an <code> 
     *          ObstacleEnabler </code> 
     *  @return list of obstacle <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> obstacleEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getObstacleIdsForObstacleEnabler(org.osid.id.Id obstacleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Obstacles </code> mapped to an <code> ObstacleEnabler. 
     *  </code> 
     *
     *  @param  obstacleEnablerId <code> Id </code> of an <code> 
     *          ObstacleEnabler </code> 
     *  @return list of obstacles 
     *  @throws org.osid.NotFoundException <code> obstacleEnablerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.ObstacleList getObstaclesForObstacleEnabler(org.osid.id.Id obstacleEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
