//
// org.osid.mapping.path.rules.ObstacleEnablerSearchSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.ObstacleEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  ObstacleEnabler </code> objects. The search query is constructed using the 
 *  <code> ObstacleEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getObstacleEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> ObstacleEnablers. </code> A more advanced 
 *  search may be performed with <code> getObstacleEnablersBySearch(). </code> 
 *  It accepts an <code> ObstacleEnablerSearch </code> in addition to the 
 *  query for the purpose of specifying additional options affecting the 
 *  entire search, such as mapping. <code> getObstacleEnablersBySearch() 
 *  </code> returns an <code> ObstacleEnablerSearchResults </code> that can be 
 *  used to access the resulting <code> ObstacleEnablerList </code> or be used 
 *  to perform a search within the result set through <code> 
 *  ObstacleEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include obstacle enabler in map of 
 *      which this map matchmaker is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to obstacle enabler in 
 *      this office </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> ObstacleEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  ObstacleEnablerQuery. </code> </p>
 */

public interface ObstacleEnablerSearchSession
    extends org.osid.mapping.path.rules.ObstacleEnablerQuerySession {


    /**
     *  Gets an obstacle enabler search. 
     *
     *  @return the obstacle enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerSearch getObstacleEnablerSearch();


    /**
     *  Gets an obstacle enabler search order. The <code> 
     *  ObstacleEnablerSearchOrder </code> is supplied to an <code> 
     *  ObstacleEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the obstacle enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerSearchOrder getObstacleEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  obstacleEnablerQuery the obstacle enabler query 
     *  @param  obstacleEnablerSearch the obstacle enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> obstacleEnablerQuery 
     *          </code> or <code> obstacleEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> obstacleEnablerQuery 
     *          </code> or <code> obstacleEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerSearchResults getObstacleEnablersBySearch(org.osid.mapping.path.rules.ObstacleEnablerQuery obstacleEnablerQuery, 
                                                                                                org.osid.mapping.path.rules.ObstacleEnablerSearch obstacleEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an obstacle enabler query from an inspector. The inspector is 
     *  available from an <code> ObstacleEnablerSearchResults. </code> 
     *
     *  @param  obstacleEnablerQueryInspector an obstacle enabler query 
     *          inspector 
     *  @return the obstacle enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          obstacleEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          obstacleEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.ObstacleEnablerQuery getObstacleEnablerQueryFromInspector(org.osid.mapping.path.rules.ObstacleEnablerQueryInspector obstacleEnablerQueryInspector);
}
