//
// org.osid.mapping.path.rules.SignalEnablerQuery
//
//     The OSID Java specification for org.osid.mapping.path.rules.SignalEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This is the query for searching signal enablers. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface SignalEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to a signal. 
     *
     *  @param  signalId the signal <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> signalId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledSignalId(org.osid.id.Id signalId, boolean match);


    /**
     *  Clears the signal <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSignalIdTerms();


    /**
     *  Tests if a <code> SignalQuery </code> is available. 
     *
     *  @return <code> true </code> if a signal query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledSignalQuery();


    /**
     *  Gets the query for a signal. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the signal query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledSignalQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledSignalQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.path.SignalQuery getRuledSignalQuery();


    /**
     *  Matches rules mapped to any signal. 
     *
     *  @param  match <code> true </code> for rules mapped to any signal, 
     *          <code> false </code> to match rules mapped to no signals 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledSignal(boolean match);


    /**
     *  Clears the signal query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledSignalTerms();


    /**
     *  Matches enablers mapped to an map. 
     *
     *  @param  mapId the map <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMapId(org.osid.id.Id mapId, boolean match);


    /**
     *  Clears the map <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapIdTerms();


    /**
     *  Tests if an <code> MapQuery </code> is available. 
     *
     *  @return <code> true </code> if an map query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapQuery();


    /**
     *  Gets the query for an map. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the map query 
     *  @throws org.osid.UnimplementedException <code> supportsMapQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMapQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.MapQuery getMapQuery();


    /**
     *  Clears the map query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapTerms();


    /**
     *  Gets the signal enabler query record corresponding to the given <code> 
     *  SignalEnabler </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  signalEnablerRecordType a signal enabler record type 
     *  @return the signal enabler query record 
     *  @throws org.osid.NullArgumentException <code> signalEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(signalEnablerRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.records.SignalEnablerQueryRecord getSignalEnablerQueryRecord(org.osid.type.Type signalEnablerRecordType)
        throws org.osid.OperationFailedException;
}
