//
// org.osid.mapping.path.rules.SignalEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SignalEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods to apply <code> SignalEnablers </code> to 
 *  <code> Signals. </code> A <code> Signal </code> with multiple <code> 
 *  SignalEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an enabled <code> Signal. </code> </p>
 */

public interface SignalEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter signal enabler/signal mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSignalEnablers();


    /**
     *  Adds an existing <code> SignalEnabler </code> to a <code> Signal. 
     *  </code> 
     *
     *  @param  signalEnablerId the <code> Id </code> of the <code> 
     *          SignalEnabler </code> 
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> 
     *  @throws org.osid.AlreadyExistsException <code> signalEnablerId </code> 
     *          is already applied to <code> signalId </code> 
     *  @throws org.osid.NotFoundException <code> signalEnablerId </code> or 
     *          <code> signalId </code> not found 
     *  @throws org.osid.NullArgumentException <code> signalEnablerId </code> 
     *          or <code> signalId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignSignalEnablerToSignal(org.osid.id.Id signalEnablerId, 
                                            org.osid.id.Id signalId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> SignalEnabler </code> from a <code> Signal. </code> 
     *
     *  @param  signalEnablerId the <code> Id </code> of the <code> 
     *          SignalEnabler </code> 
     *  @param  signalId the <code> Id </code> of the <code> Signal </code> 
     *  @throws org.osid.NotFoundException <code> signalEnablerId </code> or 
     *          <code> signalId </code> not found or <code> signalEnablerId 
     *          </code> not applied to <code> signalId </code> 
     *  @throws org.osid.NullArgumentException <code> signalEnablerId </code> 
     *          or <code> signalId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignSignalEnablerFromSignal(org.osid.id.Id signalEnablerId, 
                                                org.osid.id.Id signalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> SignalEnablers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> SignalEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceSignalEnablers();


    /**
     *  Reorders signal enablers for a signal by moving the specified signal 
     *  enabler in front of a reference signal enabler. 
     *
     *  @param  signalEnablerId the <code> Id </code> of a <code> 
     *          SignalEnabler </code> 
     *  @param  signalId the <code> Id </code> of a <code> Signal </code> 
     *  @param  referenceId the reference signal enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> signalEnablerId, signalId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          signalEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> signalId </code> 
     *  @throws org.osid.NullArgumentException <code> signalEnablerId, 
     *          signalId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSignalEnablerAhead(org.osid.id.Id signalEnablerId, 
                                       org.osid.id.Id signalId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders signal enablers for a signal by moving the specified signal 
     *  enabler behind a reference signal enabler. 
     *
     *  @param  signalEnablerId the <code> Id </code> of a <code> 
     *          SignalEnabler </code> 
     *  @param  signalId the <code> Id </code> of a <code> Signal </code> 
     *  @param  referenceId the reference signal enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> signalEnablerId, signalId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          signalEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> signalId </code> 
     *  @throws org.osid.NullArgumentException <code> signalEnablerId, 
     *          signalId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSignalEnablerBehind(org.osid.id.Id signalEnablerId, 
                                        org.osid.id.Id signalId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of signal enablers for a signal. 
     *
     *  @param  signalEnablerIds the <code> Ids </code> for a set of <code> 
     *          SignalEnablers </code> 
     *  @param  signalId the <code> Id </code> of a <code> Signal </code> 
     *  @throws org.osid.NotFoundException <code> signalId </code> not found 
     *          or, an <code> signalEnablerId </code> not related to <code> 
     *          signalId </code> 
     *  @throws org.osid.NullArgumentException <code> signalEnabelrIds </code> 
     *          or <code> signalId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderSignalEnablers(org.osid.id.Id[] signalEnablerIds, 
                                    org.osid.id.Id signalId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
