//
// org.osid.mapping.path.rules.SignalEnablerSearchSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SignalEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods for searching among <code> SignalEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  SignalEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getSignalEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> SignalEnablers. </code> A more advanced 
 *  search may be performed with <code> getSignalEnablersBySearch(). </code> 
 *  It accepts a <code> SignalEnablerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as mapping. <code> getSignalEnablersBySearch() </code> 
 *  returns a <code> SignalEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> SignalEnablerList </code> or be used to 
 *  perform a search within the result set through <code> SignalEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include signal enabler in map of 
 *      which this map matchmaker is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to signal enabler in 
 *      this office </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> SignalEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  SignalEnablerQuery. </code> </p>
 */

public interface SignalEnablerSearchSession
    extends org.osid.mapping.path.rules.SignalEnablerQuerySession {


    /**
     *  Gets a signal enabler search. 
     *
     *  @return the signal enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SignalEnablerSearch getSignalEnablerSearch();


    /**
     *  Gets a signal enabler search order. The <code> 
     *  SignalEnablerSearchOrder </code> is supplied to a <code> 
     *  SignalEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the signal enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SignalEnablerSearchOrder getSignalEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  signalEnablerQuery the signal enabler query 
     *  @param  signalEnablerSearch the signal enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> signalEnablerQuery 
     *          </code> or <code> signalEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> signalEnablerQuery 
     *          </code> or <code> signalEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SignalEnablerSearchResults getSignalEnablersBySearch(org.osid.mapping.path.rules.SignalEnablerQuery signalEnablerQuery, 
                                                                                            org.osid.mapping.path.rules.SignalEnablerSearch signalEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a signal enabler query from an inspector. The inspector is 
     *  available from a <code> SignalEnablerSearchResults. </code> 
     *
     *  @param  signalEnablerQueryInspector a signal enabler query inspector 
     *  @return the signal enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          signalEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          signalEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SignalEnablerQuery getSignalEnablerQueryFromInspector(org.osid.mapping.path.rules.SignalEnablerQueryInspector signalEnablerQueryInspector);
}
