//
// org.osid.mapping.path.rules.SpeedZoneEnablerAdminSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session creates and removes speed zone enablers. The data for 
 *  create and update is provided via the <code> SpeedZoneEnablerForm. </code> 
 *  </p>
 */

public interface SpeedZoneEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create speed zone enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> SpeedZoneEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZoneEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSpeedZoneEnabler();


    /**
     *  Tests if this user can create a single <code> SpeedZoneEnabler </code> 
     *  using the desired record types. While <code> 
     *  MappingPathRulesManager.getSpeedZoneEnablerRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  SpeedZoneEnabler. </code> Providing an empty array tests if a <code> 
     *  SpeedZoneEnabler </code> can be created with no records. 
     *
     *  @param  speedZoneEnablerRecordTypes array of speed zone enabler record 
     *          types 
     *  @return <code> true </code> if <code> SpeedZoneEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSpeedZoneEnablerWithRecordTypes(org.osid.type.Type[] speedZoneEnablerRecordTypes);


    /**
     *  Gets the speed zone enabler form for creating new speed zone enablers. 
     *  A new form should be requested for each create transaction. 
     *
     *  @param  speedZoneEnablerRecordTypes array of speed zone enabler record 
     *          types 
     *  @return the speed zone enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerForm getSpeedZoneEnablerFormForCreate(org.osid.type.Type[] speedZoneEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> SpeedZoneEnabler. </code> 
     *
     *  @param  speedZoneEnablerForm the form for this <code> SpeedZoneEnabler 
     *          </code> 
     *  @return the new <code> SpeedZoneEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> speedZoneEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> speedZoneEnablerForm 
     *          </code> did not originate from <code> 
     *          getSpeedZoneEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnabler createSpeedZoneEnabler(org.osid.mapping.path.rules.SpeedZoneEnablerForm speedZoneEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update speed zone enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> SpeedZoneEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZoneEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateSpeedZoneEnablers();


    /**
     *  Gets the speed zone enabler form for updating an existing speed zone 
     *  enabler. A new speed zone enabler form should be requested for each 
     *  update transaction. 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of the <code> 
     *          SpeedZoneEnabler </code> 
     *  @return the speed zone enabler form 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerForm getSpeedZoneEnablerFormForUpdate(org.osid.id.Id speedZoneEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing speed zone enabler. 
     *
     *  @param  speedZoneEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> speedZoneEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> speedZoneEnablerForm 
     *          </code> did not originate from <code> 
     *          getSpeedZoneEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateSpeedZoneEnabler(org.osid.mapping.path.rules.SpeedZoneEnablerForm speedZoneEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete speed zone enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> SpeedZoneEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZoneEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteSpeedZoneEnablers();


    /**
     *  Deletes a <code> SpeedZoneEnabler. </code> 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of the <code> 
     *          SpeedZoneEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteSpeedZoneEnabler(org.osid.id.Id speedZoneEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for speed zone 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZoneEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSpeedZoneEnablerAliases();


    /**
     *  Adds a <code> Id </code> to a <code> SpeedZoneEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> SpeedZoneEnabler </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another speed zone enabler. it 
     *  is reassigned to the given speed zone enabler <code> Id. </code> 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of a <code> 
     *          SpeedZoneEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasSpeedZoneEnabler(org.osid.id.Id speedZoneEnablerId, 
                                      org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
