//
// org.osid.mapping.path.rules.SpeedZoneEnablerLookupSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods for retrieving <code> SpeedZoneEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated map view: All speed zone enabler methods in this session 
 *      operate, retrieve and pertain to speed zone enablers defined 
 *      explicitly in the current map. Using an isolated view is useful for 
 *      managing <code> SpeedZoneEnablers </code> with the <code> 
 *      SpeedZoneEnablerAdminSession. </code> </li> 
 *      <li> federated map view: All speed zone enabler methods in this 
 *      session operate, retrieve and pertain to all speed zone enablers 
 *      defined in this map and any other speed zone enablers implicitly 
 *      available in this map through map inheritence. </li> 
 *      <li> active speed zone enabler view: All speed zone enabler lookup 
 *      methods return active speed zone enablers. </li> 
 *      <li> any active speed zone enabler view: Speed zone enablers of any 
 *      active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedMapView() </code> and <code> 
 *  useIsolatedMapView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface SpeedZoneEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> SpeedZoneEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSpeedZoneEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSpeedZoneEnablerView();


    /**
     *  A complete view of the <code> SpeedZoneEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySpeedZoneEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include speed zone enablers in maps which are children of this map in 
     *  the map hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Only active speed zone enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveSpeedZoneEnablerView();


    /**
     *  All active and inactive speed zone enablers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusSpeedZoneEnablerView();


    /**
     *  Gets the <code> SpeedZoneEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  SpeedZoneEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> SpeedZoneEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @param  speedZoneEnablerId <code> Id </code> of the <code> 
     *          SpeedZoneEnabler </code> 
     *  @return the speed zone enabler 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnabler getSpeedZoneEnabler(org.osid.id.Id speedZoneEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  speed zone enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if a 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> SpeedZoneEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @param  speedZoneEnablerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> SpeedZoneEnabler </code> list 
     *  @throws org.osid.NotFoundException a <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablersByIds(org.osid.id.IdList speedZoneEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneEnablerList </code> corresponding to the given 
     *  speed zone enabler genus <code> Type </code> which does not include 
     *  speed zone enablers of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  speed zone enablers or an error results. Otherwise, the returned list 
     *  may contain only those speed zone enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @param  speedZoneEnablerGenusType a speed zone enabler genus type 
     *  @return the returned <code> SpeedZoneEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablersByGenusType(org.osid.type.Type speedZoneEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneEnablerList </code> corresponding to the given 
     *  speed zone enabler genus <code> Type </code> and include any 
     *  additional speed zone enablers with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  speed zone enablers or an error results. Otherwise, the returned list 
     *  may contain only those speed zone enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @param  speedZoneEnablerGenusType a speed zone enabler genus type 
     *  @return the returned <code> SpeedZoneEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablersByParentGenusType(org.osid.type.Type speedZoneEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneEnablerList </code> containing the given speed 
     *  zone enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  speed zone enablers or an error results. Otherwise, the returned list 
     *  may contain only those speed zone enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @param  speedZoneEnablerRecordType a speed zone enabler record type 
     *  @return the returned <code> SpeedZoneEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablersByRecordType(org.osid.type.Type speedZoneEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneEnablerList </code> that are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  for any agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  speed zone enablers or an error results. Otherwise, the returned list 
     *  may contain only those speed zone enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> SpeedZoneEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater tha <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SpeedZoneEnablerList </code> that are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  and evaluated against the given agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  speed zone enablers or an error results. Otherwise, the returned list 
     *  may contain only those speed zone enablers that are accessible through 
     *  this session. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> SpeedZoneEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater tha <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                org.osid.calendaring.DateTime from, 
                                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> SpeedZoneEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known speed zone 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those speed zone enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, speed zone enablers are returned that are currently 
     *  active. In any status mode, active and inactive speed zone enablers 
     *  are returned. 
     *
     *  @return the returned <code> SpeedZoneEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerList getSpeedZoneEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
