//
// org.osid.mapping.path.rules.SpeedZoneEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods to apply <code> SpeedZoneEnablers </code> 
 *  to <code> SpeedZones. </code> a <code> SpeedZone </code> with multiple 
 *  <code> SpeedZoneEnablers </code> means any positive rule evaluation across 
 *  the enablers result in an effective <code> SpeedZone. </code> </p>
 */

public interface SpeedZoneEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter speed zone enabler/speed zone mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSpeedZoneEnablers();


    /**
     *  Adds an existing <code> SpeedZoneEnabler </code> to a <code> 
     *  SpeedZone. </code> 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of the <code> 
     *          SpeedZoneEnabler </code> 
     *  @param  speedZoneId the <code> Id </code> of the <code> SpeedZone 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> speedZoneEnablerId 
     *          </code> is already applied to <code> speedZoneId </code> 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          or <code> speedZoneId </code> not found 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> or <code> speed zoneId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignSpeedZoneEnablerToSpeedZone(org.osid.id.Id speedZoneEnablerId, 
                                                  org.osid.id.Id speedZoneId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> SpeedZoneEnabler </code> from a <code> SpeedZone. 
     *  </code> 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of the <code> 
     *          SpeedZoneEnabler </code> 
     *  @param  speedZoneId the <code> Id </code> of the <code> SpeedZone 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId </code> 
     *          or <code> speedZoneId </code> not found or <code> 
     *          speedZoneEnablerId </code> not applied to <code> speedZoneId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId 
     *          </code> or <code> speed zoneId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignSpeedZoneEnablerFromSpeedZone(org.osid.id.Id speedZoneEnablerId, 
                                                      org.osid.id.Id speedZoneId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> SpeedZoneEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> SpeedZoneEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceSpeedZoneEnablers();


    /**
     *  Reorders speed zone enablers for a speed zone by moving the specified 
     *  speed zone enabler in front of a reference speed zone enabler. 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of a <code> 
     *          SpeedZoneEnabler </code> 
     *  @param  speedZoneId the <code> Id </code> of a <code> SpeedZone 
     *          </code> 
     *  @param  referenceId the reference speed zone enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId, speed 
     *          zoneId, </code> or <code> referenceId </code> not found or, 
     *          <code> speedZoneEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> speedZoneId </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId, 
     *          speed zoneId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSpeedZoneEnablerAhead(org.osid.id.Id speedZoneEnablerId, 
                                          org.osid.id.Id speedZoneId, 
                                          org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders speed zone enablers for a speed zone by moving the specified 
     *  speed zone enabler behind a reference speed zone enabler. 
     *
     *  @param  speedZoneEnablerId the <code> Id </code> of a <code> 
     *          SpeedZoneEnabler </code> 
     *  @param  speedZoneId the <code> Id </code> of a <code> SpeedZone 
     *          </code> 
     *  @param  referenceId the reference speed zone enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> speedZoneEnablerId, speed 
     *          zoneId, </code> or <code> referenceId </code> not found or, 
     *          <code> speedZoneEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> speedZoneId </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerId, 
     *          speed zoneId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveSpeedZoneEnablerBehind(org.osid.id.Id speedZoneEnablerId, 
                                           org.osid.id.Id speedZoneId, 
                                           org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of speed zone enablers for a speed zone. 
     *
     *  @param  speedZoneEnablerIds the <code> Ids </code> for a set of <code> 
     *          SpeedZoneEnablers </code> 
     *  @param  speedZoneId the <code> Id </code> of a <code> SpeedZone 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> speedZoneId </code> not 
     *          found or, an <code> speedZoneEnablerId </code> not related to 
     *          <code> speedZoneId </code> 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerIds 
     *          </code> or <code> speedZoneId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderSpeedZoneEnablers(org.osid.id.Id[] speedZoneEnablerIds, 
                                       org.osid.id.Id speedZoneId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
