//
// org.osid.mapping.path.rules.SpeedZoneEnablerSearch
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerSearch.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>The search interface for governing speed zone enabler searches. </p>
 */

public interface SpeedZoneEnablerSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of speed zone enablers. 
     *
     *  @param  speedZoneEnablerIds list of speed zone enablers 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerIds 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongSpeedZoneEnablers(org.osid.id.IdList speedZoneEnablerIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  speedZoneEnablerSearchOrder speed zone enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          speedZoneEnablerSearchOrder </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderSpeedZoneEnablerResults(org.osid.mapping.path.rules.SpeedZoneEnablerSearchOrder speedZoneEnablerSearchOrder);


    /**
     *  Gets the speed zone enabler search record corresponding to the given 
     *  speed zone enabler search record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. 
     *
     *  @param  speedZoneEnablerSearchRecordType a speed zone enabler search 
     *          record type 
     *  @return the speed zone enabler search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(speedZoneEnablerSearchRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.records.SpeedZoneEnablerSearchRecord getSpeedZoneEnablerSearchRecord(org.osid.type.Type speedZoneEnablerSearchRecordType)
        throws org.osid.OperationFailedException;
}
