//
// org.osid.mapping.path.rules.SpeedZoneEnablerSearchSession
//
//     The OSID Java specification for org.osid.mapping.path.rules.SpeedZoneEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.path.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  SpeedZoneEnabler </code> objects. The search query is constructed using 
 *  the <code> SpeedZoneEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getSpeedZoneEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> SpeedZoneEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getSpeedZoneEnablersBySearch(). </code> It accepts a <code> 
 *  SpeedZoneEnablerSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  mapping. <code> getSpeedZoneEnablersBySearch() </code> returns a <code> 
 *  SpeedZoneEnablerSearchResults </code> that can be used to access the 
 *  resulting <code> SpeedZoneEnablerList </code> or be used to perform a 
 *  search within the result set through <code> SpeedZoneEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include speed zone enablers in map 
 *      of which this map matchmaker is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to speed zone enablers 
 *      in this map </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> SpeedZoneEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  SpeedZoneEnablerQuery. </code> </p>
 */

public interface SpeedZoneEnablerSearchSession
    extends org.osid.mapping.path.rules.SpeedZoneEnablerQuerySession {


    /**
     *  Gets a speed zone enabler search. 
     *
     *  @return the speed zone enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerSearch getSpeedZoneEnablerSearch();


    /**
     *  Gets a speed zone enabler search order. The <code> 
     *  SpeedZoneEnablerSearchOrder </code> is supplied to a <code> 
     *  SpeedZoneEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the speed zone enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerSearchOrder getSpeedZoneEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  speedZoneEnablerQuery the speed zone enabler query 
     *  @param  speedZoneEnablerSearch the speed zone enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> speedZoneEnablerQuery 
     *          </code> or <code> speed zoneEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> speedZoneEnablerQuery 
     *          </code> or <code> speed zoneEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerSearchResults getSpeedZoneEnablersBySearch(org.osid.mapping.path.rules.SpeedZoneEnablerQuery speedZoneEnablerQuery, 
                                                                                                  org.osid.mapping.path.rules.SpeedZoneEnablerSearch speedZoneEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a speed zone enabler query from an inspector. The inspector is 
     *  available from a <code> SpeedZoneEnablerSearchResults. </code> 
     *
     *  @param  speedZoneEnablerQueryInspector a speed zone enabler query 
     *          inspector 
     *  @return the speed zone enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          speedZoneEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          speedZoneEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.path.rules.SpeedZoneEnablerQuery getSpeedZoneEnablerQueryFromInspector(org.osid.mapping.path.rules.SpeedZoneEnablerQueryInspector speedZoneEnablerQueryInspector);
}
