//
// org.osid.mapping.route.MappingRouteProfile
//
//     The OSID Java specification for org.osid.mapping.route.MappingRouteProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>The mapping profile describes the interoperability among mapping 
 *  services. </p>
 */

public interface MappingRouteProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any map federation is exposed. Federation is exposed when a 
     *  specific map may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of maps appears 
     *  as a single map. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if a location routing service is supported. 
     *
     *  @return <code> true </code> if a location routing service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationRouting();


    /**
     *  Tests if a location service is supported for the current agent. 
     *
     *  @return <code> true </code> if my location is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyLocation();


    /**
     *  Tests if looking up routes is supported. 
     *
     *  @return <code> true </code> if route lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteLookup();


    /**
     *  Tests if querying routes is supported. 
     *
     *  @return <code> true </code> if route query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteQuery();


    /**
     *  Tests if searching routes is supported. 
     *
     *  @return <code> true </code> if route search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteSearch();


    /**
     *  Tests if a route <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if route administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteAdmin();


    /**
     *  Tests if a route <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if route notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteNotification();


    /**
     *  Tests if a route map lookup service is supported. 
     *
     *  @return <code> true </code> if a route map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteMap();


    /**
     *  Tests if a route map service is supported. 
     *
     *  @return <code> true </code> if a route to map assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteMapAssignment();


    /**
     *  Tests if a route smart map service is supported. 
     *
     *  @return <code> true </code> if a route smart map lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteSmartMap();


    /**
     *  Tests if a resource route service is supported. 
     *
     *  @return <code> true </code> if a resource route service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRoute();


    /**
     *  Tests if a resource route update service is supported. 
     *
     *  @return <code> true </code> if a resource route update service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRouteAssignment();


    /**
     *  Tests if a resource route notification service is supported. 
     *
     *  @return <code> true </code> if a resource route notification service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRouteNotification();


    /**
     *  Tests if a route service is supported for the current agent. 
     *
     *  @return <code> true </code> if my route is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyRoute();


    /**
     *  Gets the supported <code> Route </code> record types. 
     *
     *  @return a list containing the supported <code> Route </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRouteRecordTypes();


    /**
     *  Tests if the given <code> Route </code> record type is supported. 
     *
     *  @param  routeRecordType a <code> Type </code> indicating a <code> 
     *          Route </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> routeRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteRecordType(org.osid.type.Type routeRecordType);


    /**
     *  Gets the supported <code> Route </code> search record types. 
     *
     *  @return a list containing the supported <code> Route </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRouteSearchRecordTypes();


    /**
     *  Tests if the given <code> Route </code> search record type is 
     *  supported. 
     *
     *  @param  routeSearchRecordType a <code> Type </code> indicating a 
     *          <code> Route </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> routeSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteSearchRecordType(org.osid.type.Type routeSearchRecordType);


    /**
     *  Gets the supported <code> RouteSegment </code> record types. 
     *
     *  @return a list containing the supported <code> RouteSegment </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRouteSegmentRecordTypes();


    /**
     *  Tests if the given <code> RouteSegment </code> record type is 
     *  supported. 
     *
     *  @param  routeSegmentRecordType a <code> Type </code> indicating a 
     *          <code> RouteSegment </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          supportsRouteSegmentRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteSegmentRecordType(org.osid.type.Type routeSegmentRecordType);


    /**
     *  Gets the supported <code> RouteProgresst </code> record types. 
     *
     *  @return a list containing the supported <code> RouteProgress </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRouteProgressRecordTypes();


    /**
     *  Tests if the given <code> RouteProgress </code> record type is 
     *  supported. 
     *
     *  @param  routeProgressRecordType a <code> Type </code> indicating a 
     *          <code> RouteProgress </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          supportsRouteProgressRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRouteProgressRecordType(org.osid.type.Type routeProgressRecordType);
}
