//
// org.osid.mapping.route.ResourceRouteAssignmentSession
//
//     The OSID Java specification for org.osid.mapping.route.ResourceRouteAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This session defines methods to manage resources on routes. </p>
 */

public interface ResourceRouteAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can set the routes for resources. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer assignment operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if routing methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignResourceRoutes();


    /**
     *  Assigns a resource to a route. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  routeId a route <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> resourceId </code> 
     *          already on <code> routeId </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          routeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> routeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignResourceToRoute(org.osid.id.Id resourceId, 
                                      org.osid.id.Id routeId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates the route segment for a resource. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  routeSegmentId a route segment <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> routeSegmentId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException coordinate not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRouteSegmentForResource(org.osid.id.Id resourceId, 
                                              org.osid.id.Id routeSegmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Unassigns a resource from a route. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  routeId a route <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          routeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> routeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeResourceFromRoute(org.osid.id.Id resourceId, 
                                        org.osid.id.Id routeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
