//
// org.osid.mapping.route.RouteNotificationSession
//
//     The OSID Java specification for org.osid.mapping.route.RouteNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Route </code> objects in this <code> Map. </code> This also 
 *  includes existing routes that may appear or disappear due to changes in 
 *  the <code> Map </code> hierarchy, This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> RouteLookupSession. </code> </p>
 */

public interface RouteNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Map </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Map Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMapId();


    /**
     *  Gets the <code> Map </code> associated with this session. 
     *
     *  @return the map 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.Map getMap()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Route </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForRouteNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include routes in maps which are children of this map in the map 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedMapView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this map only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedMapView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> acknowledgeRouteNotification() 
     *  </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableRouteNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableRouteNotifications();


    /**
     *  Acknowledge a route notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeRouteNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new routes. <code> 
     *  RouteReceiver.newRoutes() </code> is invoked when a new <code> Route 
     *  </code> appears in this map. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRoutes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new routes for the given starting 
     *  location. <code> RouteReceiver.newRoutes() </code> is invoked when a 
     *  new <code> Route </code> appears in this map. 
     *
     *  @param  startingLocationId the <code> Id </code> of the <code> 
     *          Location </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> startingLocationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRoutesForStartingLocation(org.osid.id.Id startingLocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new routes for the given ending 
     *  location. <code> RouteReceiver.newRoutes() </code> is invoked when a 
     *  new <code> Route </code> appears in this map. 
     *
     *  @param  endingLocationId the <code> Id </code> of the <code> Location 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> endingLocationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRoutesForEndingLocation(org.osid.id.Id endingLocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new routes through the given location. 
     *  <code> RouteReceiver.newRoutes() </code> is invoked when a new <code> 
     *  Route </code> appears in this map. 
     *
     *  @param  locationId the <code> Id </code> of the <code> Location 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewRoutesThroughLocation(org.osid.id.Id locationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated routes. <code> 
     *  RouteReceiver.changedRoutes() </code> is invoked when a route in this 
     *  map is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRoutes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated routes for the given starting 
     *  location. <code> RouteReceiver.updatedRoutes() </code> is invoked when 
     *  a route is changed in this map. 
     *
     *  @param  startingLocationId the <code> Id </code> of the <code> 
     *          Location </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> startingLocationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRoutesForStartingLocation(org.osid.id.Id startingLocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated routes for the given ending 
     *  location. <code> RouteReceiver.changedRoutes() </code> is invoked when 
     *  a route is changed in this map. 
     *
     *  @param  endingLocationId the <code> Id </code> of the <code> Location 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> endingLocationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRoutesForEndingLocation(org.osid.id.Id endingLocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated routes through the given 
     *  location. <code> RouteReceiver.changedRoutes() </code> is invoked when 
     *  a route is changed in this map. 
     *
     *  @param  locationId the <code> Id </code> of the <code> Location 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRoutesThroughLocation(org.osid.id.Id locationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated route. <code> 
     *  RouteReceiver.changedRoutes() </code> is invoked when the specified 
     *  route in this map is changed. 
     *
     *  @param  routeId the <code> Id </code> of the <code> Route </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedRoute(org.osid.id.Id routeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted routes. <code> 
     *  RouteReceiver.deletedRoutes() </code> is invoked when a route is 
     *  deleted or removed from this map. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRoutes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted routes for the given starting 
     *  location. <code> RouteReceiver.deletedRoutes() </code> is invoked when 
     *  a route is removed from this map. 
     *
     *  @param  startingLocationId the <code> Id </code> of the <code> 
     *          Location </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> startingLocationId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRoutesForStartingLocation(org.osid.id.Id startingLocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted routes for the given ending 
     *  location. <code> RouteReceiver.deletedRoutes() </code> is invoked when 
     *  a route is removed from this map. 
     *
     *  @param  endingLocationId the <code> Id </code> of the <code> Location 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> endingLocationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRoutesForEndingLocation(org.osid.id.Id endingLocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted routes through the given 
     *  location. <code> RouteReceiver.deletedRoutes() </code> is invoked when 
     *  a route is removed from this map. 
     *
     *  @param  locationId the <code> Id </code> of the <code> Location 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRoutesThroughLocation(org.osid.id.Id locationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted route. <code> 
     *  RouteReceiver.deletedRoutes() </code> is invoked when the specified 
     *  route is deleted or removed from this map. 
     *
     *  @param  routeId the <code> Id </code> of the <code> Route </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> routeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedRoute(org.osid.id.Id routeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
