//
// org.osid.mapping.route.RouteQuery
//
//     The OSID Java specification for org.osid.mapping.route.RouteQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This is the query for searching routes. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface RouteQuery
    extends org.osid.OsidRelationshipQuery,
            org.osid.OsidAggregateableQuery {


    /**
     *  Sets the location <code> Id </code> for this query to match routes 
     *  with a starting location. 
     *
     *  @param  locationId the location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStartingLocationId(org.osid.id.Id locationId, 
                                        boolean match);


    /**
     *  Clears the starting location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available for a starting 
     *  location. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStartingLocationQuery();


    /**
     *  Gets the query for a starting location. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStartingLocationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStartingLocationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationQuery getStartingLocationQuery();


    /**
     *  Clears the starting location query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingLocationTerms();


    /**
     *  Sets the location <code> Id </code> for this query to match routes 
     *  with an ending location. 
     *
     *  @param  locationId the location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEndingLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the ending location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndingLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available for an ending 
     *  location. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEndingLocationQuery();


    /**
     *  Gets the query for an ending location. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEndingLocationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEndingLocationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.mapping.LocationQuery getEndingLocationQuery();


    /**
     *  Clears the ending location query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndingLocationTerms();


    /**
     *  Sets the location <code> Id </code> for this query to match routes 
     *  along all the given locations. 
     *
     *  @param  locationIds the location <code> Ids </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAlongLocationIds(org.osid.id.Id[] locationIds, 
                                      boolean match);


    /**
     *  Clears the along location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAlongLocationIdsTerms();


    /**
     *  Matches routes that have distances within the specified range 
     *  inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistance(org.osid.mapping.Distance from, 
                              org.osid.mapping.Distance to, boolean match);


    /**
     *  Matches routes that has any distance assigned or calculated. 
     *
     *  @param  match <code> true </code> to match routes with any distance, 
     *          <code> false </code> to match routes with no distance 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDistance(boolean match);


    /**
     *  Clears the distance query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistanceTerms();


    /**
     *  Matches routes that have the specified estimated travel time 
     *  inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchETA(org.osid.calendaring.Duration from, 
                         org.osid.calendaring.Duration to, boolean match);


    /**
     *  Matches routes that has any estimated time assigned or calculated. 
     *
     *  @param  match <code> true </code> to match routes with any eta, <code> 
     *          false </code> to match routes with no eta 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyETA(boolean match);


    /**
     *  Clears the ETA query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearETATerms();


    /**
     *  Sets the location <code> Id </code> for this query to match routes 
     *  through a location. 
     *
     *  @param  locationId the location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the location <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Gets the query for a location. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> supportsLocationQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.LocationQuery getLocationQuery();


    /**
     *  Matches routes that has any location along the route, exclusive of the 
     *  endpoints. 
     *
     *  @param  match <code> true </code> to match routes with any location, 
     *          <code> false </code> to match routes with no location 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocation(boolean match);


    /**
     *  Clears the location query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationTerms();


    /**
     *  Sets the path <code> Id </code> for this query to match routes using a 
     *  designated path. 
     *
     *  @param  pathId the path <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPathId(org.osid.id.Id pathId, boolean match);


    /**
     *  Clears the path <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathIdTerms();


    /**
     *  Tests if a <code> PathQuery </code> is available. 
     *
     *  @return <code> true </code> if a path query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPathQuery();


    /**
     *  Gets the query for a path. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the path query 
     *  @throws org.osid.UnimplementedException <code> supportsPathQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPathQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.path.PathQuery getPathQuery();


    /**
     *  Matches routes using any designated path. 
     *
     *  @param  match <code> true </code> to match routes with any path <code> 
     *          false </code> to match routes with no path 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPath(boolean match);


    /**
     *  Clears the path query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPathTerms();


    /**
     *  Sets the map <code> Id </code> for this query to match routes assigned 
     *  to maps. 
     *
     *  @param  mapId the map <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mapId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMapId(org.osid.id.Id mapId, boolean match);


    /**
     *  Clears the map <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapIdTerms();


    /**
     *  Tests if a <code> MapQuery </code> is available. 
     *
     *  @return <code> true </code> if a map query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMapQuery();


    /**
     *  Gets the query for a map. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the map query 
     *  @throws org.osid.UnimplementedException <code> supportsMapQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMapQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.MapQuery getMapQuery();


    /**
     *  Clears the map query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMapTerms();


    /**
     *  Gets the route query record corresponding to the given <code> Route 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  routeRecordType a route record type 
     *  @return the route query record 
     *  @throws org.osid.NullArgumentException <code> routeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(routeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.records.RouteQueryRecord getRouteQueryRecord(org.osid.type.Type routeRecordType)
        throws org.osid.OperationFailedException;
}
