//
// org.osid.mapping.route.RouteSearchSession
//
//     The OSID Java specification for org.osid.mapping.route.RouteSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>This session provides methods for searching among <code> Route </code> 
 *  objects. The search query is constructed using the <code> RouteQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getRoutesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Routes. </code> A more advanced search may be 
 *  performed with <code> getRoutesBySearch(). </code> It accepts a <code> 
 *  RouteSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getRoutesBySearch() </code> returns a <code> RouteSearchResults </code> 
 *  that can be used to access the resulting <code> RouteList </code> or be 
 *  used to perform a search within the result set through <code> RouteSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated map view: searches include routes in maps of which this 
 *      map is an ancestor in the map hierarchy </li> 
 *      <li> isolated map view: searches are restricted to routes in this map 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Routes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> RouteQuery. </code> 
 *  </p>
 */

public interface RouteSearchSession
    extends org.osid.mapping.route.RouteQuerySession {


    /**
     *  Gets a route search. 
     *
     *  @return the route search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSearch getRouteSearch();


    /**
     *  Gets a route search order. The <code> RouteSearchOrder </code> is 
     *  supplied to a <code> RouteSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the route search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSearchOrder getRouteSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  routeQuery the route query 
     *  @param  routeSearch the route search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> routeQuery </code> or 
     *          <code> routeSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> routeQuery </code> or 
     *          <code> routeSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteSearchResults getRoutesBySearch(org.osid.mapping.route.RouteQuery routeQuery, 
                                                                       org.osid.mapping.route.RouteSearch routeSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a route query from an inspector. The inspector is available from 
     *  a <code> RouteSearchResults. </code> 
     *
     *  @param  routeQueryInspector a route query inspector 
     *  @return the route query 
     *  @throws org.osid.NullArgumentException <code> routeQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> routeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.RouteQuery getRouteQueryFromInspector(org.osid.mapping.route.RouteQueryInspector routeQueryInspector);
}
