//
// org.osid.mapping.route.RouteSegmentForm
//
//     The OSID Java specification for org.osid.mapping.route.RouteSegmentForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.mapping.route;


/**
 *  <p>A route segment represents a portion of a route. </p>
 */

public interface RouteSegmentForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for the starting instructions. 
     *
     *  @return metadata for the starting instructions 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getStartingInstructionsMetadata();


    /**
     *  Sets the starting instructions. 
     *
     *  @param  startingInstructions the new starting instructions 
     *  @throws org.osid.InvalidArgumentException <code> startingInstructions 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> startingInstructions 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setStartingInstructions(String startingInstructions);


    /**
     *  Clears the starting instructions. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStartingInstructions();


    /**
     *  Gets the metadata for the ending instructions. 
     *
     *  @return metadata for the ending instructions 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getEndingInstructionsMetadata();


    /**
     *  Sets the ending instructions. 
     *
     *  @param  endingInstructions the new ending instructions 
     *  @throws org.osid.InvalidArgumentException <code> endingInstructions 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> endingInstructions 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEndingInstructions(String endingInstructions);


    /**
     *  Clears the ending instructions. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEndingInstructions();


    /**
     *  Gets the metadata for the distance. 
     *
     *  @return metadata for the distance 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDistanceMetadata();


    /**
     *  Sets the distance for this segment. 
     *
     *  @param  distance the new distance 
     *  @throws org.osid.InvalidArgumentException <code> distance </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> distance </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDistance(org.osid.mapping.Distance distance);


    /**
     *  Clears the distance. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistance();


    /**
     *  Gets the metadata for the estimated travel time. 
     *
     *  @return metadata for the eta 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getETAMetadata();


    /**
     *  Sets the estimated travel time for this segment. 
     *
     *  @param  eta the new eta 
     *  @throws org.osid.InvalidArgumentException <code> eta </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> eta </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setETA(org.osid.calendaring.Duration eta);


    /**
     *  Clears the eta. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearETA();


    /**
     *  Gets the metadata for the path. 
     *
     *  @return metadata for the path 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPathMetadata();


    /**
     *  Sets the path for this segment. 
     *
     *  @param  pathId the new path 
     *  @throws org.osid.InvalidArgumentException <code> pathId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPath(org.osid.id.Id pathId);


    /**
     *  Clears the path. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPath();


    /**
     *  Gets the <code> RouteSegmentFormRecord </code> corresponding to the 
     *  given route segment record <code> Type. </code> 
     *
     *  @param  routeSegmentRecordType a route segment record type 
     *  @return the route segment form record 
     *  @throws org.osid.NullArgumentException <code> routeSegmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(routeSegmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.mapping.route.records.RouteSegmentFormRecord getRouteSegmentFormRecord(org.osid.type.Type routeSegmentRecordType)
        throws org.osid.OperationFailedException;
}
