//
// org.osid.messaging.MailboxLookupSession
//
//     The OSID Java specification for org.osid.messaging.MailboxLookupSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session provides methods for retrieving <code> Mailbox </code> 
 *  objects. The <code> Mailbox </code> represents a collection messages. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. For 
 *  example, a browsing application may only need to examine the <code> 
 *  Mailboxes </code> it can access, without breaking execution. However, an 
 *  administrative application may require all <code> Mailbox </code> elements 
 *  to be available. </p> 
 *  
 *  <p> Mailboxes may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Mailbox. </code> </p>
 */

public interface MailboxLookupSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform <code> Mailbox </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupMailboxes();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeMailboxView();


    /**
     *  A complete view of the <code> Mailbox </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryMailboxView();


    /**
     *  Gets the <code> Mailbox </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Mailbox 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Mailbox </code> and retained for compatibility. 
     *
     *  @param  mailboxId <code> Id </code> of the <code> Mailbox </code> 
     *  @return the mailbox 
     *  @throws org.osid.NotFoundException <code> mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.messaging.Mailbox getMailbox(org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MailboxLidt </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  mailboxes specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible mailboxes may be omitted from the list and may present 
     *  the elements in any order including returning a unique set. 
     *
     *  @param  mailboxIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Mailbox list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> mailboxIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxList getMailboxesByIds(org.osid.id.IdList mailboxIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> Mailbox </code> corresponding to the given mailbox genus 
     *  <code> Type </code> which does not include mailboxes of types derived 
     *  from the specified <code> Type. </code> In plenary mode, the returned 
     *  list contains all known mailboxes or an error results. Otherwise, the 
     *  returned list may contain only those mailboxes that are accessible 
     *  through this session. 
     *
     *  @param  mailboxGenusType a mailbox genus type 
     *  @return the returned <code> Mailbox </code> list 
     *  @throws org.osid.NullArgumentException <code> mailboxGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxList getMailboxesByGenusType(org.osid.type.Type mailboxGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MailboxList </code> corresponding to the given psocess 
     *  genus <code> Type </code> and include any additional mailboxes with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known mailboxes or an error 
     *  results. Otherwise, the returned list may contain only those mailboxes 
     *  that are accessible through this session. 
     *
     *  @param  mailboxGenusType a mailbox genus type 
     *  @return the returned <code> Mailbox </code> list 
     *  @throws org.osid.NullArgumentException <code> mailboxGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxList getMailboxesByParentGenusType(org.osid.type.Type mailboxGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MailboxList </code> containing the given mailbox record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known mailboxes or an error results. Otherwise, the returned list may 
     *  contain only those mailboxes that are accessible through this session. 
     *
     *  @param  mailboxRecordType a mailbox record type 
     *  @return the returned <code> Mailbox </code> list 
     *  @throws org.osid.NullArgumentException <code> mailboxRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxList getMailboxesByRecordType(org.osid.type.Type mailboxRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> MailboxList </code> for the given provider. <code> 
     *  </code> In plenary mode, the returned list contains all known 
     *  mailboxes or an error results. Otherwise, the returned list may 
     *  contain only those mailboxes that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Mailbox </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxList getMailboxesByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Mailboxes. </code> In plenary mode, the returned list 
     *  contains all known mailboxes or an error results. Otherwise, the 
     *  returned list may contain only those mailboxes that are accessible 
     *  through this session. 
     *
     *  @return a list of mailboxes 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxList getMailboxes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
