//
// org.osid.messaging.MailboxQuery
//
//     The OSID Java specification for org.osid.messaging.MailboxQuery.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This is the query for searching mailboxes. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface MailboxQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the message <code> Id </code> for this query. 
     *
     *  @param  messageId a message <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> messageId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMessageId(org.osid.id.Id messageId, boolean match);


    /**
     *  Clears the message <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMessageIdTerms();


    /**
     *  Tests if a <code> MessageQuery </code> is available. 
     *
     *  @return <code> true </code> if a message query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageQuery();


    /**
     *  Gets the query for a message. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the message query 
     *  @throws org.osid.UnimplementedException <code> supportsMessageQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMessageQuery() </code> is <code> true. </code> 
     */

    public org.osid.messaging.MessageQuery getMessageQuery();


    /**
     *  Matches mailboxes with any messages. 
     *
     *  @param  match <code> true </code> to match mailboxes with any 
     *          messages, <code> false </code> to match mailboxes with no 
     *          messages 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMessage(boolean match);


    /**
     *  Clears the message terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMessageTerms();


    /**
     *  Sets the mailbox <code> Id </code> for this query to match mailboxes 
     *  that have the specified mailbox as an ancestor. 
     *
     *  @param  mailboxId a mailbox <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorMailboxId(org.osid.id.Id mailboxId, boolean match);


    /**
     *  Clears the ancestor mailbox <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorMailboxIdTerms();


    /**
     *  Tests if a <code> MailboxQuery </code> is available. 
     *
     *  @return <code> true </code> if a mailbox query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorMailboxQuery();


    /**
     *  Gets the query for a mailbox. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the mailbox query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorMailboxQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorMailboxQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MailboxQuery getAncestorMailboxQuery();


    /**
     *  Matches mailboxes with any ancestor. 
     *
     *  @param  match <code> true </code> to match mailboxes with any 
     *          ancestor, <code> false </code> to match root mailboxes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorMailbox(boolean match);


    /**
     *  Clears the ancestor mailbox terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorMailboxTerms();


    /**
     *  Sets the mailbox <code> Id </code> for this query to match mailboxes 
     *  that have the specified mailbox as a descendant. 
     *
     *  @param  mailboxId a mailbox <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantMailboxId(org.osid.id.Id mailboxId, 
                                         boolean match);


    /**
     *  Clears the descendant mailbox <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantMailboxIdTerms();


    /**
     *  Tests if a <code> MailboxQuery </code> is available. 
     *
     *  @return <code> true </code> if a mailbox query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantMailboxQuery();


    /**
     *  Gets the query for a mailbox. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the mailbox query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantMailboxQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantMailboxQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.messaging.MailboxQuery getDescendantMailboxQuery();


    /**
     *  Matches mailboxes with any descendant. 
     *
     *  @param  match <code> true </code> to match mailboxes with any 
     *          descendant, <code> false </code> to match leaf mailboxes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantMailbox(boolean match);


    /**
     *  Clears the descendant mailbox terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantMailboxTerms();


    /**
     *  Gets the mailbox query record corresponding to the given <code> 
     *  Mailbox </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  mailboxRecordType a mailbox record type 
     *  @return the mailbox query record 
     *  @throws org.osid.NullArgumentException <code> mailboxRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(mailboxRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.records.MailboxQueryRecord getMailboxQueryRecord(org.osid.type.Type mailboxRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
