//
// org.osid.messaging.MailboxReceiver
//
//     The OSID Java specification for org.osid.messaging.MailboxReceiver.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>The mailbox receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Mailbox </code> 
 *  objects. </p>
 */

public interface MailboxReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new mailboxes. 
     *
     *  @param  mailboxIds the <code> Ids </code> of the new <code> Mailboxes 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newMailboxes(org.osid.id.IdList mailboxIds);


    /**
     *  The callback for notifications of new mailbox ancestors. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Mailbox 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorMailbox(org.osid.id.Id mailboxId, 
                                   org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new mailbox descendants. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> Mailbox 
     *          </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantMailbox(org.osid.id.Id mailboxId, 
                                     org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated mailboxes. 
     *
     *  @param  mailboxIds the <code> Ids </code> of the updated <code> 
     *          Mailboxes </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedMailboxes(org.osid.id.IdList mailboxIds);


    /**
     *  The callback for notification of deleted mailboxes. 
     *
     *  @param  mailboxIds the <code> Ids </code> of the deleted <code> 
     *          Mailboxes </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedMailboxes(org.osid.id.IdList mailboxIds);


    /**
     *  The callback for notifications of deleted mailbox ancestors. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @param  ancestorId the <code> Id </code> of the removed <code> Mailbox 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorMailbox(org.osid.id.Id mailboxId, 
                                       org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted mailbox descendants. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @param  descendantId the <code> Id </code> of the removed <code> 
     *          Mailbox </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantMailbox(org.osid.id.Id mailboxId, 
                                         org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a mailbox hierarchy where 
     *  the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredMailboxHierarchy();
}
