//
// org.osid.messaging.MailboxSearchSession
//
//     The OSID Java specification for org.osid.messaging.MailboxSearchSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session provides methods for searching among <code> Mailbox 
 *  </code> objects. The search query is constructed using the <code> 
 *  MailboxQuery. </code> </p> 
 *  
 *  <p> <code> getMailboxesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Mailbox </code> objects.A more advanced search 
 *  may be performed with <code> getMailboxesBySearch(). </code> It accepts a 
 *  <code> MailboxSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getMailboxesBySearch() </code> returns a <code> 
 *  MailboxSearchResults </code> that can be used to access the resulting 
 *  <code> MailboxList </code> or be used to perform a search within the 
 *  result set through <code> MailboxSearch. </code> </p> 
 *  
 *  <p> Mailboxes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> MailboxQuery. </code> 
 *  </p>
 */

public interface MailboxSearchSession
    extends org.osid.messaging.MailboxQuerySession {


    /**
     *  Gets a mailbox search. 
     *
     *  @return the mailbox search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxSearch getMailboxSearch();


    /**
     *  Gets a mailbox search order. The <code> MailboxSearchOrder </code> is 
     *  supplied to a <code> MailboxSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the mailbox search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxSearchOrder getMailboxSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  mailboxQuery the mailbox query 
     *  @param  mailboxSearch the mailbox search 
     *  @return the mailbox search results 
     *  @throws org.osid.NullArgumentException <code> mailboxQuery </code> or 
     *          <code> mailboxSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> mailboxQuery </code> or 
     *          <code> mailboxSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxSearchResults getMailboxesBySearch(org.osid.messaging.MailboxQuery mailboxQuery, 
                                                                        org.osid.messaging.MailboxSearch mailboxSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a mailbox query from an inspector. The inspector is available 
     *  from a <code> MailboxSearchResults. </code> 
     *
     *  @param  mailboxQueryInspector a mailbox query inspector 
     *  @return the mailbox query 
     *  @throws org.osid.NullArgumentException <code> mailboxQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> mailboxQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MailboxQuery getMailboxQueryFromInspector(org.osid.messaging.MailboxQueryInspector mailboxQueryInspector);
}
