//
// org.osid.messaging.MessageMailboxAssignmentSession
//
//     The OSID Java specification for org.osid.messaging.MessageMailboxAssignmentSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session provides methods to re-assign <code> Messages </code> to 
 *  <code> Mailboxes. </code> A <code> Message </code> may map to multiple 
 *  <code> Mailbox </code> objects and removing the last reference to a <code> 
 *  Message </code> is the equivalent of deleting it. Each <code> Mailbox 
 *  </code> may have its own authorizations governing who is allowed to 
 *  operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> Message </code> to another 
 *  <code> Mailbox </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface MessageMailboxAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter message/mailbox mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignMessages();


    /**
     *  Tests if this user can alter message/mailbox mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @return <code> false </code> if messaging is not authorized, <code> 
     *          true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignMessagesToMailbox(org.osid.id.Id mailboxId);


    /**
     *  Gets a list of mailboxes including and under the given mailbox node in 
     *  which any message can be assigned. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @return list of assignable mailbox <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableMailboxIds(org.osid.id.Id mailboxId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of mailboxes including and under the given mailbox node in 
     *  which a specific message can be assigned. 
     *
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *  @return list of assignable mailbox <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> mailboxId </code> or 
     *          <code> messageId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableMailboxIdsForMessage(org.osid.id.Id mailboxId, 
                                                                org.osid.id.Id messageId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Message </code> to a <code> Mailbox. </code> 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @throws org.osid.AlreadyExistsException <code> messageId </code> is 
     *          already assigned to <code> mailboxId </code> 
     *  @throws org.osid.NotFoundException <code> messageId </code> or <code> 
     *          mailboxId </code> not found 
     *  @throws org.osid.NullArgumentException <code> messageId </code> or 
     *          <code> mailboxId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignMessageToMailbox(org.osid.id.Id messageId, 
                                       org.osid.id.Id mailboxId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Message </code> from a <code> Mailbox. </code> 
     *
     *  @param  messageId the <code> Id </code> of the <code> Message </code> 
     *  @param  mailboxId the <code> Id </code> of the <code> Mailbox </code> 
     *  @throws org.osid.NotFoundException <code> messageId </code> or <code> 
     *          mailboxId </code> or <code> messageId </code> not assigned to 
     *          <code> mailboxId </code> 
     *  @throws org.osid.NullArgumentException <code> messageId </code> or 
     *          <code> mailboxId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignMessageFromMailbox(org.osid.id.Id messageId, 
                                           org.osid.id.Id mailboxId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
