//
// org.osid.messaging.MessageSearchSession
//
//     The OSID Java specification for org.osid.messaging.MessageSearchSession.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>This session provides methods for searching among <code> Message 
 *  </code> objects. The search query is constructed using the <code> 
 *  MessageQuery. </code> </p> 
 *  
 *  <p> <code> getMessagesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Messages. </code> A more advanced search may be 
 *  performed with <code> getMessagesBySearch(). </code> It accepts an <code> 
 *  MessageSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getMessagesBySearch() </code> returns an <code> 
 *  MessageSearchResults </code> that can be used to access the resulting 
 *  <code> MessageList </code> or be used to perform a search within the 
 *  result set through <code> MessageList. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated mailbox view: searches include messages in mailboxes of 
 *      which this mailbox is a ancestor in the mailbox hierarchy </li> 
 *      <li> isolated mailbox view: searches are restricted to messages in 
 *      this mailbox </li> 
 *  </ul>
 *  
 *  
 *  <p> Messages may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> MessageQuery. </code> 
 *  </p>
 */

public interface MessageSearchSession
    extends org.osid.messaging.MessageQuerySession {


    /**
     *  Gets a message search. 
     *
     *  @return the message search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageSearch getMessageSearch();


    /**
     *  Gets a message search order. The <code> MessageSearchOrder </code> is 
     *  supplied to a <code> MessageSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the message search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageSearchOrder getMessageSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  messageQuery the message query 
     *  @param  messageSearch the message search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> messageQuery </code> or 
     *          <code> messageSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> messageQuery </code> or 
     *          <code> messageSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageSearchResults getMessagesBySearch(org.osid.messaging.MessageQuery messageQuery, 
                                                                       org.osid.messaging.MessageSearch messageSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a message query from an inspector. The inspector is available 
     *  from a <code> MessageSearchResults. </code> 
     *
     *  @param  messageQueryInspector a message query inspector 
     *  @return the message query 
     *  @throws org.osid.NullArgumentException <code> messageQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> messageQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.MessageQuery getMessageQueryFromInspector(org.osid.messaging.MessageQueryInspector messageQueryInspector);
}
