//
// org.osid.messaging.MessagingProfile
//
//     The OSID Java specification for org.osid.messaging.MessagingProfile.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>The message profile describes interoperability among message services. 
 *  </p>
 */

public interface MessagingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if sending messages is supported. 
     *
     *  @return <code> true </code> if message sending is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessaging();


    /**
     *  Tests if message lookup is supported. 
     *
     *  @return <code> true </code> if message lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageLookup();


    /**
     *  Tests if querying messages is supported. 
     *
     *  @return <code> true </code> if message query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageQuery();


    /**
     *  Tests if message search is supported. 
     *
     *  @return <code> true </code> if message search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageSearch();


    /**
     *  Tests if creating, updating and deleting messages is supported. 
     *
     *  @return <code> true </code> if message administration is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageAdmin();


    /**
     *  Tests if message notification is supported. Messages may be sent when 
     *  messages are created, modified, or deleted. 
     *
     *  @return <code> true </code> if message notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageNotification();


    /**
     *  Tests if retrieving mappings of message and mailboxes is supported. 
     *
     *  @return <code> true </code> if message mailbox mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageMailbox();


    /**
     *  Tests if managing mappings of messages and mailboxes is supported. 
     *
     *  @return <code> true </code> if message mailbox assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageMailboxAssignment();


    /**
     *  Tests if a messaging smart mailbox service is supported. 
     *
     *  @return <code> true </code> if a message smart mailbox service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageSmartMailbox();


    /**
     *  Tests if receipt lookup is supported. 
     *
     *  @return <code> true </code> if receipt lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReceiptLookup();


    /**
     *  Tests if updating receipts is supported. 
     *
     *  @return <code> true </code> if receipt administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReceiptAdmin();


    /**
     *  Tests if receipts notification is supported. Messages may be sent when 
     *  receipts are created, modified, or deleted. 
     *
     *  @return <code> true </code> if receipt notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReceiptNotification();


    /**
     *  Tests if mailbox lookup is supported. 
     *
     *  @return <code> true </code> if mailbox lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxLookup();


    /**
     *  Tests if mailbox search is supported. 
     *
     *  @return <code> true </code> if mailbox search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxSearch();


    /**
     *  Tests if mailbox administration is supported. 
     *
     *  @return <code> true </code> if mailbox administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxAdmin();


    /**
     *  Tests if mailbox notification is supported. Messages may be sent when 
     *  <code> Mailbox </code> objects are created, deleted or updated. 
     *  Notifications for messages within mailboxes are sent via the message 
     *  notification session. 
     *
     *  @return <code> true </code> if mailbox notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxNotification();


    /**
     *  Tests if a mailbox hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a mailbox hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxHierarchy();


    /**
     *  Tests if a mailbox hierarchy design is supported. 
     *
     *  @return <code> true </code> if a mailbox hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxHierarchyDesign();


    /**
     *  Tests if a messaging batch service is supported. 
     *
     *  @return <code> true </code> if a messaging batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessagingBatch();


    /**
     *  Gets all the message record types supported. 
     *
     *  @return the list of supported message record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMessageRecordTypes();


    /**
     *  Tests if a given message record type is supported. 
     *
     *  @param  messageRecordType the message type 
     *  @return <code> true </code> if the message record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> messageRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageRecordType(org.osid.type.Type messageRecordType);


    /**
     *  Gets all the message search record types supported. 
     *
     *  @return the list of supported message search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMessageSearchRecordTypes();


    /**
     *  Tests if a given message search type is supported. 
     *
     *  @param  messageSearchRecordType the message search type 
     *  @return <code> true </code> if the message search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> messageSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessageSearchRecordType(org.osid.type.Type messageSearchRecordType);


    /**
     *  Gets all the receipt record types supported. 
     *
     *  @return the list of supported receipt record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getReceiptRecordTypes();


    /**
     *  Tests if a given receipt record type is supported. 
     *
     *  @param  receiptRecordType the mesreceiptsage type 
     *  @return <code> true </code> if the receipt record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> receiptRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsReceiptRecordType(org.osid.type.Type receiptRecordType);


    /**
     *  Gets all the mailbox record types supported. 
     *
     *  @return the list of supported mailbox record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMailboxRecordTypes();


    /**
     *  Tests if a given mailbox record type is supported. 
     *
     *  @param  mailboxRecordType the mailbox record type 
     *  @return <code> true </code> if the mailbox record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mailboxRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxRecordType(org.osid.type.Type mailboxRecordType);


    /**
     *  Gets all the mailbox search record types supported. 
     *
     *  @return the list of supported mailbox search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMailboxSearchRecordTypes();


    /**
     *  Tests if a given mailbox search record type is supported. 
     *
     *  @param  mailboxSearchRecordType the mailbox search record type 
     *  @return <code> true </code> if the mailbox search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> mailboxSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMailboxSearchRecordType(org.osid.type.Type mailboxSearchRecordType);
}
