//
// org.osid.messaging.Receipt
//
//     The OSID Java specification for org.osid.messaging.Receipt.
//
// Copyright (C) 2002-2004, 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingeenscus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.messaging;


/**
 *  <p>A <code> Message </code> receipt is generated when a message is 
 *  received by a receiving agent. </p>
 */

public interface Receipt
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the <code> Message. </code> 
     *
     *  @return the message <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMessageId();


    /**
     *  Gets the <code> Message. </code> 
     *
     *  @return the message 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.Message getMessage()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the time the message was received. 
     *
     *  @return the time 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getReceivedTime();


    /**
     *  Gets the <code> Id </code> of the <code> Agent </code> that received 
     *  this message at this endpoint. 
     *
     *  @return the receiving agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReceivingAgentId();


    /**
     *  Gets the <code> Agent </code> that received this message at this 
     *  endpoint. 
     *
     *  @return the receiving agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getReceivingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the <code> Resource </code> that 
     *  received this message at this endpoint. 
     *
     *  @return the recipient <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRecipientId();


    /**
     *  Gets the <code> Resource </code> that received this message at this 
     *  endpoint. 
     *
     *  @return the recipient 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getRecipient()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the receipt record corresponding to the given <code> Receipt 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> receiptRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(receiptRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  receiptRecordType the receipt record type 
     *  @return the receipt record 
     *  @throws org.osid.NullArgumentException <code> receiptRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(receiptRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.messaging.records.ReceiptRecord getReceiptRecord(org.osid.type.Type receiptRecordType)
        throws org.osid.OperationFailedException;
}
