//
// Osid.java
//
//     Represents an OSID.
//
//
// Tom Coppeto
// OnTapSolutions
// 4 January 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//      Permission is hereby granted, free of charge, to any person
//      obtaining a copy of this software and associated documentation
//      files (the "Software"), to deal in the Software without
//      restriction, including without limitation the rights to use,
//      copy, modify, merge, publish, distribute, sublicesne, and/or
//      sell copies of the Software, and to permit the persons to whom
//      the Software is furnished to do so, subject the following
//      conditions:
//
//      The above copyright notice and this permission notice shall be
//      included in all copies or substantial portions of the
//      Software.
//
//      The Software is provided "AS IS", WITHOUT WARRANTY OF ANY
//      KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
//      WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
//      PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
//      COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
//      OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
//      SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package org.osid.meta;


/**
 *  Represents an OSID.
 */

public class Osid {    
    private final String name;
    private final java.util.Map<String, OsidInterface> interfaces = java.util.Collections.synchronizedMap(new java.util.HashMap<String, OsidInterface>());
    private final java.util.Map<String, OsidEnumeration> enumerations = java.util.Collections.synchronizedMap(new java.util.HashMap<String, OsidEnumeration>());


    /**
     *  Constructs a new <code>Osid</code>.
     *
     *  @param name the name of the Osid;
     */

    public Osid(String name) {
        this.name = name;
        return;
    }

    
    /**
     *  Gets the name of this Osid.
     *
     *  @return the Osid name
     */

    public String getName() {
        return (this.name);
    }


    /**
     *  Gets an interface defined in this Osid.
     *
     *  @param name the name of the interface to retrieve
     *  @return the interface or <code>null</code> if not found
     */
    
    public OsidInterface getInterface(String name) {
        return (this.interfaces.get(name));
    }


    /**
     *  Gets all interfaces defined in this Osid.
     *
     *  @return a list of OSID interfaces
     */
    
    public java.util.Collection<OsidInterface> getInterfaces() {
        return (this.interfaces.values());
    }


    /**
     *  Adds an interface to this osid.
     *
     *  @param iface the interface to add
     */

    public void addInterface(OsidInterface iface) {
        if (!this.interfaces.containsKey(iface.getName())) {
            this.interfaces.put(iface.getName(), iface);
        }

        OsidInterfaces.addInterface(iface);
        return;
    }


    /**
     *  Gets an enumeration defined in this Osid.
     *
     *  @param name the name of the enumeration to retrieve
     *  @return the enumeration or <code>null</code> if not found
     */
    
    public OsidEnumeration getEnumeration(String name) {
        return (this.enumerations.get(name));
    }


    /**
     *  Gets all enumerations defined in this Osid.
     *
     *  @return a list of OSID enumerations
     */
    
    public java.util.Collection<OsidEnumeration> getEnumerations() {
        return (this.enumerations.values());
    }


    /**
     *  Adds an enumeration to this osid.
     *
     *  @param enumeration
     */

    public void addEnumeration(OsidEnumeration enumeration) {
        if (!this.enumerations.containsKey(enumeration.getName())) {
            this.enumerations.put(enumeration.getName(), enumeration);
        }

        OsidInterfaces.addEnumeration(enumeration);
        return;
    }
}
