//
// OsidEnumeration.java
//
//     An OSID Enumeration representation.
//
//
// Tom Coppeto
// OnTapSolutions
// 4 January 2009
//
// Copyright (c) 2009 Massachusetts Institute of Technology. All Rights
// Reserved.
//
//      Permission is hereby granted, free of charge, to any person
//      obtaining a copy of this software and associated documentation
//      files (the "Software"), to deal in the Software without
//      restriction, including without limitation the rights to use,
//      copy, modify, merge, publish, distribute, sublicesne, and/or
//      sell copies of the Software, and to permit the persons to whom the
//      Software is furnished to do so, subject the following conditions:
//
//      The above copyright notice and this permission notice shall be
//      included in all copies or substantial portions of the Software.
//
//      The Software is provided "AS IS", WITHOUT WARRANTY OF ANY KIND,
//      EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//      OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//      NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
//      HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
//      WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//      OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//      DEALINGS IN THE SOFTWARE.
//

package org.osid.meta;


/**
 *  This doesn't do much other than capture the name of the
 *  enumeration.
 */

public class OsidEnumeration {    
    private final String name;
    private boolean deprecated;
    private boolean newEnumeration;
    private String asOf;


    /**
     *  Creates a new <code>OsidEnumeration</code>.
     *
     *  @param name the enumeration name
     */

    protected OsidEnumeration(String name) {
        this.name = name;
        return;
    }


    /**
     *  Gets the name of this enumeratioan.
     *
     *  @return the name of this enumeration
     */

    public String getName() {
        return (this.name);
    }


    /**
     *  Tests if the enumeration is specified as deprecated.
     *
     *  @return <code>true</code> if the enumeration is deprecated,
     *          <code>false</code> otherwise
     */

    public boolean isDeprecated() {
        return (this.deprecated);
    }

    
    protected void setDeprecated(String asOf) {
        this.deprecated = true;
        this.asOf = asOf;
        return;
    }


    /**
     *  Tests if the enumeration is specified as new.
     *
     *  @return <code>true</code> if the enumeration is new,
     *          <code>false</code> otherwise
     */

    public boolean isNew() {
        return (this.newEnumeration);
    }

    
    protected void setNew(String asOf) {
        this.newEnumeration = true;
        this.asOf = asOf;
        return;
    }


    /*
     * The spec needs to make sure all interface names are unique so
     * we can simplify the operators in the hash map.
     */

    @Override
    public int hashCode() {
        return (this.name.hashCode());
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return (true);
        }

        if (!(o instanceof OsidEnumeration)) {
            return (false);
        }

        return (getName().equals(((OsidEnumeration) o).getName()));
    }
}
    
