//
// Osids.java
//
//     Stores the OSIDs.
//
//
// Tom Coppeto
// OnTapSolutions
// 4 January 2009
//
// Copyright (c) 2009 Ingenescus. All Rights Reserved.
//
//      Permission is hereby granted, free of charge, to any person
//      obtaining a copy of this software and associated documentation
//      files (the "Software"), to deal in the Software without
//      restriction, including without limitation the rights to use,
//      copy, modify, merge, publish, distribute, sublicesne, and/or
//      sell copies of the Software, and to permit the persons to whom
//      the Software is furnished to do so, subject the following
//      conditions:
//
//      The above copyright notice and this permission notice shall be
//      included in all copies or substantial portions of the
//      Software.
//
//      The Software is provided "AS IS", WITHOUT WARRANTY OF ANY
//      KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
//      WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
//      PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
//      COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//      LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
//      OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
//      SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package org.osid.meta;


/**
 *  Represents an OSID.
 */

public class Osids {    
    private final java.util.Map<String, Osid> osids = new java.util.HashMap<>();
    

    private Osids() {
        return;
    }


    /**
     *  Gets an Osid by package name.
     *
     *  @param name the package name of the osid to retrieve
     *  @return the osid or <code>null</code> if not found
     */
    
    public Osid getOsid(String name) {
        return (this.osids.get(name));
    }


    /**
     *  Gets an Osid by OSID.
     *
     *  @param osid an OSID
     *  @return an <code>Osid</code> or <code>null</code>
     *          if not found
     */

    public Osid getOsid(org.osid.OSID osid) {
        return (getOsid(osid.getOSIDPackageName()));
    }


    /** 
     *  Gets all Osids.
     *
     *  @return a list of Osids
     */
    
    public java.util.Collection<Osid> getOsids() {
        return (this.osids.values());
    }


    public synchronized void addOsid(Osid osid) {
        if (!this.osids.containsKey(osid.getName())) {
            this.osids.put(osid.getName(), osid);
        }

        return;
    }


    /**
     *  Gets an instance of this class.
     *
     *  @return instance of Osids
     */

    public static Osids getInstance() {
        return SingletonHolder.instance;
    }


    private static class SingletonHolder { 
        public static final Osids instance = new Osids();
    }
}
    
