//
// org.osid.metering.MeterReadingSession
//
//     The OSID Java specification for org.osid.metering.MeterReadingSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session is used to read meters. </p> 
 *  
 *  <p> This reading session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> federated utility view: includes meters in utilities which are 
 *      children of this utility in the utility hierarchy </li> 
 *      <li> isolated utility view: restricts lookups to this utility only 
 *      </li> 
 *  </ul>
 *  
 */

public interface MeterReadingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Utility </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Utility Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getUtilityId();


    /**
     *  Gets the <code> Utility </code> associated with this session. 
     *
     *  @return the utility 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Utility getUtility()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can read meters. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer metering operations. 
     *
     *  @return <code> false </code> if metering methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canReadMeters();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeMeterView();


    /**
     *  A complete view of the returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryMeterView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include meters in utilities which are children of this utility in the 
     *  utility hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedUtilityView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this utility only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedUtilityView();


    /**
     *  Gets the reading of the <code> Meter </code> specified by its <code> 
     *  Id. </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> Meter 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Meter </code> and retained for compatibility. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> to 
     *          retrieve 
     *  @param  meteredObjectId the <code> Id </code> of the <code> Metered 
     *          </code> to retrieve 
     *  @return the meter reading 
     *  @throws org.osid.NotFoundException no <code> Meter </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> meterId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.Reading readMeter(org.osid.id.Id meterId, 
                                               org.osid.id.Id meteredObjectId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ReadingList </code> corresponding to the given <code> 
     *  meterdId </code> and metered object list In plenary mode, the returned 
     *  list contains all of the readings specified in the <code> Id </code> 
     *  list, in the order of the list, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible readings may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *
     *  @param  meterId the <code> Id </code> of the <code> Meter </code> to 
     *          retrieve 
     *  @param  meteredObjectIds the <code> Ids </code> of the metered objects 
     *          to retrieve 
     *  @return the returned <code> Reading </code> list 
     *  @throws org.osid.NotFoundException <code> meterId </code> or an <code> 
     *          Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> meterI </code> d or 
     *          <code> meteredObjectIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.ReadingList readMeters(org.osid.id.Id meterId, 
                                                    org.osid.id.IdList meteredObjectIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
