//
// org.osid.metering.MeterSearchSession
//
//     The OSID Java specification for org.osid.metering.MeterSearchSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session provides methods for searching among meters. The search 
 *  query is constructed using the <code> MeterQuery. </code> </p> 
 *  
 *  <p> <code> getMetersByQuery() </code> is the basic search method and 
 *  returns a list of meters. A more advanced search may be performed with 
 *  <code> getMetersBySearch(). </code> It accepts a <code> MeterSearch 
 *  </code> in addition to the query for the purpose of specifying additional 
 *  options affecting the entire search, such as ordering. <code> 
 *  getMetersBySearch() </code> returns a <code> MeterSearchResults </code> 
 *  that can be used to access the resulting <code> MeterList </code> or be 
 *  used to perform a search within the result set through <code> MeterSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated utility view: searches include meters in utilities of 
 *      which this utility is an ancestor in the utility hierarchy </li> 
 *      <li> isolated utility view: searches are restricted to meters in this 
 *      utility only </li> 
 *  </ul>
 *  
 */

public interface MeterSearchSession
    extends org.osid.metering.MeterQuerySession {


    /**
     *  Gets a meter search. 
     *
     *  @return the meter search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.MeterSearch getMeterSearch();


    /**
     *  Gets a meter search order. The <code> MeterSearchOrder </code> is 
     *  supplied to a <code> MeterSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the meter search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.MeterSearchOrder getMeterSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  meterQuery the meter query 
     *  @param  meterSearch the meter search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> meterQuery </code> or 
     *          <code> meterSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> meterQuery </code> or 
     *          <code> meterSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.MeterSearchResults getMetersBySearch(org.osid.metering.MeterQuery meterQuery, 
                                                                  org.osid.metering.MeterSearch meterSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a meter query from an inspector. The inspector is available from 
     *  a <code> MeterSearchResults. </code> 
     *
     *  @param  meterQueryInspector a meter query inspector 
     *  @return the meter query 
     *  @throws org.osid.NullArgumentException <code> meterQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> meterQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.MeterQuery getMeterQueryFromInspector(org.osid.metering.MeterQueryInspector meterQueryInspector);
}
