//
// org.osid.metering.MeteringProfile
//
//     The OSID Java specification for org.osid.metering.MeteringProfile.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>The metering profile describes the interoperability among metering 
 *  services. </p>
 */

public interface MeteringProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if visible federation is supported. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if reading meters is supported. 
     *
     *  @return <code> true </code> if reading meters is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterReading();


    /**
     *  Tests if statistical lookup is supported. 
     *
     *  @return <code> true </code> if statistical lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStatisticLookup();


    /**
     *  Tests if statistical query is supported. 
     *
     *  @return <code> true </code> if statistical query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStatisticQuery();


    /**
     *  Tests if statistical search is supported. 
     *
     *  @return <code> true </code> if statistical search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStatisticSearch();


    /**
     *  Tests if statistical notification is supported. 
     *
     *  @return <code> true </code> if statistical notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStatisticNotification();


    /**
     *  Tests if statistical smart utilitiy is supported. 
     *
     *  @return <code> true </code> if statistical smart utility is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStatisticSmartUtility();


    /**
     *  Tests if looking up meters is supported. 
     *
     *  @return <code> true </code> if looking up meters is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterLookup();


    /**
     *  Tests if querying meters is supported. 
     *
     *  @return <code> true </code> if querying meters is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterQuery();


    /**
     *  Tests if searching meters is supported. 
     *
     *  @return <code> true </code> if searching meters is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterSearch();


    /**
     *  Tests if meter notification is supported,. 
     *
     *  @return <code> true </code> if meter notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterNotification();


    /**
     *  Tests if looking up meter utlity mappings is supported,. 
     *
     *  @return <code> true </code> if utility meter mapping is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterUtility();


    /**
     *  Tests if managing meter utlity mappings is supported,. 
     *
     *  @return <code> true </code> if assigning utility meter mappings is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterUtilityAssignment();


    /**
     *  Tests if managing meter smart utlity service is supported,. 
     *
     *  @return <code> true </code> if a meter smart utility service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSmartMeterUtility();


    /**
     *  Tests for the availability of a utility lookup service. 
     *
     *  @return <code> true </code> if utility lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUtilityLookup();


    /**
     *  Tests for the availability of a utility query service. 
     *
     *  @return <code> true </code> if utility query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUtilityQuery();


    /**
     *  Tests if searching for utilities is available. 
     *
     *  @return <code> true </code> if utility search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUtilitySearch();


    /**
     *  Tests for the availability of a utility administrative service for 
     *  creating and deleting utilities. 
     *
     *  @return <code> true </code> if utility administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUtilityAdmin();


    /**
     *  Tests for the availability of a utility notification service. 
     *
     *  @return <code> true </code> if utility notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsUtilityNotification();


    /**
     *  Tests for the availability of a utility hierarchy traversal service. 
     *
     *  @return <code> true </code> if utility hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUtilityHierarchy();


    /**
     *  Tests for the availability of a utility hierarchy design service. 
     *
     *  @return <code> true </code> if utility hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsUtilityHierarchyDesign();


    /**
     *  Tests for the availability of a metering batch service. 
     *
     *  @return <code> true </code> if metering batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsMeteringBatch();


    /**
     *  Tests for the availability of a metering threshold service. 
     *
     *  @return <code> true </code> if metering threshold service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsMeteringThreshold();


    /**
     *  Gets the supported <code> Statistic </code> record types. 
     *
     *  @return a list containing the supported statistic record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStatisticRecordTypes();


    /**
     *  Tests if the given <code> Statistic </code> record type is supported. 
     *
     *  @param  statisticRecordType a <code> Type </code> indicating a <code> 
     *          Statistic </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> statisticRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStatisticRecordType(org.osid.type.Type statisticRecordType);


    /**
     *  Gets the supported statistic search record types. 
     *
     *  @return a list containing the supported statistic search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStatisticSearchRecordTypes();


    /**
     *  Tests if the given statistic search record type is supported. 
     *
     *  @param  statisticSearchRecordType a <code> Type </code> indicating a 
     *          statistic record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          statisticSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStatisticSearchRecordType(org.osid.type.Type statisticSearchRecordType);


    /**
     *  Gets the supported <code> Meter </code> record types. 
     *
     *  @return a list containing the supported meter record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMeterRecordTypes();


    /**
     *  Tests if the given <code> Meter </code> record type is supported. 
     *
     *  @param  meterRecordType a <code> Type </code> indicating a <code> 
     *          Meter </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> meterRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterRecordType(org.osid.type.Type meterRecordType);


    /**
     *  Gets the supported meter search record types. 
     *
     *  @return a list containing the supported meter search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getMeterSearchRecordTypes();


    /**
     *  Tests if the given meter search record type is supported. 
     *
     *  @param  meterSearchRecordType a <code> Type </code> indicating a meter 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> meterSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterSearchRecordType(org.osid.type.Type meterSearchRecordType);


    /**
     *  Gets the supported <code> Utility </code> record types. 
     *
     *  @return a list containing the supported utility record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getUtilityRecordTypes();


    /**
     *  Tests if the given <code> Utility </code> record type is supported. 
     *
     *  @param  utilityRecordType a <code> Type </code> indicating a <code> 
     *          Utility </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> utilityRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUtilityRecordType(org.osid.type.Type utilityRecordType);


    /**
     *  Gets the supported utility search record types. 
     *
     *  @return a list containing the supported utility search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getUtilitySearchRecordTypes();


    /**
     *  Tests if the given utility search record type is supported. 
     *
     *  @param  utilitySearchRecordType a <code> Type </code> indicating a 
     *          utility record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> utilitySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsUtilitySearchRecordType(org.osid.type.Type utilitySearchRecordType);
}
