//
// org.osid.metering.StatisticQueryInspector
//
//     The OSID Java specification for org.osid.metering.StatisticQueryInspector.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This is the query inspector for examining meter queries. Each method 
 *  specifies an <code> AND </code> term while multiple terms of the same 
 *  method produce a nested <code> OR. </code> </p>
 */

public interface StatisticQueryInspector
    extends org.osid.OsidCompendiumQueryInspector {


    /**
     *  Gets the meter <code> Id </code> terms. 
     *
     *  @return the meter <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getMeterIdTerms();


    /**
     *  Gets the meter terms. 
     *
     *  @return the meter terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.MeterQueryInspector[] getMeterTerms();


    /**
     *  Gets the object <code> Id </code> terms. 
     *
     *  @return the object <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getMeteredObjectIdTerms();


    /**
     *  Gets the time interval term. 
     *
     *  @return the time interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getTimeRangeTerms();


    /**
     *  Gets the sum terms. 
     *
     *  @return the sum terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getSumTerms();


    /**
     *  Gets the minumim sum terms. 
     *
     *  @return the minumim sum terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumSumTerms();


    /**
     *  Gets the mean terms. 
     *
     *  @return the mean terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getMeanTerms();


    /**
     *  Gets the minumim mean terms. 
     *
     *  @return the minumim mean terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumMeanTerms();


    /**
     *  Gets the median terms. 
     *
     *  @return the median terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getMedianTerms();


    /**
     *  Gets the minumim median terms. 
     *
     *  @return the minumim median terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumMedianTerms();


    /**
     *  Gets the mode terms. 
     *
     *  @return the mode terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getModeTerms();


    /**
     *  Gets the minumim mode terms. 
     *
     *  @return the minumim mode terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumModeTerms();


    /**
     *  Gets the standard deviation terms. 
     *
     *  @return the standard deviation terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getStandardDeviationTerms();


    /**
     *  Gets the minumim standard deviation terms. 
     *
     *  @return the minumim standard deviation terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumStandardDeviationTerms();


    /**
     *  Gets the root mean square terms. 
     *
     *  @return the root mean square terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getRMSTerms();


    /**
     *  Gets the minumim root mean square terms. 
     *
     *  @return the minumim root mean square terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumRMSTerms();


    /**
     *  Gets the delta terms. 
     *
     *  @return the delta terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getDeltaTerms();


    /**
     *  Gets the minumim delta terms. 
     *
     *  @return the minumim delta terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumDeltaTerms();


    /**
     *  Gets the percentage change terms. 
     *
     *  @return the percentage change terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getPercentChangeTerms();


    /**
     *  Gets the minimum delta terms. 
     *
     *  @return the minumim percentage change terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalTerm[] getMinimumPercentChangeTerms();


    /**
     *  Gets the average rate terms. 
     *
     *  @return the average rate terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DecimalRangeTerm[] getAverageRateTerms();


    /**
     *  Gets the statistic query inspector record corresponding to the given 
     *  <code> Statistic </code> record <code> Type. </code> Multiple 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  statisticRecordType a statistic record type 
     *  @return the statistic query inspector record 
     *  @throws org.osid.NullArgumentException <code> statisticRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(statisticRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.records.StatisticQueryInspectorRecord getStatisticQueryInspectorRecord(org.osid.type.Type statisticRecordType)
        throws org.osid.OperationFailedException;
}
