//
// org.osid.metering.StatisticSearchSession
//
//     The OSID Java specification for org.osid.metering.StatisticSearchSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session provides methods for searching among statistics The search 
 *  query is constructed using the <code> StatisticQuery. </code> </p> 
 *  
 *  <p> <code> getStatisticsByQuery() </code> is the basic search method and 
 *  returns a list of statistics. A more advanced search may be performed with 
 *  <code> getStatisticsBySearch(). </code> It accepts a <code> 
 *  StatisticSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getStatisticsBySearch() </code> returns a <code> 
 *  StatisticSearchResults </code> that can be used to access the resulting 
 *  <code> StatisticList </code> or be used to perform a search within the 
 *  result set through <code> StatisticSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated utility view: searches include statistic in utilities 
 *      of which this utility is an ancestor in the utility hierarchy </li> 
 *      <li> isolated utility view: searches are restricted to statistics in 
 *      this utility only </li> 
 *  </ul>
 *  
 */

public interface StatisticSearchSession
    extends org.osid.metering.MeterQuerySession {


    /**
     *  Gets a statistic search. 
     *
     *  @return the statistic search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticSearch getStatisticSearch();


    /**
     *  Gets a statistic search order. The <code> StatisticSearchOrder </code> 
     *  is supplied to a <code> StatisticSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the statistic search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticSearchOrder getStatisticSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  statisticQuery the statistics query 
     *  @param  statisticSearch the statistics search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> statisticQuery </code> 
     *          or <code> statisticSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> statisticQuery </code> or 
     *          <code> statisticSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticSearchResults getStatisticsBySearch(org.osid.metering.StatisticQuery statisticQuery, 
                                                                          org.osid.metering.StatisticSearch statisticSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a statistic query from an inspector. The inspector is available 
     *  from a <code> StatisticSearchResults. </code> 
     *
     *  @param  statisticQueryInspector a statistic query inspector 
     *  @return the statistic query 
     *  @throws org.osid.NullArgumentException <code> statisticQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> statisticQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.StatisticQuery getStatisticQueryFromInspector(org.osid.metering.StatisticQueryInspector statisticQueryInspector);
}
