//
// org.osid.metering.UtilityHierarchyDesignSession
//
//     The OSID Java specification for org.osid.metering.UtilityHierarchyDesignSession.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This session manages a hierarchy of utilities. Utilities may be 
 *  organized into a hierarchy for organizing or federating. A parent <code> 
 *  Utility </code> includes all of the Ids of its children such that a single 
 *  root node contains all of the <code> Ids </code> of the federation. </p>
 */

public interface UtilityHierarchyDesignSession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getUtilityHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getUtilityHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can change the hierarchy. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known performing any update will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if changing this hierarchy is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canModifyUtilityHierarchy();


    /**
     *  Adds a root utility. 
     *
     *  @param  utilityId the <code> Id </code> of a utility 
     *  @throws org.osid.AlreadyExistsException <code> utilityId </code> is 
     *          already in hierarchy 
     *  @throws org.osid.NotFoundException <code> utilityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addRootUtility(org.osid.id.Id utilityId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a root utility. 
     *
     *  @param  utilityId the <code> Id </code> of a utility 
     *  @throws org.osid.NotFoundException <code> utilityId </code> is not a 
     *          root 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeRootUtility(org.osid.id.Id utilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a child to a utility. 
     *
     *  @param  utilityId the <code> Id </code> of a utility 
     *  @param  childId the <code> Id </code> of the new child 
     *  @throws org.osid.AlreadyExistsException <code> utilityId </code> is 
     *          already a parent of <code> childId </code> 
     *  @throws org.osid.NotFoundException <code> utilityId </code> or <code> 
     *          childId </code> not found 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> childId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addChildUtility(org.osid.id.Id utilityId, 
                                org.osid.id.Id childId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a child from a utility. 
     *
     *  @param  utilityId the <code> Id </code> of a utility 
     *  @param  childId the <code> Id </code> of the new child 
     *  @throws org.osid.NotFoundException <code> utilityId </code> not a 
     *          parent of <code> childId </code> 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> or 
     *          <code> childId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeChildUtility(org.osid.id.Id utilityId, 
                                   org.osid.id.Id childId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes all children from a utility. 
     *
     *  @param  utilityId the <code> Id </code> of a utility 
     *  @throws org.osid.NotFoundException <code> utilityId </code> not found 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeChildUtilities(org.osid.id.Id utilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
