//
// org.osid.metering.UtilityQuery
//
//     The OSID Java specification for org.osid.metering.UtilityQuery.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>This is the query for searching for utilities. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface UtilityQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets a meter <code> Id. </code> 
     *
     *  @param  meterId a meter <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> meterId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMeterId(org.osid.id.Id meterId, boolean match);


    /**
     *  Clears the meter <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeterIdTerms();


    /**
     *  Tests if a meter query is available. 
     *
     *  @return <code> true </code> if a meter query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeterQuery();


    /**
     *  Gets the query for a meter. 
     *
     *  @return the meter query 
     *  @throws org.osid.UnimplementedException <code> supportsMeterQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMeterQuery() </code> is <code> true. </code> 
     */

    public org.osid.metering.MeterQuery getMeterQuery();


    /**
     *  Matches utilities with any meter. 
     *
     *  @param  match <code> true </code> to match utilities with any meter, 
     *          <code> false </code> to match utilities with no meters 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMeter(boolean match);


    /**
     *  Clears the meter query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMeterTerms();


    /**
     *  Sets the utility <code> Id </code> for this query to match utilities 
     *  that have the specified utility as an ancestor. 
     *
     *  @param  utilityId a utility <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorUtilityId(org.osid.id.Id utilityId, boolean match);


    /**
     *  Clears the ancestor utility <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorUtilityIdTerms();


    /**
     *  Tests if a <code> UtilityQuery </code> is available. 
     *
     *  @return <code> true </code> if a utility query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorUtilityQuery();


    /**
     *  Gets the query for a utility. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the utility query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorUtilityQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorUtilityQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.UtilityQuery getAncestorUtilityQuery();


    /**
     *  Clears the ancestor utility query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorUtilityTerms();


    /**
     *  Matches utilities with any ancestor. 
     *
     *  @param  match <code> true </code> to match utilities with any 
     *          ancestor, <code> false </code> to match root utilities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorUtility(boolean match);


    /**
     *  Sets the utility <code> Id </code> for this query to match utilities 
     *  that have the specified utility as a descendant. 
     *
     *  @param  utilityId a utility <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> utilityId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantUtilityId(org.osid.id.Id utilityId, 
                                         boolean match);


    /**
     *  Clears the descendant utility <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantUtilityIdTerms();


    /**
     *  Tests if a <code> UtilityQuery </code> is available. 
     *
     *  @return <code> true </code> if a utility query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantUtilityQuery();


    /**
     *  Gets the query for a utility. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the utility query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantUtilityQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantUtilityQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.metering.UtilityQuery getDescendantUtilityQuery();


    /**
     *  Matches utilities with any descendant. 
     *
     *  @param  match <code> true </code> to match utilities with any 
     *          descendant, <code> false </code> to match leaf utilities 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantUtility(boolean match);


    /**
     *  Clears the descendant utility query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantUtilityTerms();


    /**
     *  Gets the utility query record corresponding to the given <code> 
     *  Utility </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested boolean <code> OR </code> term. 
     *
     *  @param  utilityRecordType a utility record type 
     *  @return the utility query record 
     *  @throws org.osid.NullArgumentException <code> utilityRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(utilityRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.metering.records.UtilityQueryRecord getUtilityQueryRecord(org.osid.type.Type utilityRecordType)
        throws org.osid.OperationFailedException;
}
