//
// org.osid.metering.UtilityReceiver
//
//     The OSID Java specification for org.osid.metering.UtilityReceiver.
//
// Copyright (C) 2009-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.metering;


/**
 *  <p>The utility receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted <code> Utility </code> 
 *  objects. </p>
 */

public interface UtilityReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new utilities. 
     *
     *  @param  utilityIds the <code> Ids </code> of the new <code> Utilities 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newUtilities(org.osid.id.IdList utilityIds);


    /**
     *  The callback for notifications of new ancestors of a utility. 
     *
     *  @param  utilityId the <code> Id </code> of the registered <code> 
     *          Utility </code> 
     *  @param  ancestorId the <code> Id </code> of the new ancestor utility 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorUtility(org.osid.id.Id utilityId, 
                                   org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new descendant of a utility. 
     *
     *  @param  utilityId the <code> Id </code> of the registered <code> 
     *          Utility </code> 
     *  @param  descendantId the <code> Id </code> of the new descendant 
     *          utility 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantUtility(org.osid.id.Id utilityId, 
                                     org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated utilities. 
     *
     *  @param  utilityIds the <code> Ids </code> of the updated <code> 
     *          Utilities </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedUtilities(org.osid.id.IdList utilityIds);


    /**
     *  the callback for notification of deleted utilities. 
     *
     *  @param  utilityIds the <code> Ids </code> of the registered <code> 
     *          Utilities </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedUtilities(org.osid.id.IdList utilityIds);


    /**
     *  The callback for notifications of deleted ancestors of a utility, 
     *
     *  @param  utilityId the <code> Id </code> of the registered <code> 
     *          Utility </code> 
     *  @param  ancestorId the <code> Id </code> of the removed ancestor 
     *          utility 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorUtility(org.osid.id.Id utilityId, 
                                       org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted descendants of a utility. 
     *
     *  @param  utilityId the <code> Id </code> of the registered <code> 
     *          Utility </code> 
     *  @param  descendantId the <code> Id </code> of the deleted descendant 
     *          utility 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantUtility(org.osid.id.Id utilityId, 
                                         org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a utility hierarchy where 
     *  the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredUtilityHierarchy();
}
