//
// org.osid.offering.CanonicalUnitForm
//
//     The OSID Java specification for org.osid.offering.CanonicalUnitForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This is the form for creating and updating <code> CanonicalUnit </code> 
 *  objects. Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  CanonicalUnitAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface CanonicalUnitForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidOperableForm {


    /**
     *  Gets the metadata for a title. 
     *
     *  @return metadata for the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTitleMetadata();


    /**
     *  Sets the title. 
     *
     *  @param  title the title 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTitle(String title);


    /**
     *  Clears the title. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitle();


    /**
     *  Gets the metadata for a given name. 
     *
     *  @return metadata for the given name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCodeMetadata();


    /**
     *  Sets the code. 
     *
     *  @param  code the code 
     *  @throws org.osid.InvalidArgumentException <code> code </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCode(String code);


    /**
     *  Clears the code. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCode();


    /**
     *  Gets the metadata for a the cyclic time periods. 
     *
     *  @return metadata for the cyclic time periods 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOfferedCyclicTimePeriodsMetadata();


    /**
     *  Sets the cyclic time periods. 
     *
     *  @param  cyclicTimePeriodIds the cyclic time periods 
     *  @throws org.osid.InvalidArgumentException <code> cylciPeriodIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> cyclicPeriodIds </code> 
     *          is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOfferedCyclicTimePeriods(org.osid.id.Id[] cyclicTimePeriodIds);


    /**
     *  Clears the cyclic time periods. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfferedCyclicTimePeriods();


    /**
     *  Gets the metadata for the grading options. 
     *
     *  @return metadata for the prerequisite information 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getResultOptionsMetadata();


    /**
     *  Sets the grading options. 
     *
     *  @param  gradeSystemIds the new grading options 
     *  @throws org.osid.InvalidArgumentException <code> gradeSystemIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeSystemIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setResultOptions(org.osid.id.Id[] gradeSystemIds);


    /**
     *  Removes the grading options. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultOptions();


    /**
     *  Gets the metadata for the sponsors. 
     *
     *  @return metadata for the sponsors 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSponsorsMetadata();


    /**
     *  Sets the sponsors. 
     *
     *  @param  sponsorIds the new sponsors 
     *  @throws org.osid.InvalidArgumentException <code> sponsorIds </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> sponsorIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSponsors(org.osid.id.Id[] sponsorIds);


    /**
     *  Removes the sponsors. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsors();


    /**
     *  Gets the <code> CanonicalUnitFormRecord </code> interface 
     *  corresponding to the given canonical unit record <code> Type. </code> 
     *
     *  @param  canonicalUnitRecordType the canonical unit record type 
     *  @return the record 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(canonicalUnitRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.records.CanonicalUnitFormRecord getCanonicalUnitFormRecord(org.osid.type.Type canonicalUnitRecordType)
        throws org.osid.OperationFailedException;
}
