//
// org.osid.offering.CanonicalUnitSearchSession
//
//     The OSID Java specification for org.osid.offering.CanonicalUnitSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session provides methods for searching <code> CanonicalUnit 
 *  </code> objects. The search query is constructed using the <code> 
 *  CanonicalUnitQuery. </code> The canonical unit record <code> Type </code> 
 *  also specifies the record for the canonical unit query. </p> 
 *  
 *  <p> <code> getCanonicalUnitsByQuery() </code> is the basic search method 
 *  and returns a list of <code> CanonicalUnit </code> elements. A more 
 *  advanced search may be performed with <code> getCanonicalUnitsBySearch(). 
 *  </code> It accepts a <code> CanonicalUnitSearch </code> in addition to the 
 *  query for the purpose of specifying additional options affecting the 
 *  entire search, such as ordering. <code> getCanonicalUnitsBySearch() 
 *  </code> returns a <code> CanonicalUnitSearchResults </code> that can be 
 *  used to access the resulting <code> CanonicalUnitList </code> or be used 
 *  to perform a search within the result set through <code> 
 *  CanonicalUnitSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated catalogue view: searches include canonical units in 
 *      catalogues of which this catalogue is a ancestor in the catalogue 
 *      hierarchy </li> 
 *      <li> isolated catalogue view: searches are restricted to canonical 
 *      units in this catalogue </li> 
 *  </ul>
 *  
 *  
 *  <p> CanonicalUnits may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  CanonicalUnitQuery. </code> The returns in this session may not be cast 
 *  directly to these interfaces. </p>
 */

public interface CanonicalUnitSearchSession
    extends org.osid.offering.CanonicalUnitQuerySession {


    /**
     *  Gets a canonical unit search. 
     *
     *  @return the canonical unit search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitSearch getCanonicalUnitSearch();


    /**
     *  Gets a canonical unit search order. The <code> 
     *  CanonicalUnitSearchOrder </code> is supplied to a <code> 
     *  CanonicalUnitSearch </code> to specify the ordering of results. 
     *
     *  @return the canonical unit search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitSearchOrder getCanonicalUnitSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  canonicalUnitQuery the canonical unit query 
     *  @param  canonicalUnitSearch the canonical unit search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitQuery 
     *          </code> or <code> canonicalUnitSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> canonicalUnitQuery 
     *          </code> or <code> canonicalUnitSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitSearchResults getCanonicalUnitsBySearch(org.osid.offering.CanonicalUnitQuery canonicalUnitQuery, 
                                                                                  org.osid.offering.CanonicalUnitSearch canonicalUnitSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit query from an inspector. The inspector is 
     *  available from a <code> CanonicalUnitSearchResults. </code> 
     *
     *  @param  canonicalUnitQueryInspector a canonical unit query inspector 
     *  @return the canonical unit query 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnitQuery getCanonicalUnitQueryFromInspector(org.osid.offering.CanonicalUnitQueryInspector canonicalUnitQueryInspector);
}
