//
// org.osid.offering.CatalogueAdminSession
//
//     The OSID Java specification for org.osid.offering.CatalogueAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session creates, updates, and deletes <code> Catalogues. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Catalogue, </code> a <code> CatalogueForm </code> is requested using 
 *  <code> getCatalogueFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> CatalogueForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> CatalogueForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  CatalogueForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CatalogueForms </code> are requested to the <code> 
 *  Catalogue </code> <code> Id </code> that is to be updated using <code> 
 *  getCatalogueFormForUpdate(). </code> Similarly, the <code> CatalogueForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> CatalogueForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Catalogues. </code> It is safer to 
 *  remove all mappings to the <code> Catalogue </code> catalogs before 
 *  deletion. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CatalogueAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Catalogues. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Catalogue </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Catalogue </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCatalogues();


    /**
     *  Tests if this user can create a single <code> Catalogue </code> using 
     *  the desired record types. While <code> 
     *  OfferingManager.getCatalogueRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Catalogue. </code> 
     *  Providing an empty array tests if a <code> Catalogue </code> can be 
     *  created with no records. 
     *
     *  @param  catalogueRecordTypes array of types 
     *  @return <code> true </code> if <code> Catalogue </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> catalogueRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCatalogueWithRecordTypes(org.osid.type.Type[] catalogueRecordTypes);


    /**
     *  Gets the catalogue form for creating new catalogues. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  catalogueRecordTypes array of types 
     *  @return the catalogue form 
     *  @throws org.osid.NullArgumentException <code> catalogueRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException cannot get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CatalogueForm getCatalogueFormForCreate(org.osid.type.Type[] catalogueRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Catalogue. </code> 
     *
     *  @param  catalogueForm the form for this <code> Catalogue </code> 
     *  @return the new <code> Catalogue </code> 
     *  @throws org.osid.IllegalStateException <code> catalogueForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> catalogueForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> catalogueForm </code> did 
     *          not originate from <code> getCatalogueFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue createCatalogue(org.osid.offering.CatalogueForm catalogueForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Catalogues. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Catalogue </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Catalogue </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCatalogues();


    /**
     *  Gets the catalogue form for updating an existing catalogue. A new 
     *  catalogue form should be requested for each update transaction. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return the catalogue form 
     *  @throws org.osid.NotFoundException <code> catalogueId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CatalogueForm getCatalogueFormForUpdate(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing catalogue. 
     *
     *  @param  catalogueForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> catalogueForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> catalogueForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> catalogueForm did not 
     *          originate from getCataloguetFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCatalogue(org.osid.offering.CatalogueForm catalogueForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Catalogues </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Catalogue </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Catalogue </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCatalogues();


    /**
     *  Deletes a <code> Catalogue. </code> 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> catalogueId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Catalogues. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Catalogue </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCatalogueAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Catalogue </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Item </code> is determined by the provider. The new <code> 
     *  Id </code> is an alias to the primary <code> Id. </code> If the alias 
     *  is a pointer to another catalogue, it is reassigned to the given 
     *  catalogue <code> Id. </code> 
     *
     *  @param  catalogueId the <code> Id </code> of a <code> Catalogue 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> catalogueId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCatalogue(org.osid.id.Id catalogueId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
