//
// org.osid.offering.CatalogueSearchSession
//
//     The OSID Java specification for org.osid.offering.CatalogueSearchSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>This session provides methods for searching <code> Catalogue </code> 
 *  objects. The search query is constructed using the <code> CatalogueQuery. 
 *  </code> The catalogue record <code> Type </code> also specifies the 
 *  catalogue query record for the catalogue query. </p> 
 *  
 *  <p> <code> getCataloguesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Catalogue </code> elements. A more advanced 
 *  search may be performed with <code> getCataloguesBySearch(). </code> It 
 *  accepts a <code> CatalogueSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getCataloguesBySearch() </code> returns a <code> 
 *  CatalogueSearchResults </code> that can be used to access the resulting 
 *  <code> CatalogueList </code> or be used to perform a search within the 
 *  result set through <code> CatalogueSearch. </code> </p> 
 *  
 *  <p> Catalogues may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> CatalogueQuery. 
 *  </code> The returns in this session may not be cast directly to these 
 *  interfaces. </p>
 */

public interface CatalogueSearchSession
    extends org.osid.offering.CatalogueQuerySession {


    /**
     *  Gets a catalogue search. 
     *
     *  @return the catalogue search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CatalogueSearch getCatalogueSearch();


    /**
     *  Gets a catalogue search order. The <code> CatalogueSearchOrder </code> 
     *  is supplied to a <code> CatalogueSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the catalogue search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CatalogueSearchOrder getCatalogueSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  catalogueQuery the catalogue query 
     *  @param  catalogueSearch the catalogue search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> catalogueQuery </code> 
     *          or <code> catalogueSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> catalogueQuery </code> or 
     *          <code> catalogueSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CatalogueSearchResults getCataloguesBySearch(org.osid.offering.CatalogueQuery catalogueQuery, 
                                                                          org.osid.offering.CatalogueSearch catalogueSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a catalogue query from an inspector. The inspector is available 
     *  from a <code> CatalogueSearchResults. </code> 
     *
     *  @param  catalogueQueryInspector a catalogue query inspector 
     *  @return the catalogue query 
     *  @throws org.osid.NullArgumentException <code> catalogueQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> icatalogueQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CatalogueQuery getCatalogueQueryFromInspector(org.osid.offering.CatalogueQueryInspector catalogueQueryInspector);
}
