//
// org.osid.offering.Offering
//
//     The OSID Java specification for org.osid.offering.Offering.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>An <code> Offering </code> is an <code> OsidRelationship </code> 
 *  between a <code> CanonicalUnit </code> and a <code> TimePeriod. </code> 
 *  </p>
 */

public interface Offering
    extends org.osid.OsidRelationship {


    /**
     *  Gets the <code> Id </code> of the canonical unit. 
     *
     *  @return the canonical unit <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCanonicalUnitId();


    /**
     *  Gets the canonical of this offering. 
     *
     *  @return the canonical unit 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.CanonicalUnit getCanonicalUnit()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the time period. 
     *
     *  @return the time period <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTimePeriodId();


    /**
     *  Gets the time period of this offering 
     *
     *  @return the time period 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.TimePeriod getTimePeriod()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the title for this offering. 
     *
     *  @return the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getTitle();


    /**
     *  Gets the code for this offering. 
     *
     *  @return the code 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getCode();


    /**
     *  Tests if this offering has results when offered. 
     *
     *  @return <code> true </code> if this offering has results, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasResults();


    /**
     *  Gets the various result option <code> Ids </code> allowed for results. 
     *
     *  @return the returned list of grading option <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasResults() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResultOptionIds();


    /**
     *  Gets the various result options allowed for this offering. 
     *
     *  @return the returned list of grading options 
     *  @throws org.osid.IllegalStateException <code> hasResults() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeSystemList getResultOptions()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this offering has sponsors. 
     *
     *  @return <code> true </code> if this offering has sponsors, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSponsors();


    /**
     *  Gets the sponsor <code> Ids. </code> 
     *
     *  @return the sponsor <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSponsorIds();


    /**
     *  Gets the sponsors. 
     *
     *  @return the sponsors 
     *  @throws org.osid.IllegalStateException <code> hasSponsors() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getSponsors()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the schedule <code> Ids </code> associated with this offering. 
     *
     *  @return the schedule <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getScheduleIds();


    /**
     *  Gets the schedules associated with this offering. 
     *
     *  @return the schedules 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.ScheduleList getSchedules()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the record corresponding to the given <code> Offering </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> offeringRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(offeringRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  offeringRecordType the type of offering record to retrieve 
     *  @return the offering record 
     *  @throws org.osid.NullArgumentException <code> offeringRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offeringRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.records.OfferingRecord getOfferingRecord(org.osid.type.Type offeringRecordType)
        throws org.osid.OperationFailedException;
}
