//
// org.osid.offering.OfferingManager
//
//     The OSID Java specification for org.osid.offering.OfferingManager.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering;


/**
 *  <p>The offering manager provides access to offering sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> CanonicalUnitLookupSession: </code> a session to lookup 
 *      canonical units </li> 
 *      <li> <code> CanonicalUnitQuerySession: </code> a session for querying 
 *      canonical units </li> 
 *      <li> <code> CanonicalUnitSearchSession: </code> a session to search 
 *      canonical units </li> 
 *      <li> <code> CanonicalUnitAdminSession: </code> a session to manage 
 *      canonical units </li> 
 *      <li> <code> CanonicalUnitNotificationSession: </code> a session to 
 *      subscribe to notifications of canonical unit changes </li> 
 *      <li> <code> CanonicalUnitCatalogueSession: </code> a session to look 
 *      up canonical unit to catalogue mappings </li> 
 *      <li> <code> CanonicalUnitCatalogueAssignmentSession: </code> a session 
 *      to manage canonical unit to catalogue mappings </li> 
 *      <li> <code> CanonicalUnitSmartCatalogueSession: </code> a session to 
 *      manage dynamic canonical unit to catalogue mappings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> OfferingLookupSession: </code> a session to lookup 
 *      offerings </li> 
 *      <li> <code> OfferingQuerySession: </code> a session for querying 
 *      offerings </li> 
 *      <li> <code> OfferingSearchSession: </code> a session to search 
 *      offerings </li> 
 *      <li> <code> OfferingAdminSession: </code> a session to manage 
 *      offerings </li> 
 *      <li> <code> OfferingNotificationSession: </code> a session to 
 *      subscribe to notifications of offering changes </li> 
 *      <li> <code> OfferingCatalogueSession: </code> a session to look up 
 *      offering to catalogue mappings </li> 
 *      <li> <code> OfferingCatalogueAssignmentSession: </code> a session to 
 *      manage offering to catalogue mappings </li> 
 *      <li> <code> OfferingSmartCatalogueSession: </code> a session to manage 
 *      dynamic offering to catalogue mappings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ParticipantLookupSession: </code> a session to lookup 
 *      participants </li> 
 *      <li> <code> ParticipantQuerySession: </code> a session for querying 
 *      participants </li> 
 *      <li> <code> ParticipantSearchSession: </code> a session to search 
 *      participants </li> 
 *      <li> <code> ParticipantAdminSession: </code> a session to manage 
 *      participants </li> 
 *      <li> <code> ParticipantNotificationSession: </code> a session to 
 *      subscribe to notifications of participant changes </li> 
 *      <li> <code> ParticipantCatalogueSession: </code> a session to look up 
 *      participant to catalogue mappings </li> 
 *      <li> <code> ParticipantCatalogueAssignmentSession: </code> a session 
 *      to manage participant to catalogue mappings </li> 
 *      <li> <code> ParticipantSmartCatalogueSession: </code> a session to 
 *      manage dynamic participant to catalogue mappings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ResultLookupSession: </code> a session to lookup results 
 *      </li> 
 *      <li> <code> ResultQuerySession: </code> a session for querying results 
 *      </li> 
 *      <li> <code> ResultSearchSession: </code> a session to search results 
 *      </li> 
 *      <li> <code> ResultAdminSession: </code> a session to manage results 
 *      </li> 
 *      <li> <code> ResultNotificationSession: </code> a session to subscribe 
 *      to notifications of result changes </li> 
 *      <li> <code> ResultCatalogueSession: </code> a session to look up 
 *      result to catalogue mappings </li> 
 *      <li> <code> ResultCatalogueAssignmentSession: </code> a session to 
 *      manage result to catalogue mappings </li> 
 *      <li> <code> ResultSmartCatalogueSession: </code> a session to manage 
 *      dynamic result to catalogue mappings </li> 
 *      <li> <code> CatalogueLookupSession: </code> a session to retrieve 
 *      catalogues </li> 
 *      <li> <code> CatalogueQuerySession: </code> a session for querying 
 *      catalogues </li> 
 *      <li> <code> CatalogueSearchSession: </code> a session to search for 
 *      catalogues </li> 
 *      <li> <code> CatalogueAdminSession: </code> a session to create, update 
 *      and delete catalogues </li> 
 *      <li> <code> CatalogueNotificationSession: </code> a session to receive 
 *      notifications for changes in catalogues </li> 
 *      <li> <code> CatalogueHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of catalogues </li> 
 *      <li> <code> CatalogueHierarchyDesignSession: </code> a session to 
 *      manage hierarchies of catalogues </li> 
 *  </ul>
 *  
 *  
 *  <p> The offering manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface OfferingManager
    extends org.osid.OsidManager,
            org.osid.offering.OfferingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  lookup service. 
     *
     *  @return a <code> CanonicalUnitLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitLookupSession getCanonicalUnitLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitLookupSession getCanonicalUnitLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  query service. 
     *
     *  @return a <code> CanonicalUnitQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitQuerySession getCanonicalUnitQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  query service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitQuerySession getCanonicalUnitQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  search service. 
     *
     *  @return a <code> CanonicalUnitSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitSearchSession getCanonicalUnitSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  search service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitSearchSession getCanonicalUnitSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  administration service. 
     *
     *  @return a <code> CanonicalUnitAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitAdminSession getCanonicalUnitAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitAdminSession getCanonicalUnitAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  notification service. 
     *
     *  @param  canonicalUnitReceiver the receiver 
     *  @return a <code> CanonicalUnitNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.CanonicalUnitNotificationSession getCanonicalUnitNotificationSession(org.osid.offering.CanonicalUnitReceiver canonicalUnitReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the canonical unit 
     *  notification service for the given catalogue. 
     *
     *  @param  canonicalUnitReceiver the receiver 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> CanonicalUnitNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitReceiver 
     *          </code> or <code> catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitNotificationSession getCanonicalUnitNotificationSessionForCatalogue(org.osid.offering.CanonicalUnitReceiver canonicalUnitReceiver, 
                                                                                                              org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving canonical unit to catalogue mappings. 
     *
     *  @return a <code> CanonicalUnitCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitCatalogue() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitCatalogue() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitCatalogueSession getCanonicalUnitCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning canonical unit to catalogue mappings. 
     *
     *  @return a <code> CanonicalUnitCatalogueAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitCatalogueAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitCatalogueAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.offering.CanonicalUnitCatalogueAssignmentSession getCanonicalUnitCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the canonical unit smart catalogue 
     *  for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the catalogue 
     *  @return a <code> CanonicalUnitSmartCatalogueSession </code> 
     *  @throws org.osid.NotFoundException <code> catalogueId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCanonicalUnitSmartCatalogue() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCanonicalUnitSmartCatalogue() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.CanonicalUnitSmartCatalogueSession getCanonicalUnitSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  lookup service. 
     *
     *  @return an <code> OfferingLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingLookup() </code> is <code> true. </code> 
     */

    public org.osid.offering.OfferingLookupSession getOfferingLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.OfferingLookupSession getOfferingLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering query 
     *  service. 
     *
     *  @return an <code> OfferingQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfferingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.OfferingQuerySession getOfferingQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering query 
     *  service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfferingQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.OfferingQuerySession getOfferingQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  search service. 
     *
     *  @return an <code> OfferingSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingSearch() </code> is <code> true. </code> 
     */

    public org.osid.offering.OfferingSearchSession getOfferingSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  search service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.OfferingSearchSession getOfferingSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  administration service. 
     *
     *  @return an <code> OfferingAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfferingAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingAdmin() </code> is <code> true. </code> 
     */

    public org.osid.offering.OfferingAdminSession getOfferingAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfferingAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.OfferingAdminSession getOfferingAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  notification service. 
     *
     *  @param  offeringReceiver the receiver 
     *  @return an <code> OfferingNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> offeringReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.OfferingNotificationSession getOfferingNotificationSession(org.osid.offering.OfferingReceiver offeringReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the offering 
     *  notification service for the given catalogue. 
     *
     *  @param  offeringReceiver the receiver 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> OfferingNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> offeringReceiver </code> 
     *          or <code> catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.OfferingNotificationSession getOfferingNotificationSessionForCatalogue(org.osid.offering.OfferingReceiver offeringReceiver, 
                                                                                                    org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving offering to catalogue mappings. 
     *
     *  @return an <code> OfferingCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingCatalogue() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingCatalogue() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.OfferingCatalogueSession getOfferingCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning offering to catalogue mappings. 
     *
     *  @return an <code> OfferingCatalogueAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingCatalogueAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingCatalogueAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.OfferingCatalogueAssignmentSession getOfferingCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the offering smart catalogue for the 
     *  given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the catalogue 
     *  @return an <code> OfferingSmartCatalogueSession </code> 
     *  @throws org.osid.NotFoundException <code> catalogueId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfferingSmartCatalogue() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingSmartCatalogue() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.OfferingSmartCatalogueSession getOfferingSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  lookup service. 
     *
     *  @return a <code> ParticipantLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.ParticipantLookupSession getParticipantLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  lookup service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> ParticipantLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ParticipantLookupSession getParticipantLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  query service. 
     *
     *  @return a <code> ParticipantQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.ParticipantQuerySession getParticipantQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  query service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> ParticipantQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ParticipantQuerySession getParticipantQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  search service. 
     *
     *  @return a <code> ParticipantSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.ParticipantSearchSession getParticipantSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  search service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> ParticipantSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ParticipantSearchSession getParticipantSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  administration service. 
     *
     *  @return a <code> ParticipantAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantAdmin() </code> is <code> true. </code> 
     */

    public org.osid.offering.ParticipantAdminSession getParticipantAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> ParticipantAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ParticipantAdminSession getParticipantAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  notification service. 
     *
     *  @param  participantReceiver the receiver 
     *  @return a <code> ParticipantNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> participantReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.ParticipantNotificationSession getParticipantNotificationSession(org.osid.offering.ParticipantReceiver participantReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the participant 
     *  notification service for the given catalogue. 
     *
     *  @param  participantReceiver the receiver 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return a <code> ParticipantNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> participantReceiver 
     *          </code> or <code> catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ParticipantNotificationSession getParticipantNotificationSessionForCatalogue(org.osid.offering.ParticipantReceiver participantReceiver, 
                                                                                                          org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving participant to catalogue mappings. 
     *
     *  @return a <code> ParticipantCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantCatalogue() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantCatalogue() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.ParticipantCatalogueSession getParticipantCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning participant to catalogue mappings. 
     *
     *  @return a <code> ParticipantCatalogueAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantCatalogueAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantCatalogueAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.ParticipantCatalogueAssignmentSession getParticipantCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the participant smart catalogue for 
     *  the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the catalogue 
     *  @return a <code> ParticipantSmartCatalogueSession </code> 
     *  @throws org.osid.NotFoundException <code> catalogueId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsParticipantSmartCatalogue() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsParticipantSmartCatalogue() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.ParticipantSmartCatalogueSession getParticipantSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result lookup 
     *  service. 
     *
     *  @return an <code> ResultLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultLookup() </code> is <code> true. </code> 
     */

    public org.osid.offering.ResultLookupSession getResultLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result lookup 
     *  service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> ResultLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ResultLookupSession getResultLookupSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result query 
     *  service. 
     *
     *  @return an <code> ResultQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.ResultQuerySession getResultQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result query 
     *  service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> ResultQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ResultQuerySession getResultQuerySessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result search 
     *  service. 
     *
     *  @return an <code> ResultSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultSearch() </code> is <code> true. </code> 
     */

    public org.osid.offering.ResultSearchSession getResultSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result search 
     *  service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> ResultSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ResultSearchSession getResultSearchSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result 
     *  administration service. 
     *
     *  @return an <code> ResultAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultAdmin() </code> is <code> true. </code> 
     */

    public org.osid.offering.ResultAdminSession getResultAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result 
     *  administration service for the given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> ResultAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResultAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ResultAdminSession getResultAdminSessionForCatalogue(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result 
     *  notification service. 
     *
     *  @param  resultReceiver the receiver 
     *  @return an <code> ResultNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> resultReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResultNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.ResultNotificationSession getResultNotificationSession(org.osid.offering.ResultReceiver resultReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the result 
     *  notification service for the given catalogue. 
     *
     *  @param  resultReceiver the receiver 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return an <code> ResultNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Catalogue </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> resultReceiver </code> 
     *          or <code> catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResultNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.offering.ResultNotificationSession getResultNotificationSessionForCatalogue(org.osid.offering.ResultReceiver resultReceiver, 
                                                                                                org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving result to catalogue mappings. 
     *
     *  @return an <code> ResultCatalogueSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResultCatalogue() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultCatalogue() </code> is <code> true. </code> 
     */

    public org.osid.offering.ResultCatalogueSession getResultCatalogueSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning result to catalogue mappings. 
     *
     *  @return an <code> ResultCatalogueAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResultCatalogueAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResultCatalogueAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.ResultCatalogueAssignmentSession getResultCatalogueAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the result smart catalogue for the 
     *  given catalogue. 
     *
     *  @param  catalogueId the <code> Id </code> of the catalogue 
     *  @return an <code> ResultSmartCatalogueSession </code> 
     *  @throws org.osid.NotFoundException <code> catalogueId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResultSmartCatalogue() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmenSmarttCatalogue() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.offering.ResultSmartCatalogueSession getResultSmartCatalogueSession(org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalogue 
     *  lookup service. 
     *
     *  @return a <code> CatalogueLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueLookup() </code> is <code> true. </code> 
     */

    public org.osid.offering.CatalogueLookupSession getCatalogueLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalogue 
     *  query service. 
     *
     *  @return a <code> CatalogueQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.CatalogueQuerySession getCatalogueQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalogue 
     *  search service. 
     *
     *  @return a <code> CatalogueSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueSearch() </code> is <code> true. </code> 
     */

    public org.osid.offering.CatalogueSearchSession getCatalogueSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalogue 
     *  administrative service. 
     *
     *  @return a <code> CatalogueAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueAdmin() </code> is <code> true. </code> 
     */

    public org.osid.offering.CatalogueAdminSession getCatalogueAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalogue 
     *  notification service. 
     *
     *  @param  catalogueReceiver the receiver 
     *  @return a <code> CatalogueNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CatalogueNotificationSession getCatalogueNotificationSession(org.osid.offering.CatalogueReceiver catalogueReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalogue 
     *  hierarchy service. 
     *
     *  @return a <code> CatalogueHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CatalogueHierarchySession getCatalogueHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the catalogue 
     *  hierarchy design service. 
     *
     *  @return a <code> CatalogueHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CatalogueHierarchyDesignSession getCatalogueHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> OfferingBatchManager. </code> 
     *
     *  @return a <code> OfferingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfferingBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingBatch() </code> is <code> true. </code> 
     */

    public org.osid.offering.batch.OfferingBatchManager getOfferingBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> OfferingRulesManager. </code> 
     *
     *  @return a <code> OfferingRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfferingRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfferingRules() </code> is <code> true. </code> 
     */

    public org.osid.offering.rules.OfferingRulesManager getOfferingRulesManager()
        throws org.osid.OperationFailedException;
}
