//
// org.osid.offering.batch.ResultBatchAdminSession
//
//     The OSID Java specification for org.osid.offering.batch.ResultBatchAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Results </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Result, </code> a <code> ResultForm </code> is requested using <code> 
 *  getResultFormsForCreate() </code> specifying the desired participant, and 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. Each of the returned <code> ResultForms </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once a <code> ResultForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ResultForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ResultForms </code> returned from <code> 
 *  getResultFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> ResultForm. </code> In 
 *  the case where there may be duplicates, any <code> ResultForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ResultForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> ResultForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createResults(), 
 *  </code> errors specific to an individual <code> ResultForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> ResultForm 
 *  </code> through the <code> ResultForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ResultForms </code> are requested to the <code> 
 *  Result </code> <code> Id </code> that is to be updated using <code> 
 *  getResultFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> ResultForm </code> may be used to link the request. Similarly, 
 *  the <code> ResultForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> ResultForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ResultForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> ResultForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateResults(), 
 *  </code> errors specific to an individual <code> ResultForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> ResultForm 
 *  </code> through the <code> ResultForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Results </code> in bulk. To unmap 
 *  a <code> Result </code> from the current <code> Catalogue, </code> the 
 *  <code> ResultCatalogueAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Result </code> itself thus 
 *  removing it from all known <code> Catalogue </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface ResultBatchAdminSession
    extends org.osid.offering.ResultAdminSession {


    /**
     *  Gets the result forms for creating a bunch of new results. A form is 
     *  returned for each participant. 
     *
     *  @param  participantIds a list of participants 
     *  @param  resultRecordTypes array of result record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the result forms 
     *  @throws org.osid.NotFoundException a <code> participantId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> participantIds </code> 
     *          or <code> resultRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.batch.ResultBatchFormList getResultFormsForCreate(org.osid.id.IdList participantIds, 
                                                                               org.osid.type.Type[] resultRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Results. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  resultForms the result forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> resultForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createResults(org.osid.offering.batch.ResultBatchFormList resultForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the result forms for updating an existing set of results. A new 
     *  result form should be requested for each update transaction. 
     *
     *  @param  resultIds the <code> Ids </code> of the <code> Result </code> 
     *  @return the result form 
     *  @throws org.osid.NotFoundException a <code> resultId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resultIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.batch.ResultBatchFormList getResultFormsForUpdate(org.osid.id.IdList resultIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing results. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  resultForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> resultForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateResults(org.osid.offering.batch.ResultBatchFormList resultForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Results </code> in this <code> Catalogue </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllResults()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes results for the given <code> Ids. </code> 
     *
     *  @param  resultIds the <code> Ids </code> of the results to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resultIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteResults(org.osid.id.IdList resultIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes results for the given participant. 
     *
     *  @param  participantId an <code> Id </code> of a participant 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> participantId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteResultsForParticipant(org.osid.id.Id participantId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Result </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Result </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another result, it is reassigned to the given result 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasResults(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
