//
// org.osid.offering.rules.CanonicalUnitEnablerAdminSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitEnablerAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session creates and removes canonical unit enablers. The data for 
 *  create and update is provided via the <code> CanonicalUnitEnablerForm. 
 *  </code> </p>
 */

public interface CanonicalUnitEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create canonical unit enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> CanonicalUnitEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCanonicalUnitEnabler();


    /**
     *  Tests if this user can create a single <code> CanonicalUnitEnabler 
     *  </code> using the desired record types. While <code> 
     *  OfferingRulesManager.getCanonicalUnitEnablerRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  CanonicalUnitEnabler. </code> Providing an empty array tests if a 
     *  <code> CanonicalUnitEnabler </code> can be created with no records. 
     *
     *  @param  canonicalUnitEnablerRecordTypes array of canonical unit 
     *          enabler record types 
     *  @return <code> true </code> if <code> CanonicalUnitEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCanonicalUnitEnablerWithRecordTypes(org.osid.type.Type[] canonicalUnitEnablerRecordTypes);


    /**
     *  Gets the canonical unit enabler form for creating new canonical unit 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  canonicalUnitEnablerRecordTypes array of canonical unit 
     *          enabler record types 
     *  @return the canonical unit enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerForm getCanonicalUnitEnablerFormForCreate(org.osid.type.Type[] canonicalUnitEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CanonicalUnitEnabler. </code> 
     *
     *  @param  canonicalUnitEnablerForm the form for this <code> 
     *          CanonicalUnitEnabler </code> 
     *  @return the new <code> CanonicalUnitEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> canonicalUnitEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> canonicalUnitEnablerForm 
     *          did not originate from getCanonicalUnitEnablerFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitEnabler createCanonicalUnitEnabler(org.osid.offering.rules.CanonicalUnitEnablerForm canonicalUnitEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update canonical unit enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> CanonicalUnitEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCanonicalUnitEnablers();


    /**
     *  Gets the canonical unit enabler form for updating an existing 
     *  canonical unit enabler. A new canonical unit enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  canonicalUnitEnablerId the <code> Id </code> of the <code> 
     *          CanonicalUnitEnabler </code> 
     *  @return the canonical unit enabler form 
     *  @throws org.osid.NotFoundException <code> canonicalUnitEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitEnablerForm getCanonicalUnitEnablerFormForUpdate(org.osid.id.Id canonicalUnitEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing canonical unit enabler. 
     *
     *  @param  canonicalUnitEnablerForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> canonicalUnitEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> canonicalUnitEnablerForm 
     *          </code> did not originate from <code> 
     *          getCanonicalUnitEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCanonicalUnitEnabler(org.osid.offering.rules.CanonicalUnitEnablerForm canonicalUnitEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete canonical unit enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> CanonicalUnitEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCanonicalUnitEnablers();


    /**
     *  Deletes a <code> CanonicalUnitEnabler. </code> 
     *
     *  @param  canonicalUnitEnablerId the <code> Id </code> of the <code> 
     *          CanonicalUnitEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> canonicalUnitEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCanonicalUnitEnabler(org.osid.id.Id canonicalUnitEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for canonical 
     *  unit enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCanonicalUnitEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CanonicalUnitEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> CanonicalUnitEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  canonical unit enabler. it is reassigned to the given canonical unit 
     *  enabler <code> Id. </code> 
     *
     *  @param  canonicalUnitEnablerId the <code> Id </code> of a <code> 
     *          CanonicalUnitEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> canonicalUnitEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCanonicalUnitEnabler(org.osid.id.Id canonicalUnitEnablerId, 
                                          org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
