//
// org.osid.offering.rules.CanonicalUnitEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitEnablerRuleApplicationSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods to apply <code> CanonicalUnitEnablers 
 *  </code> to <code> CanonicalUnits. </code> A <code> CanonicalUnit </code> 
 *  with multiple <code> CanonicalUnitEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an active <code> CanonicalUnit. 
 *  </code> </p>
 */

public interface CanonicalUnitEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter canonical unit enabler/canonical unit 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCanonicalUnitEnablers();


    /**
     *  Adds an existing <code> CanonicalUnitEnabler </code> to a <code> 
     *  CanonicalUnit. </code> 
     *
     *  @param  canonicalUnitEnablerId the <code> Id </code> of the <code> 
     *          CanonicalUnitEnabler </code> 
     *  @param  canonicalUnitId the <code> Id </code> of the <code> 
     *          CanonicalUnit </code> 
     *  @throws org.osid.AlreadyExistsException <code> canonicalUnitEnablerId 
     *          </code> already applied to <code> canonicalUnitId </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitEnablerId 
     *          </code> or <code> canonicalUnitId </code> not found 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerId 
     *          </code> or <code> canonicalUnitId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCanonicalUnitEnablerToCanonicalUnit(org.osid.id.Id canonicalUnitEnablerId, 
                                                          org.osid.id.Id canonicalUnitId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CanonicalUnitEnabler </code> from a <code> 
     *  CanonicalUnit. </code> 
     *
     *  @param  canonicalUnitEnablerId the <code> Id </code> of the <code> 
     *          CanonicalUnitEnabler </code> 
     *  @param  canonicalUnitId the <code> Id </code> of the <code> 
     *          CanonicalUnit </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitEnablerId 
     *          </code> or <code> canonicalUnitId </code> not found or <code> 
     *          canonicalUnitEnablerId </code> not applied to <code> 
     *          canonicalUnitId </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerId 
     *          </code> or <code> canonicalUnitId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCanonicalUnitEnablerFromCanonicalUnit(org.osid.id.Id canonicalUnitEnablerId, 
                                                              org.osid.id.Id canonicalUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> CanonicalUnitEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CanonicalUnitEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceCanonicalUnitEnablers();


    /**
     *  Reorders canonical unit enablers for a canonical unit by moving the 
     *  specified canonical unit enabler in front of a reference canonical 
     *  unit enabler. 
     *
     *  @param  canonicalUnitEnablerId the <code> Id </code> of a <code> 
     *          CanonicalUnitEnabler </code> 
     *  @param  canonicalUnitId the <code> Id </code> of a <code> 
     *          CanonicalUnit </code> 
     *  @param  referenceId the reference canonical unit enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitEnablerId, 
     *          canonicalUnitId, </code> or <code> referenceId </code> not 
     *          found or, <code> canonicalUnitEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> canonicalUnitId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerId, 
     *          canonicalUnitId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCanonicalUnitEnablerAhead(org.osid.id.Id canonicalUnitEnablerId, 
                                              org.osid.id.Id canonicalUnitId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders canonical unit enablers for a canonical unit by moving the 
     *  specified canonical unit enabler behind a reference canonical unit 
     *  enabler. 
     *
     *  @param  canonicalUnitEnablerId the <code> Id </code> of a <code> 
     *          CanonicalUnitEnabler </code> 
     *  @param  canonicalUnitId the <code> Id </code> of a <code> 
     *          CanonicalUnit </code> 
     *  @param  referenceId the reference canonical unit enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitEnablerId, 
     *          canonicalUnitId, </code> or <code> referenceId </code> not 
     *          found or, <code> canonicalUnitEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> canonicalUnitId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerId, 
     *          canonicalUnitId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCanonicalUnitEnablerBehind(org.osid.id.Id canonicalUnitEnablerId, 
                                               org.osid.id.Id canonicalUnitId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of canonical unit enablers for a canonical unit. 
     *
     *  @param  canonicalUnitEnablerIds the <code> Ids </code> for a set of 
     *          <code> CanonicalUnitEnablers </code> 
     *  @param  canonicalUnitId the <code> Id </code> of a <code> 
     *          CanonicalUnit </code> 
     *  @throws org.osid.NotFoundException <code> canonicalUnitConstraienrId 
     *          </code> not found or, a <code> canonicalUnitEnablerId </code> 
     *          not related to <code> canonicalUnitId </code> 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitEnablerIds 
     *          </code> or <code> canonicalUnitId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderCanonicalUnitEnablers(org.osid.id.Id[] canonicalUnitEnablerIds, 
                                           org.osid.id.Id canonicalUnitId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
