//
// org.osid.offering.rules.CanonicalUnitProcessorEnablerSmartCatalogueSession
//
//     The OSID Java specification for org.osid.offering.rules.CanonicalUnitProcessorEnablerSmartCatalogueSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogues. A <code> CanonicalUnitProcessorEnablerQuery </code> can be 
 *  retrieved from this session and mapped to this <code> Catalogue </code> to 
 *  create a virtual collection of canonical unit processor enablers. The 
 *  canonical unit processor enablers may be sequenced using the <code> 
 *  CanonicalUnitProcessorEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Catalogue </code> has a default query that matches any 
 *  canonical unit processor enabler and a default search order that specifies 
 *  no sequencing. The queries may be examined using a <code> 
 *  CanonicalUnitProcessorEnablerQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to a <code> 
 *  CanonicalUnitProcessorEnablerQuery. </code> </p>
 */

public interface CanonicalUnitProcessorEnablerSmartCatalogueSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart catalogues. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart catalogue management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCatalogues();


    /**
     *  Gets a canonical unit processor enabler query. 
     *
     *  @return the canonical unit processor enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerQuery getCanonicalUnitProcessorEnablerQuery();


    /**
     *  Gets a canonical unit processor enabler search order. 
     *
     *  @return the canonical unit processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchOrder getCanonicalUnitProcessorEnablerSearchOrder();


    /**
     *  Applies a canonical unit processor enabler query to this catalogue. 
     *
     *  @param  canonicalUnitProcessorEnablerQuery the canonical unit 
     *          processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerQuery </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerQuery </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCanonicalUnitProcessorEnablerQuery(org.osid.offering.rules.CanonicalUnitProcessorEnablerQuery canonicalUnitProcessorEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit processor enabler query inspector for this 
     *  catalogue. 
     *
     *  @return the canonical unit processor enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerQueryInspector inspectCanonicalUnitProcessorEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a canonical unit processor enabler search order to this 
     *  catalogue. 
     *
     *  @param  canonicalUnitProcessorEnablerSearchOrder the canonical unit 
     *          processor enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerSearchOrder </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerSearchOrder </code> not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCanonicalUnitProcessorEnablerSequencing(org.osid.offering.rules.CanonicalUnitProcessorEnablerSearchOrder canonicalUnitProcessorEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a canonical unit processor enabler query from an inspector. 
     *
     *  @param  canonicalUnitProcessorEnablerQueryInspector a canonical unit 
     *          processor enabler query inspector 
     *  @return the canonical unit processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerQueryInspector </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          canonicalUnitProcessorEnablerQueryInspector </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.CanonicalUnitProcessorEnablerQuery getCanonicalUnitProcessorEnablerQueryFromInspector(org.osid.offering.rules.CanonicalUnitProcessorEnablerQueryInspector canonicalUnitProcessorEnablerQueryInspector);
}
