//
// org.osid.offering.rules.OfferingConstrainer
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainer.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>An <code> OfferingConstrainer </code> describes the rules for 
 *  constraining the bids in a canonical unit. </p>
 */

public interface OfferingConstrainer
    extends org.osid.OsidConstrainer {


    /**
     *  Tests if the description can be overridden at offering. 
     *
     *  @return <code> true </code> if the description can be overridden, 
     *          <code> false </code> if constrained 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOverrideDescription();


    /**
     *  Tests if the title can be overridden at offering. 
     *
     *  @return <code> true </code> if the title can be overridden, <code> 
     *          false </code> if constrained 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOverrideTitle();


    /**
     *  Tests if the code can be overridden at offering. 
     *
     *  @return <code> true </code> if the code can be overridden, <code> 
     *          false </code> if constrained 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOverrideCode();


    /**
     *  Tests if the offerings can be made outside the specified time period 
     *  cycles. 
     *
     *  @return <code> true </code> if the time period cycles can be 
     *          overridden, <code> false </code> if constrained 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOverrideTimePeriods();


    /**
     *  Tests if offerings in all specified time periods are optional. 
     *
     *  @return <code> true </code> if the time period cycles can be optional, 
     *          <code> false </code> if constrained 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canConstrainTimePeriods();


    /**
     *  Tests if the result options can be overridden at offering. 
     *
     *  @return <code> true </code> if the result options can be overridden, 
     *          <code> false </code> if constrained 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOverrideResultOptions();


    /**
     *  Tests if the offering result options can be a subset of the canonical 
     *  set. 
     *
     *  @return <code> true </code> if the result options can be a subset, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canConstrainResultOptions();


    /**
     *  Tests if the sponsors can be overridden at offering. 
     *
     *  @return <code> true </code> if the sponsors can be overridden, <code> 
     *          false </code> if constrained 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOverrideSponsors();


    /**
     *  Tests if the offering sponsors can be a subset of the canonical set. 
     *
     *  @return <code> true </code> if the sponsors can be a subset, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canConstrainSponsors();


    /**
     *  Gets the offering constrainer record corresponding to the given <code> 
     *  OfferingConstrainer </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> offeringConstrainerRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(offeringConstrainerRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  offeringConstrainerRecordType the type of offering constrainer 
     *          record to retrieve 
     *  @return the offering constrainer record 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offeringConstrainerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.records.OfferingConstrainerRecord getOfferingConstrainerRecord(org.osid.type.Type offeringConstrainerRecordType)
        throws org.osid.OperationFailedException;
}
