//
// org.osid.offering.rules.OfferingConstrainerCatalogueAssignmentSession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerCatalogueAssignmentSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods to re-assign <code> OfferingConstrainer 
 *  </code> to <code> Catalogue </code> mappings. An <code> 
 *  OfferingConstrainer </code> may appear in multiple <code> Catalogue 
 *  </code> objects and removing the last reference to an <code> 
 *  OfferingConstrainer </code> is the equivalent of deleting it. Each <code> 
 *  Catalogue </code> may have its own authorizations governing who is allowed 
 *  to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> OfferingConstrainer </code> to another 
 *  <code> Catalogue </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface OfferingConstrainerCatalogueAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter offering constrainer/catalogue mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignOfferingConstrainers();


    /**
     *  Tests if this user can alter offering constrainer/catalogue mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignOfferingConstrainersToCatalogue(org.osid.id.Id catalogueId);


    /**
     *  Gets a list of catalogues including and under the given catalogue node 
     *  in which any offering constrainer can be assigned. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @return list of assignable catalogue <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCatalogueIds(org.osid.id.Id catalogueId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of catalogues including and under the given catalogue node 
     *  in which a specific offering constrainer can be assigned. 
     *
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @param  offeringConstrainerId the <code> Id </code> of the <code> 
     *          OfferingConstrainer </code> 
     *  @return list of assignable catalogue <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> or 
     *          <code> offeringConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableCatalogueIdsForOfferingConstrainer(org.osid.id.Id catalogueId, 
                                                                              org.osid.id.Id offeringConstrainerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> OfferingConstrainer </code> to a <code> 
     *  Catalogue. </code> 
     *
     *  @param  offeringConstrainerId the <code> Id </code> of the <code> 
     *          OfferingConstrainer </code> 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> offeringConstrainerId 
     *          </code> already assigned to <code> catalogueId </code> 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerId 
     *          </code> or <code> catalogueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> offeringConstrainerId 
     *          </code> or <code> catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignOfferingConstrainerToCatalogue(org.osid.id.Id offeringConstrainerId, 
                                                     org.osid.id.Id catalogueId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> OfferingConstrainer </code> from a <code> Catalogue. 
     *  </code> 
     *
     *  @param  offeringConstrainerId the <code> Id </code> of the <code> 
     *          OfferingConstrainer </code> 
     *  @param  catalogueId the <code> Id </code> of the <code> Catalogue 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerId 
     *          </code> or <code> catalogueId </code> not found or <code> 
     *          offeringConstrainerId </code> already assigned to <code> 
     *          catalogueId </code> 
     *  @throws org.osid.NullArgumentException <code> offeringConstrainerId 
     *          </code> or <code> catalogueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignOfferingConstrainerFromCatalogue(org.osid.id.Id offeringConstrainerId, 
                                                         org.osid.id.Id catalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves an <code> OfferingConstrainer </code> from one <code> Catalogue 
     *  </code> to another. Mappings to other <code> Catalogues </code> are 
     *  unaffected. 
     *
     *  @param  offeringConstrainerId the <code> Id </code> of the <code> 
     *          OfferingConstrainer </code> 
     *  @param  fromCatalogueId the <code> Id </code> of the current <code> 
     *          Catalogue </code> 
     *  @param  toCatalogueId the <code> Id </code> of the destination <code> 
     *          Catalogue </code> 
     *  @throws org.osid.NotFoundException <code> offeringConstraienrId, 
     *          fromCatalogueId, </code> or <code> toCatalogueId </code> not 
     *          found or <code> offeringConstrainerId, </code> not mapped to 
     *          <code> fromCatalogueId </code> 
     *  @throws org.osid.NullArgumentException <code> offeringConstrainerId, 
     *          fromCatalogueId, </code> or <code> toCatalogueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignOfferingConstrainerToCatalogue(org.osid.id.Id offeringConstrainerId, 
                                                       org.osid.id.Id fromCatalogueId, 
                                                       org.osid.id.Id toCatalogueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
