//
// org.osid.offering.rules.OfferingConstrainerEnablerAdminSession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerEnablerAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session creates and removes offering constrainer enablers. The 
 *  data for create and update is provided via the <code> 
 *  OfferingConstrainerEnablerForm. </code> </p>
 */

public interface OfferingConstrainerEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create offering constrainer enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> 
     *  OfferingConstrainerEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> OfferingConstrainerEnabler 
     *          </code> creation is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateOfferingConstrainerEnabler();


    /**
     *  Tests if this user can create a single <code> 
     *  OfferingConstrainerEnabler </code> using the desired record types. 
     *  While <code> 
     *  OfferingRulesManager.getOfferingConstrainerEnablerRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> OfferingConstrainerEnabler. </code> Providing an empty array 
     *  tests if an <code> OfferingConstrainerEnabler </code> can be created 
     *  with no records. 
     *
     *  @param  offeringConstrainerEnablerRecordTypes array of offering 
     *          constrainer enabler record types 
     *  @return <code> true </code> if <code> OfferingConstrainerEnabler 
     *          </code> creation using the specified record <code> Types 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateOfferingConstrainerEnablerWithRecordTypes(org.osid.type.Type[] offeringConstrainerEnablerRecordTypes);


    /**
     *  Gets the offering constrainer enabler form for creating new offering 
     *  constrainer enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  offeringConstrainerEnablerRecordTypes array of offering 
     *          constrainer enabler record types 
     *  @return the offering constrainer enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerForm getOfferingConstrainerEnablerFormForCreate(org.osid.type.Type[] offeringConstrainerEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> OfferingConstrainerEnabler. </code> 
     *
     *  @param  offeringConstrainerEnablerForm the form for this <code> 
     *          OfferingConstrainerEnabler </code> 
     *  @return the new <code> OfferingConstrainerEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          offeringConstrainerEnablerForm </code> already used in a 
     *          create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerForm did not originate from 
     *          getOfferingConstrainerEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnabler createOfferingConstrainerEnabler(org.osid.offering.rules.OfferingConstrainerEnablerForm offeringConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update offering constrainer enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> 
     *  OfferingConstrainerEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> OfferingConstrainerEnabler 
     *          </code> modification is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateOfferingConstrainerEnablers();


    /**
     *  Gets the offering constrainer enabler form for updating an existing 
     *  offering constrainer enabler. A new offering constrainer enabler form 
     *  should be requested for each update transaction. 
     *
     *  @param  offeringConstrainerEnablerId the <code> Id </code> of the 
     *          <code> OfferingConstrainerEnabler </code> 
     *  @return the offering constrainer enabler form 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerForm getOfferingConstrainerEnablerFormForUpdate(org.osid.id.Id offeringConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing offering constrainer enabler. 
     *
     *  @param  offeringConstrainerEnablerForm the form containing the 
     *          elements to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          offeringConstrainerEnablerForm </code> already used in an 
     *          update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerForm </code> did not originate from 
     *          <code> getOfferingConstrainerEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateOfferingConstrainerEnabler(org.osid.offering.rules.OfferingConstrainerEnablerForm offeringConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete offering constrainer enablers. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> 
     *  OfferingConstrainerEnabler </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> OfferingConstrainerEnabler 
     *          </code> deletion is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteOfferingConstrainerEnablers();


    /**
     *  Deletes an <code> OfferingConstrainerEnabler. </code> 
     *
     *  @param  offeringConstrainerEnablerId the <code> Id </code> of the 
     *          <code> OfferingConstrainerEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteOfferingConstrainerEnabler(org.osid.id.Id offeringConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for offering 
     *  constrainer enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> OfferingConstrainerEnabler 
     *          </code> aliasing is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageOfferingConstrainerEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> OfferingConstrainerEnabler 
     *  </code> for the purpose of creating compatibility. The primary <code> 
     *  Id </code> of the <code> OfferingConstrainerEnabler </code> is 
     *  determined by the provider. The new <code> Id </code> performs as an 
     *  alias to the primary <code> Id </code> . If the alias is a pointer to 
     *  another offering constrainer enabler. it is reassigned to the given 
     *  offering constrainer enabler <code> Id. </code> 
     *
     *  @param  offeringConstrainerEnablerId the <code> Id </code> of an 
     *          <code> OfferingConstrainerEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerId </code> or <code> aliasId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasOfferingConstrainerEnabler(org.osid.id.Id offeringConstrainerEnablerId, 
                                                org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
