//
// org.osid.offering.rules.OfferingConstrainerEnablerSmartCatalogueSession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerEnablerSmartCatalogueSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogues. An <code> OfferingConstrainerEnablerQuery </code> can be 
 *  retrieved from this session and mapped to this <code> Catalogue </code> to 
 *  create a virtual collection of offering constrainer enablers. The offering 
 *  constrainer enablers may be sequenced using the <code> 
 *  OfferingConstrainerEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Catalogue </code> has a default query that matches any 
 *  offering constrainer enabler and a default search order that specifies no 
 *  sequencing. The queries may be examined using an <code> 
 *  OfferingConstrainerEnablerQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to an <code> 
 *  OfferingConstrainerEnablerQuery. </code> </p>
 */

public interface OfferingConstrainerEnablerSmartCatalogueSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart catalogues. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart catalogue management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCatalogues();


    /**
     *  Gets an offering constrainer enabler query. 
     *
     *  @return the offering constrainer enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerQuery getOfferingConstrainerEnablerQuery();


    /**
     *  Gets an offering constrainer enabler search order. 
     *
     *  @return the offering constrainer enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerSearchOrder getOfferingConstrainerEnablerSearchOrder();


    /**
     *  Applies an offering constrainer enabler query to this catalogue. 
     *
     *  @param  offeringConstrainerEnablerQuery the offering constrainer 
     *          enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerQuery </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyOfferingConstrainerEnablerQuery(org.osid.offering.rules.OfferingConstrainerEnablerQuery offeringConstrainerEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offering constrainer enabler query inspector for this 
     *  catalogue. 
     *
     *  @return the offering constrainer enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerQueryInspector inspectOfferingConstrainerEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an offering constrainer enabler search order to this 
     *  catalogue. 
     *
     *  @param  offeringConstrainerEnablerSearchOrder the offering constrainer 
     *          enabler search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerSearchOrder </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerSearchOrder </code> not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyOfferingConstrainerEnablerSequencing(org.osid.offering.rules.OfferingConstrainerEnablerSearchOrder offeringConstrainerEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an offering constrainer enabler query from an inspector. 
     *
     *  @param  offeringConstrainerEnablerQueryInspector an offering 
     *          constrainer enabler query inspector 
     *  @return the offering constrainer enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerQueryInspector </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          offeringConstrainerEnablerQueryInspector </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerEnablerQuery getOfferingConstrainerEnablerQueryFromInspector(org.osid.offering.rules.OfferingConstrainerEnablerQueryInspector offeringConstrainerEnablerQueryInspector);
}
