//
// org.osid.offering.rules.OfferingConstrainerForm
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerForm.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This is the form for creating and updating <code> OfferingConstrainers. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  OfferingConstrainerAdminSession. </code> For each data element that may be 
 *  set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface OfferingConstrainerForm
    extends org.osid.OsidConstrainerForm {


    /**
     *  Gets the metadata for the override description flag. 
     *
     *  @return metadata for the override description flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOverrideDescriptionMetadata();


    /**
     *  Sets the overrride description flag. 
     *
     *  @param  overrideDescription the override description flag 
     *  @throws org.osid.InvalidArgumentException <code> overrideDescription 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOverrideDescription(boolean overrideDescription);


    /**
     *  Clears the override description flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideDescription();


    /**
     *  Gets the metadata for the override title flag. 
     *
     *  @return metadata for the override title flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOverrideTitleMetadata();


    /**
     *  Sets the overrride title flag. 
     *
     *  @param  overrideTitle the override title flag 
     *  @throws org.osid.InvalidArgumentException <code> overrideTitlen 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOverrideTitle(boolean overrideTitle);


    /**
     *  Clears the override title flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideTitle();


    /**
     *  Gets the metadata for the override code flag. 
     *
     *  @return metadata for the override code flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOverrideCodeMetadata();


    /**
     *  Sets the overrride code flag. 
     *
     *  @param  overrideCode the override code flag 
     *  @throws org.osid.InvalidArgumentException <code> overrideCode </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOverrideCode(boolean overrideCode);


    /**
     *  Clears the override time periods flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideCode();


    /**
     *  Gets the metadata for the override time periods flag. 
     *
     *  @return metadata for the override time periods flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOverrideTimePeriodsMetadata();


    /**
     *  Sets the overrride time periods flag. 
     *
     *  @param  overrideTimePeriods the override time periods flag 
     *  @throws org.osid.InvalidArgumentException <code> overrideTimePeriods 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOverrideTimePeriods(boolean overrideTimePeriods);


    /**
     *  Clears the override time periods flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideTimePeriods();


    /**
     *  Gets the metadata for the constrain time periods flag. 
     *
     *  @return metadata for the constrain time periods flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getConstrainTimePeriodsMetadata();


    /**
     *  Sets the constrain time periods flag. 
     *
     *  @param  constrainTimePeriods the constrain time periods flag 
     *  @throws org.osid.InvalidArgumentException <code> constrainTimePeriods 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setConstrainTimePeriods(boolean constrainTimePeriods);


    /**
     *  Clears the constrain time periods flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConstrainTimePeriods();


    /**
     *  Gets the metadata for the override result options flag. 
     *
     *  @return metadata for the override result options flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOverrideResultOptionsMetadata();


    /**
     *  Sets the overrride result options flag. 
     *
     *  @param  overrideResultOptions the override result options flag 
     *  @throws org.osid.InvalidArgumentException <code> overrideResultOptions 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOverrideResultOptions(boolean overrideResultOptions);


    /**
     *  Clears the override result options flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultOptions();


    /**
     *  Gets the metadata for the constrain result options flag. 
     *
     *  @return metadata for the constrain result options flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getConstrainResultOptionsMetadata();


    /**
     *  Sets the constrain result options flag. 
     *
     *  @param  constrainResultOptions the constrain result options flag 
     *  @throws org.osid.InvalidArgumentException <code> 
     *          constrainResultOptions </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setConstrainResultOptions(boolean constrainResultOptions);


    /**
     *  Clears the constrain result options flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConstrainResultOptions();


    /**
     *  Gets the metadata for the override sponsors flag. 
     *
     *  @return metadata for the override sponsors flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getOverrideSponsorsMetadata();


    /**
     *  Sets the overrride sponsors flag. 
     *
     *  @param  overrideSponsors the override sponsors flag 
     *  @throws org.osid.InvalidArgumentException <code> overrideSponsors 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setOverrideSponsors(boolean overrideSponsors);


    /**
     *  Clears the override sponsors flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSponsors();


    /**
     *  Gets the metadata for the constrain sponsors flag. 
     *
     *  @return metadata for the constrain sponsors flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getConstrainSponsorsMetadata();


    /**
     *  Sets the constrain sponsors flag. 
     *
     *  @param  constrainSponsors the constrain sponsors flag 
     *  @throws org.osid.InvalidArgumentException <code> constrainSponsors 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setConstrainSponsors(boolean constrainSponsors);


    /**
     *  Clears the constrain sponsors flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConstrainSponsors();


    /**
     *  Gets the <code> OfferingConstrainerFormRecord </code> corresponding to 
     *  the given offering constrainer record <code> Type. </code> 
     *
     *  @param  offeringConstrainerRecordType an offering constrainer record 
     *          type 
     *  @return the offering constrainer form record 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offeringConstrainerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.records.OfferingConstrainerFormRecord getOfferingConstrainerFormRecord(org.osid.type.Type offeringConstrainerRecordType)
        throws org.osid.OperationFailedException;
}
