//
// org.osid.offering.rules.OfferingConstrainerLookupSession
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerLookupSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  OfferingConstrainers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated catalogue view: All offering constrainer methods in this 
 *      session operate, retrieve and pertain to offering constrainer defined 
 *      explicitly in the current catalogue. Using an isolated view is useful 
 *      for managing <code> OfferingConstrainers </code> with the <code> 
 *      OfferingConstrainerAdminSession. </code> </li> 
 *      <li> federated catalogue view: All offering constrainer methods in 
 *      this session operate, retrieve and pertain to all offering constrainer 
 *      defined in this catalogue and any other offering constrainer 
 *      implicitly available in this catalogue through catalogue inheritence. 
 *      </li> 
 *      <li> active offering constrainer view: All offering constrainer lookup 
 *      methods return active offering constrainers. </li> 
 *      <li> any status offering constrainer view: CanonicalUnit constrainers 
 *      of any active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface OfferingConstrainerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Catalogue </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Catalogue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCatalogueId();


    /**
     *  Gets the <code> Catalogue </code> associated with this session. 
     *
     *  @return the catalogue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.Catalogue getCatalogue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> OfferingConstrainers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupOfferingConstrainers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeOfferingConstrainerView();


    /**
     *  A complete view of the <code> OfferingConstrainer </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryOfferingConstrainerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include offering constrainer in catalogues which are children of this 
     *  catalogue in the catalogue hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCatalogueView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this catalogue only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCatalogueView();


    /**
     *  Only active offering constrainers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveOfferingConstrainerView();


    /**
     *  All active and inactive offering constrainers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusOfferingConstrainerView();


    /**
     *  Gets the <code> OfferingConstrainer </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  OfferingConstrainer </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to an <code> OfferingConstrainer </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, offering constrainers are returned that are currently 
     *  active. In any status mode, active and inactive offering constrainers 
     *  are returned. 
     *
     *  @param  offeringConstrainerId <code> Id </code> of the <code> 
     *          OfferingConstrainer </code> 
     *  @return the offering constrainer 
     *  @throws org.osid.NotFoundException <code> offeringConstrainerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> offeringConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainer getOfferingConstrainer(org.osid.id.Id offeringConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingConstrainerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  offering constrainer specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> OfferingConstrainers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, offering constrainers are returned that are currently 
     *  active. In any status mode, active and inactive offering constrainers 
     *  are returned. 
     *
     *  @param  offeringConstrainerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> OfferingConstrainer </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> offeringConstrainerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerList getOfferingConstrainersByIds(org.osid.id.IdList offeringConstrainerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingConstrainerList </code> corresponding to the 
     *  given offering constrainer genus <code> Type </code> which does not 
     *  include offering constrainer of genus types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offering constrainer or an error results. Otherwise, the returned list 
     *  may contain only those offering constrainer that are accessible 
     *  through this session. 
     *  
     *  In active mode, offering constrainers are returned that are currently 
     *  active. In any status mode, active and inactive offering constrainers 
     *  are returned. 
     *
     *  @param  offeringConstrainerGenusType an offering constrainer genus 
     *          type 
     *  @return the returned <code> OfferingConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerList getOfferingConstrainersByGenusType(org.osid.type.Type offeringConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingConstrainerList </code> corresponding to the 
     *  given offering constrainer genus <code> Type </code> and include any 
     *  additional offering constrainer with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offering constrainer or an error results. Otherwise, the returned list 
     *  may contain only those offering constrainer that are accessible 
     *  through this session. 
     *  
     *  In active mode, offering constrainers are returned that are currently 
     *  active. In any status mode, active and inactive offering constrainers 
     *  are returned. 
     *
     *  @param  offeringConstrainerGenusType an offering constrainer genus 
     *          type 
     *  @return the returned <code> OfferingConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerList getOfferingConstrainersByParentGenusType(org.osid.type.Type offeringConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OfferingConstrainerList </code> containing the given 
     *  offering constrainer record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  offering constrainer or an error results. Otherwise, the returned list 
     *  may contain only those offering constrainer that are accessible 
     *  through this session. 
     *  
     *  In active mode, offering constrainers are returned that are currently 
     *  active. In any status mode, active and inactive offering constrainers 
     *  are returned. 
     *
     *  @param  offeringConstrainerRecordType an offering constrainer record 
     *          type 
     *  @return the returned <code> OfferingConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerList getOfferingConstrainersByRecordType(org.osid.type.Type offeringConstrainerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> OfferingConstrainers. </code> 
     *  
     *  In plenary mode, the returned list contains all known offering 
     *  constrainer or an error results. Otherwise, the returned list may 
     *  contain only those offering constrainer that are accessible through 
     *  this session. 
     *  
     *  In active mode, offering constrainers are returned that are currently 
     *  active. In any status mode, active and inactive offering constrainers 
     *  are returned. 
     *
     *  @return the returned <code> OfferingConstrainer </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.OfferingConstrainerList getOfferingConstrainers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
