//
// org.osid.offering.rules.OfferingConstrainerQuery
//
//     The OSID Java specification for org.osid.offering.rules.OfferingConstrainerQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>This is the query for searching offering constrainers. Each method 
 *  match specifies an <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface OfferingConstrainerQuery
    extends org.osid.OsidConstrainerQuery {


    /**
     *  Matches mapped to the canonical unit. 
     *
     *  @param  canonicalUnitId the canonical unit <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> canonicalUnitId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledCanonicalUnitId(org.osid.id.Id canonicalUnitId, 
                                          boolean match);


    /**
     *  Clears the canonical unit <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCanonicalUnitIdTerms();


    /**
     *  Tests if an <code> CanonicalUnitQuery </code> is available. 
     *
     *  @return <code> true </code> if a canonical unit query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledCanonicalUnitQuery();


    /**
     *  Gets the query for a canonical unit. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the canonical unit query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledCanonicalUnitQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledCanonicalUnitQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.offering.CanonicalUnitQuery getRuledCanonicalUnitQuery();


    /**
     *  Matches rules mapped to any canonical unit. 
     *
     *  @param  match <code> true </code> for mapped to any canonical unit, 
     *          <code> false </code> to match mapped to no canonicalUnit 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledCanonicalUnit(boolean match);


    /**
     *  Clears the canonical unit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCanonicalUnitTerms();


    /**
     *  Matches description overrides. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverrideDescription(boolean match);


    /**
     *  Matches any description override. 
     *
     *  @param  match <code> true </code> for any description override, <code> 
     *          false </code> to match no description override 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverrideDescription(boolean match);


    /**
     *  Clears the description override query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideDescriptionTerms();


    /**
     *  Matches title overrides. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverrideTitle(boolean match);


    /**
     *  Matches any title override. 
     *
     *  @param  match <code> true </code> for any title override, <code> false 
     *          </code> to match no title override 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverrideTitle(boolean match);


    /**
     *  Clears the title override query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideTitleTerms();


    /**
     *  Matches code overrides. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverrideCode(boolean match);


    /**
     *  Matches any code override. 
     *
     *  @param  match <code> true </code> for any code override, <code> false 
     *          </code> to match no code override 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverrideCode(boolean match);


    /**
     *  Clears the code override query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideCodeTerms();


    /**
     *  Matches time periods overrides. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverrideTimePeriods(boolean match);


    /**
     *  Matches any time periods override. 
     *
     *  @param  match <code> true </code> for any time periods override, 
     *          <code> false </code> to match no time periods override 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverrideTimePeriods(boolean match);


    /**
     *  Clears the time periods override query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideTimePeriodsTerms();


    /**
     *  Matches constrain time periods. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConstrainTimePeriods(boolean match);


    /**
     *  Matches any constrain time periods. 
     *
     *  @param  match <code> true </code> for any time periods constraints, 
     *          <code> false </code> to match no time periods constraints 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyConstrainTimePeriods(boolean match);


    /**
     *  Clears the constrain time periods query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConstrainTimePeriodsTerms();


    /**
     *  Matches result options overrides. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverrideResultOptions(boolean match);


    /**
     *  Matches any result options override. 
     *
     *  @param  match <code> true </code> for any result options override, 
     *          <code> false </code> to match no result options override 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverrideResultOptions(boolean match);


    /**
     *  Clears the result options override query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideResultOptionsTerms();


    /**
     *  Matches constrain result options. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConstrainResultOptions(boolean match);


    /**
     *  Matches any constrain result options. 
     *
     *  @param  match <code> true </code> for any result options constraints, 
     *          <code> false </code> to match no result options constraints 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyConstrainResultOptions(boolean match);


    /**
     *  Clears the constrain result options query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConstrainResultOptionsTerms();


    /**
     *  Matches result options overrides. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOverrideSponsors(boolean match);


    /**
     *  Matches any sponsors override. 
     *
     *  @param  match <code> true </code> for any sponsors override, <code> 
     *          false </code> to match no sponsors override 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOverrideSponsors(boolean match);


    /**
     *  Clears the sponsors override query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOverrideSponsorsTerms();


    /**
     *  Matches constrain sponsors. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConstrainSponsors(boolean match);


    /**
     *  Matches any constrain sponsors. 
     *
     *  @param  match <code> true </code> for any sponsors constraints, <code> 
     *          false </code> to match no sponsors constraints 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyConstrainSponsors(boolean match);


    /**
     *  Clears the constrain sponsors query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConstrainSponsorsTerms();


    /**
     *  Matches mapped to the catalogue. 
     *
     *  @param  catalogueId the catalogue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> catalogueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCatalogueId(org.osid.id.Id catalogueId, boolean match);


    /**
     *  Clears the catalogue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogueIdTerms();


    /**
     *  Tests if a <code> CatalogueQuery </code> is available. 
     *
     *  @return <code> true </code> if a catalogue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogueQuery();


    /**
     *  Gets the query for a catalogue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the catalogue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCatalogueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCatalogueQuery() </code> is <code> true. </code> 
     */

    public org.osid.offering.CatalogueQuery getCatalogueQuery();


    /**
     *  Clears the catalogue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCatalogueTerms();


    /**
     *  Gets the offering constrainer query record corresponding to the given 
     *  <code> OfferingConstrainer </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  offeringConstrainerRecordType an offering constrainer record 
     *          type 
     *  @return the offering constrainer query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(offeringConstrainerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.offering.rules.records.OfferingConstrainerQueryRecord getOfferingConstrainerQueryRecord(org.osid.type.Type offeringConstrainerRecordType)
        throws org.osid.OperationFailedException;
}
