//
// org.osid.offering.rules.OfferingRulesProfile
//
//     The OSID Java specification for org.osid.offering.rules.OfferingRulesProfile.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.offering.rules;


/**
 *  <p>The offering rules profile describes the interoperability among 
 *  offering rules services. </p>
 */

public interface OfferingRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up canonical unit enablers is supported. 
     *
     *  @return <code> true </code> if canonical unit enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerLookup();


    /**
     *  Tests if querying canonical unit enablers is supported. 
     *
     *  @return <code> true </code> if canonical unit enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerQuery();


    /**
     *  Tests if searching canonical unit enablers is supported. 
     *
     *  @return <code> true </code> if canonical unit enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerSearch();


    /**
     *  Tests if a canonical unit enabler administrative service is supported. 
     *
     *  @return <code> true </code> if canonical unit enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerAdmin();


    /**
     *  Tests if a canonical unit enabler notification service is supported. 
     *
     *  @return <code> true </code> if canonical unit enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerNotification();


    /**
     *  Tests if a canonical unit enabler catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a canonical unit enabler catalogue 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerCatalogue();


    /**
     *  Tests if a canonical unit enabler catalogue service is supported. 
     *
     *  @return <code> true </code> if canonical unit enabler catalogue 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerCatalogueAssignment();


    /**
     *  Tests if a canonical unit enabler catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a canonical unit enabler catalogue 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerSmartCatalogue();


    /**
     *  Tests if looking up canonical unit processor is supported. 
     *
     *  @return <code> true </code> if canonical unit processor lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorLookup();


    /**
     *  Tests if querying canonical unit processor is supported. 
     *
     *  @return <code> true </code> if canonical unit processor query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorQuery();


    /**
     *  Tests if searching canonical unit processor is supported. 
     *
     *  @return <code> true </code> if canonical unit processor search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorSearch();


    /**
     *  Tests if a canonical unit processor administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if canonical unit processor administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorAdmin();


    /**
     *  Tests if a canonical unit processor notification service is supported. 
     *
     *  @return <code> true </code> if canonical unit processor notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorNotification();


    /**
     *  Tests if a canonical unit processor catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a canonical unit processor catalogue 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorCatalogue();


    /**
     *  Tests if a canonical unit processor catalogue service is supported. 
     *
     *  @return <code> true </code> if canonical unit processor catalogue 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorCatalogueAssignment();


    /**
     *  Tests if a canonical unit processor catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a canonical unit processor catalogue 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorSmartCatalogue();


    /**
     *  Tests if a canonical unit processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a canonical unit processor rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorRuleLookup();


    /**
     *  Tests if a canonical unit processor rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if canonical unit processor rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorRuleApplication();


    /**
     *  Tests if looking up canonical unit processor enablers is supported. 
     *
     *  @return <code> true </code> if canonical unit processor enabler lookup 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerLookup();


    /**
     *  Tests if querying canonical unit processor enablers is supported. 
     *
     *  @return <code> true </code> if canonical unit processor enabler query 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerQuery();


    /**
     *  Tests if searching canonical unit processor enablers is supported. 
     *
     *  @return <code> true </code> if canonical unit processor enabler search 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerSearch();


    /**
     *  Tests if a canonical unit processor enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if canonical unit processor enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerAdmin();


    /**
     *  Tests if a canonical unit processor enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if canonical unit processor enabler 
     *          notification is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerNotification();


    /**
     *  Tests if a canonical unit processor enabler catalogue lookup service 
     *  is supported. 
     *
     *  @return <code> true </code> if a canonical unit processor enabler 
     *          catalogue lookup service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerCatalogue();


    /**
     *  Tests if a canonical unit processor enabler catalogue service is 
     *  supported. 
     *
     *  @return <code> true </code> if canonical unit processor enabler 
     *          catalogue assignment service is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerCatalogueAssignment();


    /**
     *  Tests if a canonical unit processor enabler catalogue lookup service 
     *  is supported. 
     *
     *  @return <code> true </code> if a canonical unit processor enabler 
     *          catalogue service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerSmartCatalogue();


    /**
     *  Tests if a canonical unit processor enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerRuleLookup();


    /**
     *  Tests if a canonical unit processor enabler rule application service 
     *  is supported. 
     *
     *  @return <code> true </code> if canonical unit processor enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerRuleApplication();


    /**
     *  Tests if looking up offering constrainer is supported. 
     *
     *  @return <code> true </code> if offering constrainer lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerLookup();


    /**
     *  Tests if querying offering constrainer is supported. 
     *
     *  @return <code> true </code> if offering constrainer query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerQuery();


    /**
     *  Tests if searching offering constrainer is supported. 
     *
     *  @return <code> true </code> if offering constrainer search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerSearch();


    /**
     *  Tests if an offering constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if offering constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerAdmin();


    /**
     *  Tests if an offering constrainer notification service is supported. 
     *
     *  @return <code> true </code> if offering constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerNotification();


    /**
     *  Tests if an offering constrainer catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an offering constrainer catalogue 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerCatalogue();


    /**
     *  Tests if an offering constrainer catalogue service is supported. 
     *
     *  @return <code> true </code> if offering constrainer catalogue 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerCatalogueAssignment();


    /**
     *  Tests if an offering constrainer catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an offering constrainer catalogue 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerSmartCatalogue();


    /**
     *  Tests if an offering constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if an offering constrainer rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerRuleLookup();


    /**
     *  Tests if an offering constrainer rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if an offering constrainer rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerRuleApplication();


    /**
     *  Tests if looking up offering constrainer enablers is supported. 
     *
     *  @return <code> true </code> if offering constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerLookup();


    /**
     *  Tests if querying offering constrainer enablers is supported. 
     *
     *  @return <code> true </code> if offering constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerQuery();


    /**
     *  Tests if searching offering constrainer enablers is supported. 
     *
     *  @return <code> true </code> if offering constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerSearch();


    /**
     *  Tests if an offering constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if offering constrainer enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerAdmin();


    /**
     *  Tests if an offering constrainer enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if offering constrainer enabler 
     *          notification is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerNotification();


    /**
     *  Tests if an offering constrainer enabler catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an offering constrainer enabler 
     *          catalogue lookup service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerCatalogue();


    /**
     *  Tests if an offering constrainer enabler catalogue service is 
     *  supported. 
     *
     *  @return <code> true </code> if offering constrainer enabler catalogue 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerCatalogueAssignment();


    /**
     *  Tests if an offering constrainer enabler catalogue lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an offering constrainer enabler 
     *          catalogue service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerSmartCatalogue();


    /**
     *  Tests if an offering constrainer enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if an offering constrainer enabler rule 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerRuleLookup();


    /**
     *  Tests if an offering constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if offering constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerRuleApplication();


    /**
     *  Gets the supported <code> CanonicalUnitEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> CanonicalUnitEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitEnablerRecordTypes();


    /**
     *  Tests if the given <code> CanonicalUnitEnabler </code> record type is 
     *  supported. 
     *
     *  @param  canonicalUnitEnablerRecordType a <code> Type </code> 
     *          indicating a <code> CanonicalUnitEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerRecordType(org.osid.type.Type canonicalUnitEnablerRecordType);


    /**
     *  Gets the supported <code> CanonicalUnitEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> CanonicalUnitEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> CanonicalUnitEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  canonicalUnitEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> CanonicalUnitEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitEnablerSearchRecordType(org.osid.type.Type canonicalUnitEnablerSearchRecordType);


    /**
     *  Gets the supported <code> CanonicalUnitProcessor </code> record types. 
     *
     *  @return a list containing the supported <code> CanonicalUnitProcessor 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitProcessorRecordTypes();


    /**
     *  Tests if the given <code> CanonicalUnitProcessor </code> record type 
     *  is supported. 
     *
     *  @param  canonicalUnitProcessorRecordType a <code> Type </code> 
     *          indicating a <code> CanonicalUnitProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorRecordType(org.osid.type.Type canonicalUnitProcessorRecordType);


    /**
     *  Gets the supported <code> CanonicalUnitProcessor </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> CanonicalUnitProcessor 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> CanonicalUnitProcessor </code> search record 
     *  type is supported. 
     *
     *  @param  canonicalUnitProcessorSearchRecordType a <code> Type </code> 
     *          indicating a <code> CanonicalUnitProcessor </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorSearchRecordType(org.osid.type.Type canonicalUnitProcessorSearchRecordType);


    /**
     *  Gets the supported <code> CanonicalUnitProcessorEnabler </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> 
     *          CanonicalUnitProcessorEnabler </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> CanonicalUnitProcessorEnabler </code> record 
     *  type is supported. 
     *
     *  @param  canonicalUnitProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> CanonicalUnitProcessorEnabler </code> 
     *          record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerRecordType(org.osid.type.Type canonicalUnitProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> CanonicalUnitProcessorEnabler </code> search 
     *  record types. 
     *
     *  @return a list containing the supported <code> 
     *          CanonicalUnitProcessorEnabler </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCanonicalUnitProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> CanonicalUnitProcessorEnabler </code> search 
     *  record type is supported. 
     *
     *  @param  canonicalUnitProcessorEnablerSearchRecordType a <code> Type 
     *          </code> indicating a <code> CanonicalUnitProcessorEnabler 
     *          </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          canonicalUnitProcessorEnablerSearchRecordType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCanonicalUnitProcessorEnablerSearchRecordType(org.osid.type.Type canonicalUnitProcessorEnablerSearchRecordType);


    /**
     *  Gets the supported <code> OfferingConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> OfferingConstrainer 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfferingConstrainerRecordTypes();


    /**
     *  Tests if the given <code> OfferingConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  offeringConstrainerRecordType a <code> Type </code> indicating 
     *          an <code> OfferingConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerRecordType(org.osid.type.Type offeringConstrainerRecordType);


    /**
     *  Gets the supported <code> OfferingConstrainer </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> OfferingConstrainer 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfferingConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> OfferingConstrainer </code> search record 
     *  type is supported. 
     *
     *  @param  offeringConstrainerSearchRecordType a <code> Type </code> 
     *          indicating an <code> OfferingConstrainer </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerSearchRecordType(org.osid.type.Type offeringConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> OfferingConstrainerEnabler </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> 
     *          OfferingConstrainerEnabler </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfferingConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> OfferingConstrainerEnabler </code> record 
     *  type is supported. 
     *
     *  @param  offeringConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating an <code> OfferingConstrainerEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerRecordType(org.osid.type.Type offeringConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> OfferingConstrainerEnabler </code> search 
     *  record types. 
     *
     *  @return a list containing the supported <code> 
     *          OfferingConstrainerEnabler </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfferingConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> OfferingConstrainerEnabler </code> search 
     *  record type is supported. 
     *
     *  @param  offeringConstrainerEnablerSearchRecordType a <code> Type 
     *          </code> indicating an <code> OfferingConstrainerEnabler 
     *          </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          offeringConstrainerEnablerSearchRecordType </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingConstrainerEnablerSearchRecordType(org.osid.type.Type offeringConstrainerEnablerSearchRecordType);
}
