//
// org.osid.ontology.OntologyAssignmentSession
//
//     The OSID Java specification for org.osid.ontology.OntologyAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session provides methods to manage <code> Id </code> to <code> 
 *  Ontology </code> mappings. Arbitrary <code> Ids </code> may be used to 
 *  offer a restricted ontology to allow an arbitrary <code> Id </code> to be 
 *  used in the <code> SubjectLookupSession </code> or the <code> 
 *  SubjectHierarchySession. </code> Only one ontology can be assigned to an 
 *  <code> Id. </code> </p>
 */

public interface OntologyAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can manage of id/ontology mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known assignment methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may wish not to offer mapping functions to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if managing mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignOntologies();


    /**
     *  Assigns an <code> Id </code> to an ontology. 
     *
     *  @param  id <code> an Id </code> 
     *  @param  ontologyId <code> Id </code> of the <code> Ontology </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          ontologyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignOntology(org.osid.id.Id id, org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Unassigns an <code> Id </code> from an ontology. 
     *
     *  @param  id <code> an Id </code> 
     *  @param  ontologyId <code> Id </code> of the <code> Ontology </code> 
     *  @throws org.osid.NotFoundException <code> id </code> not assigned to 
     *          <code> ontologyId </code> 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          ontologyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignOntology(org.osid.id.Id id, org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the ontology to which the <code> Id </code> is assigned. 
     *
     *  @param  id <code> an Id </code> 
     *  @throws org.osid.NotFoundException <code> id </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void getOntology(org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of the <code> Ids </code> assigned to an ontology. 
     *
     *  @param  ontologyId <code> Id </code> of the <code> Ontology </code> 
     *  @throws org.osid.NotFoundException <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void getIds(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
