//
// org.osid.ontology.OntologyQuery
//
//     The OSID Java specification for org.osid.ontology.OntologyQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This is the query for searching ontologies. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface OntologyQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the subject <code> Id </code> for this query. 
     *
     *  @param  subjectId a subject <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubjectId(org.osid.id.Id subjectId, boolean match);


    /**
     *  Clears the subject <code> Id </code> terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubjectIdTerms();


    /**
     *  Tests if a <code> SubjectQuery </code> is available. 
     *
     *  @return <code> true </code> if a subject query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubjectQuery();


    /**
     *  Gets the query for a subject. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the subject query 
     *  @throws org.osid.UnimplementedException <code> supportsSubjectQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubjectQuery() </code> is <code> true. </code> 
     */

    public org.osid.ontology.SubjectQuery getSubjectQuery();


    /**
     *  Matches ontologies that have any subject. 
     *
     *  @param  match <code> true </code> to match ontologies with any 
     *          subject, <code> false </code> to match ontologies with no 
     *          subject 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySubject(boolean match);


    /**
     *  Clears the subject terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubjectTerms();


    /**
     *  Sets the relevancy <code> Id </code> for this query. 
     *
     *  @param  relevancyId a relevancy <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> relevancyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelevancyId(org.osid.id.Id relevancyId, boolean match);


    /**
     *  Clears the relevancy <code> Id </code> terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelevancyIdTerms();


    /**
     *  Tests if a <code> RelevancyQuery </code> is available. 
     *
     *  @return <code> true </code> if a relevancy query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelevancyQuery();


    /**
     *  Gets the query for a relevancy. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the relevancy query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyQuery() </code> is <code> true. </code> 
     */

    public org.osid.ontology.RelevancyQuery getRelevancyQuery();


    /**
     *  Matches ontologies that have any relevancy. 
     *
     *  @param  match <code> true </code> to match ontologies with any 
     *          relevancy, <code> false </code> to match ontologies with no 
     *          relevancy 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRelevancy(boolean match);


    /**
     *  Clears the relevancy terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelevancyTerms();


    /**
     *  Sets the ontology <code> Id </code> for this query to match ontologies 
     *  that have the specified ontology as an ancestor. 
     *
     *  @param  ontologyId an ontology <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorOntologyId(org.osid.id.Id ontologyId, 
                                        boolean match);


    /**
     *  Clears the ancestor ontology <code> Id </code> terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOntologyIdTerms();


    /**
     *  Tests if an <code> OntologyQuery </code> is available. 
     *
     *  @return <code> true </code> if an ontology query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorOntologyQuery();


    /**
     *  Gets the query for an ontology. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the ontology query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorOntologyQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorOntologyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.OntologyQuery getAncestorOntologyQuery();


    /**
     *  Matches ontologies with any ancestor. 
     *
     *  @param  match <code> true </code> to match ontologies with any 
     *          ancestor, <code> false </code> to match root ontologies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorOntology(boolean match);


    /**
     *  Clears the ancestor ontology terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOntologyTerms();


    /**
     *  Sets the ontology <code> Id </code> for this query to match ontologies 
     *  that have the specified ontology as a descendant. 
     *
     *  @param  ontologyId an ontology <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantOntologyId(org.osid.id.Id ontologyId, 
                                          boolean match);


    /**
     *  Clears the descendant ontology <code> Id </code> terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOntologyIdTerms();


    /**
     *  Tests if an <code> OntologyQuery </code> is available. 
     *
     *  @return <code> true </code> if an ontology query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantOntologyQuery();


    /**
     *  Gets the query for an ontology. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the ontology query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantOntologyQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantOntologyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.OntologyQuery getDescendantOntologyQuery();


    /**
     *  Matches ontologies with any descendant. 
     *
     *  @param  match <code> true </code> to match ontologies with any 
     *          descendant, <code> false </code> to match leaf ontologies 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantOntology(boolean match);


    /**
     *  Clears the descendant ontology terms for this query. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOntologyTerms();


    /**
     *  Gets the ontology query record corresponding to the given <code> 
     *  Ontology </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  ontologyRecordType a ontology record type 
     *  @return the ontology query record 
     *  @throws org.osid.NullArgumentException <code> ontologyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(ontologyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.records.OntologyQueryRecord getOntologyQueryRecord(org.osid.type.Type ontologyRecordType)
        throws org.osid.OperationFailedException;
}
