//
// org.osid.ontology.RelevancyAdminSession
//
//     The OSID Java specification for org.osid.ontology.RelevancyAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session creates, updates, and deletes <code> Relevancies. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Relevancy, </code> a <code> RelevancyForm </code> is requested using 
 *  <code> getRelevancyFormForCreate() </code> specifying the desired peers 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. The returned <code> RelevancyForm </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> RelevancyForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> RelevancyForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> RelevancyForms </code> are requested to the <code> 
 *  Relevancy </code> <code> Id </code> that is to be updated using <code> 
 *  getRelevancyFormForUpdate(). </code> Similarly, the <code> RelevancyForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> RelevancyForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Relevancies. </code> To unmap a 
 *  <code> Relevancy </code> from the current <code> Ontology, </code> the 
 *  <code> RelevancyOntologyAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Relevancy </code> itself 
 *  thus removing it from all known <code> Ontology </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RelevancyAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the <code> Ontology </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create relevancies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Relevancy </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Relevancy </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRelevancies();


    /**
     *  Tests if this user can create a single <code> Relevancy </code> using 
     *  the desired record interface types. While <code> 
     *  OntologyManager.getRelevancyRecordTypes() </code> can be used to 
     *  examine which record interfaces are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Relevancy. 
     *  </code> Providing an empty array tests if a <code> Relevancy </code> 
     *  can be created with no records. 
     *
     *  @param  relevancyRecordTypes array of relevancy record types 
     *  @return <code> true </code> if <code> Relevancy </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> relevancyRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRelevancyWithRecordTypes(org.osid.type.Type[] relevancyRecordTypes);


    /**
     *  Gets the relevancy form for creating new relevancies. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  subjectId the <code> Id </code> of the <code> Subject </code> 
     *  @param  id a mapped <code> Id </code> 
     *  @param  relevancyRecordTypes array of relevancy record types 
     *  @return the relevancy form 
     *  @throws org.osid.NotFoundException <code> subjectId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyForm getRelevancyFormForCreate(org.osid.id.Id subjectId, 
                                                                     org.osid.id.Id id, 
                                                                     org.osid.type.Type[] relevancyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Relevancy. </code> 
     *
     *  @param  relevancyForm the form for this <code> Relevancy </code> 
     *  @return the new <code> Relevancy </code> 
     *  @throws org.osid.IllegalStateException <code> relevancyForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> relevancyForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relevancyForm </code> did 
     *          not originate from <code> getRelevancyFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Relevancy createRelevancy(org.osid.ontology.RelevancyForm relevancyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update relevancies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Relevancy </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if relevancy modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRelevancies();


    /**
     *  Gets the relevancy form for updating an existing relevancy. A new 
     *  relevancy form should be requested for each update transaction. 
     *
     *  @param  relevancyId the <code> Id </code> of the <code> Relevancy 
     *          </code> 
     *  @return the relevancy form 
     *  @throws org.osid.NotFoundException <code> relevancyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relevancyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyForm getRelevancyFormForUpdate(org.osid.id.Id relevancyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing relevancy. 
     *
     *  @param  relevancyForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> relevancyForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> relevancyForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relevancyForm </code> did 
     *          not originate from <code> getRelevancyFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRelevancy(org.osid.ontology.RelevancyForm relevancyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete relevancies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> Relevancy </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Relevancy </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRelevancies();


    /**
     *  Deletes the <code> Relevancy </code> identified by the given <code> 
     *  Id. </code> 
     *
     *  @param  relevancyId the <code> Id </code> of the <code> Relevancy 
     *          </code> to delete 
     *  @throws org.osid.NotFoundException a <code> Relevancy </code> was not 
     *          found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRelevancy(org.osid.id.Id relevancyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  relevancies. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Relevancy </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRelevancyAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Relevancy </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Relevancy </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another relevancy, it is 
     *  reassigned to the given relevancy <code> Id. </code> 
     *
     *  @param  relevancyId the <code> Id </code> of a <code> Relevancy 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> relevancyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relevancyId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRelevancy(org.osid.id.Id relevancyId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
