//
// org.osid.ontology.RelevancyLookupSession
//
//     The OSID Java specification for org.osid.ontology.RelevancyLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session provides methods for examining subject relevancy. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated ontology view: All relevancy methods in this session 
 *      operate, retrieve and pertain to relevancies defined explicitly in the 
 *      current ontology. Using an isolated view is useful for managing 
 *      relevancies with the <code> RelevancyAdminSession. </code> </li> 
 *      <li> federated ontology view: All relevancy methods in this session 
 *      operate, retrieve and pertain to all relevancies defined in this 
 *      ontology and any other obtologies implicitly available in this 
 *      ontology through ontology inheritence. </li> 
 *      <li> effective relevancy view: All relevancy methods return effective 
 *      relevancies. </li> 
 *      <li> any effective relevancy view: Both effective and ineffective 
 *      relevancies are returned. </li> 
 *  </ul>
 *  
 */

public interface RelevancyLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the <code> Ontology </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup subject relevancies. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRelevancies();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRelevancyView();


    /**
     *  A complete view of the <code> Relevancy </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRelevancyView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include relevancies in ontologies which are children of this ontology 
     *  in the ontology hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOntologyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this ontology only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOntologyView();


    /**
     *  The returns from the lookup methods return only effetive relevancies. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveRelevancyView();


    /**
     *  Both effective and ineffective relavcnies are returned. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveRelevancyView();


    /**
     *  Gets the <code> Relevancy </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relevancy </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relevancy </code> and retained for compatibility. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  relevancyId <code> Id </code> of the <code> Relevancy </code> 
     *  @return the relevancy 
     *  @throws org.osid.NotFoundException <code> relevancyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relevancyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.Relevancy getRelevancy(org.osid.id.Id relevancyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relevancies specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible relevancies may be omitted from the list and may present 
     *  the elements in any order including returning a unique set. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  relevancyIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Relevancy list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> relevancyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByIds(org.osid.id.IdList relevancyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the relevancies for the given relevancy and genus type. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  relevancyGenusType relevancy genus type 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> relevancyGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusType(org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the relevancies for the given relevancy genus type and include 
     *  any relevancies with a genus type derived from the specified genus 
     *  type. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  relevancyGenusType relevancy genus type 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> relevancyGenusTYpe 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByParentGenusType(org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> containing the given relevancy 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relevancies or an error results. Otherwise, the returned list may 
     *  contain only those relevancies that are accessible through this 
     *  session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  relevancyRecordType a relevancy record type 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> relevancyRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByRecordType(org.osid.type.Type relevancyRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesOnDate(org.osid.calendaring.DateTime from, 
                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> of the given genus type and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  relevancyGenusType relevancy genus type 
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyGenusType, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusTypeOnDate(org.osid.type.Type relevancyGenusType, 
                                                                           org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancy </code> mapped to a subject <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relevancy </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relevancy </code> and retained for compatibility. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForSubject(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> for the given subject effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> subjectId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForSubjectOnDate(org.osid.id.Id subjectId, 
                                                                          org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancy </code> mapped to a subject <code> Id 
     *  </code> and relevancy <code> genus Type. </code> Genus <code> Types 
     *  </code> derived from the given genus <code> Typ </code> e are 
     *  included. 
     *  
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Relevancy 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Relevancy </code> and retained for compatibility. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @param  relevancyGenusType relevancy genus type 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> or 
     *          <code> relevancyGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusTypeForSubject(org.osid.id.Id subjectId, 
                                                                               org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> of the given genus type for the 
     *  given subject effective during the entire given date range inclusive 
     *  but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @param  relevancyGenusType relevancy genus type 
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> subjectId, 
     *          relevancyGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusTypeForSubjectOnDate(org.osid.id.Id subjectId, 
                                                                                     org.osid.type.Type relevancyGenusType, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the relevancies for the given subject <code> Ids. </code> 
     *  
     *  In plenary mode, the returned list contains all of the relevancies 
     *  specified in the subject <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if a relevancy <code> 
     *  Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible relevancies may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectIds list of subject <code> Ids </code> 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> subjectIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForSubjects(org.osid.id.IdList subjectIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancy </code> elements mapped to an <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relevancy </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relevancy </code> and retained for compatibility. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  id an <code> Id </code> 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForMappedId(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> for the given mapped <code> Id 
     *  </code> effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> id, from, </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForMappedIdOnDate(org.osid.id.Id id, 
                                                                           org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancy </code> elements mapped to an <code> Id 
     *  </code> of the given relevancy genus <code> Type </code> which 
     *  includes derived genus <code> Types. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relevancy </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relevancy </code> and retained for compatibility. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  relevancyGenusType relevancy genus type 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          relevancyGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusTypeForMappedId(org.osid.id.Id id, 
                                                                                org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> of the given genus type for the 
     *  given mapped <code> Id </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  relevancyGenusType relevancy genus type 
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> id, relevancyGenusType, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusTypeForMappedIdOnDate(org.osid.id.Id id, 
                                                                                      org.osid.type.Type relevancyGenusType, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the relevancies for the given mapped <code> Ids. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relevancies mapped to the <code> Id </code> or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible relevancies may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  ids a list of <code> Ids </code> 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> ids </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForMappedIds(org.osid.id.IdList ids)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancy </code> mapped to a subject and mapped 
     *  <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relevancy </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relevancy </code> and retained for compatibility. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @param  id the mapped <code> Id </code> 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForSubjectAndMappedId(org.osid.id.Id subjectId, 
                                                                               org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> for the given subject and mapped 
     *  <code> Id </code> effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @param  id the mapped <code> Id </code> 
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> subjectId, id, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesForSubjectAndMappedIdOnDate(org.osid.id.Id subjectId, 
                                                                                     org.osid.id.Id id, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Relevancy </code> of the given genus type and mapped 
     *  to a subject and mapped <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relevancy </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relevancy </code> and retained for compatibility. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @param  id the mapped <code> Id </code> 
     *  @param  relevancyGenusType relevancy genus type 
     *  @return list of relevancies 
     *  @throws org.osid.NullArgumentException <code> subjectId, id </code> , 
     *          or <code> relevancyGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusTypeForSubjectAndMappedId(org.osid.id.Id subjectId, 
                                                                                          org.osid.id.Id id, 
                                                                                          org.osid.type.Type relevancyGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelevancyList </code> of the given genus type and 
     *  related to the given subject and mapped <code> Id </code> effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @param  subjectId the subject <code> Id </code> 
     *  @param  id the mapped <code> Id </code> 
     *  @param  relevancyGenusType relevancy genus type 
     *  @param  from a starting date 
     *  @param  to an ending date 
     *  @return list of relevancies 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> subjectId, id, 
     *          relevancyGenusTYpe, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevanciesByGenusTypeForSubjectAndMappedIdOnDate(org.osid.id.Id subjectId, 
                                                                                                org.osid.id.Id id, 
                                                                                                org.osid.type.Type relevancyGenusType, 
                                                                                                org.osid.calendaring.DateTime from, 
                                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all relevancies. 
     *  
     *  In plenary mode, the returned list contains all known relevancies or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relevancies that are accessible through this session. 
     *  
     *  In effective mode, relevancies are returned that are currently 
     *  effective. In any effective mode, effective relevancies and those 
     *  currently expired are returned. 
     *
     *  @return list of relevancies 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ontology.RelevancyList getRelevancies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
