//
// org.osid.ontology.RelevancySearchSession
//
//     The OSID Java specification for org.osid.ontology.RelevancySearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session provides methods for searching <code> Relevancy </code> 
 *  objects. The search query is constructed using the <code> RelevancyQuery. 
 *  </code> The relevancy record <code> Type </code> also specifies the record 
 *  for the relevancy query. </p> 
 *  
 *  <p> <code> getRelevanciesByQuery() </code> is the basic search method and 
 *  returns a list of relevancies. A more advanced search may be performed 
 *  with <code> getRelevanciesBySearch(). </code> It accepts a <code> 
 *  RelevancySearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRelevanciesBySearch() </code> returns a <code> 
 *  RelevancySearchResults </code> that can be used to access the resulting 
 *  <code> RelevancyList </code> or be used to perform a search within the 
 *  result set through <code> RelevancySearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated ontology view: searches include relevancies in 
 *      ontologies of which this ontology is a ancestor in the ontology 
 *      hierarchy </li> 
 *      <li> isolated ontology view: searches are restricted </li> 
 *  </ul>
 *  
 *  
 *  <p> Relevancies may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> RelevancyQuery. 
 *  </code> </p>
 */

public interface RelevancySearchSession
    extends org.osid.ontology.RelevancyQuerySession {


    /**
     *  Gets a relevancy search. 
     *
     *  @return the relevancy search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancySearch getRelevancySearch();


    /**
     *  Gets a relevancy search order. The <code> RelevancySearchOrder </code> 
     *  is supplied to a <code> RelevancySearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the relevancy search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancySearchOrder getRelevancySearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  relevancyQuery the relevancy query 
     *  @param  relevancySearch the relevancy search 
     *  @return the relevancy search results 
     *  @throws org.osid.NullArgumentException <code> relevancyQuery </code> 
     *          or <code> relevancySearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relevancySearch </code> 
     *          or <code> relevancyQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancySearchResults getRelevanciesBySearch(org.osid.ontology.RelevancyQuery relevancyQuery, 
                                                                           org.osid.ontology.RelevancySearch relevancySearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relevancy query from an inspector. The inspector is available 
     *  from a <code> RelevancySearchResults. </code> 
     *
     *  @param  relevancyQueryInspector a relevancy query inspector 
     *  @return the relevancy query 
     *  @throws org.osid.NullArgumentException <code> relevancyQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> relevancyQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.RelevancyQuery getRelevancyQueryFromInspector(org.osid.ontology.RelevancyQueryInspector relevancyQueryInspector);
}
