//
// org.osid.ontology.SubjectSearchSession
//
//     The OSID Java specification for org.osid.ontology.SubjectSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session provides methods for searching <code> Subject </code> 
 *  objects. The search query is constructed using the <code> SubjectQuery. 
 *  </code> The subject record <code> Type </code> also specifies the record 
 *  for the subject query. </p> 
 *  
 *  <p> <code> getSubjectsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Subjects. </code> A more advanced search may be 
 *  performed with <code> getSubjectsBySearch(). </code> It accepts a <code> 
 *  SubjectSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getSubjectsBySearch() </code> returns a <code> 
 *  SubjectSearchResults </code> that can be used to access the resulting 
 *  <code> SubjectList </code> or be used to perform a search within the 
 *  result set through <code> SubjectSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated ontology view: searches include subjects in ontologies 
 *      of which this ontology is a ancestor in the ontology hierarchy </li> 
 *      <li> isolated ontology view: searches are restricted to subjects in 
 *      this ontology </li> 
 *  </ul>
 *  
 *  
 *  <p> Subjects may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> SubjectQuery. </code> 
 *  </p>
 */

public interface SubjectSearchSession
    extends org.osid.ontology.SubjectQuerySession {


    /**
     *  Gets a subject search. 
     *
     *  @return the subject search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectSearch getSubjectSearch();


    /**
     *  Gets a subject search order. The <code> SubjectSearchOrder </code> is 
     *  supplied to a <code> SubjectSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the subject search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectSearchOrder getSubjectSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  subjectQuery the subject query 
     *  @param  subjectSearch the subject search 
     *  @return the subject search results 
     *  @throws org.osid.NullArgumentException <code> subjectQuery </code> or 
     *          <code> subjectSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subjectSearch </code> or 
     *          <code> subjectQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectSearchResults getSubjectsBySearch(org.osid.ontology.SubjectQuery subjectQuery, 
                                                                      org.osid.ontology.SubjectSearch subjectSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a subject query from an inspector. The inspector is available 
     *  from a <code> SubjecttSearchResults. </code> 
     *
     *  @param  subjectQueryInspector a subject query inspector 
     *  @return the subject query 
     *  @throws org.osid.NullArgumentException <code> subjectQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> subjectQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectQuery getSubjectQueryFromInspector(org.osid.ontology.SubjectQueryInspector subjectQueryInspector);
}
