//
// org.osid.ontology.SubjectSmartOntologySession
//
//     The OSID Java specification for org.osid.ontology.SubjectSmartOntologySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> SubjectQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Ontology </code> to create a virtual collection 
 *  of <code> Subjects. </code> The entries may be sequenced using the <code> 
 *  SubjectSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Ontology </code> has a default query that matches any 
 *  subject and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> SubjectQueryInspector. </code> The 
 *  query may be modified by converting the inspector back to a <code> 
 *  SubjectQuery. </code> </p>
 */

public interface SubjectSmartOntologySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the <code> Ontology </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart ontologies. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer smart operations. 
     *
     *  @return <code> false </code> if smart ontology methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartOntologies();


    /**
     *  Gets a subject query. 
     *
     *  @return the subject query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectQuery getSubjectQuery();


    /**
     *  Gets a subject search order. 
     *
     *  @return the subject search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectSearchOrder getSubjectSearchOrder();


    /**
     *  Applies a subject query to this ontology. 
     *
     *  @param  subjectQuery the subject query 
     *  @throws org.osid.NullArgumentException <code> subjectQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> subjectQuery </code> not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applySubjectQuery(org.osid.ontology.SubjectQuery subjectQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a subject query inspector for this ontology. 
     *
     *  @return the subject query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectQueryInspector inspectSubjectQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a subject search order to this ontology. 
     *
     *  @param  subjectSearchOrder the subject search order 
     *  @throws org.osid.NullArgumentException <code> subjectSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> subjectSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applySubjectSequencing(org.osid.ontology.SubjectSearchOrder subjectSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a subject query from an inspector. 
     *
     *  @param  subjectQueryInspector a subject query inspector 
     *  @return the subject query 
     *  @throws org.osid.NullArgumentException <code> subjectQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> subjectQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.SubjectQuery getSubjectQueryFromInspector(org.osid.ontology.SubjectQueryInspector subjectQueryInspector);
}
