//
// org.osid.ontology.batch.RelevancyBatchAdminSession
//
//     The OSID Java specification for org.osid.ontology.batch.RelevancyBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Relevancies </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Relevancy, </code> a <code> RelevancyForm </code> is requested using 
 *  <code> getRelevancyFormsForCreate() </code> specifying the desired 
 *  subject, id, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> RelevancyForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once a 
 *  <code> RelevancyForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> RelevancyForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> RelevancyForms </code> returned from <code> 
 *  getRelevancyFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> RelevancyForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  RelevancyForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> RelevancyForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  RelevancyForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createRelevancies(), </code> errors specific to an individual <code> 
 *  RelevancyForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> RelevancyForm </code> through the <code> 
 *  RelevancyForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> RelevancyForms </code> are requested to the <code> 
 *  Relevancy </code> <code> Id </code> that is to be updated using <code> 
 *  getRelevancyFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> RelevancyForm </code> may be used to link the request. 
 *  Similarly, the <code> RelevancyForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> RelevancyForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> RelevancyForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  RelevancyForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateRelevancies(), </code> errors specific to an individual <code> 
 *  RelevancyForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> RelevancyForm </code> through the <code> 
 *  RelevancyForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Relevancies </code> in bulk. To 
 *  unmap a <code> Relevancy </code> from the current <code> Ontology, </code> 
 *  the <code> RelevancyOntologyAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Relevancy </code> 
 *  itself thus removing it from all known <code> Ontology </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface RelevancyBatchAdminSession
    extends org.osid.ontology.RelevancyAdminSession {


    /**
     *  Gets the relevancy forms for creating a bunch of new relevancies. A 
     *  form is returned for each subject and related pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  relevancyRecordTypes array of relevancy record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the relevancy forms 
     *  @throws org.osid.NotFoundException a <code> subjectId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          relevancyRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.batch.RelevancyBatchFormList getRelevancyFormsForCreate(org.osid.ontology.batch.RelevancyPeerList peers, 
                                                                                     org.osid.type.Type[] relevancyRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Relevancies. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  relevancyForms the relevancy forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> relevancyForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createRelevancies(org.osid.ontology.batch.RelevancyBatchFormList relevancyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the relevancy forms for updating an existing set of relevancies. 
     *  A new relevancy form should be requested for each update transaction. 
     *
     *  @param  relevancyIds the <code> Ids </code> of the <code> Relevancy 
     *          </code> 
     *  @return the relevancy form 
     *  @throws org.osid.NotFoundException a <code> relevancyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relevancyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.batch.RelevancyBatchFormList getRelevancyFormsForUpdate(org.osid.id.IdList relevancyIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing relevancies. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  relevancyForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> relevancyForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateRelevancies(org.osid.ontology.batch.RelevancyBatchFormList relevancyForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Relevancies </code> in this <code> Ontology </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllRelevancies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relevancies for the given <code> Ids. </code> 
     *
     *  @param  relevancyIds the <code> Ids </code> of the relevancies to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> relevancyIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRelevancies(org.osid.id.IdList relevancyIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relevancies for the given subject. 
     *
     *  @param  subjectId the <code> Id </code> of a subject 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> subjectId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRelevanciesForSubject(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relevancies for the given mapped <code> Id. </code> 
     *
     *  @param  id an <code> Id </code> 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> id </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRelevanciesForMappedId(org.osid.id.Id id)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relevancies expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveRelevanciesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Relevancy </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Relevancy </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another relevancy, it is reassigned to the given 
     *  relevancy <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasRelevancies(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
