//
// org.osid.ontology.rules.OntologyRulesManager
//
//     The OSID Java specification for org.osid.ontology.rules.OntologyRulesManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.rules;


/**
 *  <p>The ontology rules manager provides access to ontology rules sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RelevancyEnablerLookupSession: </code> a session to 
 *      retrieve relevancy enablers </li> 
 *      <li> <code> RelevancyEnablerQuerySession: </code> a session to query 
 *      for relevancy enablers </li> 
 *      <li> <code> RelevancyEnablerSearchSession: </code> a session to search 
 *      for relevancy enablers </li> 
 *      <li> <code> RelevancyEnablerAdminSession: </code> a session to create 
 *      and delete relevancy enablers </li> 
 *      <li> <code> RelevancyEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to relevancy enabler changes </li> 
 *      <li> <code> RelevancyEnablerOntologySession: </code> a session to look 
 *      up relevancy enabler ontology mappings </li> 
 *      <li> <code> RelevancyEnablerOntologyAssignmentSession: </code> a 
 *      session to manage relevancy enabler to ontology mappings </li> 
 *      <li> <code> RelevancyEnablerSmartOntologySession: </code> a session to 
 *      manage dynamic ontologies of relevancy enablers </li> 
 *      <li> <code> RelevancyEnablerRuleLookupSession: </code> a session to 
 *      look up relevancy enabler to relevancy mappings </li> 
 *      <li> <code> RelevancyEnablerRuleApplicationSession: </code> a session 
 *      to apply relevancy enablers to relevancies </li> 
 *  </ul>
 *  
 */

public interface OntologyRulesManager
    extends org.osid.OsidManager,
            org.osid.ontology.rules.OntologyRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler lookup service. 
     *
     *  @return a <code> RelevancyEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerLookupSession getRelevancyEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler lookup service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Ontology </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerLookupSession getRelevancyEnablerLookupSessionForOntology(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler query service. 
     *
     *  @return a <code> RelevancyEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerQuerySession getRelevancyEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler query service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Ontology </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerQuerySession getRelevancyEnablerQuerySessionForOntology(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler search service. 
     *
     *  @return a <code> RelevancyEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerSearchSession getRelevancyEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enablers earch service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Ontology </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerSearchSession getRelevancyEnablerSearchSessionForOntology(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler administration service. 
     *
     *  @return a <code> RelevancyEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerAdminSession getRelevancyEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler administration service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Ontology </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerAdminSession getRelevancyEnablerAdminSessionForOntology(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler notification service. 
     *
     *  @param  relevancyEnablerReceiver the notification callback 
     *  @return a <code> RelevancyEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerNotificationSession getRelevancyEnablerNotificationSession(org.osid.ontology.rules.RelevancyEnablerReceiver relevancyEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler notification service for the given ontology. 
     *
     *  @param  relevancyEnablerReceiver the notification callback 
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no ontology found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerReceiver 
     *          </code> or <code> ontologyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerNotificationSession getRelevancyEnablerNotificationSessionForOntology(org.osid.ontology.rules.RelevancyEnablerReceiver relevancyEnablerReceiver, 
                                                                                                                         org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup relevancy 
     *  enabler/ontology mappings for relevancy enablers. 
     *
     *  @return a <code> RelevancyEnablerOntologySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerOntology() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerOntology() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerOntologySession getRelevancyEnablerOntologySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  relevancy enablers to ontologies for relevancy. 
     *
     *  @return a <code> RelevancyEnablerOntologyAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerOntologyAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerOntologyAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerOntologyAssignmentSession getRelevancyEnablerOntologyAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage relevancy enabler smart 
     *  ontologies. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerSmartOntologySession </code> 
     *  @throws org.osid.NotFoundException no <code> Ontology </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerSmartOntology() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerSmartOntology() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerSmartOntologySession getRelevancyEnablerSmartOntologySession(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler mapping lookup service. 
     *
     *  @return a <code> RelevancyEnablerRuleSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerRuleLookupSession getRelevancyEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler mapping lookup service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Ontology </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerRuleLookupSession getRelevancyEnablerRuleLookupSessionForOntology(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler assignment service. 
     *
     *  @return a <code> RelevancyEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerRuleApplicationSession getRelevancyEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relevancy 
     *  enabler assignment service for the given ontology. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return a <code> RelevancyEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Ontology </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelevancyEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelevancyEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.ontology.rules.RelevancyEnablerRuleApplicationSession getRelevancyEnablerRuleApplicationSessionForOntology(org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
