//
// org.osid.ontology.rules.RelevancyEnablerOntologyAssignmentSession
//
//     The OSID Java specification for org.osid.ontology.rules.RelevancyEnablerOntologyAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.rules;


/**
 *  <p>This session provides methods to re-assign <code> RelevancyEnabler 
 *  </code> to <code> Ontology </code> mappings. A <code> RelevancyEnabler 
 *  </code> may appear in multiple <code> Ontology </code> objects and 
 *  removing the last reference to a <code> RelevancyEnabler </code> is the 
 *  equivalent of deleting it. Each <code> Ontology </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> RelevancyEnabler </code> to another 
 *  <code> Ontology </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface RelevancyEnablerOntologyAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter relevancy enabler/ontology mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRelevancyEnablers();


    /**
     *  Tests if this user can alter relevancy enabler/ontology mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRelevancyEnablersToOntology(org.osid.id.Id ontologyId);


    /**
     *  Gets a list of ontologies including and under the given ontology node 
     *  in which any relevancy enabler can be assigned. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @return list of assignable ontology <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOntologyIds(org.osid.id.Id ontologyId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of ontologies including and under the given ontology node 
     *  in which a specific relevancy enabler can be assigned. 
     *
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> 
     *  @return list of assignable ontology <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> ontologyId </code> or 
     *          <code> relevancyEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOntologyIdsForRelevancyEnabler(org.osid.id.Id ontologyId, 
                                                                          org.osid.id.Id relevancyEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> RelevancyEnabler </code> to an <code> 
     *  Ontology. </code> 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> 
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> relevancyEnablerId 
     *          </code> is already assigned to <code> ontologyId </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          or <code> ontologyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> or <code> ontologyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRelevancyEnablerToOntology(org.osid.id.Id relevancyEnablerId, 
                                                 org.osid.id.Id ontologyId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RelevancyEnabler </code> from an <code> Ontology. 
     *  </code> 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> 
     *  @param  ontologyId the <code> Id </code> of the <code> Ontology 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          or <code> ontologyId </code> not found or <code> 
     *          relevancyEnablerId </code> not assigned to <code> ontologyId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> or <code> ontologyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRelevancyEnablerFromOntology(org.osid.id.Id relevancyEnablerId, 
                                                     org.osid.id.Id ontologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> RelevancyEnabler </code> from one <code> Ontology 
     *  </code> to another. Mappings to other <code> Ontologies </code> are 
     *  unaffected. 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> 
     *  @param  fromOntologyId the <code> Id </code> of the current <code> 
     *          Ontology </code> 
     *  @param  toOntologyId the <code> Id </code> of the destination <code> 
     *          Ontology </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId, 
     *          fromOntologyId, </code> or <code> toOntologyId </code> not 
     *          found or <code> relevancyEnablerId </code> not mapped to 
     *          <code> fromOntologyId </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId, 
     *          fromOntologyId, </code> or <code> toOntologyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignRelevancyEnablerToOntology(org.osid.id.Id relevancyEnablerId, 
                                                   org.osid.id.Id fromOntologyId, 
                                                   org.osid.id.Id toOntologyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
