//
// org.osid.ontology.rules.RelevancyEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.ontology.rules.RelevancyEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ontology.rules;


/**
 *  <p>This session provides methods to apply <code> RelevancyEnablers </code> 
 *  to <code> Relevancies. </code> A <code> Relevancy </code> with multiple 
 *  <code> RelevancyEnablers </code> means any positive rule evaluation across 
 *  the enablers result in an effective <code> Relevancy. </code> </p>
 */

public interface RelevancyEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Ontology </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Ontology Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOntologyId();


    /**
     *  Gets the <code> Ontology </code> associated with this session. 
     *
     *  @return the ontology 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Ontology getOntology()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter relevancy enabler/relevancy mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRelevancyEnablers();


    /**
     *  Adds an existing <code> RelevancyEnabler </code> to a <code> 
     *  Relevancy. </code> 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> 
     *  @param  relevancyId the <code> Id </code> of the <code> Relevancy 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> relevancyEnablerId 
     *          </code> is already applied to <code> relevancyId </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          or <code> relevancyId </code> not found 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> or <code> relevancyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRelevancyEnablerToRelevancy(org.osid.id.Id relevancyEnablerId, 
                                                  org.osid.id.Id relevancyId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RelevancyEnabler </code> from a <code> Relevancy. 
     *  </code> 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of the <code> 
     *          RelevancyEnabler </code> 
     *  @param  relevancyId the <code> Id </code> of the <code> Relevancy 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId </code> 
     *          or <code> relevancyId </code> not found or <code> 
     *          relevancyEnablerId </code> not applied to <code> relevancyId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId 
     *          </code> or <code> relevancyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRelevancyEnablerFromRelevancy(org.osid.id.Id relevancyEnablerId, 
                                                      org.osid.id.Id relevancyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> RelevancyEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RelevancyEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceRelevancyEnablers();


    /**
     *  Reorders relevancy enablers for a relevancy by moving the specified 
     *  relevancy enabler in front of a reference relevancy enabler. 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of a <code> 
     *          RelevancyEnabler </code> 
     *  @param  relevancyId the <code> Id </code> of a <code> Relevancy 
     *          </code> 
     *  @param  referenceId the reference relevancy enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId, 
     *          relevancyId, </code> or <code> referenceId </code> not found 
     *          or, <code> relevancyEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> relevancyId </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId, 
     *          relevancyId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRelevancyEnablerAhead(org.osid.id.Id relevancyEnablerId, 
                                          org.osid.id.Id relevancyId, 
                                          org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders relevancy enablers for a relevancy by moving the specified 
     *  relevancy enabler behind a reference relevancy enabler. 
     *
     *  @param  relevancyEnablerId the <code> Id </code> of a <code> 
     *          RelevancyEnabler </code> 
     *  @param  relevancyId the <code> Id </code> of a <code> Relevancy 
     *          </code> 
     *  @param  referenceId the reference relevancy enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> relevancyEnablerId, 
     *          relevancyId, </code> or <code> referenceId </code> not found 
     *          or, <code> relevancyEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> relevancyId </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerId, 
     *          relevancyId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRelevancyEnablerBehind(org.osid.id.Id relevancyEnablerId, 
                                           org.osid.id.Id relevancyId, 
                                           org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of relevancy enablers for a relevancy. 
     *
     *  @param  relevancyEnablerIds the <code> Ids </code> for a set of <code> 
     *          RelevancyEnablers </code> 
     *  @param  relevancyId the <code> Id </code> of a <code> Relevancy 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> relevancyId </code> not 
     *          found or, a <code> relevancyEnablerId </code> not related to 
     *          <code> relevancyId </code> 
     *  @throws org.osid.NullArgumentException <code> relevancyEnablerIds 
     *          </code> or <code> relevancyId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderRelevancyEnablers(org.osid.id.Id[] relevancyEnablerIds, 
                                       org.osid.id.Id relevancyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
