//
// org.osid.orchestration.OrchestrationProfile
//
//     The OSID Java specification for org.osid.orchestration.OrchestrationProfile.
//
// Copyright (C) 2009 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.orchestration;


/**
 *  <p>The <code> OrchestrationProfile </code> describes what OSID Providers 
 *  are available. </p>
 */

public interface OrchestrationProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if an acknowledgement provider is supported. 
     *
     *  @return <code> true </code> if an acknowledgement provider is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcknowledgementProvider();


    /**
     *  Tests if an assessment provider is supported. 
     *
     *  @return <code> true </code> if an assessment provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentProvider();


    /**
     *  Tests if an authentication provider is supported. 
     *
     *  @return <code> true </code> if an authentication provider is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationProvider();


    /**
     *  Tests if an authorization provider is supported. 
     *
     *  @return <code> true </code> if an authorization provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationProvider();


    /**
     *  Tests if a bidding provider is supported. 
     *
     *  @return <code> true </code> if a bidding provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBiddingProvider();


    /**
     *  Tests if a billing provider is supported. 
     *
     *  @return <code> true </code> if a billing provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingProvider();


    /**
     *  Tests if a blogging provider is supported. 
     *
     *  @return <code> true </code> if a blogging provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBloggingProvider();


    /**
     *  Tests if a calendaring provider is supported. 
     *
     *  @return <code> true </code> if a calendaring provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendaringProvider();


    /**
     *  Tests if a cataloging provider is supported. 
     *
     *  @return <code> true </code> if a cataloging provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogingProvider();


    /**
     *  Tests if a checklist provider is supported. 
     *
     *  @return <code> true </code> if a checklist provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistProvider();


    /**
     *  Tests if a commenting provider is supported. 
     *
     *  @return <code> true </code> if a commenting provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentingProvider();


    /**
     *  Tests if a communication provider is supported. 
     *
     *  @return <code> true </code> if a communication provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommunicationProvider();


    /**
     *  Tests if a configuration provider is supported. 
     *
     *  @return <code> true </code> if a configuration provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationProvider();


    /**
     *  Tests if a contact provider is supported. 
     *
     *  @return <code> true </code> if a contact provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactProvider();


    /**
     *  Tests if a control provider is supported. 
     *
     *  @return <code> true </code> if a control provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControlProvider();


    /**
     *  Tests if a course provider is supported. 
     *
     *  @return <code> true </code> if a course provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseProvider();


    /**
     *  Tests if a dictionary provider is supported. 
     *
     *  @return <code> true </code> if a dictionary provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryProvider();


    /**
     *  Tests if a filing provider is supported. 
     *
     *  @return <code> true </code> if a filing provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFilingProvider();


    /**
     *  Tests if a financials provider is supported. 
     *
     *  @return <code> true </code> if a financials provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFinancialsProvider();


    /**
     *  Tests if a forum provider is supported. 
     *
     *  @return <code> true </code> if a forum provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumProvider();


    /**
     *  Tests if a grading provider is supported. 
     *
     *  @return <code> true </code> if a grading provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingProvider();


    /**
     *  Tests if a hierarchy provider is supported. 
     *
     *  @return <code> true </code> if a hierarchy provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyProvider();


    /**
     *  Tests if a hold provider is supported. 
     *
     *  @return <code> true </code> if hold provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldProvider();


    /**
     *  Tests if an id provider is supported. 
     *
     *  @return <code> true </code> if an id provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIdProvider();


    /**
     *  Tests if an inquiry provider is supported. 
     *
     *  @return <code> true </code> if an inquiry provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryProvider();


    /**
     *  Tests if an installation provider is supported. 
     *
     *  @return <code> true </code> if an installation provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationProvider();


    /**
     *  Tests if an inventory provider is supported. 
     *
     *  @return <code> true </code> if an inventory provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryProvider();


    /**
     *  Tests if a journaling provider is supported. 
     *
     *  @return <code> true </code> if a journaling provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalingProvider();


    /**
     *  Tests if a learning provider is supported. 
     *
     *  @return <code> true </code> if a learning provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningProvider();


    /**
     *  Tests if a locale provider is supported. 
     *
     *  @return <code> true </code> if a locale provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocaleProvider();


    /**
     *  Tests if a logging provider is supported. 
     *
     *  @return <code> true </code> if a logging provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLoggingProvider();


    /**
     *  Tests if a mapping provider is supported. 
     *
     *  @return <code> true </code> if a mapping provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMappingProvider();


    /**
     *  Tests if a messaging provider is supported. 
     *
     *  @return <code> true </code> if a messaging provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessagingProvider();


    /**
     *  Tests if a metering provider is supported. 
     *
     *  @return <code> true </code> if a metering provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeteringProvider();


    /**
     *  Tests if an offering provider is supported. 
     *
     *  @return <code> true </code> if an offering provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingProvider();


    /**
     *  Tests if an ontology provider is supported. 
     *
     *  @return <code> true </code> if an ontology provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyProvider();


    /**
     *  Tests if an ordering provider is supported. 
     *
     *  @return <code> true </code> if an ordering provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderingProvider();


    /**
     *  Tests if a personnel provider is supported. 
     *
     *  @return <code> true </code> if a personnel provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonnelProvider();


    /**
     *  Tests if a process provider is supported. 
     *
     *  @return <code> true </code> if a process provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessProvider();


    /**
     *  Tests if a profile provider is supported. 
     *
     *  @return <code> true </code> if a profile provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileProvider();


    /**
     *  Tests if a provisioning provider is supported. 
     *
     *  @return <code> true </code> if a provisioning provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisioningProvider();


    /**
     *  Tests if a proxy provider is supported. 
     *
     *  @return <code> true </code> if a proxy provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProxyProvider();


    /**
     *  Tests if a recipe provider is supported. 
     *
     *  @return <code> true </code> if a recipe provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeProvider();


    /**
     *  Tests if a recognition provider is supported. 
     *
     *  @return <code> true </code> if a recognition provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecognitionProvider();


    /**
     *  Tests if a relationship provider is supported. 
     *
     *  @return <code> true </code> if a relationship provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipProvider();


    /**
     *  Tests if a repository provider is supported. 
     *
     *  @return <code> true </code> if a repository provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryProvider();


    /**
     *  Tests if a resource provider is supported. 
     *
     *  @return <code> true </code> if a resource provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceProvider();


    /**
     *  Tests if a resourcing provider is supported. 
     *
     *  @return <code> true </code> if a resourcing provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourcingProvider();


    /**
     *  Tests if a rules provider is supported. 
     *
     *  @return <code> true </code> if a rules provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRulesProvider();


    /**
     *  Tests if a search provider is supported. 
     *
     *  @return <code> true </code> if a search provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSearchProvider();


    /**
     *  Tests if a sequencing provider is supported. 
     *
     *  @return <code> true </code> if a sequencing provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequencingProvider();


    /**
     *  Tests if a subscription provider is supported. 
     *
     *  @return <code> true </code> if a subscription provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionProvider();


    /**
     *  Tests if a topology provider is supported. 
     *
     *  @return <code> true </code> if a topology provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopologyProvider();


    /**
     *  Tests if a tracking provider is supported. 
     *
     *  @return <code> true </code> if a tracking provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTrackingProvider();


    /**
     *  Tests if a transaction provider is supported. 
     *
     *  @return <code> true </code> if a transaction provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTransactionProvider();


    /**
     *  Tests if a transport provider is supported. 
     *
     *  @return <code> true </code> if a transport provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTransportProvider();


    /**
     *  Tests if a type provider is supported. 
     *
     *  @return <code> true </code> if a type provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTypeProvider();


    /**
     *  Tests if a voting provider is supported. 
     *
     *  @return <code> true </code> if a voting provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotingProvider();


    /**
     *  Tests if a workflow provider is supported. 
     *
     *  @return <code> true </code> if a workflow provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowProvider();


    /**
     *  Tests if an acknowledgement provider is supported. 
     *
     *  @return <code> true </code> if an acknowledgement provider is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcknowledgementProxyProvider();


    /**
     *  Tests if an assessment provider is supported. 
     *
     *  @return <code> true </code> if an assessment provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssessmentProxyProvider();


    /**
     *  Tests if an authentication provider is supported. 
     *
     *  @return <code> true </code> if an authentication provider is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthenticationProxyProvider();


    /**
     *  Tests if an authorization provider is supported. 
     *
     *  @return <code> true </code> if an authorization provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAuthorizationProxyProvider();


    /**
     *  Tests if a bidding provider is supported. 
     *
     *  @return <code> true </code> if a bidding provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBiddingProxyProvider();


    /**
     *  Tests if a billing provider is supported. 
     *
     *  @return <code> true </code> if a billing provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBillingProxyProvider();


    /**
     *  Tests if a blogging provider is supported. 
     *
     *  @return <code> true </code> if a blogging provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBloggingProxyProvider();


    /**
     *  Tests if a calendaring provider is supported. 
     *
     *  @return <code> true </code> if a calendaring provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCalendaringProxyProvider();


    /**
     *  Tests if a cataloging provider is supported. 
     *
     *  @return <code> true </code> if a cataloging provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCatalogingProxyProvider();


    /**
     *  Tests if a checklist provider is supported. 
     *
     *  @return <code> true </code> if a checklist provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChecklistProxyProvider();


    /**
     *  Tests if a commenting provider is supported. 
     *
     *  @return <code> true </code> if a commenting provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommentingProxyProvider();


    /**
     *  Tests if a communication provider is supported. 
     *
     *  @return <code> true </code> if a communication provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommunicationProxyProvider();


    /**
     *  Tests if a configuration provider is supported. 
     *
     *  @return <code> true </code> if a configuration provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConfigurationProxyProvider();


    /**
     *  Tests if a contact provider is supported. 
     *
     *  @return <code> true </code> if a contact provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsContactProxyProvider();


    /**
     *  Tests if a control provider is supported. 
     *
     *  @return <code> true </code> if a control provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsControlProxyProvider();


    /**
     *  Tests if a course provider is supported. 
     *
     *  @return <code> true </code> if a course provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCourseProxyProvider();


    /**
     *  Tests if a dictionary provider is supported. 
     *
     *  @return <code> true </code> if a dictionary provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDictionaryProxyProvider();


    /**
     *  Tests if a filing provider is supported. 
     *
     *  @return <code> true </code> if a filing provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFilingProxyProvider();


    /**
     *  Tests if a financials provider is supported. 
     *
     *  @return <code> true </code> if a financials provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFinancialsProxyProvider();


    /**
     *  Tests if a forum provider is supported. 
     *
     *  @return <code> true </code> if a forum provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsForumProxyProvider();


    /**
     *  Tests if a grading provider is supported. 
     *
     *  @return <code> true </code> if a grading provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGradingProxyProvider();


    /**
     *  Tests if a hierarchy provider is supported. 
     *
     *  @return <code> true </code> if a hierarchy provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHierarchyProxyProvider();


    /**
     *  Tests if a hold provider is supported. 
     *
     *  @return <code> true </code> if a hold provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldProxyProvider();


    /**
     *  Tests if an id provider is supported. 
     *
     *  @return <code> true </code> if an id provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIdProxyProvider();


    /**
     *  Tests if an inquiry provider is supported. 
     *
     *  @return <code> true </code> if an inquiry provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryProxyProvider();


    /**
     *  Tests if an installation provider is supported. 
     *
     *  @return <code> true </code> if an installation provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstallationProxyProvider();


    /**
     *  Tests if an inventory provider is supported. 
     *
     *  @return <code> true </code> if an inventory provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInventoryProxyProvider();


    /**
     *  Tests if a journaling provider is supported. 
     *
     *  @return <code> true </code> if a journaling provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJournalingProxyProvider();


    /**
     *  Tests if a learning provider is supported. 
     *
     *  @return <code> true </code> if a learning provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLearningProxyProvider();


    /**
     *  Tests if a locale provider is supported. 
     *
     *  @return <code> true </code> if a locale provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocaleProxyProvider();


    /**
     *  Tests if a logging provider is supported. 
     *
     *  @return <code> true </code> if a logging provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLoggingProxyProvider();


    /**
     *  Tests if a mapping provider is supported. 
     *
     *  @return <code> true </code> if a mapping provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMappingProxyProvider();


    /**
     *  Tests if a messaging provider is supported. 
     *
     *  @return <code> true </code> if a messaging provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMessagingProxyProvider();


    /**
     *  Tests if a metering provider is supported. 
     *
     *  @return <code> true </code> if a metering provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMeteringProxyProvider();


    /**
     *  Tests if an offering provider is supported. 
     *
     *  @return <code> true </code> if an offering provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfferingProxyProvider();


    /**
     *  Tests if an ontology provider is supported. 
     *
     *  @return <code> true </code> if an ontology provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOntologyProxyProvider();


    /**
     *  Tests if an ordering provider is supported. 
     *
     *  @return <code> true </code> if an ordering provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderingProxyProvider();


    /**
     *  Tests if a personnel provider is supported. 
     *
     *  @return <code> true </code> if a personnel provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonnelProxyProvider();


    /**
     *  Tests if a process provider is supported. 
     *
     *  @return <code> true </code> if a process provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessProxyProvider();


    /**
     *  Tests if a profile provider is supported. 
     *
     *  @return <code> true </code> if a profile provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileProxyProvider();


    /**
     *  Tests if a provisioning provider is supported. 
     *
     *  @return <code> true </code> if a provisioning provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisioningProxyProvider();


    /**
     *  Tests if a proxy provider is supported. 
     *
     *  @return <code> true </code> if a proxy provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProxyProxyProvider();


    /**
     *  Tests if a recipe provider is supported. 
     *
     *  @return <code> true </code> if a recipe provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeProxyProvider();


    /**
     *  Tests if a recognition provider is supported. 
     *
     *  @return <code> true </code> if a recognition provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecognitionProxyProvider();


    /**
     *  Tests if a relationship provider is supported. 
     *
     *  @return <code> true </code> if a relationship provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipProxyProvider();


    /**
     *  Tests if a repository provider is supported. 
     *
     *  @return <code> true </code> if a repository provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryProxyProvider();


    /**
     *  Tests if a resource provider is supported. 
     *
     *  @return <code> true </code> if a resource provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceProxyProvider();


    /**
     *  Tests if a resourcing provider is supported. 
     *
     *  @return <code> true </code> if a resourcing provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourcingProxyProvider();


    /**
     *  Tests if a rules provider is supported. 
     *
     *  @return <code> true </code> if a rules provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRulesProxyProvider();


    /**
     *  Tests if a search provider is supported. 
     *
     *  @return <code> true </code> if a search provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSearchProxyProvider();


    /**
     *  Tests if a sequencing provider is supported. 
     *
     *  @return <code> true </code> if a sequencing provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequencingProxyProvider();


    /**
     *  Tests if a subscription provider is supported. 
     *
     *  @return <code> true </code> if a subscription provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionProxyProvider();


    /**
     *  Tests if a topology provider is supported. 
     *
     *  @return <code> true </code> if a topology provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopologyProxyProvider();


    /**
     *  Tests if a tracking provider is supported. 
     *
     *  @return <code> true </code> if a tracking provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTrackingProxyProvider();


    /**
     *  Tests if a transaction provider is supported. 
     *
     *  @return <code> true </code> if a transaction provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTransactionProxyProvider();


    /**
     *  Tests if a transport provider is supported. 
     *
     *  @return <code> true </code> if a transport provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTransportProxyProvider();


    /**
     *  Tests if a type provider is supported. 
     *
     *  @return <code> true </code> if a type provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTypeProxyProvider();


    /**
     *  Tests if a voting provider is supported. 
     *
     *  @return <code> true </code> if a voting provider is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVotingProxyProvider();


    /**
     *  Tests if a workflow provider is supported. 
     *
     *  @return <code> true </code> if a workflow provider is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowProxyProvider();
}
