//
// org.osid.ordering.ItemQuery
//
//     The OSID Java specification for org.osid.ordering.ItemQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the query for searching for items. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ItemQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the order <code> Id </code> for this query to match orders 
     *  assigned to items. 
     *
     *  @param  orderId a order <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> orderId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOrderId(org.osid.id.Id orderId, boolean match);


    /**
     *  Clears the order <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrderIdTerms();


    /**
     *  Tests if a order query is available. 
     *
     *  @return <code> true </code> if a order query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderQuery();


    /**
     *  Gets the query for an item. 
     *
     *  @return the order query 
     *  @throws org.osid.UnimplementedException <code> supportsOrderQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderQuery getOrderQuery();


    /**
     *  Clears the order terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrderTerms();


    /**
     *  Matches items that are derived. 
     *
     *  @param  match <code> true </code> to match derived items, <code> false 
     *          </code> to match selected items 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDerived(boolean match);


    /**
     *  Clears the derived terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDerivedTerms();


    /**
     *  Sets the product <code> Id </code> for this query. 
     *
     *  @param  productId a product <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> productId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProductId(org.osid.id.Id productId, boolean match);


    /**
     *  Clears the product <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProductIdTerms();


    /**
     *  Tests if a product query is available. 
     *
     *  @return <code> true </code> if a product query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductQuery();


    /**
     *  Gets the query for a product. 
     *
     *  @return the product query 
     *  @throws org.osid.UnimplementedException <code> supportsProductQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductQuery getProductQuery();


    /**
     *  Clears the product terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProductTerms();


    /**
     *  Matches quantities between the given range inclusive. 
     *
     *  @param  low low range 
     *  @param  high high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQuantity(long low, long high, boolean match);


    /**
     *  Clears the quantity terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQuantityTerms();


    /**
     *  Matches costs between the given range inclusive. 
     *
     *  @param  low low range 
     *  @param  high high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCost(org.osid.financials.Currency low, 
                          org.osid.financials.Currency high, boolean match);


    /**
     *  Clears the cost terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCostTerms();


    /**
     *  Matches minimum costs between the given range inclusive. 
     *
     *  @param  cost cost 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cost </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumCost(org.osid.financials.Currency cost, 
                                 boolean match);


    /**
     *  Clears the minimum cost terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumCostTerms();


    /**
     *  Sets the item <code> Id </code> for this query to match orders 
     *  assigned to stores. 
     *
     *  @param  storeId a store <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStoreId(org.osid.id.Id storeId, boolean match);


    /**
     *  Clears the store <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreIdTerms();


    /**
     *  Tests if a <code> StoreQuery </code> is available. 
     *
     *  @return <code> true </code> if a store query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreQuery();


    /**
     *  Gets the query for a store query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the store query 
     *  @throws org.osid.UnimplementedException <code> supportsStoreQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreQuery getStoreQuery();


    /**
     *  Clears the store terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreTerms();


    /**
     *  Gets the item query record corresponding to the given <code> Item 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  itemRecordType an item record type 
     *  @return the item query record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.ItemQueryRecord getItemQueryRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
