//
// org.osid.ordering.ItemSearchOrder
//
//     The OSID Java specification for org.osid.ordering.ItemSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface ItemSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the order. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByOrder(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an order order is available. 
     *
     *  @return <code> true </code> if an order order is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderSearchOrder();


    /**
     *  Gets the order order. 
     *
     *  @return the order search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrderSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderSearchOrder() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderSearchOrder getOrderSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the derived 
     *  flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDerived(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the product. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByProduct(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a product order is available. 
     *
     *  @return <code> true </code> if a product order is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductSearchOrder();


    /**
     *  Gets the product order. 
     *
     *  @return the product search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProductSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.ProductSearchOrder getProductSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the quantity. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByQuantity(org.osid.SearchOrderStyle style);


    /**
     *  Gets the item search record order corresponding to the given item 
     *  record Type. Multiple retrievals return the same underlying object. 
     *
     *  @param  itemRecordType an item record type 
     *  @return the item search order record 
     *  @throws org.osid.NullArgumentException <code> itemRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(itemRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.ItemSearchOrderRecord getItemSearchOrderRecord(org.osid.type.Type itemRecordType)
        throws org.osid.OperationFailedException;
}
