//
// org.osid.ordering.MyOrderSession
//
//     The OSID Java specification for org.osid.ordering.MyOrderSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This session defines methods for retrieving orders. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated store view: All order methods in this session operate, 
 *      retrieve and pertain to orders defined explicitly in the current 
 *      store. Using an isolated view is useful for managing orders with the 
 *      <code> OrderAdminSession. </code> </li> 
 *      <li> federated store view: All order lookup methods in this session 
 *      operate, retrieve and pertain to all orders defined in this store and 
 *      any other stores implicitly available in this store through store 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedStoreView() </code> and <code> 
 *  useIsolatedStoreView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface MyOrderSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup orders. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if order lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupMyOrders();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeOrderView();


    /**
     *  A complete view of the <code> Order </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryOrderView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in stores which are children of this store in the 
     *  store hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedStoreView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this store only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedStoreView();


    /**
     *  Gets all orders for the subscriber related to the current agent. In 
     *  plenary mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session. In both cases, the order of 
     *  the set is not specifed. 
     *
     *  @return a list of orders 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOrders()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all orders not yet submitted for the customer related to this 
     *  agent. In plenary mode, the returned list contains all known entries 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those entries that are accessible through this session. In both cases, 
     *  the order of the set is not specifed. 
     *
     *  @return a list of orders 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getUnsubmittedOrders()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all submitted and not closed orders for the customer related to 
     *  this agent. In plenary mode, the returned list contains all known 
     *  entries or an error results. Otherwise, the returned list may contain 
     *  only those entries that are accessible through this session. In both 
     *  cases, the order of the set is not specifed. 
     *
     *  @return a list of orders 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getOpenOrders()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all closed orders for the customer related to this agent. In 
     *  plenary mode, the returned list contains all known entries or an error 
     *  results. Otherwise, the returned list may contain only those entries 
     *  that are accessible through this session. In both cases, the order of 
     *  the set is not specifed. 
     *
     *  @return a list of orders 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderList getClosedOrders()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
