//
// org.osid.ordering.OrderQuery
//
//     The OSID Java specification for org.osid.ordering.OrderQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the query for searching orders. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface OrderQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidAggregateableQuery {


    /**
     *  Sets the item <code> Id </code> for this query to match orders by 
     *  customers. 
     *
     *  @param  customerId a customer <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCustomerId(org.osid.id.Id customerId, boolean match);


    /**
     *  Clears the customer <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerIdTerms();


    /**
     *  Tests if a <code> CustomerQuery </code> is available. 
     *
     *  @return <code> true </code> if a customer query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCustomerQuery();


    /**
     *  Gets the query for a customer query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the customer query 
     *  @throws org.osid.UnimplementedException <code> supportsCustomerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCustomerQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getCustomerQuery();


    /**
     *  Clears the customer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCustomerTerms();


    /**
     *  Sets the item <code> Id </code> for this query to match orders 
     *  assigned to items. 
     *
     *  @param  itemId an item <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchItemId(org.osid.id.Id itemId, boolean match);


    /**
     *  Clears the item <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemIdTerms();


    /**
     *  Tests if an <code> ItemQuery </code> is available. 
     *
     *  @return <code> true </code> if an item query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsItemQuery();


    /**
     *  Gets the query for an item query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the item query 
     *  @throws org.osid.UnimplementedException <code> supportsItemQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ItemQuery getItemQuery();


    /**
     *  Matches orders with any item. 
     *
     *  @param  match <code> true </code> for a to matc h odrers with any 
     *          items, <code> false </code> to match orders with no items 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyItem(boolean match);


    /**
     *  Clears the item terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearItemTerms();


    /**
     *  Matches total costs between the given range inclusive. 
     *
     *  @param  low low range 
     *  @param  high high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTotalCost(org.osid.financials.Currency low, 
                               org.osid.financials.Currency high, 
                               boolean match);


    /**
     *  Clears the total cost terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTotalCostTerms();


    /**
     *  Matches total costs greter than or equal to the given cost. 
     *
     *  @param  cost a cost 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMinimumTotalCost(org.osid.financials.Currency cost, 
                                      boolean match);


    /**
     *  Clears the minimum total cost terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumTotalCostTerms();


    /**
     *  Matches atomic orders. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAtomic(boolean match);


    /**
     *  Clears the atomic terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAtomicTerms();


    /**
     *  Matches orders submitted between the given time range inclusive. 
     *
     *  @param  from starting time range 
     *  @param  to ending time range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubmitDate(org.osid.calendaring.DateTime from, 
                                org.osid.calendaring.DateTime to, 
                                boolean match);


    /**
     *  Clears the submit date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubmitDateTerms();


    /**
     *  Sets a submitting resource <code> Id. </code> 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubmitterId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the submitter <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubmitterIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubmitterQuery();


    /**
     *  Gets the query for a submitting agent query. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubmitterQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubmitterQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSubmitterQuery();


    /**
     *  Matches any submitted order. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySubmitter(boolean match);


    /**
     *  Clears the submitter terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubmitterTerms();


    /**
     *  Sets a submitting agent <code> Id. </code> 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubmittingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the submitter <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubmittingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubmittingAgentQuery();


    /**
     *  Gets the query for a submitting agent query. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubmittingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubmittingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getSubmittingAgentQuery();


    /**
     *  Matches any submitted order. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySubmittingAgent(boolean match);


    /**
     *  Clears the submitter terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubmittingAgentTerms();


    /**
     *  Matches orders closed between the given time range inclusive. 
     *
     *  @param  from starting time range 
     *  @param  to ending time range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> itemId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClosedDate(org.osid.calendaring.DateTime from, 
                                org.osid.calendaring.DateTime to, 
                                boolean match);


    /**
     *  Clears the closed date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosedDateTerms();


    /**
     *  Sets a closer resource <code> Id. </code> 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCloserId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the closer <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloserIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCloserQuery();


    /**
     *  Gets the query for a closer resource query. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsCloserQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCloserQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getCloserQuery();


    /**
     *  Matches any closed order. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCloser(boolean match);


    /**
     *  Clears the closer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCloserTerms();


    /**
     *  Sets a closing agent <code> Id. </code> 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchClosingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the closer <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsClosingAgentQuery();


    /**
     *  Gets the query for a closing agent query. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsClosingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsClosingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getClosingAgentQuery();


    /**
     *  Matches any closed order. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyClosingAgent(boolean match);


    /**
     *  Clears the closer terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearClosingAgentTerms();


    /**
     *  Sets the item <code> Id </code> for this query to match orders 
     *  assigned to stores. 
     *
     *  @param  storeId a store <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStoreId(org.osid.id.Id storeId, boolean match);


    /**
     *  Clears the store <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreIdTerms();


    /**
     *  Tests if a <code> StoreQuery </code> is available. 
     *
     *  @return <code> true </code> if a store query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreQuery();


    /**
     *  Gets the query for a store query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the store query 
     *  @throws org.osid.UnimplementedException <code> supportsStoreQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreQuery getStoreQuery();


    /**
     *  Clears the store terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreTerms();


    /**
     *  Gets the order query record corresponding to the given <code> Order 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  orderRecordType a order record type 
     *  @return the order query record 
     *  @throws org.osid.NullArgumentException <code> orderRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(orderRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.OrderQueryRecord getOrderQueryRecord(org.osid.type.Type orderRecordType)
        throws org.osid.OperationFailedException;
}
