//
// org.osid.ordering.PriceForm
//
//     The OSID Java specification for org.osid.ordering.PriceForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the form for creating and updating <code> Prices. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> PriceAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface PriceForm
    extends org.osid.OsidRuleForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for the minimum quantity. 
     *
     *  @return metadata for the minumim quantity 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinQuantityMetadata();


    /**
     *  Sets the minimum quantity. 
     *
     *  @param  minQuantity the new minumim quantity 
     *  @throws org.osid.InvalidArgumentException <code> minQuantity </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumQuantity(long minQuantity);


    /**
     *  Clears the minimum quantity. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumQuantity();


    /**
     *  Gets the metadata for the minimum quantity. 
     *
     *  @return metadata for the maximum quantity 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaxQuantityMetadata();


    /**
     *  Sets the maximum quantity. 
     *
     *  @param  minQuantity the new maximum quantity 
     *  @throws org.osid.InvalidArgumentException <code> maxQuantity </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaximumQuantity(long minQuantity);


    /**
     *  Clears the maximum quantity. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumQuantity();


    /**
     *  Gets the metadata for the demographic. 
     *
     *  @return metadata for the demographic 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDemographicMetadata();


    /**
     *  Sets the demographic. 
     *
     *  @param  resourceId the new demographic 
     *  @throws org.osid.InvalidArgumentException <code> resourceId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDemographic(org.osid.id.Id resourceId);


    /**
     *  Clears the demographic. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDemographic();


    /**
     *  Gets the metadata for the amount. 
     *
     *  @return metadata for the amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAmountMetadata();


    /**
     *  Sets the amount. 
     *
     *  @param  amount the new amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAmount(org.osid.search.terms.CurrencyRangeTerm[] amount);


    /**
     *  Clears the amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAmount();


    /**
     *  Gets the metadata for the recurring interval. 
     *
     *  @return metadata for the recurring interval 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRecurringIntervalMetadata();


    /**
     *  Sets the recurring interval. 
     *
     *  @param  interval the new recurring interval 
     *  @throws org.osid.InvalidArgumentException <code> interval </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRecurringInterval(org.osid.calendaring.Duration interval);


    /**
     *  Clears the recurring interval. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecurringInterval();


    /**
     *  Gets the <code> PriceFormRecord </code> corresponding to the given 
     *  price record <code> Type. </code> 
     *
     *  @param  priceRecordType the price record type 
     *  @return the price form record 
     *  @throws org.osid.NullArgumentException <code> priceRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(priceRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.PriceFormRecord getPriceFormRecord(org.osid.type.Type priceRecordType)
        throws org.osid.OperationFailedException;
}
