//
// org.osid.ordering.PriceQueryInspector
//
//     The OSID Java specification for org.osid.ordering.PriceQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the query inspector for examining price queries. </p>
 */

public interface PriceQueryInspector
    extends org.osid.OsidRuleQueryInspector,
            org.osid.OsidSubjugateableQueryInspector {


    /**
     *  Gets the price schedule <code> Id </code> terms. 
     *
     *  @return the price schedule <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getPriceScheduleIdTerms();


    /**
     *  Gets the price schedule terms. 
     *
     *  @return the price schedule terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleQueryInspector[] getPriceScheduleTerms();


    /**
     *  Gets the minimum quantity terms. 
     *
     *  @return the minimum quantity terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getMinimumQuantityTerms();


    /**
     *  Gets the maximum quantity terms. 
     *
     *  @return the maximum quantity terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CardinalRangeTerm[] getMaximumQuantityTerms();


    /**
     *  Gets the demographic <code> Id </code> terms. 
     *
     *  @return the demographic <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDemographicIdTerms();


    /**
     *  Gets the demographic terms. 
     *
     *  @return the demographic terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getDemographicTerms();


    /**
     *  Gets the amount terms. 
     *
     *  @return the amount terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyRangeTerm[] getAmountTerms();


    /**
     *  Gets the minimum amount terms. 
     *
     *  @return the minimum amount terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.CurrencyTerm[] getMinimumAmountTerms();


    /**
     *  Gets the recurring interval terms. 
     *
     *  @return the recurring interval terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DurationRangeTerm[] getRecurringIntervalTerms();


    /**
     *  Gets the item <code> Id </code> terms. 
     *
     *  @return the item <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getItemIdTerms();


    /**
     *  Gets the item terms. 
     *
     *  @return the item terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ItemQueryInspector[] getItemTerms();


    /**
     *  Gets the store <code> Id </code> terms. 
     *
     *  @return the store <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getStoreIdTerms();


    /**
     *  Gets the store terms. 
     *
     *  @return the store terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.StoreQueryInspector[] getStoreTerms();


    /**
     *  Gets the price query inspector record corresponding to the given 
     *  <code> Price </code> record <code> Type. </code> 
     *
     *  @param  priceRecordType an price record type 
     *  @return the price query inspector record 
     *  @throws org.osid.NullArgumentException <code> priceRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(priceRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.PriceQueryInspectorRecord getPriceQueryInspectorRecord(org.osid.type.Type priceRecordType)
        throws org.osid.OperationFailedException;
}
