//
// org.osid.ordering.PriceScheduleAdminSession
//
//     The OSID Java specification for org.osid.ordering.PriceScheduleAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This session creates, updates, and deletes <code> PriceSchedules. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  PriceSchedule, </code> a <code> PriceScheduleForm </code> is requested 
 *  using <code> gePriceScheduleFormForCreate() </code> specifying the desired 
 *  record <code> Types </code> or none if no record <code> Types </code> are 
 *  needed. The returned <code> PriceScheduleForm </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> 
 *  PriceScheduleForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> PriceScheduleForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> PriceScheduleForms </code> are requested to the 
 *  <code> PriceSchedule </code> <code> Id </code> that is to be updated using 
 *  <code> getPriceScheduleFormForUpdate(). </code> Similarly, the <code> 
 *  PriceScheduleForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  PriceScheduleForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> PriceSchedules. </code> To unmap a 
 *  <code> PriceSchedule </code> from the current <code> Store, </code> the 
 *  <code> PriceScheduleStoreAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> PriceSchedule </code> 
 *  itself thus removing it from all known <code> Store </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface PriceScheduleAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> PriceSchedules. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Price </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> PriceSchedule </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePriceSchedules();


    /**
     *  Tests if this user can create a single <code> PriceSchedule </code> 
     *  using the desired record types. While <code> 
     *  OrderingManager.getPriceScheduleRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> PriceSchedule. </code> 
     *  Providing an empty array tests if a <code> PriceSchedule </code> can 
     *  be created with no records. 
     *
     *  @param  priceScheduleRecordTypes array of price schedule record types 
     *  @return <code> true </code> if <code> PriceSchedule </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceScheduleRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePriceScheduleWithRecordTypes(org.osid.type.Type[] priceScheduleRecordTypes);


    /**
     *  Gets the price schedule form for creating new prices. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  priceScheduleRecordTypes array of price schedule record types 
     *  @return the price schedule form 
     *  @throws org.osid.NullArgumentException <code> priceScheduleRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleForm getPriceScheduleFormForCreate(org.osid.type.Type[] priceScheduleRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> PriceSchedule. </code> 
     *
     *  @param  priceScheduleForm the form for this <code> PriceSchedule 
     *          </code> 
     *  @return the new <code> PriceSchedule </code> 
     *  @throws org.osid.IllegalStateException <code> priceScheduleForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> priceScheduleForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> priceScheduleForm </code> 
     *          did not originate from <code> getPriceScheduleFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceSchedule createPriceSchedule(org.osid.ordering.PriceForm priceScheduleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> PriceSchedules. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> PriceSchedule </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer update operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> PriceSchedule </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdatePriceSchedules();


    /**
     *  Gets the price S\schedule form for updating an existing price. A new 
     *  price schedule form should be requested for each update transaction. 
     *
     *  @param  priceScheduleId the <code> Id </code> of the <code> Price 
     *          </code> 
     *  @return the price schedule form 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleForm getPriceScheduleFormForUpdate(org.osid.id.Id priceScheduleId);


    /**
     *  Updates an existing price schedule. 
     *
     *  @param  priceScheduleForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> priceScheduleForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> priceScheduleForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> priceScheduleForm </code> 
     *          did not originate from <code> getPriceScheduleFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updatePriceSchedule(org.osid.ordering.PriceScheduleForm priceScheduleForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> PriceSchedules </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> PriceSchedule </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer delete operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> PriceSchedule </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeletePriceSchedules();


    /**
     *  Deletes a <code> PriceSchedule. </code> 
     *
     *  @param  priceScheduleId the <code> Id </code> of the <code> 
     *          PriceSchedule </code> to remove 
     *  @throws org.osid.NotFoundException <code> priceScheduleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletePriceSchedule(org.osid.id.Id priceScheduleId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  PriceSchedules. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> PriceSchedule </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManagePriceScheduleAliases();


    /**
     *  Adds an <code> Id </code> to a <code> PriceSchedule </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> PriceSchedule </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another price schedule, it is 
     *  reassigned to the given price schedule <code> Id. </code> 
     *
     *  @param  priceScheduleId the <code> Id </code> of a <code> 
     *          PriceSchedule </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> priceScheduleId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasPriceSchedule(org.osid.id.Id priceScheduleId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Prices </code> for a <code> 
     *  PriceSchedule. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known creating a 
     *  <code> PriceSchedule </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @param  priceScheduleId the <code> Id </code> of a <code> 
     *          PriceSchedule </code> 
     *  @return <code> false </code> if <code> Price </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePrices(org.osid.id.Id priceScheduleId);


    /**
     *  Tests if this user can create a single <code> Price </code> using the 
     *  desired record types. While <code> 
     *  OrderingManager.getPriceRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Price. </code> Providing an 
     *  empty array tests if a <code> Grade </code> can be created with no 
     *  records. 
     *
     *  @param  priceScheduleId the <code> Id </code> of a <code> 
     *          PriceSchedule </code> 
     *  @param  priceRecordTypes array of price record types 
     *  @return <code> true </code> if <code> Price </code> creation using the 
     *          specified <code> Types </code> is supported, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          or <code> priceRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePriceWithRecordTypes(org.osid.id.Id priceScheduleId, 
                                                 org.osid.type.Type[] priceRecordTypes);


    /**
     *  Gets the price form for creating new prices. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  priceScheduleId the <code> Id </code> of a <code> 
     *          PriceSchedule </code> 
     *  @param  priceRecordTypes array of price record types 
     *  @return the price form 
     *  @throws org.osid.NotFoundException <code> priceScheduleId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          or <code> priceRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.GradeForm getPriceFormForCreate(org.osid.id.Id priceScheduleId, 
                                                            org.osid.type.Type[] priceRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Price. </code> 
     *
     *  @param  priceForm the form for this <code> Price </code> 
     *  @return the new <code> Price </code> 
     *  @throws org.osid.IllegalStateException <code> priceForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> priceForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> priceForm </code> did not 
     *          originate from <code> getPriceFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Price createPrice(org.osid.ordering.PriceForm priceForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Prices. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Price </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @param  priceScheduleId the <code> Id </code> of a <code> 
     *          PriceSchedule </code> 
     *  @return <code> false </code> if <code> Price </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceSchedule </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdatePrices(org.osid.id.Id priceScheduleId);


    /**
     *  Gets the price form for updating an existing price. A new price form 
     *  should be requested for each update transaction. 
     *
     *  @param  priceId the <code> Id </code> of the <code> Price </code> 
     *  @return the price form 
     *  @throws org.osid.NotFoundException <code> priceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> priceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceForm getPriceFormForUpdate(org.osid.id.Id priceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing price. 
     *
     *  @param  priceForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> priceForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> priceForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> priceForm </code> did not 
     *          originate from <code> getPriceFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updatePrice(org.osid.ordering.PriceForm priceForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete prices. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> Price </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @param  priceScheduleId the <code> Id </code> of a <code> 
     *          PriceSchedule </code> 
     *  @return <code> false </code> if <code> Grade </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeletePrices(org.osid.id.Id priceScheduleId);


    /**
     *  Deletes a <code> Price. </code> 
     *
     *  @param  priceId the <code> Id </code> of the <code> Price </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> priceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> priceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletePrice(org.osid.id.Id priceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Prices. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Price </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManagePriceAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Price </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Price </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another price, it is reassigned to the given price <code> 
     *  Id. </code> 
     *
     *  @param  priceId the <code> Id </code> of a <code> Price </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> priceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> priceId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasPrice(org.osid.id.Id priceId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
