//
// org.osid.ordering.PriceScheduleQuery
//
//     The OSID Java specification for org.osid.ordering.PriceScheduleQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the query for searching for price schedules. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface PriceScheduleQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidAggregateableQuery {


    /**
     *  Sets the price <code> Id </code> for this query. 
     *
     *  @param  priceId a price <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> priceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPriceId(org.osid.id.Id priceId, boolean match);


    /**
     *  Clears the price <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceIdTerms();


    /**
     *  Tests if a price query is available. 
     *
     *  @return <code> true </code> if a price query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceQuery();


    /**
     *  Gets the query for a price. 
     *
     *  @return the price query 
     *  @throws org.osid.UnimplementedException <code> supportsPriceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.PriceQuery getPriceQuery();


    /**
     *  Matches price schedules with any price. 
     *
     *  @param  match <code> true </code> to match price sschedules with any 
     *          price, <code> false </code> to match price schedules with no 
     *          prices 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPrice(boolean match);


    /**
     *  Clears the price terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceTerms();


    /**
     *  Sets the product <code> Id </code> for this query. 
     *
     *  @param  productId a product <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> productId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProductId(org.osid.id.Id productId, boolean match);


    /**
     *  Clears the product <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProductIdTerms();


    /**
     *  Tests if a product query is available. 
     *
     *  @return <code> true </code> if a product query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductQuery();


    /**
     *  Gets the query for a product. 
     *
     *  @return the product query 
     *  @throws org.osid.UnimplementedException <code> supportsProductQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductQuery getProductQuery();


    /**
     *  Matches price schedules used with any product. 
     *
     *  @param  match <code> true </code> to match price schedules with any 
     *          product, <code> false </code> to match price schedules with no 
     *          products 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProduct(boolean match);


    /**
     *  Clears the product terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProductTerms();


    /**
     *  Sets the price <code> Id </code> for this query to match orders 
     *  assigned to stores. 
     *
     *  @param  storeId a store <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStoreId(org.osid.id.Id storeId, boolean match);


    /**
     *  Clears the store <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreIdTerms();


    /**
     *  Tests if a <code> StoreQuery </code> is available. 
     *
     *  @return <code> true </code> if a store query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStoreQuery();


    /**
     *  Gets the query for a store query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the store query 
     *  @throws org.osid.UnimplementedException <code> supportsStoreQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStoreQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.StoreQuery getStoreQuery();


    /**
     *  Clears the store terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStoreTerms();


    /**
     *  Gets the price schedule query record corresponding to the given <code> 
     *  PriceSchedule </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested boolean <code> OR </code> term. 
     *
     *  @param  priceScheduleRecordType a price schedule record type 
     *  @return the price schedule query record 
     *  @throws org.osid.NullArgumentException <code> priceScheduleRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(priceScheduleRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.PriceScheduleQueryRecord getPriceScheduleQueryRecord(org.osid.type.Type priceScheduleRecordType)
        throws org.osid.OperationFailedException;
}
