//
// org.osid.ordering.ProductLookupSession
//
//     The OSID Java specification for org.osid.ordering.ProductLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This session provides methods for retrieving <code> Product </code> 
 *  objects. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated store view: All order methods in this session operate, 
 *      retrieve and pertain to products defined explicitly in the current 
 *      store. Using an isolated view is useful for managing products with the 
 *      <code> ProductAdminSession. </code> </li> 
 *      <li> federated store view: All product lookup methods in this session 
 *      operate, retrieve and pertain to all products defined in this store 
 *      and any other stores implicitly available in this store through store 
 *      inheritence. </li> 
 *  </ul>
 *  
 */

public interface ProductLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Product </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProducts();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProductView();


    /**
     *  A complete view of the <code> Product </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProductView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include products in stores which are children of this store in the 
     *  store hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedStoreView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this store only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedStoreView();


    /**
     *  Gets the <code> Product </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Product 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Product </code> and retained for compatibility. 
     *
     *  @param  productId <code> Id </code> of the <code> Product </code> 
     *  @return the product 
     *  @throws org.osid.NotFoundException <code> productId </code> not found 
     *  @throws org.osid.NullArgumentException <code> productId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ordering.Product getProduct(org.osid.id.Id productId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProductList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  products specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Products </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  productIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Product </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> productIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ProductList getProductsByIds(org.osid.id.IdList productIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProductList </code> corresponding to the given product 
     *  genus <code> Type </code> which does not include products of genus 
     *  types derived from the specified <code> Type. </code> In plenary mode, 
     *  the returned list contains all known products or an error results. 
     *  Otherwise, the returned list may contain only those products that are 
     *  accessible through this session. 
     *
     *  @param  productGenusType a product genus type 
     *  @return the returned <code> Product </code> list 
     *  @throws org.osid.NullArgumentException <code> productGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ProductList getProductsByGenusType(org.osid.type.Type productGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProductList </code> corresponding to the given product 
     *  genus <code> Type </code> and include any additional products with 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known products or an error 
     *  results. Otherwise, the returned list may contain only those products 
     *  that are accessible through this session. 
     *
     *  @param  productGenusType a product genus type 
     *  @return the returned <code> Product </code> list 
     *  @throws org.osid.NullArgumentException <code> productGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ProductList getProductsByParentGenusType(org.osid.type.Type productGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProductList </code> containing the given repository 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known products or an error results. Otherwise, the 
     *  returned list may contain only those products that are accessible 
     *  through this session. 
     *
     *  @param  productRecordType a product record type 
     *  @return the returned <code> Product </code> list 
     *  @throws org.osid.NullArgumentException <code> productRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ProductList getProductsByRecordType(org.osid.type.Type productRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Product </code> specified by its product code. <code> 
     *  </code> 
     *
     *  @param  code a product code 
     *  @return the product 
     *  @throws org.osid.NotFoundException <code> code </code> not found 
     *  @throws org.osid.NullArgumentException <code> code </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ordering.ProductList getProductsByCode(String code)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProductList </code> containing the given price schedule. 
     *  In plenary mode, the returned list contains all known products or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  products that are accessible through this session. 
     *
     *  @param  priceScheduleId a price schedule <code> Id </code> 
     *  @return the product list 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.ordering.ProductList getProductsByPriceSchedule(org.osid.id.Id priceScheduleId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Products. </code> In plenary mode, the returned list 
     *  contains all known products or an error results. Otherwise, the 
     *  returned list may contain only those products that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Products </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ProductList getProducts()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
