//
// org.osid.ordering.ProductStoreAssignmentSession
//
//     The OSID Java specification for org.osid.ordering.ProductStoreAssignmentSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This session provides methods to re-assign <code> Products </code> to 
 *  <code> Stores. </code> A <code> Product </code> may map to multiple <code> 
 *  Stores </code> and removing the last reference to a <code> Product </code> 
 *  is the equivalent of deleting it. Each <code> Store </code> may have its 
 *  own authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Product </code> to another <code> Store 
 *  </code> is not a copy operation (eg: does not change its <code> Id </code> 
 *  ). </p>
 */

public interface ProductStoreAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter product/store mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProducts();


    /**
     *  Tests if this user can alter product/store mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProductsToStore(org.osid.id.Id storeId);


    /**
     *  Gets a list of stores including and under the given store node in 
     *  which any product can be assigned. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @return list of assignable store <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableStoreIds(org.osid.id.Id storeId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of stores including and under the given store node in 
     *  which a specific product can be assigned. 
     *
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @param  productId the <code> Id </code> of the <code> Product </code> 
     *  @return list of assignable store <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> storeId </code> or 
     *          <code> productId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableStoreIdsForProduct(org.osid.id.Id storeId, 
                                                              org.osid.id.Id productId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Product </code> to a <code> Store. </code> 
     *
     *  @param  productId the <code> Id </code> of the <code> Product </code> 
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @throws org.osid.AlreadyExistsException <code> productId </code> is 
     *          already assigned to <code> storeId </code> 
     *  @throws org.osid.NotFoundException <code> productId </code> or <code> 
     *          storeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> productId </code> or 
     *          <code> storeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignProductToStore(org.osid.id.Id productId, 
                                     org.osid.id.Id storeId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Product </code> from a <code> Store. </code> 
     *
     *  @param  productId the <code> Id </code> of the <code> Product </code> 
     *  @param  storeId the <code> Id </code> of the <code> Store </code> 
     *  @throws org.osid.NotFoundException <code> productId </code> or <code> 
     *          storeId </code> not found or <code> productId </code> not 
     *          assigned to <code> storeId </code> 
     *  @throws org.osid.NullArgumentException <code> productId </code> or 
     *          <code> storeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignProductFromStore(org.osid.id.Id productId, 
                                         org.osid.id.Id storeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
