//
// org.osid.ordering.StoreQuery
//
//     The OSID Java specification for org.osid.ordering.StoreQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the query for searching for stores. Each method specifies an 
 *  <code> AND </code> term while multiple terms of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface StoreQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the order <code> Id </code> for this query to match orders 
     *  assigned to stores. 
     *
     *  @param  orderId a order <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> orderId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOrderId(org.osid.id.Id orderId, boolean match);


    /**
     *  Clears the order <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrderIdTerms();


    /**
     *  Tests if a order query is available. 
     *
     *  @return <code> true </code> if a order query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrderQuery();


    /**
     *  Gets the query for an order. 
     *
     *  @return the order query 
     *  @throws org.osid.UnimplementedException <code> supportsOrderQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrderQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.OrderQuery getOrderQuery();


    /**
     *  Matches stores with any order. 
     *
     *  @param  match <code> true </code> to match stores with any order, 
     *          <code> false </code> to match stores with no orders 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOrder(boolean match);


    /**
     *  Clears the order terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrderTerms();


    /**
     *  Sets the product <code> Id </code> for this query. 
     *
     *  @param  productId a product <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> productId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProductId(org.osid.id.Id productId, boolean match);


    /**
     *  Clears the product <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProductIdTerms();


    /**
     *  Tests if a product query is available. 
     *
     *  @return <code> true </code> if a product query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProductQuery();


    /**
     *  Gets the query for a product. 
     *
     *  @return the product query 
     *  @throws org.osid.UnimplementedException <code> supportsProductQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProductQuery() </code> is <code> true. </code> 
     */

    public org.osid.ordering.ProductQuery getProductQuery();


    /**
     *  Matches stores with any product. 
     *
     *  @param  match <code> true </code> to match stores with any product, 
     *          <code> false </code> to match stores with no products 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProduct(boolean match);


    /**
     *  Clears the product terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProductTerms();


    /**
     *  Sets the price schedule <code> Id </code> for this query. 
     *
     *  @param  priceScheduleId a price schedule <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> priceScheduleId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPriceScheduleId(org.osid.id.Id priceScheduleId, 
                                     boolean match);


    /**
     *  Clears the price schedule <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceScheduleIdTerms();


    /**
     *  Tests if a price schedule query is available. 
     *
     *  @return <code> true </code> if a price schedule query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceScheduleQuery();


    /**
     *  Gets the query for a price schedule. 
     *
     *  @return the price schedule query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPriceScheduleQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPriceScheduleQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.PriceScheduleQuery getPriceScheduleQuery();


    /**
     *  Matches products with any price schedule. 
     *
     *  @param  match <code> true </code> to match products with any price 
     *          schedule, <code> false </code> to match products with no price 
     *          schedule 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPriceSchedule(boolean match);


    /**
     *  Clears the price schedule terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPriceScheduleTerms();


    /**
     *  Sets the store <code> Id </code> for this query to match stores that 
     *  have the specified store as an ancestor. 
     *
     *  @param  storeId a store <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorStoreId(org.osid.id.Id storeId, boolean match);


    /**
     *  Clears the ancestor store <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorStoreIdTerms();


    /**
     *  Tests if a <code> StoreQuery </code> is available. 
     *
     *  @return <code> true </code> if a store query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorStoreQuery();


    /**
     *  Gets the query for a store. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the store query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorStoreQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorStoreQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.StoreQuery getAncestorStoreQuery();


    /**
     *  Matches stores with any ancestor. 
     *
     *  @param  match <code> true </code> to match stores with any ancestor, 
     *          <code> false </code> to match root stores 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorStore(boolean match);


    /**
     *  Clears the ancestor store terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorStoreTerms();


    /**
     *  Sets the store <code> Id </code> for this query to match stores that 
     *  have the specified store as a descendant. 
     *
     *  @param  storeId a store <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> storeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantStoreId(org.osid.id.Id storeId, boolean match);


    /**
     *  Clears the descendant store <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantStoreIdTerms();


    /**
     *  Tests if a <code> StoreQuery </code> is available. 
     *
     *  @return <code> true </code> if a store query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantStoreQuery();


    /**
     *  Gets the query for a store. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the store query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantStoreQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantStoreQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.ordering.StoreQuery getDescendantStoreQuery();


    /**
     *  Matches stores with any descendant. 
     *
     *  @param  match <code> true </code> to match stores with any descendant, 
     *          <code> false </code> to match leaf stores 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantStore(boolean match);


    /**
     *  Clears the descendant store terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantStoreTerms();


    /**
     *  Gets the store query record corresponding to the given <code> Store 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  storeRecordType a store record type 
     *  @return the store query record 
     *  @throws org.osid.NullArgumentException <code> storeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(storeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.StoreQueryRecord getStoreQueryRecord(org.osid.type.Type storeRecordType)
        throws org.osid.OperationFailedException;
}
