//
// org.osid.ordering.StoreQueryInspector
//
//     The OSID Java specification for org.osid.ordering.StoreQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering;


/**
 *  <p>This is the query inspector for examining store queries. </p>
 */

public interface StoreQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the order <code> Id </code> terms. 
     *
     *  @return the order <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getOrderIdTerms();


    /**
     *  Gets the order terms. 
     *
     *  @return the order terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.OrderQueryInspector[] getOrderTerms();


    /**
     *  Gets the product <code> Id </code> terms. 
     *
     *  @return the product <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getProductIdTerms();


    /**
     *  Gets the product terms. 
     *
     *  @return the product terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.ProductQueryInspector[] getProductTerms();


    /**
     *  Gets the price schedule <code> Id </code> terms. 
     *
     *  @return the price schedule <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getPriceScheduleIdTerms();


    /**
     *  Gets the price schedule terms. 
     *
     *  @return the price schedule terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.PriceScheduleQueryInspector[] getPriceScheduleTerms();


    /**
     *  Gets the ancestor store <code> Id </code> terms. 
     *
     *  @return the ancestor store <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorStoreIdTerms();


    /**
     *  Gets the ancestor store terms. 
     *
     *  @return the ancestor store terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.StoreQueryInspector[] getAncestorStoreTerms();


    /**
     *  Gets the descendant store <code> Id </code> terms. 
     *
     *  @return the descendant store <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantStoreIdTerms();


    /**
     *  Gets the descendant store terms. 
     *
     *  @return the descendant store terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.StoreQueryInspector[] getDescendantStoreTerms();


    /**
     *  Gets the store query inspector record corresponding to the given 
     *  <code> Store </code> record <code> Type. </code> 
     *
     *  @param  storeRecordType a store record type 
     *  @return the store query inspector record 
     *  @throws org.osid.NullArgumentException <code> storeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(storeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.records.StoreQueryInspectorRecord getStoreQueryInspectorRecord(org.osid.type.Type storeRecordType)
        throws org.osid.OperationFailedException;
}
