//
// org.osid.ordering.rules.OrderingRulesProfile
//
//     The OSID Java specification for org.osid.ordering.rules.OrderingRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering.rules;


/**
 *  <p>The ordering rules profile describes the interoperability among 
 *  ordering rules services. </p>
 */

public interface OrderingRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up price enablers is supported. 
     *
     *  @return <code> true </code> if price enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerLookup();


    /**
     *  Tests if querying price enablers is supported. 
     *
     *  @return <code> true </code> if price enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerQuery();


    /**
     *  Tests if searching price enablers is supported. 
     *
     *  @return <code> true </code> if price enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerSearch();


    /**
     *  Tests if a price enabler administrative service is supported. 
     *
     *  @return <code> true </code> if price enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerAdmin();


    /**
     *  Tests if a price enabler notification service is supported. 
     *
     *  @return <code> true </code> if price enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerNotification();


    /**
     *  Tests if a price enabler store lookup service is supported. 
     *
     *  @return <code> true </code> if a price enabler store lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerStore();


    /**
     *  Tests if a price enabler store service is supported. 
     *
     *  @return <code> true </code> if price enabler store assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerStoreAssignment();


    /**
     *  Tests if a price enabler store lookup service is supported. 
     *
     *  @return <code> true </code> if a price enabler store service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerSmartStore();


    /**
     *  Tests if a price enabler price rule lookup service is supported. 
     *
     *  @return <code> true </code> if a price enabler price rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerRuleLookup();


    /**
     *  Tests if a price enabler price rule application service is supported. 
     *
     *  @return <code> true </code> if price enabler price rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerRuleApplication();


    /**
     *  Gets the supported <code> PriceEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> PriceEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPriceEnablerRecordTypes();


    /**
     *  Tests if the given <code> PriceEnabler </code> record type is 
     *  supported. 
     *
     *  @param  priceEnablerRecordType a <code> Type </code> indicating a 
     *          <code> PriceEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> priceEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerRecordType(org.osid.type.Type priceEnablerRecordType);


    /**
     *  Gets the supported <code> PriceEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> PriceEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPriceEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> PriceEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  priceEnablerSearchRecordType a <code> Type </code> indicating 
     *          a <code> PriceEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          priceEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPriceEnablerSearchRecordType(org.osid.type.Type priceEnablerSearchRecordType);
}
