//
// org.osid.ordering.rules.PriceEnablerSmartStoreSession
//
//     The OSID Java specification for org.osid.ordering.rules.PriceEnablerSmartStoreSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.ordering.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  stores. A <code> PriceEnablerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Store </code> to create a virtual 
 *  collection of price enablers. The price enablers may be sequenced using 
 *  the <code> PriceEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Store </code> has a default query that matches any price 
 *  enabler and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> PriceEnablerQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  PriceEnablerQuery. </code> </p>
 */

public interface PriceEnablerSmartStoreSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Store </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Store Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStoreId();


    /**
     *  Gets the <code> Store </code> associated with this session. 
     *
     *  @return the store 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.Store getStore()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart stores. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart store management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartStores();


    /**
     *  Gets a price enabler query. 
     *
     *  @return the price enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerQuery getPriceEnablerQuery();


    /**
     *  Gets a price enabler search order. 
     *
     *  @return the price enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerSearchOrder getPriceEnablerSearchOrder();


    /**
     *  Applies a price enabler query to this store. 
     *
     *  @param  priceEnablerQuery the price enabler query 
     *  @throws org.osid.NullArgumentException <code> priceEnablerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> priceEnablerQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPriceEnablerQuery(org.osid.ordering.rules.PriceEnablerQuery priceEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a price enabler query inspector for this store. 
     *
     *  @return the price enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerQueryInspector inspectPriceEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a price enabler search order to this store. 
     *
     *  @param  priceEnablerSearchOrder the price enabler search order 
     *  @throws org.osid.NullArgumentException <code> priceEnablerSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> priceEnablerSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPriceEnablerSequencing(org.osid.ordering.rules.PriceEnablerSearchOrder priceEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a price enabler query from an inspector. 
     *
     *  @param  priceEnablerQueryInspector a price enabler query inspector 
     *  @return the price enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          priceEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          priceEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ordering.rules.PriceEnablerQuery getPriceEnablerQueryFromInspector(org.osid.ordering.rules.PriceEnablerQueryInspector priceEnablerQueryInspector);
}
