//
// org.osid.personnel.AppointmentAdminSession
//
//     The OSID Java specification for org.osid.personnel.AppointmentAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session creates, updates, and deletes <code> Appointments. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Appointment, </code> an <code> AppointmentForm </code> is requested 
 *  using <code> getAppointmentFormForCreate() </code> specifying the desired 
 *  relationship peers and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> AppointmentForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> AppointmentForm </code> is submitted to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> AppointmentForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AppointmentForms </code> are requested to the 
 *  <code> Appointment </code> <code> Id </code> that is to be updated using 
 *  <code> getAppointmentFormForUpdate(). </code> Similarly, the <code> 
 *  AppointmentForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  AppointmentForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Appointments. </code> To unmap an 
 *  <code> Appointment </code> from the current <code> Realm, </code> the 
 *  <code> AppointmentRealmAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Appointment </code> itself 
 *  thus removing it from all known <code> Realm </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AppointmentAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Realm </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Realm Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRealmId();


    /**
     *  Gets the <code> Realm </code> associated with this session. 
     *
     *  @return the realm 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Realm getRealm()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create appointments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating an <code> Appointment </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Appointment </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAppointments();


    /**
     *  Tests if this user can create a single <code> Appointment </code> 
     *  using the desired record types. While <code> 
     *  PersonnelManager.getAppointmentRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Appointment. </code> 
     *  Providing an empty array tests if an <code> Appointment </code> can be 
     *  created with no records. 
     *
     *  @param  appointmentRecordTypes array of appointment record types 
     *  @return <code> true </code> if <code> Appointment </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> appointmentRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAppointmentWithRecordTypes(org.osid.type.Type[] appointmentRecordTypes);


    /**
     *  Gets the appointment form for creating new appointments. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  personId the person <code> Id </code> 
     *  @param  positionId the position <code> Id </code> 
     *  @param  appointmentRecordTypes array of appointment record types to be 
     *          included in the create operation or an empty list if none 
     *  @return the appointment form 
     *  @throws org.osid.NotFoundException <code> personId </code> or <code> 
     *          positionId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> personId, positionId, 
     *          </code> or <code> appointmentRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException cannot get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentForm getAppointmentFormForCreate(org.osid.id.Id personId, 
                                                                          org.osid.id.Id positionId, 
                                                                          org.osid.type.Type[] appointmentRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Appointment. </code> 
     *
     *  @param  appointmentForm the form for this <code> Appointment </code> 
     *  @return the new <code> Appointment </code> 
     *  @throws org.osid.IllegalStateException <code> appointmentForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> appointmentForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> appointmentForm </code> 
     *          did not originate from <code> getAppointmentFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Appointment createAppointment(org.osid.personnel.AppointmentForm appointmentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update appointments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating an <code> Appointment </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Appointment </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAppointments();


    /**
     *  Gets the appointment form for updating an existing appointment. A new 
     *  appointment form should be requested for each update transaction. 
     *
     *  @param  appointmentId the <code> Id </code> of the <code> Appointment 
     *          </code> 
     *  @return the appointment form 
     *  @throws org.osid.NotFoundException <code> appointmentId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> appointmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentForm getAppointmentFormForUpdate(org.osid.id.Id appointmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing appointment. 
     *
     *  @param  appointmentForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> appointmentForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> appointmentForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> appointmentForm </code> 
     *          did not originate from <code> getAppointmentFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAppointment(org.osid.personnel.AppointmentForm appointmentForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete appointments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Appointment </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Appointment </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAppointments();


    /**
     *  Deletes an <code> Appointment. </code> 
     *
     *  @param  appointmentId the <code> Id </code> of the <code> Appointment 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> appointmentId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> appointmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAppointment(org.osid.id.Id appointmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Appointments. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Appointment </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAppointmentAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Appointment </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Appointment </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another appointment, it is reassigned to the 
     *  given appointment <code> Id. </code> 
     *
     *  @param  appointmentId the <code> Id </code> of an <code> Appointment 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is in 
     *          use as a primary <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> appointmentId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> appointmentId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAppointment(org.osid.id.Id appointmentId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
