//
// org.osid.personnel.AppointmentLookupSession
//
//     The OSID Java specification for org.osid.personnel.AppointmentLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session defines methods for retrieving appointments. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated realm view: All appointment methods in this session 
 *      operate, retrieve and pertain to appointments defined explicitly in 
 *      the current realm. Using an isolated view is useful for managing 
 *      appointments with the <code> AppointmentAdminSession. </code> </li> 
 *      <li> federated realm view: All appointment lookup methods in this 
 *      session operate, retrieve and pertain to all appointments defined in 
 *      this realm and any other realms implicitly available in this realm 
 *      through realm inheritence. </li> 
 *      <li> effective appointment view: All appointment lookup methods return 
 *      appointments where the current date falls in between the effective 
 *      dates inclusive. </li> 
 *      <li> any effective appointment view: Appointments of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedRealmView() </code> and <code> 
 *  useIsolatedRealmView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface AppointmentLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Realm </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Realm Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRealmId();


    /**
     *  Gets the <code> Realm </code> associated with this session. 
     *
     *  @return the realm 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Realm getRealm()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this realm. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if realm reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAppointments();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAppointmentView();


    /**
     *  A complete view of the <code> Appointment </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAppointmentView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include appointments in realms which are children of this realm in the 
     *  realm hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRealmView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this realm only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRealmView();


    /**
     *  Only appointments whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveAppointmentView();


    /**
     *  All appointments of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveAppointmentView();


    /**
     *  Gets the <code> Appointment </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Appointment </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Appointment </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  appointmentId the <code> Id </code> of the <code> Appointment 
     *          </code> to retrieve 
     *  @return the returned <code> Appointment </code> 
     *  @throws org.osid.NotFoundException no <code> Appointment </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> appointmentId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Appointment getAppointment(org.osid.id.Id appointmentId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  appointments specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible appointments may be omitted from the list and may present 
     *  the elements in any order including returning a unique set. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  appointmentIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Appointment list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> appointmentIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsByIds(org.osid.id.IdList appointmentIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> corresponding to the given 
     *  appointment genus <code> Type </code> which does not include 
     *  appointments of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  appointments or an error results. Otherwise, the returned list may 
     *  contain only those appointments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  appointmentGenusType an appointments genus type 
     *  @return the returned <code> Appointment list </code> 
     *  @throws org.osid.NullArgumentException <code> appointmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsByGenusType(org.osid.type.Type appointmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> corresponding to the given 
     *  appointment genus <code> Type </code> and include any additional 
     *  appointments with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  appointments or an error results. Otherwise, the returned list may 
     *  contain only those appointments that are accessible through this 
     *  session. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  appointmentGenusType an appointment genus type 
     *  @return the returned <code> Appointment list </code> 
     *  @throws org.osid.NullArgumentException <code> appointmentGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsByParentGenusType(org.osid.type.Type appointmentGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> containing the given 
     *  appointment record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known appointments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  appointments that are accessible through this session. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  appointmentRecordType an appointment record type 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.NullArgumentException <code> appointmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsByRecordType(org.osid.type.Type appointmentRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known appointments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  appointments that are accessible through this session. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from or to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsOnDate(org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> for the given person <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  appointments corresponding to the given person, including duplicates, 
     *  or an error results if an appointment is inaccessible. Otherwise, 
     *  inaccessible <code> Appointments </code> may be omitted from the list. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  personId the <code> Id </code> of the person 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.NullArgumentException <code> personId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsForPerson(org.osid.id.Id personId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of appointments for a resource and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known appointments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  appointments that are accessible through this session. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  personId a person <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> personId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsForPersonOnDate(org.osid.id.Id personId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> for the given position. <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  appointments corresponding to the given position, including 
     *  duplicates, or an error results if an appointment is inaccessible. 
     *  Otherwise, inaccessible <code> Appointments </code> may be omitted 
     *  from the list. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  positionId a position <code> Id </code> 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.NullArgumentException <code> positionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsForPosition(org.osid.id.Id positionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of appointments for a position and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known appointments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  appointments that are accessible through this session. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  positionId a position <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> positionId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsForPositionOnDate(org.osid.id.Id positionId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> for the given person and 
     *  position. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  appointments corresponding to the given resource and reference, 
     *  including duplicates, or an error results if an appointment is 
     *  inaccessible. Otherwise, inaccessible <code> Appointments </code> may 
     *  be omitted from the list. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  personId a person <code> Id </code> 
     *  @param  positionId a position <code> Id </code> 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.NullArgumentException <code> personId </code> or 
     *          <code> positionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsForPersonAndPosition(org.osid.id.Id personId, 
                                                                                  org.osid.id.Id positionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AppointmentList </code> corresponding to the given 
     *  person and position and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the appointments 
     *  corresponding to the given peer, including duplicates, or an error 
     *  results if an appointment is inaccessible. Otherwise, inaccessible 
     *  <code> Appointments </code> may be omitted from the list. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @param  personId a person <code> Id </code> 
     *  @param  positionId a position <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> AppointmentList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> referenceId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointmentsForPersonAndPositionOnDate(org.osid.id.Id personId, 
                                                                                        org.osid.id.Id positionId, 
                                                                                        org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all appointments. 
     *  
     *  In plenary mode, the returned list contains all known appointments or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  appointments that are accessible through this session. 
     *  
     *  In effective mode, appointments are returned that are currently 
     *  effective. In any effective mode, effective appointments and those 
     *  currently expired are returned. 
     *
     *  @return a list of appointments 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.AppointmentList getAppointments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
