//
// org.osid.personnel.AppointmentQuery
//
//     The OSID Java specification for org.osid.personnel.AppointmentQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This is the query for searching appointments. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface AppointmentQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets a person <code> Id. </code> 
     *
     *  @param  personId a person <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> personId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPersonId(org.osid.id.Id personId, boolean match);


    /**
     *  Clears all person <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPersonIdTerms();


    /**
     *  Tests if a <code> PersonQuery </code> is available. 
     *
     *  @return <code> true </code> if a person query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonQuery();


    /**
     *  Gets the query for a person query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the person query 
     *  @throws org.osid.UnimplementedException <code> supportsPersonQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonQuery getPersonQuery();


    /**
     *  Clears all person terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPersonTerms();


    /**
     *  Sets a position <code> Id. </code> 
     *
     *  @param  positionId a position <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> positionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPositionId(org.osid.id.Id positionId, boolean match);


    /**
     *  Clears all position <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPositionIdTerms();


    /**
     *  Tests if a <code> PositionQuery </code> is available. 
     *
     *  @return <code> true </code> if a position query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionQuery();


    /**
     *  Gets the query for a position query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the position query 
     *  @throws org.osid.UnimplementedException <code> supportsPositionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PositionQuery getPositionQuery();


    /**
     *  Clears all position terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPositionTerms();


    /**
     *  Matches a commitment between the given range inclusive. 
     *
     *  @param  from a starting range 
     *  @param  to an ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCommitment(long from, long to, boolean match);


    /**
     *  Matches positions with any low salary. 
     *
     *  @param  match <code> true </code> to match appointments with any 
     *          commitment, <code> false </code> to match appointments with no 
     *          commitment 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCommitment(boolean match);


    /**
     *  Clears all commitment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommitmentTerms();


    /**
     *  Matches a title. 
     *
     *  @param  title a title 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTitle(String title, org.osid.type.Type stringMatchType, 
                           boolean match);


    /**
     *  Matches persons with any title. 
     *
     *  @param  match <code> true </code> to match appointments with any 
     *          title, <code> false </code> to match appointments with no 
     *          title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTitle(boolean match);


    /**
     *  Clears all title terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitleTerms();


    /**
     *  Matches a salary between the given range inclusive. 
     *
     *  @param  from a starting salary range 
     *  @param  to an ending salary range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSalary(org.osid.financials.Currency from, 
                            org.osid.financials.Currency to, boolean match);


    /**
     *  Matches positions with any salary. 
     *
     *  @param  match <code> true </code> to match appointments with any 
     *          salary, <code> false </code> to match appointments with no 
     *          salary 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySalary(boolean match);


    /**
     *  Clears all salary terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSalaryTerms();


    /**
     *  Sets the realm <code> Id </code> for this query to match appointments 
     *  assigned to realms. 
     *
     *  @param  realmId a realm <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRealmId(org.osid.id.Id realmId, boolean match);


    /**
     *  Clears all realm <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmIdTerms();


    /**
     *  Tests if a <code> RealmQuery </code> is available. 
     *
     *  @return <code> true </code> if a realm query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmQuery();


    /**
     *  Gets the query for a realm query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the realm query 
     *  @throws org.osid.UnimplementedException <code> supportsRealmQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmQuery getRealmQuery();


    /**
     *  Clears all realm terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmTerms();


    /**
     *  Gets the appointment query record corresponding to the given <code> 
     *  Appointment </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  appointmentRecordType an appointment record type 
     *  @return the appointment query record 
     *  @throws org.osid.NullArgumentException <code> appointmentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(appointmentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.AppointmentQueryRecord getAppointmentQueryRecord(org.osid.type.Type appointmentRecordType)
        throws org.osid.OperationFailedException;
}
