//
// org.osid.personnel.OrganizationLookupSession
//
//     The OSID Java specification for org.osid.personnel.OrganizationLookupSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session defines methods for retrieving organizations. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated realm view: All organization methods in this session 
 *      operate, retrieve and pertain to organizations defined explicitly in 
 *      the current realm. Using an isolated view is useful for managing 
 *      organizations with the <code> OrganizationAdminSession. </code> </li> 
 *      <li> federated realm view: All organization lookup methods in this 
 *      session operate, retrieve and pertain to all organizations defined in 
 *      this realm and any other realms implicitly available in this realm 
 *      through realm inheritence. </li> 
 *      <li> effective organization view: All organization lookup methods 
 *      return organizations where the current date falls in between the 
 *      effective dates inclusive. </li> 
 *      <li> any status organization view: Organizations of any effective date 
 *      are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedRealmView() </code> and <code> 
 *  useIsolatedRealmView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface OrganizationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Realm </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Realm Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRealmId();


    /**
     *  Gets the <code> Realm </code> associated with this session. 
     *
     *  @return the realm 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Realm getRealm()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can examine this realm. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if realm reading methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupOrganizations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeOrganizationView();


    /**
     *  A complete view of the <code> Organization </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryOrganizationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include organizations in realms which are children of this realm in 
     *  the realm hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRealmView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this realm only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRealmView();


    /**
     *  Only organizations whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveOrganizationView();


    /**
     *  All organizations of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveOrganizationView();


    /**
     *  Gets the <code> Organization </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Organization </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to an <code> Organization </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, organizations are returned that are currently 
     *  effective. In any effective mode, effective organizations and those 
     *  currently expired are returned. 
     *
     *  @param  organizationId the <code> Id </code> of the <code> 
     *          Organization </code> to retrieve 
     *  @return the returned <code> Organization </code> 
     *  @throws org.osid.NotFoundException no <code> Organization </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Organization getOrganization(org.osid.id.Id organizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrganizationList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  organizations specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible organizations may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, organizations are returned that are currently 
     *  effective. In any effective mode, effective organizations and those 
     *  currently expired are returned. 
     *
     *  @param  organizationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Organization list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> organizationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizationsByIds(org.osid.id.IdList organizationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrganizationList </code> corresponding to the given 
     *  organization genus <code> Type </code> which does not include 
     *  organizations of types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  organizations or an error results. Otherwise, the returned list may 
     *  contain only those organizations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, organizations are returned that are currently 
     *  effective. In any effective mode, effective organizations and those 
     *  currently expired are returned. 
     *
     *  @param  organizationGenusType an organizations genus type 
     *  @return the returned <code> Organization list </code> 
     *  @throws org.osid.NullArgumentException <code> organizationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizationsByGenusType(org.osid.type.Type organizationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrganizationList </code> corresponding to the given 
     *  organization genus <code> Type </code> and include any additional 
     *  organizations with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  organizations or an error results. Otherwise, the returned list may 
     *  contain only those organizations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, organizations are returned that are currently 
     *  effective. In any effective mode, effective organizations and those 
     *  currently expired are returned. 
     *
     *  @param  organizationGenusType an organization genus type 
     *  @return the returned <code> Organization list </code> 
     *  @throws org.osid.NullArgumentException <code> organizationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizationsByParentGenusType(org.osid.type.Type organizationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrganizationList </code> containing the given 
     *  organization record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  organizations or an error results. Otherwise, the returned list may 
     *  contain only those organizations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, organizations are returned that are currently 
     *  effective. In any effective mode, effective organizations and those 
     *  currently expired are returned. 
     *
     *  @param  organizationRecordType an organization record type 
     *  @return the returned <code> OrganizationList </code> 
     *  @throws org.osid.NullArgumentException <code> organizationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizationsByRecordType(org.osid.type.Type organizationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> OrganizationList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known organizations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  organizations that are accessible through this session. 
     *  
     *  In effective mode, organizations are returned that are currently 
     *  effective. In any effective mode, effective organizations and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> OrganizationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizationsOnDate(org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all organizations. 
     *  
     *  In plenary mode, the returned list contains all known organizations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  organizations that are accessible through this session. 
     *  
     *  In effective mode, organizations are returned that are currently 
     *  effective. In any effective mode, effective organizations and those 
     *  currently expired are returned. 
     *
     *  @return a list of organizations 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
