//
// org.osid.personnel.OrganizationQuery
//
//     The OSID Java specification for org.osid.personnel.OrganizationQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This is the query for searching organizations. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface OrganizationQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidFederateableQuery,
            org.osid.OsidTemporalQuery {


    /**
     *  Matches a display label. 
     *
     *  @param  label a display label 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> label </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> label </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDisplayLabel(String label, 
                                  org.osid.type.Type stringMatchType, 
                                  boolean match);


    /**
     *  Matches organizations with any display label. 
     *
     *  @param  match <code> true </code> to match organizations with any 
     *          display label, <code> false </code> to match organizations 
     *          with no display label 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDisplayLabel(boolean match);


    /**
     *  Clears all display label terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDisplayLabelTerms();


    /**
     *  Sets the organization <code> Id </code> for this query to match 
     *  organizations that have the specified organization as an ancestor. 
     *
     *  @param  organizationId an organization <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorOrganizationId(org.osid.id.Id organizationId, 
                                            boolean match);


    /**
     *  Clears the ancestor organization <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOrganizationIdTerms();


    /**
     *  Tests if an <code> OrganizationQuery </code> is available. 
     *
     *  @return <code> true </code> if an organization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorOrganizationQuery();


    /**
     *  Gets the query for an organization. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the organization query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorOrganizationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorOrganizationQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.personnel.OrganizationQuery getAncestorOrganizationQuery();


    /**
     *  Matches agencies with any organization ancestor. 
     *
     *  @param  match <code> true </code> to match organizations with any 
     *          ancestor, <code> false </code> to match root organizations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorOrganization(boolean match);


    /**
     *  Clears the ancestor organization query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorOrganizationTerms();


    /**
     *  Sets the organization <code> Id </code> for this query to match 
     *  organizations that have the specified organization as a descendant. 
     *
     *  @param  organizationId an organization <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantOrganizationId(org.osid.id.Id organizationId, 
                                              boolean match);


    /**
     *  Clears the descendant organization <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOrganizationIdTerms();


    /**
     *  Tests if an <code> OrganizationQuery </code> is available. 
     *
     *  @return <code> true </code> if an organization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantOrganizationQuery();


    /**
     *  Gets the query for an organization. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the organization query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantOrganizationQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantOrganizationQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.personnel.OrganizationQuery getDescendantOrganizationQuery();


    /**
     *  Matches organizations with any organization descendant. 
     *
     *  @param  match <code> true </code> to match organizations with any 
     *          descendant, <code> false </code> to match leaf organizations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantOrganization(boolean match);


    /**
     *  Clears the descendant organization query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantOrganizationTerms();


    /**
     *  Sets the realm <code> Id </code> for this query to match organizations 
     *  assigned to realms. 
     *
     *  @param  realmId a realm <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRealmId(org.osid.id.Id realmId, boolean match);


    /**
     *  Clears all realm <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmIdTerms();


    /**
     *  Tests if a <code> RealmQuery </code> is available. 
     *
     *  @return <code> true </code> if a realm query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmQuery();


    /**
     *  Gets the query for a realm query. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the realm query 
     *  @throws org.osid.UnimplementedException <code> supportsRealmQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmQuery getRealmQuery();


    /**
     *  Clears all realm terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRealmTerms();


    /**
     *  Gets the organization query record corresponding to the given <code> 
     *  Organization </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  organizationRecordType an organization record type 
     *  @return the organization query record 
     *  @throws org.osid.NullArgumentException <code> organizationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(organizationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.OrganizationQueryRecord getOrganizationQueryRecord(org.osid.type.Type organizationRecordType)
        throws org.osid.OperationFailedException;
}
