//
// org.osid.personnel.OrganizationRealmSession
//
//     The OSID Java specification for org.osid.personnel.OrganizationRealmSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session provides methods to retrieve <code> Organization </code> 
 *  to <code> Realm </code> mappings. An <code> Organization </code> may 
 *  appear in multiple <code> Realms. </code> Each <code> Realm </code> may 
 *  have its own authorizations governing who is allowed to look at it. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface OrganizationRealmSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of organization/realm mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known lookup methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intendedas 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupOrganizationRealmMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRealmView();


    /**
     *  A complete view of the <code> Organization </code> and <code> Realm 
     *  </code> returns is desired. Methods will return what is requested or 
     *  result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRealmView();


    /**
     *  Gets the list of Organization Ids associated with a <code> Realm. 
     *  </code> 
     *
     *  @param  realmId <code> Id </code> of a <code> Realms. </code> 
     *  @return list of related organization <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> realmId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getOrganizationIdsByRealm(org.osid.id.Id realmId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Organizations </code> associated with a <code> 
     *  Realm. </code> 
     *
     *  @param  realmId <code> Id </code> of a <code> Realm </code> 
     *  @return list of related organizations 
     *  @throws org.osid.NotFoundException <code> realmId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizationsByRealm(org.osid.id.Id realmId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Organization Ids </code> corresponding to a 
     *  list of <code> Realm </code> objects. 
     *
     *  @param  realmIds list of realm <code> Ids </code> 
     *  @return list of organization <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> realmIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getOrganizationIdsByRealms(org.osid.id.IdList realmIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Organizations </code> corresponding to a list 
     *  of <code> Realms. </code> 
     *
     *  @param  realmIds list of realm <code> Ids </code> 
     *  @return list of organizations 
     *  @throws org.osid.NullArgumentException <code> realmIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationList getOrganizationsByRealms(org.osid.id.IdList realmIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Realm </code> <code> Ids </code> mapped to an 
     *  <code> Organization. </code> 
     *
     *  @param  organizationId <code> Id </code> of an <code> Organization 
     *          </code> 
     *  @return list of realm <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> organizationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRealmIdsByOrganization(org.osid.id.Id organizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Realm </code> objects mapped to an <code> 
     *  Organization. </code> 
     *
     *  @param  organizationId <code> Id </code> of an <code> Organization 
     *          </code> 
     *  @return list of realms 
     *  @throws org.osid.NotFoundException <code> organizationId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.RealmList getRealmsByOrganization(org.osid.id.Id organizationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
