//
// org.osid.personnel.OrganizationSearchSession
//
//     The OSID Java specification for org.osid.personnel.OrganizationSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session provides methods for searching <code> Organization </code> 
 *  objects. The search query is constructed using the <code> 
 *  OrganizationQuery. </code> The organization record <code> Type </code> 
 *  also specifies the record for the organization query. </p> 
 *  
 *  <p> <code> getOrganizationsByQuery() </code> is the basic search method 
 *  and returns a list of <code> Organization </code> elements. A more 
 *  advanced search may be performed with <code> getOrganizationsBySearch(). 
 *  </code> It accepts an <code> OrganizationSearch </code> in addition to the 
 *  query for the purpose of specifying additional options affecting the 
 *  entire search, such as ordering. <code> getOrganizationsBySearch() </code> 
 *  returns an <code> OrganizationSearchResults </code> that can be used to 
 *  access the resulting <code> OrganizationList </code> or be used to perform 
 *  a search within the result set through <code> OrganizationSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated realm view: searches include organizations in realms of 
 *      which this realm is a ancestor in the realm hierarchy </li> 
 *      <li> isolated realm view: searches are restricted to organizations in 
 *      this realm </li> 
 *  </ul>
 *  
 *  
 *  <p> Organizations may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  OrganizationQuery. </code> The returns in this session may not be cast 
 *  directly to these interfaces. </p>
 */

public interface OrganizationSearchSession
    extends org.osid.personnel.OrganizationQuerySession {


    /**
     *  Gets an organization search. 
     *
     *  @return the organization search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationSearch getOrganizationSearch();


    /**
     *  Gets an organization search order. The <code> OrganizationSearchOrder 
     *  </code> is supplied to an <code> OrganizationSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the organization search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationSearchOrder getOrganizationSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  organizationQuery the organization query 
     *  @param  organizationSearch the organization search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> organizationQuery 
     *          </code> or <code> organizationSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> organizationQuery </code> 
     *          or <code> organizationSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationSearchResults getOrganizationsBySearch(org.osid.personnel.OrganizationQuery organizationQuery, 
                                                                                 org.osid.personnel.OrganizationSearch organizationSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an organization query from an inspector. The inspector is 
     *  available from an <code> OrganizationSearchResults. </code> 
     *
     *  @param  organizationQueryInspector an organization query inspector 
     *  @return the organization query 
     *  @throws org.osid.NullArgumentException <code> 
     *          organizationQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          organizationQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.OrganizationQuery getOrganizationQueryFromInspector(org.osid.personnel.OrganizationQueryInspector organizationQueryInspector);
}
