//
// org.osid.personnel.PersonForm
//
//     The OSID Java specification for org.osid.personnel.PersonForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This is the form for creating and updating <code> Person </code> 
 *  objects. Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  PersonAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface PersonForm
    extends org.osid.OsidObjectForm {


    /**
     *  Gets the metadata for a salutation. 
     *
     *  @return metadata for the salutation 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSalutationMetadata();


    /**
     *  Sets the salutation. 
     *
     *  @param  salutation the salutation 
     *  @throws org.osid.InvalidArgumentException <code> salutation </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> salutation </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSalutation(String salutation);


    /**
     *  Clears the salutation. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSalutation();


    /**
     *  Gets the metadata for a given name. 
     *
     *  @return metadata for the given name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGivenNameMetadata();


    /**
     *  Sets the given name, 
     *
     *  @param  givenName the given name 
     *  @throws org.osid.InvalidArgumentException <code> givenName </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> givenName </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGivenName(String givenName);


    /**
     *  Clears the given name. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGivenName();


    /**
     *  Gets the metadata for a preferred name. 
     *
     *  @return metadata for the preferred name 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPreferredNameMetadata();


    /**
     *  Sets the preferred name, 
     *
     *  @param  preferredName the preferred name 
     *  @throws org.osid.InvalidArgumentException <code> preferredName </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> preferredName </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPreferredName(String preferredName);


    /**
     *  Clears the preferred name. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPreferredName();


    /**
     *  Gets the metadata for forename aliases. 
     *
     *  @return metadata for the forename aliases 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getForenameAliasesMetadata();


    /**
     *  Sets the forename aliases. 
     *
     *  @param  aliases the forename aliases 
     *  @throws org.osid.InvalidArgumentException <code> forenames </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> forenames </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setForenameAliases(String[] aliases);


    /**
     *  Clears the forename aliases. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearForenameAliases();


    /**
     *  Gets the metadata for middle names. 
     *
     *  @return metadata for the middle names 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMiddleNamesMetadata();


    /**
     *  Sets the middle names. 
     *
     *  @param  names the middle names 
     *  @throws org.osid.InvalidArgumentException <code> names </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> names </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMiddleNames(String[] names);


    /**
     *  Clears the middele names. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMiddleNames();


    /**
     *  Gets the metadata for a surname. 
     *
     *  @return metadata for the surname 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSurameMetadata();


    /**
     *  Sets the surname. 
     *
     *  @param  surname the surname 
     *  @throws org.osid.InvalidArgumentException <code> surname </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> surname </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSurname(String surname);


    /**
     *  Clears the surname. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSurname();


    /**
     *  Gets the metadata for surname aliases. 
     *
     *  @return metadata for the surname aliases 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getSurameAliasesMetadata();


    /**
     *  Sets the surname aliases. 
     *
     *  @param  aliases the aliases 
     *  @throws org.osid.InvalidArgumentException <code> aliases </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> aliases </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setSurnameAliases(String[] aliases);


    /**
     *  Clears the surname aliases. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSurnameAliases();


    /**
     *  Gets the metadata for a generation qualifier. 
     *
     *  @return metadata for the qualifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getGenerationQualifierMetadata();


    /**
     *  Sets the generation qualifier. 
     *
     *  @param  qualifier the qualifier 
     *  @throws org.osid.InvalidArgumentException <code> qualifier </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> qualifier </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setGenerationQualifier(String qualifier);


    /**
     *  Clears the generation qualifier. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGenerationQualifier();


    /**
     *  Gets the metadata for a date of birth. 
     *
     *  @return metadata for the date of birth 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBirthDateMetadata();


    /**
     *  Sets the date of birth. 
     *
     *  @param  date the date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBirthDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the date of birth. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBirthDate();


    /**
     *  Gets the metadata for a date of death. 
     *
     *  @return metadata for the date of death 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDeathDateMetadata();


    /**
     *  Sets the date of death. 
     *
     *  @param  date the date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDeathDate(org.osid.calendaring.DateTime date);


    /**
     *  Clears the date of death. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDeathDate();


    /**
     *  Gets the metadata for an identifier. 
     *
     *  @return metadata for the identifier 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getInstitutionalIdentifierMetadata();


    /**
     *  Sets the identifier. 
     *
     *  @param  identifier the identifier 
     *  @throws org.osid.InvalidArgumentException <code> identifier </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> identifier </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setInstitutionalIdentifier(String identifier);


    /**
     *  Clears the identifier. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstitutionalIdentifier();


    /**
     *  Gets the <code> PersonFormRecord </code> interface corresponding to 
     *  the given person record <code> Type. </code> 
     *
     *  @param  personRecordType the person record type 
     *  @return the record 
     *  @throws org.osid.NullArgumentException <code> personRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(personRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PersonFormRecord getPersonFormRecord(org.osid.type.Type personRecordType)
        throws org.osid.OperationFailedException;
}
