//
// org.osid.personnel.PersonSearchSession
//
//     The OSID Java specification for org.osid.personnel.PersonSearchSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This session provides methods for searching <code> Person </code> 
 *  objects. The search query is constructed using the <code> PersonQuery. 
 *  </code> The person record <code> Type </code> also specifies the record 
 *  for the person query. </p> 
 *  
 *  <p> <code> getPersonsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Person </code> elements. A more advanced search 
 *  may be performed with <code> getPersonsBySearch(). </code> It accepts a 
 *  <code> PersonSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getPersonsBySearch() </code> returns a <code> 
 *  PersonSearchResults </code> that can be used to access the resulting 
 *  <code> PersonList </code> or be used to perform a search within the result 
 *  set through <code> PersonSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated realm view: searches include persons in realms of which 
 *      this realm is a ancestor in the realm hierarchy </li> 
 *      <li> isolated realm view: searches are restricted to persons in this 
 *      realm </li> 
 *  </ul>
 *  
 *  
 *  <p> Persons may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PersonQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface PersonSearchSession
    extends org.osid.personnel.PersonQuerySession {


    /**
     *  Gets a person search. 
     *
     *  @return the person search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonSearch getPersonSearch();


    /**
     *  Gets a person search order. The <code> PersonSearchOrder </code> is 
     *  supplied to a <code> PersonSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the person search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonSearchOrder getPersonSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  personQuery the person query 
     *  @param  personSearch the person search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> personQuery </code> or 
     *          <code> personSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> personQuery </code> or 
     *          <code> personSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonSearchResults getPersonsBySearch(org.osid.personnel.PersonQuery personQuery, 
                                                                     org.osid.personnel.PersonSearch personSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a person query from an inspector. The inspector is available from 
     *  a <code> PersonSearchResults. </code> 
     *
     *  @param  personQueryInspector a person query inspector 
     *  @return the person query 
     *  @throws org.osid.NullArgumentException <code> personQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> personQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.PersonQuery getPersonQueryFromInspector(org.osid.personnel.PersonQueryInspector personQueryInspector);
}
