//
// org.osid.personnel.PersonnelProfile
//
//     The OSID Java specification for org.osid.personnel.PersonnelProfile.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>The personnel profile describes the interoperability among personnel 
 *  services. </p>
 */

public interface PersonnelProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any realm federation is exposed. Federation is exposed when a 
     *  specific realm may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of realms 
     *  appears as a single realm. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a person lookup service. 
     *
     *  @return <code> true </code> if person lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonLookup();


    /**
     *  Tests for the availability of a person query service. 
     *
     *  @return <code> true </code> if person query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonQuery();


    /**
     *  Tests if searching for persons is available. 
     *
     *  @return <code> true </code> if person search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonSearch();


    /**
     *  Tests if managing for persons is available. 
     *
     *  @return <code> true </code> if a person adminstrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonAdmin();


    /**
     *  Tests if person notification is available. 
     *
     *  @return <code> true </code> if person notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonNotification();


    /**
     *  Tests if a person to realm lookup session is available. 
     *
     *  @return <code> true </code> if person realm lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonRealm();


    /**
     *  Tests if a person to realm assignment session is available. 
     *
     *  @return <code> true </code> if person realm assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonRealmAssignment();


    /**
     *  Tests if a person smart realm session is available. 
     *
     *  @return <code> true </code> if person smart realm is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonSmartRealm();


    /**
     *  Tests for the availability of an organization lookup service. 
     *
     *  @return <code> true </code> if organization lookup is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationLookup();


    /**
     *  Tests for the availability of an organization query service. 
     *
     *  @return <code> true </code> if organization query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationQuery();


    /**
     *  Tests if searching for organizations is available. 
     *
     *  @return <code> true </code> if organization search is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationSearch();


    /**
     *  Tests if managing for organizations is available. 
     *
     *  @return <code> true </code> if an organization adminstrative service 
     *          is available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationAdmin();


    /**
     *  Tests if organization notification is available. 
     *
     *  @return <code> true </code> if organization notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationNotification();


    /**
     *  Tests if an organization hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if an organization hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationHierarchy();


    /**
     *  Tests if organization hierarchy design is supported. 
     *
     *  @return <code> true </code> if an organization hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationHierarchyDesign();


    /**
     *  Tests if an organization to realm lookup session is available. 
     *
     *  @return <code> true </code> if organization realm lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationRealm();


    /**
     *  Tests if an organization to realm assignment session is available. 
     *
     *  @return <code> true </code> if organization realm assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationRealmAssignment();


    /**
     *  Tests if an organization smart realm session is available. 
     *
     *  @return <code> true </code> if organization smart realm is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationSmartRealm();


    /**
     *  Tests for the availability of a position lookup service. 
     *
     *  @return <code> true </code> if position lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionLookup();


    /**
     *  Tests for the availability of a position query service. 
     *
     *  @return <code> true </code> if position query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionQuery();


    /**
     *  Tests if searching for positions is available. 
     *
     *  @return <code> true </code> if position search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionSearch();


    /**
     *  Tests if managing for positions is available. 
     *
     *  @return <code> true </code> if a position adminstrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionAdmin();


    /**
     *  Tests if position notification is available. 
     *
     *  @return <code> true </code> if position notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionNotification();


    /**
     *  Tests if a position to realm lookup session is available. 
     *
     *  @return <code> true </code> if position realm lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionRealm();


    /**
     *  Tests if a position to realm assignment session is available. 
     *
     *  @return <code> true </code> if position realm assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionRealmAssignment();


    /**
     *  Tests if a position smart realm session is available. 
     *
     *  @return <code> true </code> if position smart realm is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionSmartRealm();


    /**
     *  Tests for the availability of an appointment lookup service. 
     *
     *  @return <code> true </code> if appointment lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentLookup();


    /**
     *  Tests for the availability of an appointment query service. 
     *
     *  @return <code> true </code> if appointment query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentQuery();


    /**
     *  Tests if searching for appointments is available. 
     *
     *  @return <code> true </code> if appointment search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentSearch();


    /**
     *  Tests if managing for appointments is available. 
     *
     *  @return <code> true </code> if an appointment adminstrative service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentAdmin();


    /**
     *  Tests if appointment notification is available. 
     *
     *  @return <code> true </code> if appointment notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentNotification();


    /**
     *  Tests if an appointment to realm lookup session is available. 
     *
     *  @return <code> true </code> if appointment realm lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentRealm();


    /**
     *  Tests if an appointment to realm assignment session is available. 
     *
     *  @return <code> true </code> if appointment realm assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentRealmAssignment();


    /**
     *  Tests if an appointment smart realm session is available. 
     *
     *  @return <code> true </code> if appointment smart realm is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentSmartRealm();


    /**
     *  Tests for the availability of an realm lookup service. 
     *
     *  @return <code> true </code> if realm lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmLookup();


    /**
     *  Tests if querying realms is available. 
     *
     *  @return <code> true </code> if realm query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmQuery();


    /**
     *  Tests if searching for realms is available. 
     *
     *  @return <code> true </code> if realm search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmSearch();


    /**
     *  Tests for the availability of a realm administrative service for 
     *  creating and deleting realms. 
     *
     *  @return <code> true </code> if realm administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmAdmin();


    /**
     *  Tests for the availability of a realm notification service. 
     *
     *  @return <code> true </code> if realm notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsRealmNotification();


    /**
     *  Tests for the availability of a realm hierarchy traversal service. 
     *
     *  @return <code> true </code> if realm hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmHierarchy();


    /**
     *  Tests for the availability of a realm hierarchy design service. 
     *
     *  @return <code> true </code> if realm hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsRealmHierarchyDesign();


    /**
     *  Tests for the availability of a personnel batch service. 
     *
     *  @return <code> true </code> if a personnel batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsPersonnelBatch();


    /**
     *  Gets the supported <code> Person </code> record types. 
     *
     *  @return a list containing the supported person record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPersonRecordTypes();


    /**
     *  Tests if the given <code> Person </code> record type is supported. 
     *
     *  @param  personRecordType a <code> Type </code> indicating a <code> 
     *          Person </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> personRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonRecordType(org.osid.type.Type personRecordType);


    /**
     *  Gets the supported person search record types. 
     *
     *  @return a list containing the supported person search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPersonSearchRecordTypes();


    /**
     *  Tests if the given person search record type is supported. 
     *
     *  @param  personSearchRecordType a <code> Type </code> indicating a 
     *          person record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> personSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonSearchRecordType(org.osid.type.Type personSearchRecordType);


    /**
     *  Gets the supported <code> Organization </code> record types. 
     *
     *  @return a list containing the supported organization record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOrganizationRecordTypes();


    /**
     *  Tests if the given <code> Organization </code> record type is 
     *  supported. 
     *
     *  @param  organizationRecordType a <code> Type </code> indicating an 
     *          <code> Organization </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> organizationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationRecordType(org.osid.type.Type organizationRecordType);


    /**
     *  Gets the supported organization search record types. 
     *
     *  @return a list containing the supported organization search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOrganizationSearchRecordTypes();


    /**
     *  Tests if the given organization search record type is supported. 
     *
     *  @param  organizationSearchRecordType a <code> Type </code> indicating 
     *          an organization record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          organizationSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationSearchRecordType(org.osid.type.Type organizationSearchRecordType);


    /**
     *  Gets the supported <code> Position </code> record types. 
     *
     *  @return a list containing the supported position record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPositionRecordTypes();


    /**
     *  Tests if the given <code> Position </code> record type is supported. 
     *
     *  @param  positionRecordType a <code> Type </code> indicating a <code> 
     *          Position </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> positionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionRecordType(org.osid.type.Type positionRecordType);


    /**
     *  Gets the supported position search record types. 
     *
     *  @return a list containing the supported position search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPositionSearchRecordTypes();


    /**
     *  Tests if the given position search record type is supported. 
     *
     *  @param  positionSearchRecordType a <code> Type </code> indicating a 
     *          position record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> positionSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionSearchRecordType(org.osid.type.Type positionSearchRecordType);


    /**
     *  Gets the supported <code> Appointment </code> record types. 
     *
     *  @return a list containing the supported appointment record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAppointmentRecordTypes();


    /**
     *  Tests if the given <code> Appointment </code> record type is 
     *  supported. 
     *
     *  @param  appointmentRecordType a <code> Type </code> indicating an 
     *          <code> Appointment </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> appointmentRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentRecordType(org.osid.type.Type appointmentRecordType);


    /**
     *  Gets the supported appointment search record types. 
     *
     *  @return a list containing the supported appointment search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAppointmentSearchRecordTypes();


    /**
     *  Tests if the given appointment search record type is supported. 
     *
     *  @param  appointmentSearchRecordType a <code> Type </code> indicating 
     *          an appointment record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          appointmentSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentSearchRecordType(org.osid.type.Type appointmentSearchRecordType);


    /**
     *  Gets the supported <code> Realm </code> record types. 
     *
     *  @return a list containing the supported realm record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRealmRecordTypes();


    /**
     *  Tests if the given <code> Realm </code> record type is supported. 
     *
     *  @param  realmRecordType a <code> Type </code> indicating a <code> 
     *          Realm </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> realmRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmRecordType(org.osid.type.Type realmRecordType);


    /**
     *  Gets the supported realm search record types. 
     *
     *  @return a list containing the supported realm search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRealmSearchRecordTypes();


    /**
     *  Tests if the given realm search record type is supported. 
     *
     *  @param  realmSearchRecordType a <code> Type </code> indicating a realm 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> realmSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRealmSearchRecordType(org.osid.type.Type realmSearchRecordType);
}
