//
// org.osid.personnel.PersonnelProxyManager
//
//     The OSID Java specification for org.osid.personnel.PersonnelProxyManager.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>The personnel manager provides access to personnel sessions and 
 *  provides interoperability tests for various aspects of this service. 
 *  Methods in this manager accept a <code> Proxy </code> interface for 
 *  passing information from a server environment. The sessions included in 
 *  this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> PersonLookupSession: </code> a session to lookup persons 
 *      </li> 
 *      <li> <code> PersonQuerySession: </code> a session for querying persons 
 *      </li> 
 *      <li> <code> PersonSearchSession: </code> a session to search persons 
 *      </li> 
 *      <li> <code> PersonAdminSession: </code> a session to manage persons 
 *      </li> 
 *      <li> <code> PersonNotificationSession: </code> a session to subscribe 
 *      to notifications of person changes </li> 
 *      <li> <code> PersonRealmSession: </code> a session to look up person to 
 *      realm mappings </li> 
 *      <li> <code> PersonRealmAssignmentSession: </code> a session to manage 
 *      person to realm mappings </li> 
 *      <li> <code> PersonSmartRealmSession: </code> a session to manage 
 *      dynamic person to realm mappings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> OrganizationLookupSession: </code> a session to lookup 
 *      organizations </li> 
 *      <li> <code> OrganizationQuerySession: </code> a session for querying 
 *      organizations </li> 
 *      <li> <code> OrganizationSearchSession: </code> a session to search 
 *      organizations </li> 
 *      <li> <code> OrganizationAdminSession: </code> a session to manage 
 *      organizations </li> 
 *      <li> <code> OrganizationNotificationSession: </code> a session to 
 *      subscribe to notifications of organization changes </li> 
 *      <li> <code> OrganizationHierarchySession: </code> a session to 
 *      traverse organization hierarchies </li> 
 *      <li> <code> OrganizationHierarchyDesignSession: </code> a sesion to 
 *      manage organization hierarchies </li> 
 *      <li> <code> OrganizationRealmSession: </code> a session to look up 
 *      organization to realm mappings </li> 
 *      <li> <code> OrganizationRealmAssignmentSession: </code> a session to 
 *      manage organization to realm mappings </li> 
 *      <li> <code> OrganizationSmartRealmSession: </code> a session to manage 
 *      dynamic organization to realm mappings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PositionLookupSession: </code> a session to lookup 
 *      positions </li> 
 *      <li> <code> PositionQuerySession: </code> a session for querying 
 *      positions </li> 
 *      <li> <code> PositionSearchSession: </code> a session to search 
 *      positions </li> 
 *      <li> <code> PositionAdminSession: </code> a session to manage 
 *      positions </li> 
 *      <li> <code> PositionNotificationSession: </code> a session to 
 *      subscribe to notifications of position changes </li> 
 *      <li> <code> PositionRealmSession: </code> a session to look up 
 *      position to realm mappings </li> 
 *      <li> <code> PositionRealmAssignmentSession: </code> a session to 
 *      manage position to realm mappings </li> 
 *      <li> <code> PositionSmartRealmSession: </code> a session to manage 
 *      dynamic position to realm mappings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AppointmentLookupSession: </code> a session to lookup 
 *      appointments </li> 
 *      <li> <code> AppointmentQuerySession: </code> a session for querying 
 *      appointments </li> 
 *      <li> <code> AppointmentSearchSession: </code> a session to search 
 *      appointments </li> 
 *      <li> <code> AppointmentAdminSession: </code> a session to manage 
 *      appointments </li> 
 *      <li> <code> AppointmentNotificationSession: </code> a session to 
 *      subscribe to notifications of appointment changes </li> 
 *      <li> <code> AppointmentRealmSession: </code> a session to look up 
 *      appointment to realm mappings </li> 
 *      <li> <code> AppointmentRealmAssignmentSession: </code> a session to 
 *      manage appointment to realm mappings </li> 
 *      <li> <code> AppointmentSmartRealmSession: </code> a session to manage 
 *      dynamic appointment to realm mappings </li> 
 *      <li> <code> RealmLookupSession: </code> a session to retrieve realms 
 *      </li> 
 *      <li> <code> RealmQuerySession: </code> a session for querying realms 
 *      </li> 
 *      <li> <code> RealmSearchSession: </code> a session to search for realms 
 *      </li> 
 *      <li> <code> RealmAdminSession: </code> a session to create, update and 
 *      delete realms </li> 
 *      <li> <code> RealmNotificationSession: </code> a session to receive 
 *      notifications for changes in realms </li> 
 *      <li> <code> RealmHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of realms </li> 
 *      <li> <code> RealmHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of realms </li> 
 *  </ul>
 *  
 *  
 *  <p> The personnel manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface PersonnelProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.personnel.PersonnelProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the person lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PersonLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonLookup() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonLookupSession getPersonLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person lookup 
     *  service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PersonLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PersonLookupSession getPersonLookupSessionForRealm(org.osid.id.Id realmId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PersonQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonQuerySession getPersonQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person query 
     *  service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PersonQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PersonQuerySession getPersonQuerySessionForRealm(org.osid.id.Id realmId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PersonSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonSearch() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonSearchSession getPersonSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person search 
     *  service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PersonSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PersonSearchSession getPersonSearchSessionForRealm(org.osid.id.Id realmId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PersonAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonAdmin() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonAdminSession getPersonAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person 
     *  administration service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PersonAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PersonAdminSession getPersonAdminSessionForRealm(org.osid.id.Id realmId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person 
     *  notification service. 
     *
     *  @param  personReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> PersonNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> personReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PersonNotificationSession getPersonNotificationSession(org.osid.personnel.PersonReceiver personReceiver, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the person 
     *  notification service for the given realm. 
     *
     *  @param  personReceiver the receiver 
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PersonNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> personReceiver, realmId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PersonNotificationSession getPersonNotificationSessionForRealm(org.osid.personnel.PersonReceiver personReceiver, 
                                                                                             org.osid.id.Id realmId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving person to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PersonRealmSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPersonRealm() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonRealm() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonRealmSession getPersonRealmSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning person to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PersonRealmAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonRealmAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonRealmAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PersonRealmAssignmentSession getPersonRealmAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic person realms for the given 
     *  realm. 
     *
     *  @param  realmId the <code> Id </code> of a realm 
     *  @param  proxy a proxy 
     *  @return a <code> PersonSmartRealmSession </code> 
     *  @throws org.osid.NotFoundException <code> realmId </code> not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonSmartRealm() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonSmartRealm() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonSmartRealmSession getPersonSmartRealmSession(org.osid.id.Id realmId, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationLookupSession getOrganizationLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  lookup service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.OrganizationLookupSession getOrganizationLookupSessionForRealm(org.osid.id.Id realmId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationQuerySession getOrganizationQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  query service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.OrganizationQuerySession getOrganizationQuerySessionForRealm(org.osid.id.Id realmId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationSearchSession getOrganizationSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  search service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.OrganizationSearchSession getOrganizationSearchSessionForRealm(org.osid.id.Id realmId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationAdminSession getOrganizationAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  administration service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.OrganizationAdminSession getOrganizationAdminSessionForRealm(org.osid.id.Id realmId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  notification service. 
     *
     *  @param  organizationReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> organizationReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationNotificationSession getOrganizationNotificationSession(org.osid.personnel.OrganizationReceiver organizationReceiver, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  notification service for the given realm. 
     *
     *  @param  organizationReceiver the receiver 
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> organizationReceiver, 
     *          realmId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.OrganizationNotificationSession getOrganizationNotificationSessionForRealm(org.osid.personnel.OrganizationReceiver organizationReceiver, 
                                                                                                         org.osid.id.Id realmId, 
                                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session traversing organization hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationHierarchy() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationHierarchy() </code> is true. 
     */

    public org.osid.personnel.OrganizationHierarchySession getOrganizationHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  heirarchy traversal service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the realm 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationHierarchySession </code> 
     *  @throws org.osid.NotFoundException <code> realmId </code> not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationHierarchy() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationHierarchy() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationHierarchySession getOrganizationHierarchySessionForRealm(org.osid.id.Id realmId, 
                                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session designing organization hierarchies. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationHierarchyDesign() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationHierarchyDesign() </code> is true. 
     */

    public org.osid.personnel.OrganizationHierarchyDesignSession getOrganizationHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the organization 
     *  heirarchy design service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the realm 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationHierarchyDesignSession </code> 
     *  @throws org.osid.NotFoundException <code> realmId </code> not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationHierarchyDesign() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationHierarchyDesign() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationHierarchyDesignSession getOrganizationHierarchyDesignSessionForRealm(org.osid.id.Id realmId, 
                                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving organization to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationRealmSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationRealm() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationRealm() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationRealmSession getOrganizationRealmSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning organization to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationRealmAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationRealmAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationRealmAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.personnel.OrganizationRealmAssignmentSession getOrganizationRealmAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic organization realms for the 
     *  given realm. 
     *
     *  @param  realmId the <code> Id </code> of a realm 
     *  @param  proxy a proxy 
     *  @return an <code> OrganizationSmartRealmSession </code> 
     *  @throws org.osid.NotFoundException <code> realmId </code> not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationSmartRealm() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationSmartRealm() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationSmartRealmSession getOrganizationSmartRealmSession(org.osid.id.Id realmId, 
                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PositionLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionLookup() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PositionLookupSession getPositionLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  lookup service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PositionLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PositionLookupSession getPositionLookupSessionForRealm(org.osid.id.Id realmId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PositionQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPositionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PositionQuerySession getPositionQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position query 
     *  service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PositionQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPositionQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PositionQuerySession getPositionQuerySessionForRealm(org.osid.id.Id realmId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PositionSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionSearch() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PositionSearchSession getPositionSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  search service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PositionSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PositionSearchSession getPositionSearchSessionForRealm(org.osid.id.Id realmId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PositionAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPositionAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionAdmin() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PositionAdminSession getPositionAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  administration service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PositionAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPositionAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PositionAdminSession getPositionAdminSessionForRealm(org.osid.id.Id realmId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  notification service. 
     *
     *  @param  positionReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> PositionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> positionReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PositionNotificationSession getPositionNotificationSession(org.osid.personnel.PositionReceiver positionReceiver, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the position 
     *  notification service for the given realm. 
     *
     *  @param  positionReceiver the receiver 
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return a <code> PositionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> positionReceiver, 
     *          realmId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.PositionNotificationSession getPositionNotificationSessionForRealm(org.osid.personnel.PositionReceiver positionReceiver, 
                                                                                                 org.osid.id.Id realmId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving position to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PositionRealmSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPositionRealm() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionRealm() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PositionRealmSession getPositionRealmSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning position to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> PositionRealmAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionRealmAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionRealmAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PositionRealmAssignmentSession getPositionRealmAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic position realms for the given 
     *  realm. 
     *
     *  @param  realmId the <code> Id </code> of a realm 
     *  @param  proxy a proxy 
     *  @return a <code> PositionSmartRealmSession </code> 
     *  @throws org.osid.NotFoundException <code> realmId </code> not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPositionSmartRealm() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionSmartRealm() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.PositionSmartRealmSession getPositionSmartRealmSession(org.osid.id.Id realmId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.AppointmentLookupSession getAppointmentLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  lookup service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.AppointmentLookupSession getAppointmentLookupSessionForRealm(org.osid.id.Id realmId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.AppointmentQuerySession getAppointmentQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  query service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.AppointmentQuerySession getAppointmentQuerySessionForRealm(org.osid.id.Id realmId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.AppointmentSearchSession getAppointmentSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  search service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.AppointmentSearchSession getAppointmentSearchSessionForRealm(org.osid.id.Id realmId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentAdmin() </code> is <code> true. </code> 
     */

    public org.osid.personnel.AppointmentAdminSession getAppointmentAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  administration service for the given realm. 
     *
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.AppointmentAdminSession getAppointmentAdminSessionForRealm(org.osid.id.Id realmId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  notification service. 
     *
     *  @param  appointmentReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> appointmentReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.AppointmentNotificationSession getAppointmentNotificationSession(org.osid.personnel.AppointmentReceiver appointmentReceiver, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the appointment 
     *  notification service for the given realm. 
     *
     *  @param  appointmentReceiver the receiver 
     *  @param  realmId the <code> Id </code> of the <code> Realm </code> 
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Realm </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> appointmentReceiver, 
     *          realmId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.personnel.AppointmentNotificationSession getAppointmentNotificationSessionForRealm(org.osid.personnel.AppointmentReceiver appointmentReceiver, 
                                                                                                       org.osid.id.Id realmId, 
                                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving appointment to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentRealmSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentRealm() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentRealm() </code> is <code> true. </code> 
     */

    public org.osid.personnel.AppointmentRealmSession getAppointmentRealmSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning appointment to realm mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentRealmAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentRealmAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentRealmAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.personnel.AppointmentRealmAssignmentSession getAppointmentRealmAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic appointment realms for the given 
     *  realm. 
     *
     *  @param  realmId the <code> Id </code> of a realm 
     *  @param  proxy a proxy 
     *  @return an <code> AppointmentSmartRealmSession </code> 
     *  @throws org.osid.NotFoundException <code> realmId </code> not found 
     *  @throws org.osid.NullArgumentException <code> realmId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentSmartRealm() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentSmartRealm() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.AppointmentSmartRealmSession getAppointmentSmartRealmSession(org.osid.id.Id realmId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the realm lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RealmLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRealmLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmLookup() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmLookupSession getRealmLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the realm query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RealmQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRealmQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmQuerySession getRealmQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the realm search 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RealmSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRealmSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmSearch() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmSearchSession getRealmSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the realm 
     *  administrative service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RealmAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRealmAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmAdmin() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmAdminSession getRealmAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the realm 
     *  notification service. 
     *
     *  @param  realmReceiver the receiver 
     *  @param  proxy a proxy 
     *  @return a <code> RealmNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> realmReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRealmNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.RealmNotificationSession getRealmNotificationSession(org.osid.personnel.RealmReceiver realmReceiver, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the realm 
     *  hierarchy service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RealmHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRealmHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.personnel.RealmHierarchySession getRealmHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the realm 
     *  hierarchy design service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RealmHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRealmHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRealmHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.RealmHierarchyDesignSession getRealmHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> PersonnelBatchProxyManager. </code> 
     *
     *  @return a <code> PersonnelBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPersonnelBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonnelBatch() </code> is <code> true. </code> 
     */

    public org.osid.personnel.batch.PersonnelBatchProxyManager getPersonnelBatchProxyManager()
        throws org.osid.OperationFailedException;
}
