//
// org.osid.personnel.Position
//
//     The OSID Java specification for org.osid.personnel.Position.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>A <code> Position </code> in an <code> Organization. </code> </p>
 */

public interface Position
    extends org.osid.OsidObject,
            org.osid.Temporal,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the organization to which this position 
     *  is assigned. 
     *
     *  @return the <code> Organization </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOrganizationId();


    /**
     *  Gets the organization for this position. 
     *
     *  @return the <code> Organization </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.Organization getOrganization()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the title for this position. 
     *
     *  @return the position title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getTitle();


    /**
     *  Gets the <code> Id </code> of the job level. 
     *
     *  @return the <code> Grade </code> <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getLevelId();


    /**
     *  Gets the grade level for this position. 
     *
     *  @return the <code> Grade </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.grading.Grade getLevel()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if qualifications are avilable for this position. 
     *
     *  @return <code> true </code> if qualifications are available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasQualifications();


    /**
     *  Gets the qualifcation Ids. 
     *
     *  @return a list of objective <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> hasQualifications() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getQualificationIds();


    /**
     *  Gets the list of qualifications required for this position. 
     *
     *  @return the <code> Objectives </code> 
     *  @throws org.osid.IllegalStateException <code> hasQualifications() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.learning.ObjectiveList getQualifications()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the target number of <code> Appointments </code> desired for this 
     *  <code> Position. </code> 
     *
     *  @return the number of appointments 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getTargetAppointments();


    /**
     *  Gets the required percentage commitment (0-100). 
     *
     *  @return the required percentage commitment 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getRequiredCommitment();


    /**
     *  Tests if a salary range is available. 
     *
     *  @return <code> true </code> if a salary range is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSalaryRange();


    /**
     *  Gets the low end of the salary range. 
     *
     *  @return the low slaary 
     *  @throws org.osid.IllegalStateException <code> hasSalaryRange() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getLowSalaryRange();


    /**
     *  Gets the midpoint of the salary range. 
     *
     *  @return the midpoint slaary 
     *  @throws org.osid.IllegalStateException <code> hasSalaryRange() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getMidpointSalaryRange();


    /**
     *  Gets the high end of the salary range. 
     *
     *  @return the high slaary 
     *  @throws org.osid.IllegalStateException <code> hasSalaryRange() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.financials.Currency getHighSalaryRange();


    /**
     *  Gets the frequency of compensation. 
     *
     *  @return the frequency 
     *  @throws org.osid.IllegalStateException <code> hasSalaryRange() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getCompensationFrequency();


    /**
     *  Tests if this position is FLSA exempt. 
     *
     *  @return <code> true </code> if this position is exempt, <code> false 
     *          </code> is non-exempt 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isExempt();


    /**
     *  Tests if this position is eligible for benefits. 
     *
     *  @return <code> true </code> if this position has benefits, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasBenefits();


    /**
     *  Gets the benefits Type assoicated with this position. 
     *
     *  @return the benefits type 
     *  @throws org.osid.IllegalStateException <code> hasBenefits() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getBenefitsType();


    /**
     *  Gets the record corresponding to the given <code> Position </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> positionRecordType 
     *  </code> may be the <code> Type </code> returned in <code> 
     *  getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(positionRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  positionRecordType the type of position record to retrieve 
     *  @return the position record 
     *  @throws org.osid.NullArgumentException <code> positionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(positionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PositionRecord getPositionRecord(org.osid.type.Type positionRecordType)
        throws org.osid.OperationFailedException;
}
