//
// org.osid.personnel.PositionForm
//
//     The OSID Java specification for org.osid.personnel.PositionForm.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This is the form for creating and updating <code> Position </code> 
 *  objects. Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  PositionAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface PositionForm
    extends org.osid.OsidObjectForm,
            org.osid.OsidTemporalForm,
            org.osid.OsidSubjugateableForm {


    /**
     *  Gets the metadata for a title. 
     *
     *  @return metadata for the title 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTitleMetadata();


    /**
     *  Sets the title. 
     *
     *  @param  title the title 
     *  @throws org.osid.InvalidArgumentException <code> title </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTitle(String title);


    /**
     *  Clears the title. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitle();


    /**
     *  Gets the metadata for a level. 
     *
     *  @return metadata for the level 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLevelMetadata();


    /**
     *  Sets the job level. 
     *
     *  @param  gradeId the level 
     *  @throws org.osid.InvalidArgumentException <code> gradeId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> gradeId </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLevel(org.osid.id.Id gradeId);


    /**
     *  Clears the level. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLevel();


    /**
     *  Gets the metadata for the qualifications. 
     *
     *  @return metadata for the qualifications 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getQualificationsMetadata();


    /**
     *  Sets the position qualifications. 
     *
     *  @param  objectivesIds the learning objective <code> Ids </code> 
     *  @throws org.osid.InvalidArgumentException <code> objectiveIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> objectiveIds </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setQualifications(org.osid.id.Id[] objectivesIds);


    /**
     *  Clears the qualifications. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQualifications();


    /**
     *  Gets the metadata for a target appointments. 
     *
     *  @return metadata for the target appointments 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getTargetAppointmenstMetadata();


    /**
     *  Sets the target appointments. 
     *
     *  @param  appointments the target appointments 
     *  @throws org.osid.InvalidArgumentException <code> appointments </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTargetAppointments(long appointments);


    /**
     *  Clears the target appointments. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTargetAppointments();


    /**
     *  Gets the metadata for a required commitment. 
     *
     *  @return metadata for the required commitment 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRequiredCommitmentMetadata();


    /**
     *  Sets the required commitment percentage (0-100). 
     *
     *  @param  commitment the required commitment 
     *  @throws org.osid.InvalidArgumentException <code> commitment </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRequiredCommitment(long commitment);


    /**
     *  Clears the required commitment. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiredCommitment();


    /**
     *  Gets the metadata for a low salary range. 
     *
     *  @return metadata for the low salary range 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLowSalaryRangeMetadata();


    /**
     *  Sets the low salary range. 
     *
     *  @param  salary the low salary range 
     *  @throws org.osid.InvalidArgumentException <code> salary </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> salary </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLowSalaryRange(org.osid.financials.Currency salary);


    /**
     *  Clears the low salary. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLowSalaryRange();


    /**
     *  Gets the metadata for a midpoint salary range. 
     *
     *  @return metadata for the midpoint salary range 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMidpointSalaryRangeMetadata();


    /**
     *  Sets the midpoint salary range. 
     *
     *  @param  salary the midpoint salary range 
     *  @throws org.osid.InvalidArgumentException <code> salary </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> salary </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMidpointSalaryRange(org.osid.financials.Currency salary);


    /**
     *  Clears the midpoint salary. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMidpointSalaryRange();


    /**
     *  Gets the metadata for a high salary range. 
     *
     *  @return metadata for the high salary range 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getHighSalaryRangeMetadata();


    /**
     *  Sets the high salary range. 
     *
     *  @param  salary the high salary range 
     *  @throws org.osid.InvalidArgumentException <code> salary </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> salary </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setHighSalaryRange(org.osid.financials.Currency salary);


    /**
     *  Clears the high salary. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHighSalaryRange();


    /**
     *  Gets the metadata for a compensation frequency. 
     *
     *  @return metadata for the compensation frequency 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCompensationFrequencyMetadata();


    /**
     *  Sets the compensation frequency. 
     *
     *  @param  frequency the compensation frequency 
     *  @throws org.osid.InvalidArgumentException <code> frequency </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> frequency </code> is 
     *          null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCompensationFrequency(org.osid.calendaring.Duration frequency);


    /**
     *  Clears the compensation frequency. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompensationFrequency();


    /**
     *  Gets the metadata for the exempt flag. 
     *
     *  @return metadata for the exempt flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getExemptMetadata();


    /**
     *  Sets the exempt flag. 
     *
     *  @param  eempt the exempt flag 
     *  @throws org.osid.InvalidArgumentException <code> exempt </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setExempt(boolean eempt);


    /**
     *  Clears the exempt flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExempt();


    /**
     *  Gets the metadata for a benefits type. 
     *
     *  @return metadata for the benefits type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBenefitsTypeMetadata();


    /**
     *  Sets the benefits type. 
     *
     *  @param  type the benefits type 
     *  @throws org.osid.InvalidArgumentException <code> type </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> type </code> is null 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBenefitsType(org.osid.type.Type type);


    /**
     *  Clears the benefits type. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> or <code> Metadata.isReadOnly() </code> is <code> true 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBenefitsType();


    /**
     *  Gets the <code> PositionFormRecord </code> interface corresponding to 
     *  the given position record <code> Type. </code> 
     *
     *  @param  positionRecordType the position record type 
     *  @return the record 
     *  @throws org.osid.NullArgumentException <code> positionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(positionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.PositionFormRecord getPositionFormRecord(org.osid.type.Type positionRecordType)
        throws org.osid.OperationFailedException;
}
