//
// org.osid.personnel.RealmQuery
//
//     The OSID Java specification for org.osid.personnel.RealmQuery.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.personnel;


/**
 *  <p>This is the query for searching for realms. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface RealmQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the person <code> Id </code> for this query to match persons 
     *  assigned to realms. 
     *
     *  @param  personId a person <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> personId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPersonId(org.osid.id.Id personId, boolean match);


    /**
     *  Clears all person <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPersonIdTerms();


    /**
     *  Tests if a person query is available. 
     *
     *  @return <code> true </code> if a person query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPersonQuery();


    /**
     *  Gets the query for a person. 
     *
     *  @return the person query 
     *  @throws org.osid.UnimplementedException <code> supportsPersonQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPersonQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PersonQuery getPersonQuery();


    /**
     *  Matches realms with any person. 
     *
     *  @param  match <code> true </code> to match realms with any person, 
     *          <code> false </code> to match realms with no persons 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPerson(boolean match);


    /**
     *  Clears all person terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPersonTerms();


    /**
     *  Sets the organization <code> Id </code> for this query to match 
     *  organizations assigned to realms. 
     *
     *  @param  organizationId an organization <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> organizationId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOrganizationId(org.osid.id.Id organizationId, 
                                    boolean match);


    /**
     *  Clears all organization <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrganizationIdTerms();


    /**
     *  Tests if a organization query is available. 
     *
     *  @return <code> true </code> if a organization query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOrganizationQuery();


    /**
     *  Gets the query for an organization. 
     *
     *  @return the organization query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOrganizationQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOrganizationQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.OrganizationQuery getOrganizationQuery();


    /**
     *  Matches realms with any organization. 
     *
     *  @param  match <code> true </code> to match realms with any 
     *          organization, <code> false </code> to match realms with no 
     *          organizations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOrganization(boolean match);


    /**
     *  Clears all organization terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOrganizationTerms();


    /**
     *  Sets the position <code> Id </code> for this query to match positions 
     *  assigned to realms. 
     *
     *  @param  positionId a position <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> positionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPositionId(org.osid.id.Id positionId, boolean match);


    /**
     *  Clears all position <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPositionIdTerms();


    /**
     *  Tests if a position query is available. 
     *
     *  @return <code> true </code> if a position query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPositionQuery();


    /**
     *  Gets the query for a position. 
     *
     *  @return the position query 
     *  @throws org.osid.UnimplementedException <code> supportsPositionQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPositionQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.PositionQuery getPositionQuery();


    /**
     *  Matches realms with any position. 
     *
     *  @param  match <code> true </code> to match realms with any position, 
     *          <code> false </code> to match realms with no positions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPosition(boolean match);


    /**
     *  Clears all position terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPositionTerms();


    /**
     *  Sets the appointment <code> Id </code> for this query to match 
     *  positions assigned to realms. 
     *
     *  @param  appointmentId an appointment <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> appointmentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAppointmentId(org.osid.id.Id appointmentId, boolean match);


    /**
     *  Clears all appointment <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAppointmentIdTerms();


    /**
     *  Tests if an appointment query is available. 
     *
     *  @return <code> true </code> if an appointment query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAppointmentQuery();


    /**
     *  Gets the query for an appointment. 
     *
     *  @return the appointment query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAppointmentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAppointmentQuery() </code> is <code> true. </code> 
     */

    public org.osid.personnel.AppointmentQuery getAppointmentQuery();


    /**
     *  Matches realms with any appointment. 
     *
     *  @param  match <code> true </code> to match realms with any 
     *          appointment, <code> false </code> to match realms with no 
     *          appointments 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAppointment(boolean match);


    /**
     *  Clears all appointment terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAppointmentTerms();


    /**
     *  Sets the realm <code> Id </code> for this query to match realms that 
     *  have the specified realm as an ancestor. 
     *
     *  @param  realmId a realm <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorRealmId(org.osid.id.Id realmId, boolean match);


    /**
     *  Clears all ancestor realm <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorRealmIdTerms();


    /**
     *  Tests if a <code> RealmQuery </code> is available. 
     *
     *  @return <code> true </code> if a realm query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorRealmQuery();


    /**
     *  Gets the query for a realm. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the realm query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorRealmQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorRealmQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.RealmQuery getAncestorRealmQuery();


    /**
     *  Matches realms with any ancestor. 
     *
     *  @param  match <code> true </code> to match realms with any ancestor, 
     *          <code> false </code> to match root realms 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorRealm(boolean match);


    /**
     *  Clears all ancestor realm terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorRealmTerms();


    /**
     *  Sets the realm <code> Id </code> for this query to match realms that 
     *  have the specified realm as a descendant. 
     *
     *  @param  realmId a realm <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> realmId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantRealmId(org.osid.id.Id realmId, boolean match);


    /**
     *  Clears all descendant realm <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantRealmIdTerms();


    /**
     *  Tests if a <code> RealmQuery </code> is available. 
     *
     *  @return <code> true </code> if a realm query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantRealmQuery();


    /**
     *  Gets the query for a realm. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the realm query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantRealmQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantRealmQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.personnel.RealmQuery getDescendantRealmQuery();


    /**
     *  Matches realms with any descendant. 
     *
     *  @param  match <code> true </code> to match realms with any descendant, 
     *          <code> false </code> to match leaf realms 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantRealm(boolean match);


    /**
     *  Clears all descendant realm terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantRealmTerms();


    /**
     *  Gets the record query corresponding to the given <code> Realm </code> 
     *  record <code> Type. </code> Multiple record retrievals produce a 
     *  nested boolean <code> OR </code> term. 
     *
     *  @param  realmRecordType a realm record type 
     *  @return the realm query record 
     *  @throws org.osid.NullArgumentException <code> realmRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(realmRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.personnel.records.RealmQueryRecord getRealmQueryRecord(org.osid.type.Type realmRecordType)
        throws org.osid.OperationFailedException;
}
