//
// org.osid.process.ProcessProxyManager
//
//     The OSID Java specification for org.osid.process.ProcessProxyManager.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>The state manager provides access to state lookup and creation session 
 *  and provides interoperability tests for various aspects of this service. 
 *  Methods in this manager support the passing of a <code> Proxy </code> for 
 *  the purposes of passing information from a server environment. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> StateSession: </code> a session to look up state to <code> 
 *      Id </code> mappings </li> 
 *      <li> <code> StateAssignmentSession: </code> a session to manage state 
 *      to <code> Id </code> mappings </li> 
 *      <li> <code> StateChangeNotificationSession: </code> a session to 
 *      subscribe to state changes </li> 
 *      <li> <code> StateLookupSession: </code> a session to retrieve states 
 *      </li> 
 *      <li> <code> StateQuerySession: </code> a session to query states </li> 
 *      <li> <code> StateSearchSession: </code> a session to search for states 
 *      </li> 
 *      <li> <code> StateAdminSession: </code> a session to create and delete 
 *      states </li> 
 *      <li> <code> StateSequencingSession: </code> a session to sequence 
 *      states </li> 
 *      <li> <code> StateNotificationSession: </code> a session to receive 
 *      notifications pertaining to state changes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProcessLookupSession: a </code> session to retrieve 
 *      processes </li> 
 *      <li> <code> ProcessQuerySession: </code> a session to query processes 
 *      </li> 
 *      <li> <code> ProcessSearchSession: </code> a session to search for 
 *      processes </li> 
 *      <li> <code> ProcessAdminSession: </code> a session to create, update 
 *      and delete processes </li> 
 *      <li> <code> ProcessNotificationSession: </code> a session to receive 
 *      notifications pertaining to changes in processes </li> 
 *      <li> <code> ProcessHierarchySession: </code> a session to traverse 
 *      process hierarchies </li> 
 *      <li> <code> ProcessHierarchyDesignSession: </code> a session to manage 
 *      process hierarchies </li> 
 *  </ul>
 *  
 */

public interface ProcessProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.process.ProcessProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the state service. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a StateLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsState() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsState() </code> is <code> true. </code> 
     */

    public org.osid.process.StateSession getStateSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the state service 
     *  for the given process. 
     *
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateStateSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsState() </code> 
     *          or <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsState() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateSession getStateSessionForProcess(org.osid.id.Id processId, 
                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the state 
     *  assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a StateAssignmentLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateAssignment() </code> is <code> true. </code> 
     */

    public org.osid.process.StateAssignmentSession getStateAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the state 
     *  assignment service for the given process. 
     *
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateAssignmentStateSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateAssignmentSession getStateAssignmentSessionForProcess(org.osid.id.Id processId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to state 
     *  changes. 
     *
     *  @param  stateChangeReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return <code> a StateChangeNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> stateChangeReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateChangeNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateChangeNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.StateNotificationSession getStateChangeNotificationSession(org.osid.process.StateChangeReceiver stateChangeReceiver, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the state change notification session for the given process. 
     *
     *  @param  stateChangeReceiver the notification callback 
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateChangeNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> stateChangeReceiver, 
     *          processId </code> , or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateChangeNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateChangeNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateNotificationSession getStateChangeNotificationSessionForProcess(org.osid.process.StateChangeReceiver stateChangeReceiver, 
                                                                                                 org.osid.id.Id processId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the state lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a StateLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStateLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateLookup() </code> is <code> true. </code> 
     */

    public org.osid.process.StateLookupSession getStateLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the state lookup 
     *  service for the given process. 
     *
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsStateLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateLookupSession getStateLookupSessionForProcess(org.osid.id.Id processId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a state query session. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a StateQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStateQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateQuery() </code> is <code> true. </code> 
     */

    public org.osid.process.StateQuerySession getStateQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a state query session for the given process. 
     *
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsStateQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateQuerySession getStateQuerySessionForProcess(org.osid.id.Id processId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a state search session. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a StateSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStateSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateSearch() </code> is <code> true. </code> 
     */

    public org.osid.process.StateSearchSession getStateSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a state search session for the given process. 
     *
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsStateSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateSearchSession getStateSearchSessionForProcess(org.osid.id.Id processId, 
                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a state administration session for creating, updating and 
     *  deleting states. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a StateAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStateAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateAdmin() </code> is <code> true. </code> 
     */

    public org.osid.process.StateAdminSession getStateAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a state administration session for the given process. 
     *
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStateAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateAdminSession getStateAdminSessionForProcess(org.osid.id.Id processId, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a state sequencing session for ordering states. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a StateSequencingSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateSequencing() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateSequencing() </code> is <code> true. </code> 
     */

    public org.osid.process.StateSequencingSession getStateSequencingSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a state sequencing session for the given process. 
     *
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateSequencingSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateSequencing() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateSequencing() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateSequencingSession getStateSequencingSessionForProcess(org.osid.id.Id processId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the state notification session for the given process. 
     *
     *  @param  stateReceiver notification callback 
     *  @param  proxy a proxy 
     *  @return <code> a StateNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> stateReceiver </code> or 
     *          <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.StateNotificationSession getStateNotificationSession(org.osid.process.StateReceiver stateReceiver, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the state notification session for the given process. 
     *
     *  @param  stateReceiver notification callback 
     *  @param  processId the <code> Id </code> of the process 
     *  @param  proxy a proxy 
     *  @return <code> a StateNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> stateReceiver, processId 
     *          </code> or <code> proxy </code> is null 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStateNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.process.StateNotificationSession getStateNotificationSessionForProcess(org.osid.process.StateReceiver stateReceiver, 
                                                                                           org.osid.id.Id processId, 
                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the process lookup session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcessLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessLookup() </code> is <code> true. </code> 
     */

    public org.osid.process.ProcessLookupSession getProcessLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the process query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcessQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessQuery() </code> is <code> true. </code> 
     */

    public org.osid.process.ProcessQuerySession getProcessQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the process search session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcessSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessSearch() </code> is <code> true. </code> 
     */

    public org.osid.process.ProcessSearchSession getProcessSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the process administrative session for creating, updating and 
     *  deleteing processes. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcessAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessAdmin() </code> is <code> true. </code> 
     */

    public org.osid.process.ProcessAdminSession getProcessAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscriprocessg to changes to a 
     *  process. 
     *
     *  @param  processReceiver notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> ProcessNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> processReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.ProcessNotificationSession getProcessNotificationSession(org.osid.process.ProcessReceiver processReceiver, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the process hierarchy traversal session. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a ProcessHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.process.ProcessHierarchySession getProcessHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the process hierarchy design session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> ProcessHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.ProcessHierarchyDesignSession getProcessHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;
}
