//
// org.osid.process.ProcessQuery
//
//     The OSID Java specification for org.osid.process.ProcessQuery.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>This is the query for searching processes. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ProcessQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the state <code> Id </code> for this query. 
     *
     *  @param  stateId a state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchStateId(org.osid.id.Id stateId, boolean match);


    /**
     *  Clears the state <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStateIdTerms();


    /**
     *  Tests if a <code> StateQuery </code> is available. 
     *
     *  @return <code> true </code> if a state query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStateQuery();


    /**
     *  Gets the query for a state. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the state query 
     *  @throws org.osid.UnimplementedException <code> supportsStateQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStateQuery() </code> is <code> true. </code> 
     */

    public org.osid.process.StateQuery getStateQuery();


    /**
     *  Matches processes with any states. 
     *
     *  @param  match <code> true </code> to match processes with any states, 
     *          <code> false </code> to match processes with no states 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyState(boolean match);


    /**
     *  Clears the state terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearStateTerms();


    /**
     *  Sets the process <code> Id </code> for this query to match processes 
     *  that have the specified process as an ancestor. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorProcessId(org.osid.id.Id processId, boolean match);


    /**
     *  Clears the ancestor process <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorProcessIdTerms();


    /**
     *  Tests if a <code> ProcessQuery </code> is available. 
     *
     *  @return <code> true </code> if a process query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorProcessQuery();


    /**
     *  Gets the query for a process. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the process query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorProcessQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorProcessQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.ProcessQuery getAncestorProcessQuery();


    /**
     *  Matches processes with any ancestor. 
     *
     *  @param  match <code> true </code> to match process with any ancestor, 
     *          <code> false </code> to match root processes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorProcess(boolean match);


    /**
     *  Clears the ancestor process terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorProcessTerms();


    /**
     *  Sets the process <code> Id </code> for this query to match that have 
     *  the specified process as a descendant. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantProcessId(org.osid.id.Id processId, 
                                         boolean match);


    /**
     *  Clears the descendant process <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantProcessIdTerms();


    /**
     *  Tests if a <code> ProcessQuery </code> is available. 
     *
     *  @return <code> true </code> if a process query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantProcessQuery();


    /**
     *  Gets the query for a process. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the process query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantProcessQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantProcessQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.process.ProcessQuery getDescendantProcessQuery();


    /**
     *  Matches processes with any descendant. 
     *
     *  @param  match <code> true </code> to match process with any 
     *          descendant, <code> false </code> to match leaf processes 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantProcess(boolean match);


    /**
     *  Clears the descendant process terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantProcessTerms();


    /**
     *  Gets the process query record corresponding to the given <code> 
     *  Process </code> record <code> Type. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  processRecordType a process record type 
     *  @return the process query record 
     *  @throws org.osid.NullArgumentException <code> processRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(processRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.records.ProcessQueryRecord getProcessQueryRecord(org.osid.type.Type processRecordType)
        throws org.osid.OperationFailedException;
}
