//
// org.osid.process.StateAssignmentSession
//
//     The OSID Java specification for org.osid.process.StateAssignmentSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>This session provides methods to re-assign <code> State </code> to 
 *  reference <code> Ids. </code> A <code> State </code> may be associated 
 *  with multiple reference <code> ids. </code> A reference <code> id </code> 
 *  may map to only one <code> State. </code> </p>
 */

public interface StateAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter state/id mappings. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known mapping methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignStates();


    /**
     *  Gets the valid states that can be assigned to the reference <code> id 
     *  </code> in the given process. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  processId <code> Id </code> of the <code> Process </code> 
     *  @return the <code> Ids </code> of the next valid states 
     *  @throws org.osid.NotFoundException <code> referenceId </code> or 
     *          <code> processId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getNextStateIds(org.osid.id.Id referenceId, 
                                              org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the valid states that can be assigned to a reference <code> Id 
     *  </code> in the given process. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  processId <code> Id </code> of the <code> Process </code> 
     *  @return the next valid states 
     *  @throws org.osid.NotFoundException <code> referenceId </code> or 
     *          <code> processId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getNextStates(org.osid.id.Id referenceId, 
                                                    org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a reference <code> Id </code> to a <code> State. </code> 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  stateId the <code> Id </code> of the <code> State </code> 
     *  @throws org.osid.AlreadyExistsException this <code> Id </code> is 
     *          already assigned to the state 
     *  @throws org.osid.NotFoundException <code> stateId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          stateId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignReferenceToState(org.osid.id.Id referenceId, 
                                       org.osid.id.Id stateId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a reference <code> Id </code> from a <code> State. </code> 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  stateId the <code> Id </code> of the <code> State </code> 
     *  @throws org.osid.NotFoundException <code> stateId </code> not found 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> stateId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignReferenceFromState(org.osid.id.Id referenceId, 
                                           org.osid.id.Id stateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
