//
// org.osid.process.StateLookupSession
//
//     The OSID Java specification for org.osid.process.StateLookupSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>This session defines methods for retrieving states. A <code> State 
 *  </code> is an arbitrary entity that may represent a person, place or thing 
 *  used to identify an object used in various services. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated process view: All state methods in this session operate, 
 *      retrieve and pertain to states defined explicitly in the current 
 *      process. Using an isolated view is useful for managing <code> States 
 *      </code> with the <code> StateAdminSession. </code> </li> 
 *      <li> federated process view: All state methods in this session 
 *      operate, retrieve and pertain to all states defined in this process 
 *      and any other states implicitly available in this process through 
 *      process inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedProcessView() </code> and <code> 
 *  useIsolatedProcessView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> States may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  State. </code> </p>
 */

public interface StateLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Process </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Process Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProcessId();


    /**
     *  Gets the <code> Process </code> associated with this session. 
     *
     *  @return the <code> Process </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.Process getProcess()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> State </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupStates();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeStateView();


    /**
     *  A complete view of the <code> State </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryStateView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include states in processes which are children of this process in the 
     *  process hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedProcessView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this process only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedProcessView();


    /**
     *  Gets the <code> State </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> State 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  State </code> and retained for compatibility. 
     *
     *  @param  stateId the <code> Id </code> of the <code> State </code> to 
     *          retrieve 
     *  @return the returned <code> State </code> 
     *  @throws org.osid.NotFoundException no <code> State </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.State getState(org.osid.id.Id stateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StateList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  states specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> States </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  stateIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> State list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> stateIdLs </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getStatesByIds(org.osid.id.IdList stateIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StateList </code> corresponding to the given state genus 
     *  <code> Type </code> which does not include states of types derived 
     *  from the specified <code> Type. </code> In plenary mode, the returned 
     *  list contains all known states or an error results. Otherwise, the 
     *  returned list may contain only those states that are accessible 
     *  through this session. 
     *
     *  @param  stateGenusType a state genus type 
     *  @return the returned <code> State </code> list 
     *  @throws org.osid.NullArgumentException <code> stateGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getStatesByGenusType(org.osid.type.Type stateGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StateList </code> corresponding to the given state genus 
     *  <code> Type </code> and include any additional states with genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known states or an error results. 
     *  Otherwise, the returned list may contain only those states that are 
     *  accessible through this session. 
     *
     *  @param  stateGenusType a state genus type 
     *  @return the returned <code> State </code> list 
     *  @throws org.osid.NullArgumentException <code> stateGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getStatesByParentGenusType(org.osid.type.Type stateGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StateList </code> containing the given state record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known states or an error results. Otherwise, the returned list may 
     *  contain only those states that are accessible through this session. 
     *
     *  @param  stateRecordType a state record type 
     *  @return the returned <code> State </code> list 
     *  @throws org.osid.NullArgumentException <code> stateRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getStatesByRecordType(org.osid.type.Type stateRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> States. </code> In plenary mode, the returned list 
     *  contains all known states or an error results. Otherwise, the returned 
     *  list may contain only those states that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> States </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getStates()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the next valid states for the given state. 
     *
     *  @param  stateId a state <code> Id </code> 
     *  @return the valid next <code> States </code> 
     *  @throws org.osid.NotFoundException <code> stateId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getValidNextStates(org.osid.id.Id stateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
