//
// org.osid.process.StateSearchSession
//
//     The OSID Java specification for org.osid.process.StateSearchSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>This session provides methods for searching among <code> State </code> 
 *  objects. The search query is constructed using the <code> StateQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getStatesByQuery() </code> is the basic search method and 
 *  returns a list of <code> States. </code> A more advanced search may be 
 *  performed with <code> getStatesBySearch(). </code> It accepts an <code> 
 *  StateSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getStatesBySearch() </code> returns an <code> StateSearchResults </code> 
 *  that can be used to access the resulting <code> StateList </code> or be 
 *  used to perform a search within the result set through <code> StateList. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated process view: searches include states in processes of 
 *      which this process is a ancestor in the process hierarchy </li> 
 *      <li> isolated process view: searches are restricted to states in this 
 *      process </li> 
 *  </ul>
 *  
 *  
 *  <p> States may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> StateQuery. </code> 
 *  </p>
 */

public interface StateSearchSession
    extends org.osid.process.StateQuerySession {


    /**
     *  Gets a state search. 
     *
     *  @return the state search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateSearch getStateSearch();


    /**
     *  Gets a state search order. The <code> StateSearchOrder </code> is 
     *  supplied to a <code> StateSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the state search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateSearchOrder getStateSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  stateQuery the state query 
     *  @param  stateSearch the state search 
     *  @return the state search results 
     *  @throws org.osid.NullArgumentException <code> stateQuery </code> or 
     *          <code> stateSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stateQuery </code> or 
     *          <code> stateSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateSearchResults getStatesBySearch(org.osid.process.StateQuery stateQuery, 
                                                                 org.osid.process.StateSearch stateSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a state query from an inspector. The inspector is available from 
     *  a <code> StateSearchResults. </code> 
     *
     *  @param  stateQueryInspector a state inspector 
     *  @return the state query 
     *  @throws org.osid.NullArgumentException <code> stateQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> stateQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateQuery getStateQueryFromInspector(org.osid.process.StateQueryInspector stateQueryInspector);
}
