//
// org.osid.process.StateSession
//
//     The OSID Java specification for org.osid.process.StateSession.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.process;


/**
 *  <p>This session provides methods to retrieve <code> State </code> to 
 *  reference <code> Id </code> mappings. A reference <code> Id </code> may 
 *  map to only one <code> State </code> while a <code> State </code> may map 
 *  to multiple reference <code> Ids. </code> </p> 
 *  
 *  <p> This lookup session defines several views </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface StateSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform lookups of state/Id mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known lookup methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupStateMappings();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeStateView();


    /**
     *  A complete view of the <code> State </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryStateView();


    /**
     *  Gets the processes to which the reference <code> Id </code> belongs. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @return the processes to which the agent belongs 
     *  @throws org.osid.NotFoundException <code> referenceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getProcessIdsByReference(org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the processes to which the reference <code> Id </code> belongs. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @return the processes to which the agent belongs 
     *  @throws org.osid.NotFoundException <code> referenceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.ProcessList getProcessesByReference(org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> State </code> <code> Id </code> associated with the 
     *  given reference <code> Id. </code> 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @return associated states 
     *  @throws org.osid.NotFoundException <code> referenceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getStateIdsByReference(org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> State </code> associated with the given <code> Id. 
     *  </code> 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @return associated states 
     *  @throws org.osid.NotFoundException <code> referenceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getStatesByReference(org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> State </code> <code> Id </code> associated with the 
     *  given reference <code> Id </code> and process. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  processId <code> Id </code> of a <code> Process </code> 
     *  @return associated state 
     *  @throws org.osid.NotFoundException <code> referenceId </code> is not 
     *          found in process 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStateIdByReferenceAndProcess(org.osid.id.Id referenceId, 
                                                          org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> State </code> <code> Ids </code> associated with the 
     *  given reference <code> Id </code> list and process. The returned state 
     *  <code> Ids </code> are in the order they are supplied. 
     *
     *  @param  referenceIds a reference <code> Id </code> 
     *  @param  processId <code> Id </code> of a <code> Process </code> 
     *  @return associated states 
     *  @throws org.osid.NotFoundException <code> referenceId </code> is not 
     *          found in process 
     *  @throws org.osid.NullArgumentException <code> referenceIds </code> or 
     *          <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getStateIdsByReferencesAndProcess(org.osid.id.IdList referenceIds, 
                                                                org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> State </code> associated with the given reference and 
     *  process. 
     *
     *  @param  referenceId a reference <code> Id </code> 
     *  @param  processId <code> Id </code> of a <code> Process </code> 
     *  @return associated state 
     *  @throws org.osid.NotFoundException a <code> referenceId </code> is not 
     *          found in process 
     *  @throws org.osid.NullArgumentException <code> referenceId </code> or 
     *          <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.State getStateByReferenceAndProcess(org.osid.id.Id referenceId, 
                                                                org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> States </code> associated with the given references 
     *  and process. The returned states are in the order they are supplied. 
     *
     *  @param  referenceIds a reference <code> Ids </code> 
     *  @param  processId <code> Id </code> of a <code> Process </code> 
     *  @return associated state 
     *  @throws org.osid.NotFoundException a <code> referenceId </code> is not 
     *          found in process 
     *  @throws org.osid.NullArgumentException <code> referenceIds </code> or 
     *          <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.process.StateList getStatesByReferencesAndProcess(org.osid.id.IdList referenceIds, 
                                                                      org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of reference <code> Ids </code> mapped to a <code> 
     *  State. </code> 
     *
     *  @param  stateId <code> Id </code> of a <code> State </code> 
     *  @return list of reference <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> stateId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getReferencesByState(org.osid.id.Id stateId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
