//
// org.osid.profile.ProfileEntryAdminSession
//
//     The OSID Java specification for org.osid.profile.ProfileEntryAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session creates and removes <code> ProfileEntries. </code> An 
 *  <code> ProfileEntry </code> may be defined using an Agent or a Resource. 
 *  Create and delete methods exist for each type desired. </p> 
 *  
 *  <p> An explicit <code> ProfileEntry </code> is identified by the mapping 
 *  among a <code> Resource/Agent </code> and <code> ProfileItem. </code> 
 *  There can be only one explicit <code> ProfileEntry </code> for each 
 *  triplet however multiple implicit <code> ProfileEntries </code> may exist. 
 *  </p> 
 *  
 *  <p> When a profile entry is created, it is disabled until <code> 
 *  enableProfileEntry() </code> is used. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ProfileEntry, </code> a <code> ProfileEntryForm </code> is requested using 
 *  <code> geProfileEntryFormFormForCreate() </code> specifying the profile 
 *  item, resource or agent, and desired record <code> Types </code> or none 
 *  if no record <code> Types </code> are needed. The returned <code> 
 *  ProfileEntryForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> ProfileEntryForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ProfileEntryForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ProfileEntryForms </code> are requested to the 
 *  <code> ProfileEntry </code> <code> Id </code> that is to be updated using 
 *  <code> getProfileEntryFormForUpdate(). </code> Similarly, the <code> 
 *  ProfileEntry </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> 
 *  ProfileEntryForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ProfileEntries. </code> To unmap a 
 *  <code> ProfileEntry </code> from the current <code> Profile </code> the 
 *  <code> ProfileEntryProfileAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> ProfileEntry </code> itself 
 *  thus removing it from all known <code> Profile </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ProfileEntryAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the <code> Profile </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ProfileEntries. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> ProfileEntry </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProfileEntries();


    /**
     *  Tests if this user can create a single <code> ProfileEntry </code> 
     *  using the desired record types. While <code> 
     *  ProfileManager.getProfileEntryRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> ProfileEntry. </code> 
     *  Providing an empty array tests if a <code> ProfileEntry </code> can be 
     *  created with no records. 
     *
     *  @param  profileEntryRecordTypes array of profile entry types 
     *  @return <code> true </code> if <code> ProfileEntry </code> creation 
     *          using the specified <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProfileEntryWithRecordTypes(org.osid.type.Type[] profileEntryRecordTypes);


    /**
     *  Gets the profile entry form for creating new profile entries. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  profileItemId the profile item <code> Id </code> 
     *  @param  profileEntryRecordTypes array of profile entry types 
     *  @return the profile entry form 
     *  @throws org.osid.NotFoundException <code> agentId </code> or <code> 
     *          profileItemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> agentId </code> or 
     *          <code> profileItemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryForm getProfileEntryFormForCreateForAgent(org.osid.id.Id agentId, 
                                                                                  org.osid.id.Id profileItemId, 
                                                                                  org.osid.type.Type[] profileEntryRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the profile entry form for creating new profile entries. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  profileItemId the profile item <code> Id </code> 
     *  @return the profile entry form 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          profileItemId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> profileItemId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryForm getProfileEntryFormForCreateForResource(org.osid.id.Id resourceId, 
                                                                                     org.osid.id.Id profileItemId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ProfileEntry. </code> 
     *
     *  @param  profileEntryForm the profile entry form 
     *  @return <code> t </code> he new <code> ProfileEntry </code> 
     *  @throws org.osid.IllegalStateException <code> profileEntryForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> profileEntryForm </code> 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileEntryForm </code> 
     *          did not originate from <code> getprofileEntryFormForAgent() 
     *          </code> or <code> getProfileEntryFormForResource() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntry createProfileEntry(org.osid.profile.ProfileEntryForm profileEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ProfileEntries. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> ProfileEntry </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if profile entry modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProfileEntries();


    /**
     *  Gets the profile entry form for updating an existing profile entry. A 
     *  new profile entry form should be requested for each update 
     *  transaction. 
     *
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @return the profile entry form 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryForm getProfileEntryFormForUpdate(org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing profile entry. 
     *
     *  @param  profileEntryForm the profile entry form 
     *  @throws org.osid.IllegalStateException <code> profileEntryForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> profileEntryForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileEntryForm </code> 
     *          did not originate from <code> getProfileEntryFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProfileEntry(org.osid.profile.ProfileEntryForm profileEntryForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ProfileEntries. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> ProfileEntry </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProfileEntry </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProfileEntries();


    /**
     *  Deletes the <code> ProfileEntry </code> identified by the given <code> 
     *  Id. </code> 
     *
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> to delete 
     *  @throws org.osid.NotFoundException an <code> ProfileEntry </code> was 
     *          not found identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProfileEntry(org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for profile 
     *  entries. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known changing an alias will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer alias operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProfileEntry </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageProfileEntryAliases();


    /**
     *  Adds an <code> Id </code> to an <code> ProfileEntry </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> ProfileEntry </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another profile entry it is 
     *  reassigned to the given profile entry <code> Id. </code> 
     *
     *  @param  profileEntryId the <code> Id </code> of an <code> ProfileEntry 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasProfileEntry(org.osid.id.Id profileEntryId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
