//
// org.osid.profile.ProfileEntryQuerySession
//
//     The OSID Java specification for org.osid.profile.ProfileEntryQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session provides methods for searching <code> ProfileEntry </code> 
 *  objects. The search query is constructed using the <code> 
 *  ProfileEntryQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated profile view: searches include profile entries in 
 *      <code> Profiles </code> of which this profile is a ancestor in the 
 *      profile hierarchy </li> 
 *      <li> isolated profile view: searches are restricted to entries in this 
 *      <code> Profile </code> </li> 
 *  </ul>
 *  
 */

public interface ProfileEntryQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the <code> Profile </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform profile entry searches. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer search operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchProfileEntries();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include profile entries in profiles which are children of this profile 
     *  in the profile hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedProfileView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this profile only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedProfileView();


    /**
     *  Sets the view for methods in this session to implicit profile entry. 
     *  An implicit view will include entries derived from other profile 
     *  entries as a result of the <code> ProfileItem </code> or <code> 
     *  Resource </code> hierarchies. This method is the opposite of <code> 
     *  explicitProfileEntryView(). </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useImplicitProfileEntryView();


    /**
     *  Sets the view for methods in this session to explicit proffile 
     *  entries. An explicit view includes only those entries that were 
     *  explicitly defined and not implied. This method is the opposite of 
     *  <code> implicitProfileEntryView(). </code> 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useExplicitProfileEntryView();


    /**
     *  Gets a profile entry query. 
     *
     *  @return the profile entry query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryQuery getProfileEntryQuery();


    /**
     *  Gets a list of <code> ProfileEntries </code> matching the given query 
     *
     *  @param  profileEntryQuery the profile entry query 
     *  @return the returned <code> ProfileEntryList </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileEntryQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryList getProfileEntriesByQuery(org.osid.profile.ProfileEntryQuery profileEntryQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
