//
// org.osid.profile.ProfileItemSearchSession
//
//     The OSID Java specification for org.osid.profile.ProfileItemSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session provides methods for searching <code> ProfileItem </code> 
 *  objects. The search query is constructed using the <code> 
 *  ProfileItemQuery. </code> The profile item record <code> Type </code> also 
 *  specifies the query record for the profile item query. </p> 
 *  
 *  <p> <code> getProfileItemsByQuery() </code> is the basic search method and 
 *  returns a list of <code> ProfileItems. </code> A more advanced search may 
 *  be performed with <code> getProfileItemsBySearch(). </code> It accepts a 
 *  <code> ProfileItemSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProfileItemsBySearch() </code> returns an <code> 
 *  ProfileItemSearchResults </code> that can be used to access the resulting 
 *  <code> ProfileItemList </code> or be used to perform a search within the 
 *  result set through <code> ProfileItemSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated profile view: searches include profile item in profiles 
 *      of which this profile is a ancestor in the profile hierarchy </li> 
 *      <li> isolated profile view: searches are restricted to profile items 
 *      in this profile </li> 
 *  </ul>
 *  
 *  
 *  <p> Profile items may have a profie item query record indicated by their 
 *  respective record types. The profile item query record is accessed via the 
 *  <code> ProfileItemQuery. </code> </p>
 */

public interface ProfileItemSearchSession
    extends org.osid.profile.ProfileItemQuerySession {


    /**
     *  Gets a profile item search. 
     *
     *  @return the profile item search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItemSearch getProfileItemSearch();


    /**
     *  Gets a profile item search order. The <code> ProfileItemSearchOrder 
     *  </code> is supplied to a <code> ProfileItemSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the profile item search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItemSearchOrder getProfileItemSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  profileItemQuery the profile item query 
     *  @param  profileItemSearch the profile item search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> profileItemQuery </code> 
     *          or <code> profileItemSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileItemSearch </code> 
     *          or <code> profileItemQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItemSearchResults getProfileItemsBySearch(org.osid.profile.ProfileItemQuery profileItemQuery, 
                                                                             org.osid.profile.ProfileItemSearch profileItemSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a profile item query from an inspector. The inspector is 
     *  available from an <code> ProfileItemSearchResults. </code> 
     *
     *  @param  profileItemQueryInspector a profile item query inspector 
     *  @return the profile item query 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileItemQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> profileItemQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileItemQuery getProfileItemQueryFromInspector(org.osid.profile.ProfileItemQueryInspector profileItemQueryInspector);
}
