//
// org.osid.profile.ProfileProfile
//
//     The OSID Java specification for org.osid.profile.ProfileProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>The <code> ProfileProfile </code> describes the interoperability among 
 *  authentication services. </p>
 */

public interface ProfileProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a profile service which is the basic 
     *  service for checking profiles. 
     *
     *  @return <code> true </code> if profiling is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfiling();


    /**
     *  Tests if a profile entry lookup service is supported. A profile entry 
     *  lookup service defines methods to access profile entries. 
     *
     *  @return true if profile entry lookup is supported, false otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryLookup();


    /**
     *  Tests if profile entry query is supported. 
     *
     *  @return <code> true </code> if profile entry query is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryQuery();


    /**
     *  Tests if a profile entry search service is supported. 
     *
     *  @return <code> true </code> if profile entry search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntrySearch();


    /**
     *  Tests if a profile entry administrative service is supported. 
     *
     *  @return <code> true </code> if profile entry admin is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryAdmin();


    /**
     *  Tests if profile entry notification is supported. Messages may be sent 
     *  when peofile entries are created, modified, or deleted. 
     *
     *  @return <code> true </code> if profile entry notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryNotification();


    /**
     *  Tests if retrieving mappings of profile entries and profile is 
     *  supported. 
     *
     *  @return <code> true </code> if profile entry profile mapping retrieval 
     *          is supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryProfile();


    /**
     *  Tests if managing mappings of profile entries and profile is 
     *  supported. 
     *
     *  @return <code> true </code> if profile entry profile assignment is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryProfileAssignment();


    /**
     *  Tests if profile entry smart profiles are available. 
     *
     *  @return <code> true </code> if profile entry smart profiles are 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryRelationshpSmartProfile();


    /**
     *  Tests if a profile item lookup service is supported. A profile item 
     *  lookup service defines methods to access profile items. 
     *
     *  @return <code> true </code> if profile item lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemLookup();


    /**
     *  Tests if profile item query is supported. 
     *
     *  @return <code> true </code> if profile item query is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemQuery();


    /**
     *  Tests if a profile item search service is supported. 
     *
     *  @return <code> true </code> if profile item search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemSearch();


    /**
     *  Tests if a profile item administrative service is supported. 
     *
     *  @return <code> true </code> if profile item admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemAdmin();


    /**
     *  Tests if profile item notification is supported. Messages may be sent 
     *  when profile items are created, modified, or deleted. 
     *
     *  @return <code> true </code> if profile item notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemNotification();


    /**
     *  Tests if a profile item to profile lookup session is available. 
     *
     *  @return <code> true </code> if profile item profile lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemProfile();


    /**
     *  Tests if a profile item to profile assignment session is available. 
     *
     *  @return <code> true </code> if profile item profile assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemProfileAssignment();


    /**
     *  Tests if profile item smart profiles are available. 
     *
     *  @return <code> true </code> if profile item smart profiles are 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemSmartProfile();


    /**
     *  Tests if a profile lookup service is supported. A profile lookup 
     *  service defines methods to access profiles. 
     *
     *  @return <code> true </code> if profile lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileLookup();


    /**
     *  Tests if profile query is supported. 
     *
     *  @return <code> true </code> if profile query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileQuery();


    /**
     *  Tests if a profile search service is supported. 
     *
     *  @return <code> true </code> if profile search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileSearch();


    /**
     *  Tests if a profile administrative service is supported. 
     *
     *  @return <code> true </code> if profile admin is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileAdmin();


    /**
     *  Tests if profile notification is supported. Messages may be sent when 
     *  profiles are created, modified, or deleted. 
     *
     *  @return <code> true </code> if profile notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileNotification();


    /**
     *  Tests if a profile hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a profile hierarchy traversal is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileHierarchy();


    /**
     *  Tests if profile hierarchy design is supported. 
     *
     *  @return <code> true </code> if a profile hierarchy design is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileHierarchyDesign();


    /**
     *  Tests if a profile batch service is supported. 
     *
     *  @return <code> true </code> if a profile batch service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileBatch();


    /**
     *  Tests if a profile rules service is supported. 
     *
     *  @return <code> true </code> if a profile rules service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileRules();


    /**
     *  Gets the supported <code> ProfileEntry </code> record types. 
     *
     *  @return a list containing the supported profile entry record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProfileEntryRecordTypes();


    /**
     *  Tests if the given profile entry record type is supported. 
     *
     *  @param  profileEntryRecordType a <code> Type </code> indicating a 
     *          profile entry record type 
     *  @return <code> true </code> if the given record Type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileEntryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryRecordType(org.osid.type.Type profileEntryRecordType);


    /**
     *  Gets the supported <code> ProfileEntry </code> search record types. 
     *
     *  @return a list containing the supported profile entry search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProfileEntrySearchRecordTypes();


    /**
     *  Tests if the given profile entry search record type is supported. 
     *
     *  @param  profileEntrySearchRecordType a <code> Type </code> indicating 
     *          a profile entry search record type 
     *  @return <code> true </code> if the given search record Type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntrySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntrySearchRecordType(org.osid.type.Type profileEntrySearchRecordType);


    /**
     *  Gets the supported <code> ProfileItem </code> record types. 
     *
     *  @return a list containing the supported <code> ProfileItem </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProfileItemRecordTypes();


    /**
     *  Tests if the given <code> ProfileItem </code> record type is 
     *  supported. 
     *
     *  @param  profileItemRecordType a <code> Type </code> indicating a 
     *          <code> ProfileItem </code> record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileItemRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemRecordType(org.osid.type.Type profileItemRecordType);


    /**
     *  Gets the supported <code> ProfileItem </code> search record types. 
     *
     *  @return a list containing the supported <code> ProfileItem </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProfileItemSearchRecordTypes();


    /**
     *  Tests if the given <code> ProfileItem </code> search record type is 
     *  supported. 
     *
     *  @param  profileItemSearchRecordType a <code> Type </code> indicating a 
     *          <code> ProfileItem </code> search record type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileItemSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemSearchRecordType(org.osid.type.Type profileItemSearchRecordType);


    /**
     *  Gets the supported <code> Profile </code> record types. 
     *
     *  @return a list containing the supported <code> Profile </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProfileRecordTypes();


    /**
     *  Tests if the given <code> Profile </code> record type is supported. 
     *
     *  @param  profileRecordType a <code> Type </code> indicating a <code> 
     *          Profile </code> type 
     *  @return <code> true </code> if the given profile record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileRecordType(org.osid.type.Type profileRecordType);


    /**
     *  Gets the supported profile search record types. 
     *
     *  @return a list containing the supported <code> Profile </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProfileSearchRecordTypes();


    /**
     *  Tests if the given profile search record type is supported. 
     *
     *  @param  profileSearchRecordType a <code> Type </code> indicating a 
     *          <code> Profile </code> search record type 
     *  @return <code> true </code> if the given search record <code> Type 
     *          </code> is supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileSearchRecordType(org.osid.type.Type profileSearchRecordType);


    /**
     *  Gets the supported <code> ProfileEntryCondition </code> record types. 
     *
     *  @return a list containing the supported <code> ProfileEntryCondition 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProfileEntryConditionRecordTypes();


    /**
     *  Tests if the given <code> ProfileEntryCondition </code> record type is 
     *  supported. 
     *
     *  @param  profileEntryConditionRecordType a <code> Type </code> 
     *          indicating an <code> ProfileEntryCondition </code> record type 
     *  @return <code> true </code> if the given profile entry condition 
     *          record <code> Type </code> is supported, <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryConditionRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryConditionRecordType(org.osid.type.Type profileEntryConditionRecordType);
}
