//
// org.osid.profile.ProfileQuery
//
//     The OSID Java specification for org.osid.profile.ProfileQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This is the query for searching profiles. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ProfileQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the profile item <code> Id </code> for this query. 
     *
     *  @param  profileItemId a profile item <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileItemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProfileItemId(org.osid.id.Id profileItemId, boolean match);


    /**
     *  Clears the profile item <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileItemIdTerms();


    /**
     *  Tests if a <code> ProfileItemQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile item query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileItemQuery();


    /**
     *  Gets the query for a profile item. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the profile item query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileItemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileItemQuery() </code> is <code> true. </code> 
     */

    public org.osid.profile.ProfileItemQuery getProfileItemQuery();


    /**
     *  Matches profiles that have any profile item. 
     *
     *  @param  match <code> true </code> to match profiles with any item 
     *          mapping, <code> false </code> to match profiles with no item 
     *          mapping 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProfileItem(boolean match);


    /**
     *  Clears the profile item query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileItemTerms();


    /**
     *  Sets the profile entry <code> Id </code> for this query. 
     *
     *  @param  profileEntryId a profile entry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProfileEntryId(org.osid.id.Id profileEntryId, 
                                    boolean match);


    /**
     *  Clears the profile entry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileEntryIdTerms();


    /**
     *  Tests if a <code> ProfileEntryQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile entry query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProfileEntryQuery();


    /**
     *  Gets the query for a profile entry. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the profile entry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProfileEntryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProfileEntryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileEntryQuery getProfileEntryQuery();


    /**
     *  Matches profiles that have any profile entry. 
     *
     *  @param  match <code> true </code> to match profiles with any entry 
     *          mapping, <code> false </code> to match profiles with no entry 
     *          mapping 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProfileEntry(boolean match);


    /**
     *  Clears the profile entry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProfileEntryTerms();


    /**
     *  Sets the profile <code> Id </code> for this query to match profiles 
     *  that have the specified profile as an ancestor. 
     *
     *  @param  profileId a profile <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorProfileId(org.osid.id.Id profileId, boolean match);


    /**
     *  Clears the ancestor profile <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorProfileIdTerms();


    /**
     *  Tests if a <code> ProfileQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorProfileQuery();


    /**
     *  Gets the query for a profile. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the profile query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorProfileQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorProfileQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileQuery getAncestorProfileQuery();


    /**
     *  Matches profiles with any ancestor. 
     *
     *  @param  match <code> true </code> to match profile with any ancestor, 
     *          <code> false </code> to match root profiles 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorProfile(boolean match);


    /**
     *  Clears the ancestor profile query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorProfileTerms();


    /**
     *  Sets the profile <code> Id </code> for this query to match that have 
     *  the specified profile as a descendant. 
     *
     *  @param  profileId a profile <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantProfileId(org.osid.id.Id profileId, 
                                         boolean match);


    /**
     *  Clears the descendant profile <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantProfileIdTerms();


    /**
     *  Tests if a <code> ProfileQuery </code> is available. 
     *
     *  @return <code> true </code> if a profile query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantProfileQuery();


    /**
     *  Gets the query for a profile. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the profile query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantProfileQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantProfileQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.profile.ProfileQuery getDescendantProfileQuery();


    /**
     *  Matches profiles with any descendant. 
     *
     *  @param  match <code> true </code> to match profile with any 
     *          descendant, <code> false </code> to match leaf profiles 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantProfile(boolean match);


    /**
     *  Clears the descendant profile query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantProfileTerms();


    /**
     *  Gets the profile query record corresponding to the given <code> 
     *  Profile </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  profileRecordType a profile record type 
     *  @return the profile query record 
     *  @throws org.osid.NullArgumentException <code> profileRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(profileRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.records.ProfileQueryRecord getProfileQueryRecord(org.osid.type.Type profileRecordType)
        throws org.osid.OperationFailedException;
}
