//
// org.osid.profile.ProfileSearchSession
//
//     The OSID Java specification for org.osid.profile.ProfileSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This session provides methods for searching among <code> Profile 
 *  </code> objects. The search query is constructed using the <code> 
 *  ProfileQuery. </code> </p> 
 *  
 *  <p> <code> getProfilesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Profile </code> objects.A more advanced search 
 *  may be performed with <code> getProfilesBySearch(). </code> It accepts a 
 *  <code> ProfileSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProfilesBySearch() </code> returns a <code> 
 *  ProfileSearchResults </code> that can be used to access the resulting 
 *  <code> ProfileList </code> or be used to perform a search within the 
 *  result set through <code> ProfileSearch. </code> </p> 
 *  
 *  <p> Profiles may have a profile query record indicated by their respective 
 *  record types. The profile query record is accessed via the <code> 
 *  ProfileQuery. </code> </p>
 */

public interface ProfileSearchSession
    extends org.osid.profile.ProfileQuerySession {


    /**
     *  Gets a profile search. 
     *
     *  @return a profile search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileSearch getProfileSearch();


    /**
     *  Gets a profile search order. The <code> ProfileSearchOrder </code> is 
     *  supplied to a <code> ProfileSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the profile search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileSearchOrder getProfileSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  profileQuery the profile query 
     *  @param  profileSearch the profile search 
     *  @return the search results 
     *  @throws org.osid.NullArgumentException <code> profileQuery </code> or 
     *          <code> profileSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> profileQuery </code> or 
     *          <code> profileSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileSearchResults getProfilesBySearch(org.osid.profile.ProfileQuery profileQuery, 
                                                                     org.osid.profile.ProfileSearch profileSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a profile query from an inspector. The inspector is available 
     *  from an <code> ProfileSearchResults. </code> 
     *
     *  @param  profileQueryInspector a profile query inspector 
     *  @return the profile query 
     *  @throws org.osid.NullArgumentException <code> profileQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> profileQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileQuery getProfileQueryFromInspector(org.osid.profile.ProfileQueryInspector profileQueryInspector);
}
