//
// org.osid.profile.ProfilingSession
//
//     The OSID Java specification for org.osid.profile.ProfilingSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile;


/**
 *  <p>This is the basic session for querying profiles. </p>
 */

public interface ProfilingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the <code> Profile </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform profile checks. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if profile methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessProfileEntries();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include profile entries from descendant profiles in the profile 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedProfileView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this profile only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedProfileView();


    /**
     *  Determines if the question <code> Id </code> of the profile entry is 
     *  true. 
     *
     *  @param  profileItemId the <code> Id </code> of a <code> ProfileItem 
     *          </code> 
     *  @return <code> true </code> if the the profile question is true, 
     *          <code> false </code> othersise 
     *  @throws org.osid.NullArgumentException <code> profileItemId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          making request 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  Profile entries may be stored in a normalized form with 
     *          respect to various Resources and created using specific nodes 
     *          in a <code> ProfileItem </code> hierarchy. The provider needs 
     *          to maintain a de-normalized implicit profile entry store or 
     *          expand the applicable hierarchies on the fly to honor this 
     *          query. 
     */

    public boolean hasProfileEntry(org.osid.id.Id profileItemId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ProfileEntryCondition </code> for making conditional 
     *  profile checks. 
     *
     *  @param  profileItemId the <code> Id </code> of a <code> ProfileItem 
     *          </code> 
     *  @return a profil entry condition 
     *  @throws org.osid.NullArgumentException <code> profileItemId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.ProfileEntryCondition getProfileEntryCondition(org.osid.id.Id profileItemId);


    /**
     *  Determines if the question <code> Id </code> of the profile entry is 
     *  true. 
     *
     *  @param  profileItemId the <code> Id </code> of a <code> ProfileItem 
     *          </code> 
     *  @param  condition a profile entry condition 
     *  @return <code> true </code> if the profile entry is true, <code> false 
     *          </code> othersise 
     *  @throws org.osid.NullArgumentException <code> profileItemId </code> or 
     *          <code> condition </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          making request 
     *  @throws org.osid.UnsupportedException <code> condition </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  ProfileEntries may be stored in a normalized form with respect 
     *          to various Resources and created using specific nodes in a 
     *          <code> ProfileItem </code> hierarchy. The provider needs to 
     *          maintain a de-normalized implicit entry store or expand the 
     *          applicable hierarchies on the fly to honor this query. 
     */

    public boolean hasProfileEntryOnCondition(org.osid.id.Id profileItemId, 
                                              org.osid.profile.ProfileEntryCondition condition)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
