/**
 * <p>The Open Service Interface Definitions for the org.osid.profile
 * service.</p>
 * 
 * <p>The Profile OSID serves to help applications make decisions based on 
 * user attributes. The format and interpretation of the user attributes are 
 * abstracted to allow the application to ask questions of the profile 
 * service. The Profile OSID can be used to make application decisions 
 * regarding localization, accessibility, or roles. </p> 
 * <h4> ProfileItems </h4> 
 * 
 * <p> <code> ProfileItems </code> represent questions an application may wish 
 * to ask in the context of a user. The evaluation of a ProfileItem always 
 * returns a boolean result. Examples may be "display menu?" or "use audio?" 
 * </p> 
 * <h4> ProfileEntry </h4> 
 * 
 * <p> A <code> ProfileEntry </code> is an <code> OsidRelationship </code> 
 * between a <code> ProfileItem </code> and a user. Explicit profile entries 
 * can be created using either the <code> Resource </code> or an Agent. A 
 * <code> Resource </code> that maps to multiple <code> Agents </code> or a 
 * <code> Resource </code> that represents a group of other <code> Resources 
 * </code> may result in the implicit existence of additional profile entries. 
 * </p> 
 * 
 * <p> The Profile OSID is similar in operation to the Authorization OSID 
 * without a Qualifier. In both cases, an OSID Consumer asks questions 
 * identified by an OSID <code> Id </code> in the context of an <code> Agent 
 * </code> to determine how to proceed. In the Profile OSID, the Agent who is 
 * authenticated to the Profile service itself is used. </p> 
 * <h4> Profile Cataloging </h4> 
 * 
 * <p> <code> ProfileEntries </code> and <code> ProfileItems </code> may be 
 * organized into one or many <code> Profiles. </code> This serves to 
 * categorize profile data for the purpose of browsing or auditing. <code> 
 * Profiles </code> are hierarchical where each node includes all the profile 
 * data of its children. A single root node will make available all known 
 * profile entries and is a reasonable choice for a default Profile for a 
 * non-federated aware consumer. A federated profile scheme is one in which 
 * <code> Profiles </code> are available for selection. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The profile OSID contains a Profile Rules OSID for managing the 
 * effectiveness of <code> ProfileEntries </code> and a Profile Batch OSID for 
 * managing <code> ProfileItems </code> and <code> ProfileEntries </code> in 
 * bulk. </p> 
 * <h4> Example </h4> 
 * 
 * <p> An application wishing to display an additional menu for users who live 
 * in Maine may traditionally do something like: </p> 
 * 
 * <pre>
 *      
 *      
 *      if (user.getAttribute("location") == "Maine") {
 *          displayAdditionalMenu();
 *      }
 *      
 *              
 *      
 * </pre>
 * 
 * 
 * <p> The Profile OSID rephrases the question to the application viewpoint to 
 * allow for the extensibility and variation of interpretation of the 
 * attributes. </p> 
 * 
 * <pre>
 *      
 *      
 *      if (hasProfileEntry(displayAdditionalMenuId)) {
 *          displayAdditionalMenu();
 *      }
 *      
 *              
 *      
 * </pre>
 * 
 * 
 * <p> Certain consumers may wish to be notified of changes within the 
 * service. Profile supports notifications via <code> 
 * ProfileEntryNotificationSession, </code> <code> 
 * ProfileItemNotificationSession </code> and <code> 
 * ProfileNotificationSession. </code> </p> 
 * 
 * <pre>
 *      
 *      
 *      if (manager.supportsProfileEntryNotification()) {
 *          ProfileEntryNotificationSession ans = manager.getProfileEntryNotificationSession(receiver);           
 *          ans.registerForDeletedProfileEntries();
 *      }
 *      
 *      ProfileEntryReceiver receiver {
 *          newProfileEntry(ProfileEntry a) {print("profile entry created");}
 *          deletedProfileEntry(ProfileEntry a) {print("profile entry removed");}
 *      }
 *      
 *              
 *      
 * </pre>
 * 
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.profile;
