//
// org.osid.profile.rules.ProfileEntryEnablerLookupSession
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  ProfileEntryEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated profile view: All profile entry enabler methods in this 
 *      session operate, retrieve and pertain to profile entry enablers 
 *      defined explicitly in the current profile. Using an isolated view is 
 *      useful for managing <code> ProfileEntryEnablers </code> with the 
 *      <code> ProfileEntryEnablerAdminSession. </code> </li> 
 *      <li> federated profile view: All profile entry enabler methods in this 
 *      session operate, retrieve and pertain to all profile entry enablers 
 *      defined in this profile and any other profile entry enablers 
 *      implicitly available in this profile through profile inheritence. 
 *      </li> 
 *      <li> status profile entry enabler view: All profile entry enabler 
 *      lookup methods return active profile entry. </li> 
 *      <li> any status profile entry enabler view: Profile entry enablers of 
 *      any active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface ProfileEntryEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the profile 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ProfileEntryEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProfileEntryEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProfileEntryEnablerView();


    /**
     *  A complete view of the <code> ProfileEntryEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProfileEntryEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include profile entry enablers in profiles which are children of this 
     *  profile in the profile hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedProfileView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this profile only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedProfileView();


    /**
     *  Only active profile entry enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveProfileEntryEnablerView();


    /**
     *  All active and inactive profile entry enablers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusProfileEntryEnablerView();


    /**
     *  Gets the <code> ProfileEntryEnabler </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ProfileEntryEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> ProfileEntryEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active. In any status mode, active and inactive profile entry enablers 
     *  are returned. 
     *
     *  @param  profileEntryEnablerId <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @return the profile entry enabler 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnabler getProfileEntryEnabler(org.osid.id.Id profileEntryEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  profile entry enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> ProfileEntryEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active. In any status mode, active and inactive profile entry enablers 
     *  are returned. 
     *
     *  @param  profileEntryEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> ProfileEntryEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerList getProfileEntryEnablersByIds(org.osid.id.IdList profileEntryEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryEnablerList </code> corresponding to the 
     *  given profile entry enabler genus <code> Type </code> which does not 
     *  include profile entry enablers of genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  profile entry enablers or an error results. Otherwise, the returned 
     *  list may contain only those profile entry enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active. In any status mode, active and inactive profile entry enablers 
     *  are returned. 
     *
     *  @param  profileEntryEnablerGenusType a profile entry enabler genus 
     *          type 
     *  @return the returned <code> ProfileEntryEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerList getProfileEntryEnablersByGenusType(org.osid.type.Type profileEntryEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryEnablerList </code> corresponding to the 
     *  given profile entry enabler genus <code> Type </code> and include any 
     *  additional profile entry enablers with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  profile entry enablers or an error results. Otherwise, the returned 
     *  list may contain only those profile entry enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active. In any status mode, active and inactive profile entry enablers 
     *  are returned. 
     *
     *  @param  profileEntryEnablerGenusType a profile entry enabler genus 
     *          type 
     *  @return the returned <code> ProfileEntryEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerList getProfileEntryEnablersByParentGenusType(org.osid.type.Type profileEntryEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryEnablerList </code> containing the given 
     *  profile entry enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  profile entry enablers or an error results. Otherwise, the returned 
     *  list may contain only those profile entry enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active. In any status mode, active and inactive profile entry enablers 
     *  are returned. 
     *
     *  @param  profileEntryEnablerRecordType a profile entry enabler record 
     *          type 
     *  @return the returned <code> ProfileEntryEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerList getProfileEntryEnablersByRecordType(org.osid.type.Type profileEntryEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryEnablerList </code> effective during the 
     *  entire given date range inclusive but not confined to the date range 
     *  for any agent. 
     *  
     *  In plenary mode, the returned list contains all known profile entry 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those profile entry enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive profile entry enablers are 
     *  returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ProfileEntryEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerList getProfileEntryEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProfileEntryEnablerList </code> effective during the 
     *  entire given date range inclusive but not confined to the date range 
     *  aveluated against the given agent. 
     *  
     *  In plenary mode, the returned list contains all known profile entry 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those profile entry enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive profile entry enablers are 
     *  returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ProfileEntryEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerList getProfileEntryEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ProfileEntryEnablers. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  profile entry enablers or an error results. Otherwise, the returned 
     *  list may contain only those profile entry enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, profile entry enablers are returned that are currently 
     *  active. In any status mode, active and inactive profile entry enablers 
     *  are returned. 
     *
     *  @return the returned <code> ProfileEntryEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.ProfileEntryEnablerList getProfileEntryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
