//
// org.osid.profile.rules.ProfileEntryEnablerNotificationSession
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> ProfileEntryEnabler </code> objects in this <code> Profile. 
 *  </code> This also includes existing <code> ProfileEntryEnablers </code> 
 *  that may appear or disappear due to changes in the <code> Profile </code> 
 *  hierarchy, This session is intended for consumers needing to synchronize 
 *  their state with this service without the use of polling. Notifications 
 *  are cancelled when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> ProfileEntryEnablerLookupSession. </code> </p>
 */

public interface ProfileEntryEnablerNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the profile 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> ProfileEntryEnabler </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForProfileEntryEnablerNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include enablers in profiles which are children of this profile in the 
     *  profile hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedProfileView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this profile only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedProfileView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeProfileEntryEnablerNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableProfileEntryEnablerNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableProfileEntryEnablerNotifications();


    /**
     *  Acknowledge a profile entry enabler notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeProfileEntryEnablerNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new profile entry enablers. <code> 
     *  ProfileEntryEnablerReceiver.newProfileEntryEnablers() </code> is 
     *  invoked when a new <code> ProfileEntryEnabler </code> appears in this 
     *  profile. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProfileEntryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated profile enabelrs. <code> 
     *  ProfileEntryEnablerReceiver.changedProfileEntryEnablers() </code> is 
     *  invoked when a profile entry enabler in this profile is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProfileEntryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated profile entry enabler. <code> 
     *  ProvisionableReceiver.changedProfileEntryEnablers() </code> is invoked 
     *  when the specified profile entry enabler in this profile is changed. 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProfileEntryEnabler(org.osid.id.Id profileEntryEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted profile entry enablers. <code> 
     *  ProfileEntryEnablerReceiver.deletedProfileEntryEnablers() </code> is 
     *  invoked when a profile entry enabler is deleted or removed from this 
     *  profile. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProfileEntryEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted profile entry enabler. <code> 
     *  ProfileEntryEnablerReceiver.deletedProfileEntryEnablers() </code> is 
     *  invoked when the specified profile entry enabler is deleted or removed 
     *  from this profile. 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProfileEntryEnabler(org.osid.id.Id profileEntryEnablerId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
