//
// org.osid.profile.rules.ProfileEntryEnablerProfileAssignmentSession
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerProfileAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>This session provides methods to re-assign <code> ProfileEntryEnabler 
 *  </code> to <code> Profile </code> mappings. A <code> ProfileEntryEnabler 
 *  </code> may appear in multiple <code> Profile </code> objects and removing 
 *  the last reference to a <code> ProfileEntryEnabler </code> is the 
 *  equivalent of deleting it. Each <code> Profile </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> ProfileEntryEnabler </code> to another 
 *  <code> Profile </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface ProfileEntryEnablerProfileAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter profile entry enabler/profile mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProfileEntryEnablers();


    /**
     *  Tests if this user can alter profile entry enabler/profile mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProfileEntryEnablersToProfile(org.osid.id.Id profileId);


    /**
     *  Gets a list of profiles including and under the given profile node in 
     *  which any profile entry enabler can be assigned. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @return list of assignable profile <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableProfileIds(org.osid.id.Id profileId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of profiles including and under the given profile node in 
     *  which a specific profile entry enabler can be assigned. 
     *
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @return list of assignable profile <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> profileId </code> or 
     *          <code> profileEntryEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableProfileIdsForProfileEntryEnabler(org.osid.id.Id profileId, 
                                                                            org.osid.id.Id profileEntryEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ProfileEntryEnabler </code> to a <code> 
     *  Profile. </code> 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @throws org.osid.AlreadyExistsException <code> profileEntryEnablerId 
     *          </code> is already assigned to <code> profileId </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> or <code> profileId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> or <code> profileId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignProfileEntryEnablerToProfile(org.osid.id.Id profileEntryEnablerId, 
                                                   org.osid.id.Id profileId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ProfileEntryEnabler </code> from a <code> Profile. 
     *  </code> 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  profileId the <code> Id </code> of the <code> Profile </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> or <code> profileId </code> not found or <code> 
     *          profileEntryEnablerId </code> not assigned to <code> profileId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> or <code> profileId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignProfileEntryEnablerFromProfile(org.osid.id.Id profileEntryEnablerId, 
                                                       org.osid.id.Id profileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> ProfileEntryEnabler </code> from one <code> Profile 
     *  </code> to another. Mappings to other <code> Profiles </code> are 
     *  unaffected. 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  fromProfileId the <code> Id </code> of the current <code> 
     *          Profile </code> 
     *  @param  toProfileId the <code> Id </code> of the destination <code> 
     *          Profile </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId, 
     *          fromProfileId, </code> or <code> toProfileId </code> not found 
     *          or <code> profileEntryEnablerId </code> not mapped to <code> 
     *          fromProfileId </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId, 
     *          fromProfileId, </code> or <code> toProfileId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignProfileEntryEnablerToProfile(org.osid.id.Id profileEntryEnablerId, 
                                                     org.osid.id.Id fromProfileId, 
                                                     org.osid.id.Id toProfileId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
