//
// org.osid.profile.rules.ProfileEntryEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>This session provides methods to apply <code> ProfileEntryEnablers 
 *  </code> to <code> ProfileEntries. </code> A <code> ProfileEntry </code> 
 *  with multiple <code> ProfileEntryEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> ProfileEntry. 
 *  </code> </p>
 */

public interface ProfileEntryEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Profile </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Profile Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProfileId();


    /**
     *  Gets the <code> Profile </code> associated with this session. 
     *
     *  @return the profile 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.Profile getProfile()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter profile entry enabler/profile entry 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProfileEntryEnablers();


    /**
     *  Tests if this user can alter profile entry enabler/profile entry 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> profileEntryId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProfileEntryEnablerToProfileEntry(org.osid.id.Id profileEntryId);


    /**
     *  Gets a list of profile entry in which a specific profile entry enabler 
     *  can be assigned. 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @return list of assignable profile entry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableProfileEntryIdsForProfileEntryEnabler(org.osid.id.Id profileEntryEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ProfileEntryEnabler </code> to a <code> 
     *  ProfileEntry. </code> 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @throws org.osid.AlreadyExistsException <code> profileEntryEnablerId 
     *          </code> is already applied to <code> profileEntryId </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> or <code> profileEntryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> or <code> profileEntryId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignProfileEntryEnablerToProfileEntry(org.osid.id.Id profileEntryEnablerId, 
                                                        org.osid.id.Id profileEntryId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ProfileEntryEnabler </code> from a <code> 
     *  ProfileEntry. </code> 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of the <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  profileEntryId the <code> Id </code> of the <code> 
     *          ProfileEntry </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId 
     *          </code> or <code> profileEntryId </code> not found or 
     *          profileEntryEnablerId not applied to <code> profileEntryId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId 
     *          </code> or <code> profileEntryId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignProfileEntryEnablerFromProfileEntry(org.osid.id.Id profileEntryEnablerId, 
                                                            org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> ProfileEntryEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProfileEntryEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceProfileEntryEnablers();


    /**
     *  Reorders profile entry enablers for a profile entry by moving the 
     *  specified profile entry enabler in front of a reference profile entry 
     *  enabler. 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of a <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  profileEntryId the <code> Id </code> of a <code> ProfileEntry 
     *          </code> 
     *  @param  referenceId the reference profile entry enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId, 
     *          profileEntryId, </code> or <code> referenceId </code> not 
     *          found or, <code> profileEntryEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> profileEntryId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId, 
     *          profileEntryId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveProfileEntryEnablerAhead(org.osid.id.Id profileEntryEnablerId, 
                                             org.osid.id.Id profileEntryId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders profile entry enablers for a profile entry by moving the 
     *  specified profile entry enabler behind a reference profile entry 
     *  enabler. 
     *
     *  @param  profileEntryEnablerId the <code> Id </code> of a <code> 
     *          ProfileEntryEnabler </code> 
     *  @param  profileEntryId the <code> Id </code> of a <code> ProfileEntry 
     *          </code> 
     *  @param  referenceId the reference profile entry enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryEnablerId, 
     *          profileEntryId, </code> or <code> referenceId </code> not 
     *          found or, <code> profileEntryEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> profileEntryId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerId, 
     *          profileEntryId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveProfileEntryEnablerBehind(org.osid.id.Id profileEntryEnablerId, 
                                              org.osid.id.Id profileEntryId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of profile entry enablers for a profile entry. 
     *
     *  @param  profileEntryEnablerIds the <code> Ids </code> for a set of 
     *          <code> ProfileEntryEnablers </code> 
     *  @param  profileEntryId the <code> Id </code> of a <code> ProfileEntry 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> profileEntryId </code> not 
     *          found or, an <code> profileEntryEnablerId </code> not related 
     *          to <code> profileEntryId </code> 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerIds 
     *          </code> or <code> profileEntryId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderProfileEntryEnablers(org.osid.id.Id[] profileEntryEnablerIds, 
                                          org.osid.id.Id profileEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
