//
// org.osid.profile.rules.ProfileEntryEnablerSearch
//
//     The OSID Java specification for org.osid.profile.rules.ProfileEntryEnablerSearch.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.profile.rules;


/**
 *  <p>The search interface for governing profile entry enabler searches. </p>
 */

public interface ProfileEntryEnablerSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of profile entry enablers. 
     *
     *  @param  profileEntryEnablerIds list of profile entry enablers 
     *  @throws org.osid.NullArgumentException <code> profileEntryEnablerIds 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongProfileEntryEnablers(org.osid.id.IdList profileEntryEnablerIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  profileEntryEnablerSearchOrder profile entry enabler search 
     *          order 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          profileEntryEnablerSearchOrder </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderProfileEntryEnablerResults(org.osid.profile.rules.ProfileEntryEnablerSearchOrder profileEntryEnablerSearchOrder);


    /**
     *  Gets the profile entry enabler search record corresponding to the 
     *  given profile entry enabler search record <code> Type. </code> This 
     *  method is used to retrieve an object implementing the requested 
     *  record. 
     *
     *  @param  profileEntryEnablerSearchRecordType a profile entry enabler 
     *          search record type 
     *  @return the profile entry enabler search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          profileEntryEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(profileEntryEnablerSearchRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.profile.rules.records.ProfileEntryEnablerSearchRecord getProfileEntryEnablerSearchRecord(org.osid.type.Type profileEntryEnablerSearchRecordType)
        throws org.osid.OperationFailedException;
}
