//
// org.osid.provisioning.DistributorHierarchySession
//
//     The OSID Java specification for org.osid.provisioning.DistributorHierarchySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> 
 *  Distributor </code> objects. Each node in the hierarchy is a unique <code> 
 *  Distributor. </code> The hierarchy may be traversed recursively to 
 *  establish the tree structure through <code> getParentDistributors() 
 *  </code> and <code> getChildDistributors(). </code> To relate these <code> 
 *  Ids </code> to another OSID, <code> getDistributorNodes() </code> can be 
 *  used for retrievals that can be used for bulk lookups in other OSIDs. Any 
 *  <code> Distributor </code> available in the Provisioning OSID is known to 
 *  this hierarchy but does not appear in the hierarchy traversal until added 
 *  as a root distributor or a child of another distributor. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentDistributors() </code> or <code> getChildDistributors() 
 *  </code> in lieu of a <code> PERMISSION_DENIED </code> error that may 
 *  disrupt the traversal through authorized provisionways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative distributor view: distributor elements may be 
 *      silently omitted or re-ordered </li> 
 *      <li> plenary distributor view: provides a complete set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface DistributorHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getDistributorHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessDistributorHierarchy();


    /**
     *  The returns from the distributor methods may omit or translate 
     *  elements based on this session, such as authorization, and not result 
     *  in an error. This view is used when greater interoperability is 
     *  desired at the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeDistributorView();


    /**
     *  A complete view of the <code> Distributors </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryDistributorView();


    /**
     *  Gets the root distributor <code> Ids </code> in this hierarchy. 
     *
     *  @return the root distributor <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootDistributorIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root distributor in the distributor hierarchy. A distributor 
     *  with no parents is an orphan. While all distributor <code> Ids </code> 
     *  are known to the hierarchy, an orphan does not appear in the hierarchy 
     *  unless explicitly added as a root distributor or child of another 
     *  distributor. 
     *
     *  @return the root distributors 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.provisioning.DistributorList getRootDistributors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> Distributor </code> has any parents. 
     *
     *  @param  distributorId a distributor <code> Id </code> 
     *  @return <code> true </code> if the distributor has parents, f <code> 
     *          alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> distributorId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentDistributors(org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of distributor. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  distributorId the <code> Id </code> of a distributor 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> distributorId, </code> f <code> alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> distributorId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          distributorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfDistributor(org.osid.id.Id id, 
                                         org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given distributor. 
     *
     *  @param  distributorId a distributor <code> Id </code> 
     *  @return the parent <code> Ids </code> of the distributor 
     *  @throws org.osid.NotFoundException <code> distributorId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentDistributorIds(org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> to query 
     *  @return the parents of the distributor 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.DistributorList getParentDistributors(org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of a distributor. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  distributorId the <code> Id </code> of a distributor 
     *  @return <code> tru </code> e if this <code> id </code> is an ancestor 
     *          of <code> distributorId, </code> <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfDistributor(org.osid.id.Id id, 
                                           org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a distributor has any children. 
     *
     *  @param  distributorId a distributor <code> Id </code> 
     *  @return <code> true </code> if the <code> distributorId </code> has 
     *          children, <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildDistributors(org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a distributor is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  distributorId the <code> Id </code> of a distributor 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> distributorId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          distributorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfDistributor(org.osid.id.Id id, 
                                        org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> to query 
     *  @return the children of the distributor 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildDistributorIds(org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> to query 
     *  @return the children of the distributor 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.DistributorList getChildDistributors(org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of a distributor. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  distributorId the <code> Id </code> of a distributor 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> distributorId, </code> <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          distributorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfDistributor(org.osid.id.Id id, 
                                             org.osid.id.Id distributorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the distributor. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the distributor. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given distributor, <code> false </code> to omit the 
     *          siblings 
     *  @return a distributor node 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getDistributorNodeIds(org.osid.id.Id distributorId, 
                                                         long ancestorLevels, 
                                                         long descendantLevels, 
                                                         boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given distributor. 
     *
     *  @param  distributorId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the hierarchy. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the hierarchy. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given distributor, <code> false </code> to omit the 
     *          siblings 
     *  @return a distributor node 
     *  @throws org.osid.NotFoundException <code> distributorId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.DistributorNode getDistributorNodes(org.osid.id.Id distributorId, 
                                                                     long ancestorLevels, 
                                                                     long descendantLevels, 
                                                                     boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
