//
// org.osid.provisioning.DistributorReceiver
//
//     The OSID Java specification for org.osid.provisioning.DistributorReceiver.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>The distributor receiver is the consumer supplied interface for 
 *  receiving notifications pertaining to new, updated or deleted <code> 
 *  Distributor </code> objects. </p>
 */

public interface DistributorReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new distributors. 
     *
     *  @param  distributorIds the <code> Ids </code> of the new <code> 
     *          Distributors </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDistributors(org.osid.id.IdList distributorIds);


    /**
     *  The callback for notifications of new distributor ancestors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> Distributor 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorDistributor(org.osid.id.Id distributorId, 
                                       org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new distributor descendants. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> 
     *          Distributor </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantDistributor(org.osid.id.Id distributorId, 
                                         org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated distributor. 
     *
     *  @param  distributorIds the <code> Ids </code> of the updated <code> 
     *          Distributors </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedDistributors(org.osid.id.IdList distributorIds);


    /**
     *  The callback for notification of deleted distributors. 
     *
     *  @param  distributorIds the <code> Ids </code> of the deleted <code> 
     *          Distributors </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDistributors(org.osid.id.IdList distributorIds);


    /**
     *  The callback for notifications of deleted distributor ancestors. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the removed <code> 
     *          Distributor </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorDistributor(org.osid.id.Id distributorId, 
                                           org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted distributor descendants. 
     *
     *  @param  distributorId the <code> Id </code> of the <code> Distributor 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the removed <code> 
     *          Distributor </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantDistributor(org.osid.id.Id distributorId, 
                                             org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a distributor hierarchy 
     *  where the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredDistributorHierarchy();
}
