//
// org.osid.provisioning.ExchangeSession
//
//     The OSID Java specification for org.osid.provisioning.ExchangeSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session exchanges an existing provision for a request for another 
 *  provision via the queue. The data for create and update is provided via 
 *  the <code> RequestForm. </code> </p>
 */

public interface ExchangeSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Queue </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Queue Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getQueueId();


    /**
     *  Gets the <code> Queue </code> associated with this session. 
     *
     *  @return the queue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Queue getQueue()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Requests. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Request </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @param  provisionId the <code> Id </code> of the provision to exchange 
     *  @return <code> false </code> if <code> Request </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRequestsInExchange(org.osid.id.Id provisionId);


    /**
     *  Tests if this user can create a single <code> Request </code> using 
     *  the desired record types. While <code> 
     *  ProvisioningManager.getRequestRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Request. </code> Providing 
     *  an empty array tests if a <code> Request </code> can be created with 
     *  no records. 
     *
     *  @param  provisionId the <code> Id </code> of the provision to exchange 
     *  @param  requestRecordTypes array of request record types 
     *  @return <code> true </code> if <code> Request </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> or 
     *          <code> requestRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRequestWithRecordTypesInExchange(org.osid.id.Id provisionId, 
                                                             org.osid.type.Type[] requestRecordTypes);


    /**
     *  Gets the request form for creating new requests for the exchange. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  provisionId the <code> Id </code> of the provision to exchange 
     *  @param  requestRecordTypes array of request record types 
     *  @return the request form 
     *  @throws org.osid.NotFoundException <code> provisionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> or 
     *          <code> requestRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.RequestForm getRequestFormForCreate(org.osid.id.Id provisionId, 
                                                                     org.osid.type.Type[] requestRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Request. </code> 
     *
     *  @param  requestForm the form for this <code> Request </code> 
     *  @return the new <code> Request </code> 
     *  @throws org.osid.IllegalStateException <code> requestForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> requestForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> requestForm </code> did 
     *          not originate from <code> getRequestFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Request createRequestInExchange(org.osid.provisioning.RequestForm requestForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
