//
// org.osid.provisioning.PoolQuery
//
//     The OSID Java specification for org.osid.provisioning.PoolQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This is the query for searching pools. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PoolQuery
    extends org.osid.OsidGovernatorQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the broker <code> Id </code> for this query. 
     *
     *  @param  brokerId the broker <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> brokerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBrokerId(org.osid.id.Id brokerId, boolean match);


    /**
     *  Clears the broker <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrokerIdTerms();


    /**
     *  Tests if a <code> BrokerQuery </code> is available. 
     *
     *  @return <code> true </code> if a broker query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerQuery();


    /**
     *  Gets the query for a broker. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the broker query 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBrokerQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerQuery getBrokerQuery();


    /**
     *  Clears the broker query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrokerTerms();


    /**
     *  Sets the provisionable <code> Id </code> for this query. 
     *
     *  @param  provisionableId the provisionable <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProvisionableId(org.osid.id.Id provisionableId, 
                                     boolean match);


    /**
     *  Clears the provisionable <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionableIdTerms();


    /**
     *  Tests if a <code> ProvisionableQuery </code> is available. 
     *
     *  @return <code> true </code> if a provisionable query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableQuery();


    /**
     *  Gets the query for a <code> PoolQntry. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the provisionable query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionableQuery getProvisionableQuery();


    /**
     *  Matches pools that have any provisionable. 
     *
     *  @param  match <code> true </code> to match pools with any 
     *          provisionable, <code> false </code> to match pools with no 
     *          provisionable 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProvisionable(boolean match);


    /**
     *  Clears the provisionable query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionableTerms();


    /**
     *  Matches pools of the given size inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSize(long start, long end, boolean match);


    /**
     *  Matches pools with any known size. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySize(boolean match);


    /**
     *  Clears the size query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSizeTerms();


    /**
     *  Sets the distributor <code> Id </code> for this query to match queues 
     *  assigned to distributors. 
     *
     *  @param  distributorId the distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributorId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDistributorQuery();


    /**
     *  Clears the distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorTerms();


    /**
     *  Gets the pool query record corresponding to the given <code> Pool 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  poolRecordType a pool record type 
     *  @return the pool query record 
     *  @throws org.osid.NullArgumentException <code> poolRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(poolRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.PoolQueryRecord getPoolQueryRecord(org.osid.type.Type poolRecordType)
        throws org.osid.OperationFailedException;
}
