//
// org.osid.provisioning.PoolSearchSession
//
//     The OSID Java specification for org.osid.provisioning.PoolSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session provides methods for searching among <code> Pool </code> 
 *  objects. The search query is constructed using the <code> PoolQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getPoolsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Pools. </code> A more advanced search may be 
 *  performed with <code> getPoolsBySearch(). </code> It accepts a <code> 
 *  PoolSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getPoolsBySearch() </code> returns a <code> PoolSearchResults </code> that 
 *  can be used to access the resulting <code> PoolList </code> or be used to 
 *  perform a search within the result set through <code> PoolSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated broker view: searches include pools in brokers of which 
 *      this broker is an ancestor in the broker hierarchy </li> 
 *      <li> isolated broker view: searches are restricted to pools in this 
 *      broker </li> 
 *  </ul>
 *  
 *  
 *  <p> Pools may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PoolQuery. </code> </p>
 */

public interface PoolSearchSession
    extends org.osid.provisioning.PoolQuerySession {


    /**
     *  Gets a pool search. 
     *
     *  @return the pool search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolSearch getPoolSearch();


    /**
     *  Gets a pool search order. The <code> PoolSearchOrder </code> is 
     *  supplied to a <code> PoolSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the pool search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolSearchOrder getPoolSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  poolQuery the pool query 
     *  @param  poolSearch the pool search 
     *  @return the pool search results 
     *  @throws org.osid.NullArgumentException <code> poolQuery </code> or 
     *          <code> poolSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> poolQuery </code> or 
     *          <code> poolSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolSearchResults getPoolsBySearch(org.osid.provisioning.PoolQuery poolQuery, 
                                                                    org.osid.provisioning.PoolSearch poolSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a pool query from an inspector. The inspector is available from a 
     *  <code> PoolSearchResults. </code> 
     *
     *  @param  poolQueryInspector a pool query inspector 
     *  @return the pool query 
     *  @throws org.osid.NullArgumentException <code> poolQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> poolQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolQuery getPoolQueryFromInspector(org.osid.provisioning.PoolQueryInspector poolQueryInspector);
}
