//
// org.osid.provisioning.PoolSmartDistributorSession
//
//     The OSID Java specification for org.osid.provisioning.PoolSmartDistributorSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> PoolQuery </code> can be retrieved from this session 
 *  and distributorped to this <code> Distributor </code> to create a virtual 
 *  collection of <code> Pools. </code> The pools may be sequenced using the 
 *  <code> PoolSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Distributor </code> has a default query that matches any 
 *  pool and a default search order that specifies no sequencing. The queries 
 *  may be examined using a <code> PoolQueryInspector. </code> The query may 
 *  be modified by converting the inspector back to a <code> PoolQuery. 
 *  </code> </p>
 */

public interface PoolSmartDistributorSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart distributors. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart distributor management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartDistributors();


    /**
     *  Gets a pool query. 
     *
     *  @return the pool query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolQuery getPoolQuery();


    /**
     *  Gets a pool search order. 
     *
     *  @return the pool search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolSearchOrder getPoolSearchOrder();


    /**
     *  Applies a pool query to this distributor. 
     *
     *  @param  poolQuery the pool query 
     *  @throws org.osid.NullArgumentException <code> poolQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> poolQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPoolQuery(org.osid.provisioning.PoolQuery poolQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a pool query inspector for this distributor. 
     *
     *  @return the pool query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolQueryInspector inspectPoolQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a pool search order to this distributor. 
     *
     *  @param  poolSearchOrder the pool search order 
     *  @throws org.osid.NullArgumentException <code> poolSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> poolSearchOrder </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyPoolSequencing(org.osid.provisioning.PoolSearchOrder poolSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a pool query from an inspector. 
     *
     *  @param  poolQueryInspector a pool query inspector 
     *  @return the pool query 
     *  @throws org.osid.NullArgumentException <code> poolQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> poolQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolQuery getPoolQueryFromInspector(org.osid.provisioning.PoolQueryInspector poolQueryInspector);
}
