//
// org.osid.provisioning.ProvisionForm
//
//     The OSID Java specification for org.osid.provisioning.ProvisionForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This is the form for creating and updating <code> Provisions. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  ProvisionAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface ProvisionForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for the request. 
     *
     *  @return metadata for the request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRequestMetadata();


    /**
     *  Sets the request. 
     *
     *  @param  requestId the new request 
     *  @throws org.osid.InvalidArgumentException <code> requestId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> requestId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRequest(org.osid.id.Id requestId);


    /**
     *  Removes the request. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequest();


    /**
     *  Gets the metadata for the due date. 
     *
     *  @return metadata for the due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDueDateMetadata();


    /**
     *  Sets the due date. 
     *
     *  @param  date the new due date 
     *  @throws org.osid.InvalidArgumentException <code> date </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDueDate(org.osid.calendaring.DateTime date);


    /**
     *  Removes the due date. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDate();


    /**
     *  Gets the metadata for the cost. 
     *
     *  @return metadata for the cost amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCostMetadata();


    /**
     *  Sets the cost. 
     *
     *  @param  cost the new cost 
     *  @throws org.osid.InvalidArgumentException <code> cost </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> cost </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCost(org.osid.financials.Currency cost);


    /**
     *  Removes the cost. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCost();


    /**
     *  Gets the metadata for the rate amount. 
     *
     *  @return metadata for the rate amount 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRateAmountMetadata();


    /**
     *  Sets the rate amount. 
     *
     *  @param  amount the new rate amount 
     *  @throws org.osid.InvalidArgumentException <code> amount </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> amount </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRateAmount(org.osid.financials.Currency amount);


    /**
     *  Removes the rate amount. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRateAmount();


    /**
     *  Gets the metadata for the rate period. 
     *
     *  @return metadata for the rate period 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRatePeriodMetadata();


    /**
     *  Sets the rate period. 
     *
     *  @param  period the new rate period 
     *  @throws org.osid.InvalidArgumentException <code> period </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> period </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRatePeriod(org.osid.calendaring.Duration period);


    /**
     *  Removes the rate period. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRatePeriod();


    /**
     *  Gets the <code> ProvisionFormRecord </code> corresponding to the given 
     *  provision record <code> Type. </code> 
     *
     *  @param  provisionRecordType a provision record type 
     *  @return the provision form record 
     *  @throws org.osid.NullArgumentException <code> provisionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(provisionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.ProvisionFormRecord getProvisionFormRecord(org.osid.type.Type provisionRecordType)
        throws org.osid.OperationFailedException;
}
