//
// org.osid.provisioning.ProvisionQuery
//
//     The OSID Java specification for org.osid.provisioning.ProvisionQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This is the query for searching provisions. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ProvisionQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the broker <code> Id </code> for this query. 
     *
     *  @param  brokerId the broker <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> brokerId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBrokerId(org.osid.id.Id brokerId, boolean match);


    /**
     *  Clears the broker <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrokerIdTerms();


    /**
     *  Tests if a <code> BrokerQuery </code> is available. 
     *
     *  @return <code> true </code> if a broker query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerQuery();


    /**
     *  Gets the query for a <code> Broker. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the broker query 
     *  @throws org.osid.UnimplementedException <code> supportsBrokerQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportBrokerQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.BrokerQuery getBrokerQuery();


    /**
     *  Clears the broker query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBrokerTerms();


    /**
     *  Sets the provisionable <code> Id </code> for this query. 
     *
     *  @param  provisionableId the provisionable <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProvisionableId(org.osid.id.Id provisionableId, 
                                     boolean match);


    /**
     *  Clears the provisionable <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionableIdTerms();


    /**
     *  Tests if a <code> ProvisionableQuery </code> is available. 
     *
     *  @return <code> true </code> if a provisionable query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionableQuery();


    /**
     *  Gets the query for a <code> Provisionable. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the provisionable query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionableQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionableQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionableQuery getProvisionableQuery();


    /**
     *  Clears the provisionable query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionableTerms();


    /**
     *  Sets the recipient <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRecipientId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the recipient <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipientIdTerms();


    /**
     *  Tests if a <code> RecipientQuery </code> is available. 
     *
     *  @return <code> true </code> if a recipient query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipientQuery();


    /**
     *  Gets the query for a <code> Recipient. </code> Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipientQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipientQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getRecipientQuery();


    /**
     *  Clears the recipient query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipientTerms();


    /**
     *  Sets the request <code> Id </code> for this query. 
     *
     *  @param  requestId the request <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> requestId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequestId(org.osid.id.Id requestId, boolean match);


    /**
     *  Clears the request <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestIdTerms();


    /**
     *  Tests if a <code> RequestQuery </code> is available. 
     *
     *  @return <code> true </code> if a request query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestQuery();


    /**
     *  Gets the query for a request. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the request query 
     *  @throws org.osid.UnimplementedException <code> supportsRequestQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.RequestQuery getRequestQuery();


    /**
     *  Matches provisions with any request. 
     *
     *  @param  match <code> true </code> to match provisions with a request, 
     *          <code> false </code> to match provisions with no requests 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequest(boolean match);


    /**
     *  Clears the request query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestTerms();


    /**
     *  Matches provisions with a provision date in the given range inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProvisionDate(org.osid.calendaring.DateTime from, 
                                   org.osid.calendaring.DateTime to, 
                                   boolean match);


    /**
     *  Clears the provision date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionDateTerms();


    /**
     *  Matches provisions that are leases. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLeased(boolean match);


    /**
     *  Clears the leased query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLeasedTerms();


    /**
     *  Matches provisions that must be returned. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMustReturn(boolean match);


    /**
     *  Clears the must return query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMustReturnTerms();


    /**
     *  Matches leased provisions with a due date within the given range 
     *  inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDueDate(org.osid.calendaring.DateTime from, 
                             org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches provisions with any due date. 
     *
     *  @param  match <code> true </code> to match provisions with a due date, 
     *          <code> false </code> to match provisions with no due date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDueDate(boolean match);


    /**
     *  Clears the due date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDueDateTerms();


    /**
     *  Matches leased provisions with a cost within the given range 
     *  inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCost(org.osid.financials.Currency from, 
                          org.osid.financials.Currency to, boolean match);


    /**
     *  Matches provisions with any cost. 
     *
     *  @param  match <code> true </code> to match provisions with a cost, 
     *          <code> false </code> to match provisions with no cost 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCost(boolean match);


    /**
     *  Clears the cost query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCostTerms();


    /**
     *  Matches leased provisions with a rate amount within the given range 
     *  inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRateAmount(org.osid.financials.Currency from, 
                                org.osid.financials.Currency to, boolean match);


    /**
     *  Matches provisions with any rate amount. 
     *
     *  @param  match <code> true </code> to match provisions with a rate, 
     *          <code> false </code> to match provisions with no rate 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRateAmount(boolean match);


    /**
     *  Clears the rate amount query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRateAmountTerms();


    /**
     *  Matches leased provisions with a rate period within the given range 
     *  inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRatePeriod(org.osid.calendaring.Duration from, 
                                org.osid.calendaring.Duration to, 
                                boolean match);


    /**
     *  Matches provisions with any rate period. 
     *
     *  @param  match <code> true </code> to match provisions with a rate 
     *          period, <code> false </code> to match provisions with no rate 
     *          period 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRatePeriod(boolean match);


    /**
     *  Clears the rate period query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRatePeriodTerms();


    /**
     *  Tests if a <code> ProvisionReturn </code> is available. 
     *
     *  @return <code> true </code> if a provision return query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProvisionReturnQuery();


    /**
     *  Gets the query for a provision return. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the provision return query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProvisionReturnQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProvisionReturnQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionReturnQuery getProvisionReturnQuery();


    /**
     *  Matches provisions with any provision return. 
     *
     *  @param  match <code> true </code> to match provisions with a provision 
     *          return, <code> false </code> to match provisions with no 
     *          provision return 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProvisionReturn(boolean match);


    /**
     *  Clears the provision return query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProvisionReturnTerms();


    /**
     *  Sets the distributor <code> Id </code> for this query to match 
     *  provisions assigned to distributors. 
     *
     *  @param  distributorId the distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributorId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDistributorQuery();


    /**
     *  Clears the distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorTerms();


    /**
     *  Gets the provision query record corresponding to the given <code> 
     *  Provision </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  provisionRecordType a provision record type 
     *  @return the provision query record 
     *  @throws org.osid.NullArgumentException <code> provisionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(provisionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.ProvisionQueryRecord getProvisionQueryRecord(org.osid.type.Type provisionRecordType)
        throws org.osid.OperationFailedException;
}
