//
// org.osid.provisioning.ProvisionSearchSession
//
//     The OSID Java specification for org.osid.provisioning.ProvisionSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session provides methods for searching among <code> Provision 
 *  </code> objects. The search query is constructed using the <code> 
 *  ProvisionQuery. </code> </p> 
 *  
 *  <p> <code> getProvisionsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Provisions. </code> A more advanced search may be 
 *  performed with <code> getProvisionsBySearch(). </code> It accepts a <code> 
 *  ProvisionSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProvisionsBySearch() </code> returns a <code> 
 *  ProvisionSearchResults </code> that can be used to access the resulting 
 *  <code> ProvisionList </code> or be used to perform a search within the 
 *  result set through <code> ProvisionSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include provisions in 
 *      distributors of which this distributor is an ancestor in the 
 *      distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to provisions 
 *      in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> Provisions may have a record indicated by their respective record 
 *  types. The query record is accessed via the <code> ProvisionQuery. </code> 
 *  </p>
 */

public interface ProvisionSearchSession
    extends org.osid.provisioning.ProvisionQuerySession {


    /**
     *  Gets a provision search. 
     *
     *  @return the provision search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionSearch getProvisionSearch();


    /**
     *  Gets a provision search order. The <code> ProvisionSearchOrder </code> 
     *  is supplied to a <code> ProvisionSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the provision search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionSearchOrder getProvisionSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  provisionQuery the provision query 
     *  @param  provisionSearch the provision search 
     *  @return the provision search results 
     *  @throws org.osid.NullArgumentException <code> provisionQuery </code> 
     *          or <code> provisionSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> provisionQuery </code> or 
     *          <code> provisionSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionSearchResults getProvisionsBySearch(org.osid.provisioning.ProvisionQuery provisionQuery, 
                                                                              org.osid.provisioning.ProvisionSearch provisionSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a provision query from an inspector. The inspector is available 
     *  from a <code> ProvisionSearchResults. </code> 
     *
     *  @param  provisionQueryInspector a provision query inspector 
     *  @return the provision query 
     *  @throws org.osid.NullArgumentException <code> provisionQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> provisionQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionQuery getProvisionQueryFromInspector(org.osid.provisioning.ProvisionQueryInspector provisionQueryInspector);
}
