//
// org.osid.provisioning.ProvisionableAdminSession
//
//     The OSID Java specification for org.osid.provisioning.ProvisionableAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session creates, updates, and deletes <code> Provisionables. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Provisionable, </code> a <code> ProvisionableForm </code> is requested 
 *  using <code> getProvisionableFormForCreate() </code> specifying the 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> ProvisionableForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  ProvisionableForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> ProvisionableForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ProvisionableForms </code> are requested to the 
 *  <code> Provisionable </code> <code> Id </code> that is to be updated using 
 *  <code> getProvisionableFormForUpdate(). </code> Similarly, the <code> 
 *  ProvisionableForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  ProvisionableForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Provisionables. </code> To unmap a 
 *  <code> Provisionable </code> from the current <code> Distributor, </code> 
 *  the <code> ProvisionableDistributorAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> Provisionable 
 *  </code> itself thus removing it from all known <code> Distributor </code> 
 *  catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ProvisionableAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create provisionables. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> Provisionable </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Provisionable </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProvisionables();


    /**
     *  Tests if this user can create a single <code> Provisionable </code> 
     *  using the desired record types. While <code> 
     *  ProvisioningManager.getProvisionableRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Provisionable. 
     *  </code> Providing an empty array tests if a <code> Provisionable 
     *  </code> can be created with no records. 
     *
     *  @param  provisionableRecordTypes array of provisionable record types 
     *  @return <code> true </code> if <code> Provisionable </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> provisionableRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProvisionableWithRecordTypes(org.osid.type.Type[] provisionableRecordTypes);


    /**
     *  Gets the provisionable form for creating new provisionables. A new 
     *  form should be requested for each create transaction. 
     *
     *  @param  resourceId the <code> Id </code> for the resource 
     *  @param  poolId the <code> Id </code> for the pool 
     *  @param  provisionableRecordTypes array of provisionable record types 
     *  @return the provisionable form 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          poolId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId, </code> or 
     *          <code> poolId, or provisionableRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableForm getProvisionableFormForCreate(org.osid.id.Id resourceId, 
                                                                                 org.osid.id.Id poolId, 
                                                                                 org.osid.type.Type[] provisionableRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Provisionable. </code> 
     *
     *  @param  provisionableForm the form for this <code> Provisionable 
     *          </code> 
     *  @return the new <code> Provisionable </code> 
     *  @throws org.osid.IllegalStateException <code> provisionableForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> provisionableForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> provisionableForm </code> 
     *          did not originate from <code> getProvisionableFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Provisionable createProvisionable(org.osid.provisioning.ProvisionableForm provisionableForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update provisionables. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> Provisionable </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Provisionable </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProvisionables();


    /**
     *  Gets the provisionable form for updating an existing provisionable. A 
     *  new provisionable form should be requested for each update 
     *  transaction. 
     *
     *  @param  provisionableId the <code> Id </code> of the <code> 
     *          Provisionable </code> 
     *  @return the provisionable form 
     *  @throws org.osid.NotFoundException <code> provisionableId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableForm getProvisionableFormForUpdate(org.osid.id.Id provisionableId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing provisionable. 
     *
     *  @param  provisionableForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> provisionableForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> provisionableForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> provisionableForm </code> 
     *          did not originate from <code> getProvisionableFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProvisionable(org.osid.provisioning.ProvisionableForm provisionableForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete provisionables. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> Provisionable </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Provisionable </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProvisionables();


    /**
     *  Deletes a <code> Provisionable. </code> 
     *
     *  @param  provisionableId the <code> Id </code> of the <code> 
     *          Provisionable </code> to remove 
     *  @throws org.osid.NotFoundException <code> provisionableId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProvisionable(org.osid.id.Id provisionableId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Provisionables. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Provisionable </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageProvisionableAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Provisionable </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Provisionable </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another provisionable, it is 
     *  reassigned to the given provisionable <code> Id. </code> 
     *
     *  @param  provisionableId the <code> Id </code> of a <code> 
     *          Provisionable </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> provisionableId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasProvisionable(org.osid.id.Id provisionableId, 
                                   org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
