//
// org.osid.provisioning.ProvisionableLookupSession
//
//     The OSID Java specification for org.osid.provisioning.ProvisionableLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session defines methods for retrieving provisionables. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated distributor view: All provisionable methods in this 
 *      session operate, retrieve and pertain to provisionables defined 
 *      explicitly in the current distributor. Using an isolated view is 
 *      useful for managing <code> Provisionables </code> with the <code> 
 *      ProvisionableAdminSession. </code> </li> 
 *      <li> federated distributor view: All provisionable lookup methods in 
 *      this session operate, retrieve and pertain to all provisionables 
 *      defined in this distributor and any other provisionables implicitly 
 *      available in this distributor through distributor inheritence. </li> 
 *      <li> effective provisionable view: All provisionable lookup methods 
 *      return provisionables where the current date falls in between the 
 *      effective dates inclusive. </li> 
 *      <li> any effective provisionable view: provisionables of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Provisionables may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the provisionables. </p>
 */

public interface ProvisionableLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Provisionable </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProvisionables();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProvisionableView();


    /**
     *  A complete view of the <code> Provisionable </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProvisionableView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include provisionables in distributors which are children of this 
     *  distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Only provisionables whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveProvisionableView();


    /**
     *  All provisionables of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveProvisionableView();


    /**
     *  Gets the <code> Provisionable </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Provisionable </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Provisionable </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  provisionableId the <code> Id </code> of the <code> 
     *          Provisionable </code> to retrieve 
     *  @return the returned <code> Provisionable </code> 
     *  @throws org.osid.NotFoundException no <code> Provisionable </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Provisionable getProvisionable(org.osid.id.Id provisionableId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionableList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  provisionables specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Provisionables </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  provisionableIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> provisionableIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesByIds(org.osid.id.IdList provisionableIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionableList </code> corresponding to the given 
     *  provisionable genus <code> Type </code> which does not include 
     *  provisionables of types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  provisionableGenusType a provisionable genus type 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionableGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesByGenusType(org.osid.type.Type provisionableGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionableList </code> corresponding to the given 
     *  provisionable genus <code> Type </code> and include any additional 
     *  provisionables with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  provisionableGenusType a provisionable genus type 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionableGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesByParentGenusType(org.osid.type.Type provisionableGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProvisionableList </code> containing the given 
     *  provisionable record <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known provisionables 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those provisionables that are accessible through this session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  provisionableRecordType a provisionable record type 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.NullArgumentException <code> provisionableRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesByRecordType(org.osid.type.Type provisionableRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisionables effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective provisionables and those currently 
     *  expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesOnDate(org.osid.calendaring.DateTime from, 
                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisionables for a resource. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisionables for a resource and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective provisionables and those currently 
     *  expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesForResourceOnDate(org.osid.id.Id resourceId, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisionables for a pool. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  poolId a pool <code> Id </code> 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesForPool(org.osid.id.Id poolId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisionables effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective provisionables and those currently 
     *  expired are returned. 
     *
     *  @param  poolId a pool <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> poolId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesForPoolOnDate(org.osid.id.Id poolId, 
                                                                                  org.osid.calendaring.DateTime from, 
                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisionables for a resource and pool. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  poolId a pool <code> Id </code> 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> poolId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesForResourceAndPool(org.osid.id.Id resourceId, 
                                                                                       org.osid.id.Id poolId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of provisionables effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  provisionables or an error results. Otherwise, the returned list may 
     *  contain only those provisionables that are accessible through this 
     *  session. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective in addition to being effective in the given date range. In 
     *  any effective mode, effective provisionables and those currently 
     *  expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  poolId a pool <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, poolId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionablesForResourceAndPoolOnDate(org.osid.id.Id resourceId, 
                                                                                             org.osid.id.Id poolId, 
                                                                                             org.osid.calendaring.DateTime from, 
                                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all provisionables. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  provisionables including duplicates, or an error results if an <code> 
     *  Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> Provisionables </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *  
     *  In effective mode, provisionables are returned that are currently 
     *  effective. In any effective mode, effective provisionables and those 
     *  currently expired are returned. 
     *
     *  @return the returned <code> Provisionable </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableList getProvisionables()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
