//
// org.osid.provisioning.ProvisionableSearchOrder
//
//     The OSID Java specification for org.osid.provisioning.ProvisionableSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface ProvisionableSearchOrder
    extends org.osid.OsidRelationshipSearchOrder {


    /**
     *  Orders the results by pool. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPool(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a pool search order is available. 
     *
     *  @return <code> true </code> if a pool search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolSearchOrder();


    /**
     *  Gets the pool search order. 
     *
     *  @return the pool search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsPoolSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolSearchOrder getPoolSearchOrder();


    /**
     *  Orders the results by resource. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByResource(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a resource search order is available. 
     *
     *  @return <code> true </code> if a resource search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceSearchOrder();


    /**
     *  Gets the resource search order. 
     *
     *  @return the resource search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsResourceSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getResourceSearchOrder();


    /**
     *  Orders the results by use. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByUse(org.osid.SearchOrderStyle style);


    /**
     *  Gets the provisionable search order record corresponding to the given 
     *  provisionable record <code> Type. </code> Multiple retrievals return 
     *  the same underlying object. 
     *
     *  @param  provisionableRecordType a provisionable record type 
     *  @return the provisionable order record interface 
     *  @throws org.osid.NullArgumentException <code> provisionableRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(provisionableRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.ProvisionableSearchOrderRecord getProvisionableSearchOrderRecord(org.osid.type.Type provisionableRecordType)
        throws org.osid.OperationFailedException;
}
