//
// org.osid.provisioning.ProvisionableSearchSession
//
//     The OSID Java specification for org.osid.provisioning.ProvisionableSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session provides methods for searching among <code> Provisionable 
 *  </code> objects. The search query is constructed using the <code> 
 *  ProvisionableQuery. </code> </p> 
 *  
 *  <p> <code> getProvisionablesByQuery() </code> is the basic search method 
 *  and returns a list of <code> Provisionables. </code> A more advanced 
 *  search may be performed with <code> getProvisionablesBySearch(). </code> 
 *  It accepts an <code> ProvisionableSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as ordering. <code> getProvisionablesBySearch() </code> 
 *  returns an <code> ProvisionableSearchResults </code> that can be used to 
 *  access the resulting <code> ProvisionableList </code> or be used to 
 *  perform a search within the result set through <code> ProvisionableSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include provisionables in 
 *      distributors of which this distributor is an ancestor in the 
 *      distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to 
 *      provisionables in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> Provisionables may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  ProvisionableQuery. </code> </p>
 */

public interface ProvisionableSearchSession
    extends org.osid.provisioning.ProvisionableQuerySession {


    /**
     *  Gets a provisionable search. 
     *
     *  @return the provisionable search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableSearch getProvisionableSearch();


    /**
     *  Gets a provisionable search order. The <code> ProvisionableSearchOrder 
     *  </code> is supplied to a <code> ProvisionableSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the provisionable search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableSearchOrder getProvisionableSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  provisionableQuery the provisionable query 
     *  @param  provisionableSearch the provisionable search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> provisionableQuery 
     *          </code> or <code> provisionableSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> provisionableQuery 
     *          </code> or <code> provisionableSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableSearchResults getProvisionablesBySearch(org.osid.provisioning.ProvisionableQuery provisionableQuery, 
                                                                                      org.osid.provisioning.ProvisionableSearch provisionableSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a provisionable query from an inspector. The inspector is 
     *  available from a <code> ProvisionableSearchResults. </code> 
     *
     *  @param  provisionableQueryInspector a provisionable query inspector 
     *  @return the provisionable query 
     *  @throws org.osid.NullArgumentException <code> 
     *          provisionableQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          provisionableQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.ProvisionableQuery getProvisionableQueryFromInspector(org.osid.provisioning.ProvisionableQueryInspector provisionableQueryInspector);
}
