//
// org.osid.provisioning.QueueSearchSession
//
//     The OSID Java specification for org.osid.provisioning.QueueSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This session provides methods for searching among <code> Queue </code> 
 *  objects. The search query is constructed using the <code> QueueyQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getQueuesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Queues. </code> A more advanced search may be 
 *  performed with <code> getQueuesBySearch(). </code> It accepts a <code> 
 *  QueueSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getQueuesBySearch() </code> returns a <code> QueueSearchResults </code> 
 *  that can be used to access the resulting <code> QueueList </code> or be 
 *  used to perform a search within the result set through <code> QueueSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated broker view: searches include queues in brokers of 
 *      which this broker is an ancestor in the broker hierarchy </li> 
 *      <li> isolated broker view: searches are restricted to queues in this 
 *      broker </li> 
 *  </ul>
 *  
 *  
 *  <p> Queues may have a queue record indicated by their respective record 
 *  types. The queue record is accessed via the <code> QueueQuery. </code> 
 *  </p>
 */

public interface QueueSearchSession
    extends org.osid.provisioning.QueueQuerySession {


    /**
     *  Gets a queue search. 
     *
     *  @return the queue search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.QueueSearch getQueueSearch();


    /**
     *  Gets a queue search order. The <code> QueueSearchOrder </code> is 
     *  supplied to a <code> QueueSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the queue search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.QueueSearchOrder getQueueSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  queueQuery the queue query 
     *  @param  queueSearch the queue search 
     *  @return the queue search results 
     *  @throws org.osid.NullArgumentException <code> queueQuery </code> or 
     *          <code> queueSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueQuery </code> or 
     *          <code> queueSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.QueueSearchResults getQueuesBySearch(org.osid.provisioning.QueueQuery queueQuery, 
                                                                      org.osid.provisioning.QueueSearch queueSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a queue query from an inspector. The inspector is available from 
     *  a <code> QueueSearchResults. </code> 
     *
     *  @param  queueQueryInspector a queue query inspector 
     *  @return the queue query 
     *  @throws org.osid.NullArgumentException <code> queueQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> queueQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.QueueQuery getQueueQueryFromInspector(org.osid.provisioning.QueueQueryInspector queueQueryInspector);
}
