//
// org.osid.provisioning.RequestForm
//
//     The OSID Java specification for org.osid.provisioning.RequestForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This is the form for creating and updating <code> Requests. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  RequestAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface RequestForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for the pool. 
     *
     *  @return metadata for the pool 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPoolMetadata();


    /**
     *  Sets the pool. 
     *
     *  @param  poolId the new pool 
     *  @throws org.osid.InvalidArgumentException <code> poolId </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPool(org.osid.id.Id poolId);


    /**
     *  Removes the pool. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPool();


    /**
     *  Gets the metadata for the requested provisionable. 
     *
     *  @return metadata for the requested provisionable 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getRequestedProvisionablesMetadata();


    /**
     *  Sets the requested provisionables. The request will be fulfilled if 
     *  one of the requested provisionables are available but not result in 
     *  the provisioning of more than one of the given provisionables. 
     *
     *  @param  provisionableIds the new requested provisionables 
     *  @throws org.osid.InvalidArgumentException a <code> provisionableId 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setRequestedProvisionables(org.osid.id.IdList provisionableIds);


    /**
     *  Removes the requested provisionable. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestedProvisionables();


    /**
     *  Gets the metadata for the posiiton. 
     *
     *  @return metadata for the position 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getPositionMetadata();


    /**
     *  Sets the position. A new position inserts at the given place in the 
     *  queue for queues that support manual positioning. 
     *
     *  @param  position the new position 
     *  @throws org.osid.InvalidArgumentException <code> position </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setPosition(long position);


    /**
     *  Removes the position. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPosition();


    /**
     *  Gets the <code> RequestFormRecord </code> corresponding to the given 
     *  request record <code> Type. </code> 
     *
     *  @param  requestRecordType a request record type 
     *  @return the request form record 
     *  @throws org.osid.NullArgumentException <code> requestRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requestRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.RequestFormRecord getRequestFormRecord(org.osid.type.Type requestRecordType)
        throws org.osid.OperationFailedException;
}
