//
// org.osid.provisioning.RequestQuery
//
//     The OSID Java specification for org.osid.provisioning.RequestQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning;


/**
 *  <p>This is the query for searching requests. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface RequestQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the request transaction <code> Id </code> for this query. 
     *
     *  @param  transactionId the request transaction <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> transactionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequestTransactionId(org.osid.id.Id transactionId, 
                                          boolean match);


    /**
     *  Clears the request transaction <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestTransactionIdTerms();


    /**
     *  Tests if a <code> RequestTransactionQuery </code> is available. 
     *
     *  @return <code> true </code> if a request transaction query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestTransactionQuery();


    /**
     *  Gets the query for a request transaction. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the request transaction query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestTransactionQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestTransactionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.RequestTransactionQuery getRequestTransactionQuery();


    /**
     *  Clears the request transaction query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestTransactionTerms();


    /**
     *  Sets the queue <code> Id </code> for this query. 
     *
     *  @param  queueId the queue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQueueId(org.osid.id.Id queueId, boolean match);


    /**
     *  Clears the queue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueIdTerms();


    /**
     *  Tests if a <code> QueueQuery </code> is available. 
     *
     *  @return <code> true </code> if a queue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueQuery();


    /**
     *  Gets the query for a queue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the queue query 
     *  @throws org.osid.UnimplementedException <code> supportsQueueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueQuery getQueueQuery();


    /**
     *  Clears the queue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueTerms();


    /**
     *  Matches requests with a date in the given range inclusive. 
     *
     *  @param  from the range start 
     *  @param  to the range end 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequestDate(org.osid.calendaring.DateTime from, 
                                 org.osid.calendaring.DateTime to, 
                                 boolean match);


    /**
     *  Clears the request date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestDateTerms();


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequesterId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequesterIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequesterQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequesterQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequesterQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getRequesterQuery();


    /**
     *  Clears the resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequesterTerms();


    /**
     *  Sets the agent <code> Id </code> for this query. 
     *
     *  @param  agentId the agent <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequestingAgentId(org.osid.id.Id agentId, boolean match);


    /**
     *  Clears the agent <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestingAgentIdTerms();


    /**
     *  Tests if an <code> AgentQuery </code> is available. 
     *
     *  @return <code> true </code> if an agent query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestingAgentQuery();


    /**
     *  Gets the query for an agent. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agent query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestingAgentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestingAgentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.authentication.AgentQuery getRequestingAgentQuery();


    /**
     *  Clears the agent query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestingAgentTerms();


    /**
     *  Sets the pool <code> Id </code> for this query. 
     *
     *  @param  poolId the pool <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPoolId(org.osid.id.Id poolId, boolean match);


    /**
     *  Clears the pool <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPoolIdTerms();


    /**
     *  Tests if a <code> PoolQuery </code> is available. 
     *
     *  @return <code> true </code> if a pool query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolQuery();


    /**
     *  Gets the query for a pool. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the pool query 
     *  @throws org.osid.UnimplementedException <code> supportsPoolQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolQuery getPoolQuery();


    /**
     *  Matches requests with any pool. 
     *
     *  @param  match <code> true </code> to match requests with any poo, 
     *          <code> false </code> to match requests with no pool 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPool(boolean match);


    /**
     *  Clears the pool query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPoolTerms();


    /**
     *  Sets the requested provisionable <code> Id </code> for this query. 
     *
     *  @param  provisionableId the provisionable <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> provisionableId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequestedProvisionableId(org.osid.id.Id provisionableId, 
                                              boolean match);


    /**
     *  Clears the requested provisionable <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestedProvisionableIdTerms();


    /**
     *  Tests if a <code> ProvisionableQuery </code> is available. 
     *
     *  @return <code> true </code> if a provisionable query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestedProvisionableQuery();


    /**
     *  Gets the query for a requested provisionable. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the provisionable query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequestedprovisionableQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequestedProvisionableQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.ProvisionableQuery getRequestedProvisionableQuery();


    /**
     *  Matches requests with any requested provisionable. 
     *
     *  @param  match <code> true </code> to match requests with any requested 
     *          provisionable, <code> false </code> to match requests with no 
     *          requested provisionables 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequestedProvisionable(boolean match);


    /**
     *  Clears the requested provisionable query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequestedProvisionableTerms();


    /**
     *  Sets the exchange provision <code> Id </code> for this query. 
     *
     *  @param  provisionId the provision <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExchangeProvisionId(org.osid.id.Id provisionId, 
                                         boolean match);


    /**
     *  Clears the exchange provision <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExchangeProvisionIdTerms();


    /**
     *  Tests if a <code> ProvisionQuery </code> is available. 
     *
     *  @return <code> true </code> if a provision query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsExchangeProvisionQuery();


    /**
     *  Gets the query for an exchange provision. Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the provision query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsExchangeProvisionQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsExchangeProvisionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionQuery getExchangeProvisionQuery();


    /**
     *  Matches requests with any exchange provision. 
     *
     *  @param  match <code> true </code> to match requests with any exchange 
     *          provision, <code> false </code> to match requests with no 
     *          exchange provision 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyExchangeProvision(boolean match);


    /**
     *  Clears the exchange provision query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExchangeProvisionTerms();


    /**
     *  Sets the origin provision <code> Id </code> for this query. 
     *
     *  @param  provisionId the provision <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> provisionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOriginProvisionId(org.osid.id.Id provisionId, 
                                       boolean match);


    /**
     *  Clears the origin provision <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOriginProvisionIdTerms();


    /**
     *  Tests if a <code> ProvisionQuery </code> is available. 
     *
     *  @return <code> true </code> if a provision query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOriginProvisionQuery();


    /**
     *  Gets the query for an origin provision. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the provision query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOriginProvisionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOriginProvisionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.provisioning.ProvisionQuery getOriginProvisionQuery();


    /**
     *  Matches requests with any originating provision. 
     *
     *  @param  match <code> true </code> to match requests with any 
     *          originating provision, <code> false </code> to match requests 
     *          with no origininating provision 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOriginProvision(boolean match);


    /**
     *  Clears the origin provision query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOriginProvisionTerms();


    /**
     *  Matches requests whose position is in the given range inclusive,. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPosition(long start, long end, boolean match);


    /**
     *  Matches requests with any position. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPosition(boolean match);


    /**
     *  Clears the position query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPositionTerms();


    /**
     *  Matches requests whose estimated waiting time is in the given range 
     *  inclusive,. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEWA(org.osid.calendaring.Duration start, 
                         org.osid.calendaring.Duration end, boolean match);


    /**
     *  Matches requests with any ewa. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEWA(boolean match);


    /**
     *  Clears the ewa query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEWATerms();


    /**
     *  Sets the distributor <code> Id </code> for this query. 
     *
     *  @param  distributorId the distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributorId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDistributorQuery();


    /**
     *  Clears the distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorTerms();


    /**
     *  Gets the request query record corresponding to the given <code> 
     *  Request </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  requestRecordType a request record type 
     *  @return the request query record 
     *  @throws org.osid.NullArgumentException <code> requestRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(requestRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.records.RequestQueryRecord getRequestQueryRecord(org.osid.type.Type requestRecordType)
        throws org.osid.OperationFailedException;
}
