//
// org.osid.provisioning.batch.ProvisionableBatchAdminSession
//
//     The OSID Java specification for org.osid.provisioning.batch.ProvisionableBatchAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Provisionables 
 *  </code> in bulk. The data for create and update is provided by the 
 *  consumer via the form object. <code> OsidForms </code> are requested for 
 *  each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Provisionable, </code> a <code> ProvisionableForm </code> is requested 
 *  using <code> getProvisionableFormsForCreate() </code> specifying the 
 *  desired pool, resource, and record <code> Types </code> or none if no 
 *  record <code> Types </code> are needed. Each of the returned <code> 
 *  ProvisionableForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> ProvisionableForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> ProvisionableForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> ProvisionableForms </code> returned from <code> 
 *  getProvisionableFormsForCreate() </code> may be linked to the originating 
 *  request transaction through the peer <code> Ids </code> of the <code> 
 *  ProvisionableForm. </code> In the case where there may be duplicates, any 
 *  <code> ProvisionableForm </code> of the same peer <code> Ids </code> may 
 *  be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> ProvisionableForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  ProvisionableForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createProvisionables(), </code> errors specific to an individual 
 *  <code> ProvisionableForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> ProvisionableForm </code> through the <code> 
 *  ProvisionableForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> ProvisionableForms </code> are requested to the 
 *  <code> Provisionable </code> <code> Id </code> that is to be updated using 
 *  <code> getProvisionableFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> ProvisionableForm </code> may be used to link the 
 *  request transaction. Similarly, the <code> ProvisionableForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> ProvisionableForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> ProvisionableForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  ProvisionableForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateProvisionables(), </code> errors specific to an individual 
 *  <code> ProvisionableForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> ProvisionableForm </code> through the <code> 
 *  ProvisionableForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Provisionables </code> in bulk. To 
 *  unmap a <code> Provisionable </code> from the current <code> Distributor, 
 *  </code> the <code> ProvisionableDistributorAssignmentSession </code> 
 *  should be used. These delete operations attempt to remove the <code> 
 *  Provisionable </code> itself thus removing it from all known <code> 
 *  Distributor </code> catalogs. Bulk delete operations return the results in 
 *  <code> DeleteResponses. </code> </p>
 */

public interface ProvisionableBatchAdminSession
    extends org.osid.provisioning.ProvisionableAdminSession {


    /**
     *  Gets the provisionable forms for creating a bunch of new 
     *  provisionables. A <code> ProvisionableForm </code> is returned for 
     *  each pool and resource pair. 
     *
     *  @param  peers the relationship peers 
     *  @param  provisionableRecordTypes array of provisionable record types 
     *          to be included in each create operation or an empty list if 
     *          none 
     *  @return the provisionable forms 
     *  @throws org.osid.NotFoundException a <code> resourceId </code> or 
     *          <code> poolId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          provisionableRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request transaction 
     *          forms with given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.batch.ProvisionableBatchFormList getProvisionableFormsForCreate(org.osid.provisioning.batch.ProvisionablePeerList peers, 
                                                                                                 org.osid.type.Type[] provisionableRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Provisionables. </code> This method 
     *  returns an error if the entire operation fails. Otherwise, the status 
     *  of an individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  provisionableForms the provisionable forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> provisionableForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createProvisionables(org.osid.provisioning.batch.ProvisionableBatchFormList provisionableForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the provisionable forms for updating an existing set of 
     *  provisionables. A new provisionable form should be requested for each 
     *  update transaction. 
     *
     *  @param  provisionableIds the <code> Ids </code> of the <code> 
     *          Provisionable </code> 
     *  @return the provisionable form 
     *  @throws org.osid.NotFoundException a <code> provisionableId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> provisionableIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.batch.ProvisionableBatchFormList getProvisionableFormsForUpdate(org.osid.id.IdList provisionableIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing provisionables. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  provisionableForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> provisionableForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateProvisionables(org.osid.provisioning.batch.ProvisionableBatchFormList provisionableForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Provisionables </code> in this <code> Distributor 
     *  </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllProvisionables()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes provisionables for the given <code> Ids. </code> 
     *
     *  @param  provisionableIds the <code> Ids </code> of the provisionables 
     *          to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> provisionableIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProvisionables(org.osid.id.IdList provisionableIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all provisionables for the given resource. 
     *
     *  @param  resourceId an <code> Id </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProvisionablesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all provisionables for the given pool. 
     *
     *  @param  poolId an <code> Id </code> of a pool 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteProvisionablesForPool(org.osid.id.Id poolId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes provisionables expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveProvisionablesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Provisionable </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Provisionable </code> is determined by the provider. The 
     *  new <code> Id </code> is an alias to the primary <code> Id. </code> If 
     *  the alias is a pointer to another provisionable, it is reassigned to 
     *  the given provisionable <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasProvisionables(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
