/**
 * <p>The Open Service Interface Definitions for the org.osid.provisioning
 * service.</p>
 * 
 * <p>The Provisioning OSID provides a means for requesting and assigning 
 * <code> Resources. </code> There are many aspects to this service from the 
 * set up of a provisioning system to the acquisition and return of <code> 
 * Resources. </code> </p> 
 * <h4> Provisionables </h4> 
 * 
 * <p> A <code> Provisionable </code> represents a resource to be provisioned. 
 * A <code> Provisionable </code> is an <code> OsidRelationship </code> 
 * between a <code> Resource </code> and a resource <code> Pool. </code> A 
 * <code> Pool </code> is a set of like <code> Provisionables </code> that can 
 * be assigned. For example, a <code> Resource </code> may be used to 
 * represent a car. A <code> Pool </code> may be used to represent an entire 
 * set of cars that can be rented. The rental agency may have different 
 * classes of cars such as compact cars and full-size cars. <code> Pools 
 * </code> may be created for each class of cars. </p> 
 * <h4> Requests </h4> 
 * 
 * <p> A <code> Request </code> is made to request a <code> Provisionable. 
 * </code> The requester makes a <code> Request </code> for entry into a 
 * <code> Queue. </code> The <code> Queue </code> serves as a wait list for a 
 * <code> Provisionable </code> out of one or more <code> Pools. </code> The 
 * <code> Request </code> may optionally support a <code> Request </code> for 
 * a <code> Provisionable </code> out of a specific <code> Pool, </code> or a 
 * <code> Request </code> for a specific set of <code> Provisionables </code> 
 * . </p> 
 * 
 * <p> A <code> Request </code> may be made for any seat on a flight, any seat 
 * in the coach <code> Pool, </code> or any seat within the aisle coach <code> 
 * Pool, </code> or one of seats 1B, 1C in the first class <code> Pool. 
 * </code> </p> 
 * 
 * <p> Multiple <code> Requests </code> may be bundled into a single <code> 
 * RequestTransaction. </code> A <code> RequestTransaction </code> is 
 * processed atomically in that all <code> Requests </code> are fulfilled or 
 * none of the <code> Requests </code> are filled. A <code> RequestTransaction 
 * </code> may be made for a <code> Request </code> for a flight from Boston 
 * to New York and another <code> Request </code> for a flight from New York 
 * to Barcelona. The Barcelona <code> Request </code> should not be processed 
 * if there are no available flights to New York. </p> 
 * <h4> Provisions </h4> 
 * 
 * <p> A <code> Provision </code> is the result of fulfilling a <code> 
 * Request. </code> A <code> Provision </code> is an <code> OsidRelationship 
 * </code> between a <code> Provisionable </code> and a <code> Request. 
 * </code> As <code> OsidRelationships, </code> <code> Provisions </code> have 
 * effective dates and may optionally require a <code> Provision </code> to be 
 * returned. A <code> ProvisionReturn </code> captures information about the 
 * return of a <code> Provision. </code> </p> 
 * <h4> Brokers </h4> 
 * 
 * <p> A <code> Broker </code> represents the governance of <code> Queues 
 * </code> and <code> Pools. </code> The <code> Broker </code> manages 
 * behind-the-scenes operations such as consraints on entering a <code> Queue, 
 * </code> the processing of a <code> Queue, </code> and how <code> 
 * Provisionables </code> are automatically assigned to <code> Requests. 
 * </code> The <code> Broker </code> is the entity to which these various 
 * constraints and processing rules are related. While all <code> Queues 
 * </code> and Pools may be cataloged in various ways, they belong to a single 
 * <code> Broker. </code> </p> 
 * <h4> Distributor Cataloging </h4> 
 * 
 * <p> All <code> Provisions, </code> <code> Requests, </code> <code> 
 * Provisionables, </code> <code> Queues, </code> <code> Pools, </code> and 
 * <code> Brokers </code> may be organized into federateable <code> 
 * OsidCatalogs </code> called <code> Distributors. </code> </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Provisioning OSID includes a Provisioning Rules OSID for managing 
 * constraints and processing rules. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.provisioning;
