//
// org.osid.provisioning.rules.BrokerConstrainerEnablerAdminSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerConstrainerEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session creates and removes broker constrainer enablers. The data 
 *  for create and update is provided via the <code> 
 *  BrokerConstrainerEnablerForm. </code> </p>
 */

public interface BrokerConstrainerEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create broker constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known a <code> BrokerConstrainerEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainerEnabler 
     *          </code> creation is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBrokerConstrainerEnabler();


    /**
     *  Tests if this user can create a single <code> BrokerConstrainerEnabler 
     *  </code> using the desired record types. While <code> 
     *  ProvisioningRulesManager.getBrokerConstrainerEnablerRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> BrokerConstrainerEnabler. </code> Providing an empty array 
     *  tests if a <code> BrokerConstrainerEnabler </code> can be created with 
     *  no records. 
     *
     *  @param  brokerConstrainerEnablerRecordTypes array of broker 
     *          constrainer enabler record types 
     *  @return <code> true </code> if <code> BrokerConstrainerEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBrokerConstrainerEnablerWithRecordTypes(org.osid.type.Type[] brokerConstrainerEnablerRecordTypes);


    /**
     *  Gets the broker constrainer enabler form for creating new broker 
     *  constrainer enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  brokerConstrainerEnablerRecordTypes array of broker 
     *          constrainer enabler record types 
     *  @return the broker constrainer enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerForm getBrokerConstrainerEnablerFormForCreate(org.osid.type.Type[] brokerConstrainerEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> BrokerConstrainerEnabler. </code> 
     *
     *  @param  brokerConstrainerEnablerForm the form for this <code> 
     *          BrokerConstrainerEnabler </code> 
     *  @return the new <code> BrokerConstrainerEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          brokerConstrainerEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          brokerConstrainerEnablerForm </code> did not originate from 
     *          <code> getBrokerConstrainerEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnabler createBrokerConstrainerEnabler(org.osid.provisioning.rules.BrokerConstrainerEnablerForm brokerConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update broker constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> BrokerConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainerEnabler 
     *          </code> modification is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateBrokerConstrainerEnablers();


    /**
     *  Gets the broker constrainer enabler form for updating an existing 
     *  broker constrainer enabler. A new broker constrainer enabler form 
     *  should be requested for each update transaction. 
     *
     *  @param  brokerConstrainerEnablerId the <code> Id </code> of the <code> 
     *          BrokerConstrainerEnabler </code> 
     *  @return the broker constrainer enabler form 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerEnablerForm getBrokerConstrainerEnablerFormForUpdate(org.osid.id.Id brokerConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing broker constrainer enabler. 
     *
     *  @param  brokerConstrainerEnablerForm the form containing the elements 
     *          to be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          brokerConstrainerEnablerForm </code> already used in an update 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          brokerConstrainerEnablerForm </code> did not originate from 
     *          <code> getBrokerConstrainerEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateBrokerConstrainerEnabler(org.osid.provisioning.rules.BrokerConstrainerEnablerForm brokerConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete broker constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> BrokerConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainerEnabler 
     *          </code> deletion is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteBrokerConstrainerEnablers();


    /**
     *  Deletes a <code> BrokerConstrainerEnabler. </code> 
     *
     *  @param  brokerConstrainerEnablerId the <code> Id </code> of the <code> 
     *          BrokerConstrainerEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteBrokerConstrainerEnabler(org.osid.id.Id brokerConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for broker 
     *  constrainer enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BrokerConstrainerEnabler 
     *          </code> aliasing is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageBrokerConstrainerEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> BrokerConstrainerEnabler </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> BrokerConstrainerEnabler </code> is determined 
     *  by the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  broker constrainer enabler. it is reassigned to the given broker 
     *  constrainer enabler <code> Id. </code> 
     *
     *  @param  brokerConstrainerEnablerId the <code> Id </code> of a <code> 
     *          BrokerConstrainerEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> brokerConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerId </code> or <code> aliasId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasBrokerConstrainerEnabler(org.osid.id.Id brokerConstrainerEnablerId, 
                                              org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
