//
// org.osid.provisioning.rules.BrokerConstrainerSearchSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerConstrainerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  BrokerConstrainer </code> objects. The search query is constructed using 
 *  the <code> BrokerConstraineryQuery. </code> </p> 
 *  
 *  <p> <code> getBrokerConstrainersByQuery() </code> is the basic search 
 *  method and returns a list of <code> BrokerConstrainers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getBrokerConstrainersBySearch(). </code> It accepts a <code> 
 *  BrokerConstrainerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  provisioning. <code> getBrokerConstrainersBySearch() </code> returns a 
 *  <code> BrokerConstrainerSearchResults </code> that can be used to access 
 *  the resulting <code> BrokerConstrainerList </code> or be used to perform a 
 *  search within the result set through <code> BrokerConstrainerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include broker constrainer 
 *      in distributors of which this distributor is an ancestor in the 
 *      distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to broker 
 *      constrainer in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> BrokerConstrainers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  BrokerConstrainerQuery. </code> </p>
 */

public interface BrokerConstrainerSearchSession
    extends org.osid.provisioning.rules.BrokerConstrainerQuerySession {


    /**
     *  Gets a broker constrainer search. 
     *
     *  @return the broker constrainer search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerSearch getBrokerConstrainerSearch();


    /**
     *  Gets a broker constrainer search order. The <code> 
     *  BrokerConstrainerSearchOrder </code> is supplied to a <code> 
     *  BrokerConstrainerSearch </code> to specify the ordering of results. 
     *
     *  @return the broker constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerSearchOrder getBrokerConstrainerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  brokerConstrainerQuery the broker constrainer query 
     *  @param  brokerConstrainerSearch the broker constrainer search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> brokerConstrainerQuery 
     *          </code> or <code> brokerConstrainerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> brokerConstrainerQuery 
     *          </code> or <code> brokerConstrainerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerSearchResults getBrokerConstrainersBySearch(org.osid.provisioning.rules.BrokerConstrainerQuery brokerConstrainerQuery, 
                                                                                                    org.osid.provisioning.rules.BrokerConstrainerSearch brokerConstrainerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a broker constrainer query from an inspector. The inspector is 
     *  available from a <code> BrokerConstrainerSearchResults. </code> 
     *
     *  @param  brokerConstrainerQueryInspector a broker constrainer query 
     *          inspector 
     *  @return the broker constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          brokerConstrainerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerConstrainerQuery getBrokerConstrainerQueryFromInspector(org.osid.provisioning.rules.BrokerConstrainerQueryInspector brokerConstrainerQueryInspector);
}
