//
// org.osid.provisioning.rules.BrokerProcessorEnablerSearchSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  BrokerProcessorEnabler </code> objects. The search query is constructed 
 *  using the <code> BrokerProcessorEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getBrokerProcessorEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> BrokerProcessorEnablers. </code> A 
 *  more advanced search may be performed with <code> 
 *  getBrokerProcessorEnablersBySearch(). </code> It accepts a <code> 
 *  BrokerProcessorEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as provisioning. <code> getBrokerProcessorEnablersBySearch() </code> 
 *  returns a <code> BrokerProcessorEnablerSearchResults </code> that can be 
 *  used to access the resulting <code> BrokerProcessorEnablerList </code> or 
 *  be used to perform a search within the result set through <code> 
 *  BrokerProcessorEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include broker processor 
 *      enablers in distributors of which this distributor is an ancestor in 
 *      the distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to broker 
 *      processor enablers in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> BrokerProcessorEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> BrokerProcessorEnablerQuery. </code> </p>
 */

public interface BrokerProcessorEnablerSearchSession
    extends org.osid.provisioning.rules.BrokerProcessorEnablerQuerySession {


    /**
     *  Gets a broker processor enabler search. 
     *
     *  @return the broker processor enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerSearch getBrokerProcessorEnablerSearch();


    /**
     *  Gets a broker processor enabler search order. The <code> 
     *  BrokerProcessorEnablerSearchOrder </code> is supplied to a <code> 
     *  BrokerProcessorEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the broker processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerSearchOrder getBrokerProcessorEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  brokerProcessorEnablerQuery the broker processor enabler query 
     *  @param  brokerProcessorEnablerSearch the broker processor enabler 
     *          search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerQuery </code> or <code> 
     *          brokerProcessorEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          brokerProcessorEnablerQuery </code> or <code> 
     *          brokerProcessorEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerSearchResults getBrokerProcessorEnablersBySearch(org.osid.provisioning.rules.BrokerProcessorEnablerQuery brokerProcessorEnablerQuery, 
                                                                                                              org.osid.provisioning.rules.BrokerProcessorEnablerSearch brokerProcessorEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a broker processor enabler query from an inspector. The inspector 
     *  is available from a <code> BrokerProcessorEnablerSearchResults. 
     *  </code> 
     *
     *  @param  brokerProcessorEnablerQueryInspector a broker processor 
     *          enabler query inspector 
     *  @return the broker processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          brokerProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorEnablerQuery getBrokerProcessorEnablerQueryFromInspector(org.osid.provisioning.rules.BrokerProcessorEnablerQueryInspector brokerProcessorEnablerQueryInspector);
}
