//
// org.osid.provisioning.rules.BrokerProcessorForm
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This is the form for creating and updating <code> BrokerProcessors. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  BrokerProcessorAdminSession. </code> For each data element that may be 
 *  set, metadata may be examined to provide display hints or data 
 *  constraints. </p>
 */

public interface BrokerProcessorForm
    extends org.osid.OsidProcessorForm {


    /**
     *  Gets the metadata for the leasing flag. 
     *
     *  @return metadata for the leasing flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getLeasingMetadata();


    /**
     *  Sets the leasing flag. 
     *
     *  @param  leasing the new leasing flag 
     *  @throws org.osid.InvalidArgumentException <code> leasing </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLeasing(boolean leasing);


    /**
     *  Removes the fixed lease flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLeasing();


    /**
     *  Gets the metadata for the fixed lease duration. 
     *
     *  @return metadata for the fixed lease duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getFixedLeaseDurationMetadata();


    /**
     *  Sets the fixed lease duration. 
     *
     *  @param  duration the new fixed lease duration. 
     *  @throws org.osid.InvalidArgumentException <code> duration </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> duration </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFixedLeaseDuration(boolean duration);


    /**
     *  Removes the fixed lease duration. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFixedLeaseDuration();


    /**
     *  Gets the metadata for the must return provisions flag. 
     *
     *  @return metadata for the must return flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMustReturnProvisionsMetadata();


    /**
     *  Sets the must return provisions flag. 
     *
     *  @param  mustReturn the new must return provisions flag 
     *  @throws org.osid.InvalidArgumentException <code> mustReturn </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMustReturnProvisions(boolean mustReturn);


    /**
     *  Removes the must return provisions flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMustReturnProvisions();


    /**
     *  Gets the metadata for the allows provision exchange flag. 
     *
     *  @return metadata for th eallows provision exchange flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAllowsProvisionExchangeMetadata();


    /**
     *  Sets the allows provision exchange flag. 
     *
     *  @param  allowsExchange the new allows provision exchange flag 
     *  @throws org.osid.InvalidArgumentException <code> allowsExchange 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAllowsProvisionExchange(boolean allowsExchange);


    /**
     *  Removes the allows provision exchange flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllowsProvisionExchange();


    /**
     *  Gets the metadata for the allows provision exchange flag. 
     *
     *  @return metadata for th eallows provision exchange flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAllowsCompoundRequestsMetadata();


    /**
     *  Sets the allows compound requests flag. 
     *
     *  @param  allowsCompound the new allows compound requests flag 
     *  @throws org.osid.InvalidArgumentException <code> allowsExchange 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAllowsCompoundRequests(boolean allowsCompound);


    /**
     *  Removes the allows compound requests flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllowsCompoundRequests();


    /**
     *  Gets the <code> BrokerProcessorFormRecord </code> corresponding to the 
     *  given broker processor record <code> Type. </code> 
     *
     *  @param  brokerProcessorRecordType a broker processor record type 
     *  @return the broker processor form record 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(brokerProcessorRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.BrokerProcessorFormRecord getBrokerProcessorFormRecord(org.osid.type.Type brokerProcessorRecordType)
        throws org.osid.OperationFailedException;
}
