//
// org.osid.provisioning.rules.BrokerProcessorLookupSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for retrieving <code> BrokerProcessors. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated distributor view: All broker processor methods in this 
 *      session operate, retrieve and pertain to broker processor defined 
 *      explicitly in the current distributor. Using an isolated view is 
 *      useful for managing <code> BrokerProcessors </code> with the <code> 
 *      BrokerProcessorAdminSession. </code> </li> 
 *      <li> federated distributor view: All broker processor methods in this 
 *      session operate, retrieve and pertain to all broker processor defined 
 *      in this distributor and any other broker processor implicitly 
 *      available in this distributor through distributor inheritence. </li> 
 *      <li> active broker processor view: All broker processor lookup methods 
 *      return active broker processors. </li> 
 *      <li> any status broker processor view: Broker processors of any active 
 *      and inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface BrokerProcessorLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> BrokerProcessors </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBrokerProcessors();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBrokerProcessorView();


    /**
     *  A complete view of the <code> BrokerProcessor </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBrokerProcessorView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include broker processor in distributors which are children of this 
     *  distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Only active broker processors are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveBrokerProcessorView();


    /**
     *  All active and inactive broker processors are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusBrokerProcessorView();


    /**
     *  Gets the <code> BrokerProcessor </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  BrokerProcessor </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> BrokerProcessor </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, broker processors are returned that are currently 
     *  active. In any status mode, active and inactive broker processors are 
     *  returned. 
     *
     *  @param  brokerProcessorId <code> Id </code> of the <code> 
     *          BrokerProcessor </code> 
     *  @return the broker processor 
     *  @throws org.osid.NotFoundException <code> brokerProcessorId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessor getBrokerProcessor(org.osid.id.Id brokerProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerProcessorList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  broker processor specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> BrokerProcessors </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, broker processors are returned that are currently 
     *  active. In any status mode, active and inactive broker processors are 
     *  returned. 
     *
     *  @param  brokerProcessorIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> BrokerProcessor </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorList getBrokerProcessorsByIds(org.osid.id.IdList brokerProcessorIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerProcessorList </code> corresponding to the given 
     *  broker processor genus <code> Type </code> which does not include 
     *  broker processor of genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  broker processor or an error results. Otherwise, the returned list may 
     *  contain only those broker processor that are accessible through this 
     *  session. 
     *  
     *  In active mode, broker processors are returned that are currently 
     *  active. In any status mode, active and inactive broker processors are 
     *  returned. 
     *
     *  @param  brokerProcessorGenusType a broker processor genus type 
     *  @return the returned <code> BrokerProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorList getBrokerProcessorsByGenusType(org.osid.type.Type brokerProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerProcessorList </code> corresponding to the given 
     *  broker processor genus <code> Type </code> and include any additional 
     *  broker processor with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  broker processor or an error results. Otherwise, the returned list may 
     *  contain only those broker processor that are accessible through this 
     *  session. 
     *  
     *  In active mode, broker processors are returned that are currently 
     *  active. In any status mode, active and inactive broker processors are 
     *  returned. 
     *
     *  @param  brokerProcessorGenusType a broker processor genus type 
     *  @return the returned <code> BrokerProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorList getBrokerProcessorsByParentGenusType(org.osid.type.Type brokerProcessorGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BrokerProcessorList </code> containing the given broker 
     *  processor record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  broker processor or an error results. Otherwise, the returned list may 
     *  contain only those broker processor that are accessible through this 
     *  session. 
     *  
     *  In active mode, broker processors are returned that are currently 
     *  active. In any status mode, active and inactive broker processors are 
     *  returned. 
     *
     *  @param  brokerProcessorRecordType a broker processor record type 
     *  @return the returned <code> BrokerProcessor </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorList getBrokerProcessorsByRecordType(org.osid.type.Type brokerProcessorRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> BrokerProcessors. </code> 
     *  
     *  In plenary mode, the returned list contains all known broker processor 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those broker processor that are accessible through this session. 
     *  
     *  In active mode, broker processors are returned that are currently 
     *  active. In any status mode, active and inactive broker processors are 
     *  returned. 
     *
     *  @return the returned <code> BrokerProcessor </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorList getBrokerProcessors()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
