//
// org.osid.provisioning.rules.BrokerProcessorSearchSession
//
//     The OSID Java specification for org.osid.provisioning.rules.BrokerProcessorSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  BrokerProcessor </code> objects. The search query is constructed using the 
 *  <code> BrokerProcessoryQuery. </code> </p> 
 *  
 *  <p> <code> getBrokerProcessorsByQuery() </code> is the basic search method 
 *  and returns a list of <code> BrokerProcessors. </code> A more advanced 
 *  search may be performed with <code> getBrokerProcessorsBySearch(). </code> 
 *  It accepts a <code> BrokerProcessorSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as provisioning. <code> getBrokerProcessorsBySearch() </code> 
 *  returns a <code> BrokerProcessorSearchResults </code> that can be used to 
 *  access the resulting <code> BrokerProcessorList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  BrokerProcessorSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include broker processor in 
 *      distributors of which this distributor is an ancestor in the 
 *      distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to broker 
 *      processor in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> BrokerProcessors </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  BrokerProcessorQuery. </code> </p>
 */

public interface BrokerProcessorSearchSession
    extends org.osid.provisioning.rules.BrokerProcessorQuerySession {


    /**
     *  Gets a broker processor search. 
     *
     *  @return the broker processor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorSearch getBrokerProcessorSearch();


    /**
     *  Gets a broker processor search order. The <code> 
     *  BrokerProcessorSearchOrder </code> is supplied to a <code> 
     *  BrokerProcessorSearch </code> to specify the ordering of results. 
     *
     *  @return the broker processor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorSearchOrder getBrokerProcessorSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  brokerProcessorQuery the broker processor query 
     *  @param  brokerProcessorSearch the broker processor search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> brokerProcessorQuery 
     *          </code> or <code> brokerProcessorSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> brokerProcessorQuery 
     *          </code> or <code> brokerProcessorSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorSearchResults getBrokerProcessorsBySearch(org.osid.provisioning.rules.BrokerProcessorQuery brokerProcessorQuery, 
                                                                                                org.osid.provisioning.rules.BrokerProcessorSearch brokerProcessorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a broker processor query from an inspector. The inspector is 
     *  available from a <code> BrokerProcessorSearchResults. </code> 
     *
     *  @param  brokerProcessorQueryInspector a broker processor query 
     *          inspector 
     *  @return the broker processor query 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          brokerProcessorQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.BrokerProcessorQuery getBrokerProcessorQueryFromInspector(org.osid.provisioning.rules.BrokerProcessorQueryInspector brokerProcessorQueryInspector);
}
