//
// org.osid.provisioning.rules.PoolConstrainerEnablerAdminSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolConstrainerEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session creates and removes pool constrainer enablers. The data 
 *  for create and update is provided via the <code> 
 *  PoolConstrainerEnablerForm. </code> </p>
 */

public interface PoolConstrainerEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create pool constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> PoolConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> PoolConstrainerEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePoolConstrainerEnabler();


    /**
     *  Tests if this user can create a single <code> PoolConstrainerEnabler 
     *  </code> using the desired record types. While <code> 
     *  ProvisioningRulesManager.getPoolConstrainerEnablerRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> PoolConstrainerEnabler. </code> Providing an empty array tests 
     *  if a <code> PoolConstrainerEnabler </code> can be created with no 
     *  records. 
     *
     *  @param  poolConstrainerEnablerRecordTypes array of pool constrainer 
     *          enabler record types 
     *  @return <code> true </code> if <code> PoolConstrainerEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreatePoolConstrainerEnablerWithRecordTypes(org.osid.type.Type[] poolConstrainerEnablerRecordTypes);


    /**
     *  Gets the pool constrainer enabler form for creating new pool 
     *  constrainer enablers. A new form should be requested for each create 
     *  transaction. 
     *
     *  @param  poolConstrainerEnablerRecordTypes array of pool constrainer 
     *          enabler record types 
     *  @return the pool constrainer enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerForm getPoolConstrainerEnablerFormForCreate(org.osid.type.Type[] poolConstrainerEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> PoolConstrainerEnabler. </code> 
     *
     *  @param  poolConstrainerEnablerForm the form for this <code> 
     *          PoolConstrainerEnabler </code> 
     *  @return the new <code> PoolConstrainerEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> 
     *          poolConstrainerEnablerForm </code> already used in a create 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          poolConstrainerEnablerForm </code> did not originate from 
     *          <code> getPoolconstrainerEnablerForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnabler createPoolConstrainerEnabler(org.osid.provisioning.rules.PoolConstrainerEnablerForm poolConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update pool constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> PoolConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> PoolConstrainerEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdatePoolConstrainerEnablers();


    /**
     *  Gets the pool constrainer enabler form for updating a existing pool 
     *  constrainer enabler. A new pool constrainer enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> 
     *  @return the pool constrainer enabler form 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerForm getPoolConstrainerEnablerFormForUpdate(org.osid.id.Id poolConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing pool constrainer enabler. 
     *
     *  @param  poolConstrainerEnablerForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> 
     *          poolConstrainerEnablerForm </code> already used in an update 
     *          transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          poolConstrainerEnablerForm </code> did not originate from 
     *          <code> getPoolconstrainerEnablerForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updatePoolConstrainerEnabler(org.osid.provisioning.rules.PoolConstrainerEnablerForm poolConstrainerEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete pool constrainer enablers. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> PoolConstrainerEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> PoolConstrainerEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeletePoolConstrainerEnablers();


    /**
     *  Deletes a <code> PoolConstrainerEnabler. </code> 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletePoolConstrainerEnabler(org.osid.id.Id poolConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for pool 
     *  constrainer enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> PoolConstrainerEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManagePoolConstrainerEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> PoolConstrainerEnabler </code> 
     *  for the purpose of creating compatibility. The primary <code> Id 
     *  </code> of the <code> PoolConstrainerEnabler </code> is determined by 
     *  the provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another pool 
     *  constrainer enabler. it is reassigned to the given pool constrainer 
     *  enabler <code> Id. </code> 
     *
     *  @param  poolConstrainerEnablerId the <code> Id </code> of a <code> 
     *          PoolConstrainerEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasPoolConstrainerEnabler(org.osid.id.Id poolConstrainerEnablerId, 
                                            org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
