//
// org.osid.provisioning.rules.PoolConstrainerEnablerLookupSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolConstrainerEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  PoolConstrainerEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated distributor view: All pool constrainer enabler methods 
 *      in this session operate, retrieve and pertain to pool constrainer 
 *      enablers defined explicitly in the current distributor. Using an 
 *      isolated view is useful for managing <code> PoolConstrainerEnablers 
 *      </code> with the <code> PoolConstrainerEnablerAdminSession. </code> 
 *      </li> 
 *      <li> federated distributor view: All pool constrainer enabler methods 
 *      in this session operate, retrieve and pertain to all pool constrainer 
 *      enablers defined in this distributor and any other pool constrainer 
 *      enablers implicitly available in this distributor through distributor 
 *      inheritence. </li> 
 *      <li> active pool constrainer enabler view: All pool constrainer 
 *      enabler lookup methods return active pool constrainer enablers. </li> 
 *      <li> any status pool constrainer enabler view: Pool constrainer 
 *      enablers of any active or inactive status are returned from methods. 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedDistributorView() </code> and <code> 
 *  useIsolatedDistributorView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface PoolConstrainerEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> PoolConstrainerEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPoolConstrainerEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePoolConstrainerEnablerView();


    /**
     *  A complete view of the <code> PoolConstrainerEnabler </code> returns 
     *  is desired. Methods will return what is requested or result in an 
     *  error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPoolConstrainerEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include pool constrainer enablers in distributors which are children 
     *  of this distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Only active pool constrainer enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActivePoolConstrainerEnablerView();


    /**
     *  All active and inactive pool constrainer enablers are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusPoolConstrainerEnablerView();


    /**
     *  Gets the <code> PoolConstrainerEnabler </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  PoolConstrainerEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> PoolConstrainerEnabler </code> and retained 
     *  for compatibility. 
     *  
     *  In active mode, pool constrainer enablers are returned that are 
     *  currently active. In any status mode, active and inactive pool 
     *  constrainer enablers are returned. 
     *
     *  @param  poolConstrainerEnablerId <code> Id </code> of the <code> 
     *          PoolConstrainerEnabler </code> 
     *  @return the pool constrainer enabler 
     *  @throws org.osid.NotFoundException <code> poolConstrainerEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolConstrainerEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnabler getPoolConstrainerEnabler(org.osid.id.Id poolConstrainerEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolConstrainerEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> In plenary mode, the returned list 
     *  contains all of the pool constrainer enablers specified in the <code> 
     *  Id </code> list, in the order of the list, including duplicates, or an 
     *  error results if an <code> Id </code> in the supplied list is not 
     *  found or inaccessible. Otherwise, inaccessible <code> 
     *  PoolConstrainerEnablers </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  poolConstrainerEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> PoolConstrainerEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerIds </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablersByIds(org.osid.id.IdList poolConstrainerEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolConstrainerEnablerList </code> corresponding to the 
     *  given pool constrainer enabler genus <code> Type </code> which does 
     *  not include pool constrainer enablers of genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pool constrainer enablers or an error results. Otherwise, the returned 
     *  list may contain only those pool constrainer enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, pool constrainer enablers are returned that are 
     *  currently active. In any status mode, active and inactive pool 
     *  constrainer enablers are returned. 
     *
     *  @param  poolConstrainerEnablerGenusType a pool constrainer enabler 
     *          genus type 
     *  @return the returned <code> PoolConstrainerEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablersByGenusType(org.osid.type.Type poolConstrainerEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolConstrainerEnablerList </code> corresponding to the 
     *  given pool constrainer enabler genus <code> Type </code> and include 
     *  any additional pool constrainer enablers with genus types derived from 
     *  the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pool constrainer enablers or an error results. Otherwise, the returned 
     *  list may contain only those pool constrainer enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, pool constrainer enablers are returned that are 
     *  currently active. In any status mode, active and inactive pool 
     *  constrainer enablers are returned. 
     *
     *  @param  poolConstrainerEnablerGenusType a pool constrainer enabler 
     *          genus type 
     *  @return the returned <code> PoolConstrainerEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablersByParentGenusType(org.osid.type.Type poolConstrainerEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolConstrainerEnablerList </code> containing the given 
     *  pool constrainer enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  pool constrainer enablers or an error results. Otherwise, the returned 
     *  list may contain only those pool constrainer enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, pool constrainer enablers are returned that are 
     *  currently active. In any status mode, active and inactive pool 
     *  constrainer enablers are returned. 
     *
     *  @param  poolConstrainerEnablerRecordType a pool constrainer enabler 
     *          record type 
     *  @return the returned <code> PoolConstrainerEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablersByRecordType(org.osid.type.Type poolConstrainerEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolConstrainerEnablerList </code> effective for the 
     *  entire the given date range inclusive but not confisned to the date 
     *  range for any agent. 
     *  
     *  In plenary mode, the returned list contains all known pool constrainer 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those pool constrainer enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, pool constrainer enablers are returned that are 
     *  currently active in addition to being effective for the given date 
     *  range. In any status mode, active and inactive pool constrainer 
     *  enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> PoolConstrainerEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PoolConstrainerEnablerList </code> effective for the 
     *  entire the given date range inclusive but not confisned to the date 
     *  range and evaluated against the given agent. 
     *  
     *  In plenary mode, the returned list contains all known pool constrainer 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those pool constrainer enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, pool constrainer enablers are returned that are 
     *  currently active in addition to being effective for the given date 
     *  range. In any status mode, active and inactive pool constrainer 
     *  enablers are returned. 
     *
     *  @param  agentId an agent Id 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> PoolConstrainerEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                            org.osid.calendaring.DateTime from, 
                                                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> PoolConstrainerEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known pool constrainer 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those pool constrainer enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, pool constrainer enablers are returned that are 
     *  currently active. In any status mode, active and inactive pool 
     *  constrainer enablers are returned. 
     *
     *  @return the returned <code> PoolConstrainerEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolConstrainerEnablerList getPoolConstrainerEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
