//
// org.osid.provisioning.rules.PoolProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> PoolProcessorEnablers 
 *  </code> to <code> PoolProcessors. </code> A <code> PoolProcessor </code> 
 *  with multiple <code> PoolProcessorEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> 
 *  PoolProcessor. </code> </p>
 */

public interface PoolProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter pool processor enabler/pool processor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPoolProcessorEnablers();


    /**
     *  Adds an existing <code> PoolProcessorEnabler </code> to a <code> 
     *  PoolProcessor. </code> 
     *
     *  @param  poolProcessorEnablerId the <code> Id </code> of the <code> 
     *          PoolProcessorEnabler </code> 
     *  @param  poolProcessorId the <code> Id </code> of the <code> 
     *          PoolProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> poolProcessorEnablerId 
     *          </code> is already applied to <code> poolProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorEnablerId 
     *          </code> or <code> poolProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolProcessorEnablerId 
     *          </code> or <code> poolProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPoolProcessorEnablerToPoolProcessor(org.osid.id.Id poolProcessorEnablerId, 
                                                          org.osid.id.Id poolProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> PoolProcessorEnabler </code> from a <code> 
     *  PoolProcessor. </code> 
     *
     *  @param  poolProcessorEnablerId the <code> Id </code> of the <code> 
     *          PoolProcessorEnabler </code> 
     *  @param  poolProcessorId the <code> Id </code> of the <code> 
     *          PoolProcessor </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorEnablerId 
     *          </code> or <code> poolProcessorId </code> not found or <code> 
     *          poolProcessorEnablerId </code> not applied to <code> 
     *          poolProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorEnablerId 
     *          </code> or <code> poolProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPoolProcessorEnablerFromPoolProcessor(org.osid.id.Id poolProcessorEnablerId, 
                                                              org.osid.id.Id poolProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> PoolProcessorEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> PoolProcessorEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequencePoolProcessorEnablers();


    /**
     *  Reorders pool processor enablers for a pool processor by moving the 
     *  specified pool processor enabler in front of a reference pool 
     *  processor enabler. 
     *
     *  @param  poolProcessorEnablerId the <code> Id </code> of a <code> 
     *          PoolProcessorEnabler </code> 
     *  @param  poolProcessorId the <code> Id </code> of a <code> 
     *          PoolProcessor </code> 
     *  @param  referenceId the reference pool processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorEnablerId, 
     *          poolProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> poolProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> poolProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorEnablerId, 
     *          poolProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePoolProcessorEnablerAhead(org.osid.id.Id poolProcessorEnablerId, 
                                              org.osid.id.Id poolProcessorId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders pool processor enablers for a pool processor by moving the 
     *  specified pool processor enabler behind a reference pool processor 
     *  enabler. 
     *
     *  @param  poolProcessorEnablerId the <code> Id </code> of a <code> 
     *          PoolProcessorEnabler </code> 
     *  @param  poolProcessorId the <code> Id </code> of a <code> 
     *          PoolProcessor </code> 
     *  @param  referenceId the reference pool processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorEnablerId, 
     *          poolProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> poolProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> poolProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorEnablerId, 
     *          poolProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePoolProcessorEnablerBehind(org.osid.id.Id poolProcessorEnablerId, 
                                               org.osid.id.Id poolProcessorId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of pool processor enablers for a pool processor. 
     *
     *  @param  poolProcessorEnablerIds the <code> Ids </code> for a set of 
     *          <code> PoolProcessorEnablers </code> 
     *  @param  poolProcessorId the <code> Id </code> of a <code> 
     *          PoolProcessor </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorId </code> not 
     *          found or, a <code> poolProcessorEnablerId </code> not related 
     *          to <code> poolProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorEnablerIds 
     *          </code> or <code> poolProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderPoolProcessorEnablers(org.osid.id.Id[] poolProcessorEnablerIds, 
                                           org.osid.id.Id poolProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
