//
// org.osid.provisioning.rules.PoolProcessorForm
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolProcessorForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This is the form for creating and updating <code> PoolProcessors. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  PoolProcessorAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface PoolProcessorForm
    extends org.osid.OsidProcessorForm {


    /**
     *  Gets the metadata for the allocates by least use flag. 
     *
     *  @return metadata for the allocation flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAllocatesByLeastUseMetadata();


    /**
     *  Sets allocates by least use flag. Seeting this allocation rule may 
     *  disable the other allocation rules. 
     *
     *  @param  allocateByLeastUse <code> true </code> to allocate by least 
     *          use, <code> false </code> otherwise 
     *  @throws org.osid.InvalidArgumentException <code> allocateByLeastUse 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAllocatesByLeastUse(boolean allocateByLeastUse);


    /**
     *  Removes the allocate by least use flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocateByLeastUse();


    /**
     *  Gets the metadata for the allocates by most use flag. 
     *
     *  @return metadata for the allocation flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAllocatesByMostUseMetadata();


    /**
     *  Sets allocates by most use flag. Seeting this allocation rule may 
     *  disable the other allocation rules. 
     *
     *  @param  allocateByMostUse <code> true </code> to allocate by most use, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.InvalidArgumentException <code> allocateByMostUse 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAllocatesByMostUse(boolean allocateByMostUse);


    /**
     *  Removes the allocate by most use flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocateByMostUse();


    /**
     *  Gets the metadata for the allocates by least cost flag. 
     *
     *  @return metadata for the allocation flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAllocatesByLeastCostMetadata();


    /**
     *  Sets allocates by least cost flag. Seeting this allocation rule may 
     *  disable the other allocation rules. 
     *
     *  @param  allocateByLeastCost <code> true </code> to allocate by least 
     *          cost, <code> false </code> otherwise 
     *  @throws org.osid.InvalidArgumentException <code> allocateByLeastCost 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAllocatesByLeastCost(boolean allocateByLeastCost);


    /**
     *  Removes the allocate by least cost flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocateByLeastCost();


    /**
     *  Gets the metadata for the allocates by most cost flag. 
     *
     *  @return metadata for the allocation flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getAllocatesByMostCostMetadata();


    /**
     *  Sets allocates by most cost flag. Seeting this allocation rule may 
     *  disable the other allocation rules. 
     *
     *  @param  allocateByMostCost <code> true </code> to allocate by most 
     *          cost, <code> false </code> otherwise 
     *  @throws org.osid.InvalidArgumentException <code> allocateByMostCost 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setAllocatesByMostCost(boolean allocateByMostCost);


    /**
     *  Removes the allocate by most cost flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocateByMostCost();


    /**
     *  Gets the <code> PoolProcessorFormRecord </code> corresponding to the 
     *  given pool processor record <code> Type. </code> 
     *
     *  @param  poolProcessorRecordType a pool processor record type 
     *  @return the pool processor form record 
     *  @throws org.osid.NullArgumentException <code> poolProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(poolProcessorRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.PoolProcessorFormRecord getPoolProcessorFormRecord(org.osid.type.Type poolProcessorRecordType)
        throws org.osid.OperationFailedException;
}
