//
// org.osid.provisioning.rules.PoolProcessorQuery
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolProcessorQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This is the query for searching pool processors. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface PoolProcessorQuery
    extends org.osid.OsidProcessorQuery {


    /**
     *  Matches pools that allocate by least use. 
     *
     *  @param  match <code> true </code> to match pool allocators that 
     *          allocate by least use, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAllocatesByLeastUse(boolean match);


    /**
     *  Clears the allocate by least use query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocatesByLeastUseTerms();


    /**
     *  Matches pools that allocate by most use. 
     *
     *  @param  match <code> true </code> to match pool allocators that 
     *          allocate by most use, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAllocatesByMostUse(boolean match);


    /**
     *  Clears the allocate by most use query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocatesByMostUseTerms();


    /**
     *  Matches pools that allocate by least cost. 
     *
     *  @param  match <code> true </code> to match pool allocators that 
     *          allocate by least cost, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAllocatesByLeastCost(boolean match);


    /**
     *  Clears the allocate by most cost query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocatesByLeastCostTerms();


    /**
     *  Matches pools that allocate by most cost. 
     *
     *  @param  match <code> true </code> to match pool allocators that 
     *          allocate by most cost, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAllocatesByMostCost(boolean match);


    /**
     *  Clears the allocate by least cost query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAllocatesByMostCostTerms();


    /**
     *  Matches mapped to the pool. 
     *
     *  @param  distributorId the pool <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledPoolId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the pool <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledPoolIdTerms();


    /**
     *  Tests if a <code> PoolQuery </code> is available. 
     *
     *  @return <code> true </code> if a pool query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledPoolQuery();


    /**
     *  Gets the query for a pool. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the pool query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledPoolQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledPoolQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.PoolQuery getRuledPoolQuery();


    /**
     *  Matches mapped to any pool. 
     *
     *  @param  match <code> true </code> for mapped to any pool, <code> false 
     *          </code> to match mapped to no pool 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledPool(boolean match);


    /**
     *  Clears the pool query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledPoolTerms();


    /**
     *  Matches mapped to the distributor. 
     *
     *  @param  distributorId the distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributorId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDistributorQuery();


    /**
     *  Clears the distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorTerms();


    /**
     *  Gets the pool processor query record corresponding to the given <code> 
     *  PoolProcessor </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  poolProcessorRecordType a pool processor record type 
     *  @return the pool processor query record 
     *  @throws org.osid.NullArgumentException <code> poolProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(poolProcessorRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.PoolProcessorQueryRecord getPoolProcessorQueryRecord(org.osid.type.Type poolProcessorRecordType)
        throws org.osid.OperationFailedException;
}
