//
// org.osid.provisioning.rules.PoolProcessorRuleApplicationSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolProcessorRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to apply <code> PoolProcessors </code> to 
 *  <code> Pools. </code> </p>
 */

public interface PoolProcessorRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter pool processor/pool mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignPoolProcessors();


    /**
     *  Adds a existing <code> PoolProcessor </code> to a <code> Pool. </code> 
     *
     *  @param  poolProcessorId the <code> Id </code> of the <code> 
     *          PoolProcessor </code> 
     *  @param  poolId the <code> Id </code> of the <code> Pool </code> 
     *  @throws org.osid.AlreadyExistsException <code> poolProcessorId </code> 
     *          is already applied to <code> poolId </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorId </code> or 
     *          <code> poolId </code> not found 
     *  @throws org.osid.NullArgumentException <code> poolProcessorId </code> 
     *          or <code> poolId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignPoolProcessorToPool(org.osid.id.Id poolProcessorId, 
                                          org.osid.id.Id poolId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> PoolProcessor </code> from a <code> Pool. </code> 
     *
     *  @param  poolProcessorId the <code> Id </code> of the <code> 
     *          PoolProcessor </code> 
     *  @param  poolId the <code> Id </code> of the <code> Pool </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorId </code> or 
     *          <code> poolId </code> not found or <code> poolProcessorId 
     *          </code> not applied to <code> poolId </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorId </code> 
     *          or <code> poolId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignPoolProcessorFromPool(org.osid.id.Id poolProcessorId, 
                                              org.osid.id.Id poolId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> PoolProcessors. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> PoolProcessor </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequencePoolProcessors();


    /**
     *  Reorders pool processors for a pool by moving the specified pool 
     *  processor in front of a reference pool processor. 
     *
     *  @param  poolProcessorId the <code> Id </code> of a <code> 
     *          PoolProcessor </code> 
     *  @param  poolId the <code> Id </code> of a <code> Pool </code> 
     *  @param  referenceId the reference pool processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorId, poolId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          poolProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> poolId </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorId, poolId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePoolProcessorAhead(org.osid.id.Id poolProcessorId, 
                                       org.osid.id.Id poolId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders pool processors for a pool by moving the specified pool 
     *  processor behind a reference pool processor. 
     *
     *  @param  poolProcessorId the <code> Id </code> of a <code> 
     *          PoolProcessor </code> 
     *  @param  poolId the <code> Id </code> of a <code> Pool </code> 
     *  @param  referenceId the reference pool processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorId, poolId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          poolProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> poolId </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorId, poolId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void movePoolProcessorBehind(org.osid.id.Id poolProcessorId, 
                                        org.osid.id.Id poolId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of pool processors for a pool. 
     *
     *  @param  poolProcessorIds the <code> Ids </code> for a set of <code> 
     *          PoolProcessors </code> 
     *  @param  poolId the <code> Id </code> of a <code> Pool </code> 
     *  @throws org.osid.NotFoundException <code> poolId </code> not found or, 
     *          a <code> poolProcessorId </code> not related to <code> poolId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> poolProcessorIds </code> 
     *          or <code> poolId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderPoolProcessors(org.osid.id.Id[] poolProcessorIds, 
                                    org.osid.id.Id poolId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
