//
// org.osid.provisioning.rules.PoolProcessorRuleLookupSession
//
//     The OSID Java specification for org.osid.provisioning.rules.PoolProcessorRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods to retrieve <code> PoolProcessor </code> 
 *  to <code> Pool </code> mappings. <code> </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated distributor view: All methods in this session operate, 
 *      retrieve and pertain pool processor defined explicitly in the current 
 *      distributor </li> 
 *      <li> federated distributor view: All methods in this session operate, 
 *      retrieve and pertain to all pool processor defined in this distributor 
 *      and any other pool processor implicitly available in this distributor 
 *      through distributor inheritence. </li> 
 *  </ul>
 *  
 */

public interface PoolProcessorRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of pool processor/pool 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPoolProcessorRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePoolProcessorRuleView();


    /**
     *  A complete view of the <code> PoolProcessor </code> and <code> Pool 
     *  </code> returns is desired. Methods will return what is requested or 
     *  result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPoolProcessorRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include pool processor in distributors which are children of this 
     *  distributor in the distributor hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedDistributorView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this distributor only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedDistributorView();


    /**
     *  Gets the <code> PoolProcessor Id </code> associated with a <code> 
     *  Pool. </code> 
     *
     *  @param  poolId <code> Id </code> of the <code> Pool </code> 
     *  @return the pool processor <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> poolId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPoolProcessorIdsForPool(org.osid.id.Id poolId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> PoolProcessor </code> associated with a <code> Pool. 
     *  </code> 
     *
     *  @param  poolId <code> Id </code> of the <code> Pool </code> 
     *  @return the pool processors 
     *  @throws org.osid.NotFoundException <code> poolId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.PoolProcessorList getPoolProcessorsForPool(org.osid.id.Id poolId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Pool </code> <code> Ids </code> mapped to a <code> 
     *  PoolProcessor. </code> 
     *
     *  @param  poolProcessorId <code> Id </code> of a <code> PoolProcessor 
     *          </code> 
     *  @return list of pool <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> poolProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> poolProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getPoolIdsForPoolProcessor(org.osid.id.Id poolProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Pools </code> mapped to a <code> PoolProcessor. 
     *  </code> 
     *
     *  @param  poolProcessorId <code> Id </code> of a <code> PoolProcessor 
     *          </code> 
     *  @return list of pools 
     *  @throws org.osid.NotFoundException <code> poolProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> poolProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getPoolsForPoolProcessor(org.osid.id.Id poolProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
