//
// org.osid.provisioning.rules.ProvisioningRulesProfile
//
//     The OSID Java specification for org.osid.provisioning.rules.ProvisioningRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>The provisioning rules profile describes the interoperability among 
 *  provisioning rules services. </p>
 */

public interface ProvisioningRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up queue constrainer is supported. 
     *
     *  @return <code> true </code> if queue constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerLookup();


    /**
     *  Tests if querying queue constrainer is supported. 
     *
     *  @return <code> true </code> if queue constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerQuery();


    /**
     *  Tests if searching queue constrainer is supported. 
     *
     *  @return <code> true </code> if queue constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerSearch();


    /**
     *  Tests if a queue constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if queue constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerAdmin();


    /**
     *  Tests if a queue constrainer notification service is supported. 
     *
     *  @return <code> true </code> if queue constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerNotification();


    /**
     *  Tests if a queue constrainer distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer distributor lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerDistributor();


    /**
     *  Tests if a queue constrainer distributor service is supported. 
     *
     *  @return <code> true </code> if queue constrainer distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerDistributorAssignment();


    /**
     *  Tests if a queue constrainer distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer distributor service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerSmartDistributor();


    /**
     *  Tests if a queue constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerRuleLookup();


    /**
     *  Tests if a queue constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerRuleApplication();


    /**
     *  Tests if looking up queue constrainer enablers is supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerLookup();


    /**
     *  Tests if querying queue constrainer enablers is supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerQuery();


    /**
     *  Tests if searching queue constrainer enablers is supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerSearch();


    /**
     *  Tests if a queue constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerAdmin();


    /**
     *  Tests if a queue constrainer enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerNotification();


    /**
     *  Tests if a queue constrainer enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue constrainer enabler distributor 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerDistributor();


    /**
     *  Tests if a queue constrainer enabler distributor service is supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerDistributorAssignment();


    /**
     *  Tests if a queue constrainer enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue constrainer enabler distributor 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerSmartDistributor();


    /**
     *  Tests if a queue constrainer enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerRuleLookup();


    /**
     *  Tests if a queue constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up queue processor is supported. 
     *
     *  @return <code> true </code> if queue processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorLookup();


    /**
     *  Tests if querying queue processor is supported. 
     *
     *  @return <code> true </code> if queue processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorQuery();


    /**
     *  Tests if searching queue processor is supported. 
     *
     *  @return <code> true </code> if queue processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorSearch();


    /**
     *  Tests if a queue processor administrative service is supported. 
     *
     *  @return <code> true </code> if queue processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorAdmin();


    /**
     *  Tests if a queue processor notification service is supported. 
     *
     *  @return <code> true </code> if queue processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorNotification();


    /**
     *  Tests if a queue processor distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a queue processor distributor lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorDistributor();


    /**
     *  Tests if a queue processor distributor service is supported. 
     *
     *  @return <code> true </code> if queue processor distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorDistributorAssignment();


    /**
     *  Tests if a queue processor distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a queue processor distributor service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorSmartDistributor();


    /**
     *  Tests if a queue processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a queue processor rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorRuleLookup();


    /**
     *  Tests if a queue processor rule application service is supported. 
     *
     *  @return <code> true </code> if queue processor rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorRuleApplication();


    /**
     *  Tests if looking up queue processor enablers is supported. 
     *
     *  @return <code> true </code> if queue processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerLookup();


    /**
     *  Tests if querying queue processor enablers is supported. 
     *
     *  @return <code> true </code> if queue processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerQuery();


    /**
     *  Tests if searching queue processor enablers is supported. 
     *
     *  @return <code> true </code> if queue processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerSearch();


    /**
     *  Tests if a queue processor enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue processor enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerAdmin();


    /**
     *  Tests if a queue processor enabler notification service is supported. 
     *
     *  @return <code> true </code> if queue processor enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerNotification();


    /**
     *  Tests if a queue processor enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue processor enabler distributor 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerDistributor();


    /**
     *  Tests if a queue processor enabler distributor service is supported. 
     *
     *  @return <code> true </code> if queue processor enabler distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerDistributorAssignment();


    /**
     *  Tests if a queue processor enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue processor enabler distributor 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerSmartDistributor();


    /**
     *  Tests if a queue processor enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerRuleLookup();


    /**
     *  Tests if a queue processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue processor enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerRuleApplication();


    /**
     *  Tests if looking up pool constrainer is supported. 
     *
     *  @return <code> true </code> if pool constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerLookup();


    /**
     *  Tests if querying pool constrainer is supported. 
     *
     *  @return <code> true </code> if pool constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerQuery();


    /**
     *  Tests if searching pool constrainer is supported. 
     *
     *  @return <code> true </code> if pool constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerSearch();


    /**
     *  Tests if a pool constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if pool constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerAdmin();


    /**
     *  Tests if a pool constrainer notification service is supported. 
     *
     *  @return <code> true </code> if pool constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerNotification();


    /**
     *  Tests if a pool constrainer distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a pool constrainer distributor lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerDistributor();


    /**
     *  Tests if a pool constrainer distributor service is supported. 
     *
     *  @return <code> true </code> if pool constrainer distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerDistributorAssignment();


    /**
     *  Tests if a pool constrainer distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a pool constrainer distributor service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerSmartDistributor();


    /**
     *  Tests if a pool constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a pool constrainer rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerRuleLookup();


    /**
     *  Tests if a pool constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a pool constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerRuleApplication();


    /**
     *  Tests if looking up pool constrainer enablers is supported. 
     *
     *  @return <code> true </code> if pool constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerLookup();


    /**
     *  Tests if querying pool constrainer enablers is supported. 
     *
     *  @return <code> true </code> if pool constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerQuery();


    /**
     *  Tests if searching pool constrainer enablers is supported. 
     *
     *  @return <code> true </code> if pool constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerSearch();


    /**
     *  Tests if a pool constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if pool constrainer enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerAdmin();


    /**
     *  Tests if a pool constrainer enabler notification service is supported. 
     *
     *  @return <code> true </code> if pool constrainer enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerNotification();


    /**
     *  Tests if a pool constrainer enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a pool constrainer enabler distributor 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerDistributor();


    /**
     *  Tests if a pool constrainer enabler distributor service is supported. 
     *
     *  @return <code> true </code> if pool constrainer enabler distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerDistributorAssignment();


    /**
     *  Tests if a pool constrainer enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a pool constrainer enabler distributor 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerSmartDistributor();


    /**
     *  Tests if a pool constrainer enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a pool constrainer enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerRuleLookup();


    /**
     *  Tests if a pool constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if pool constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up pool processor is supported. 
     *
     *  @return <code> true </code> if pool processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorLookup();


    /**
     *  Tests if querying pool processor is supported. 
     *
     *  @return <code> true </code> if pool processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorQuery();


    /**
     *  Tests if searching pool processor is supported. 
     *
     *  @return <code> true </code> if pool processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorSearch();


    /**
     *  Tests if a pool processor administrative service is supported. 
     *
     *  @return <code> true </code> if pool processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorAdmin();


    /**
     *  Tests if a pool processor notification service is supported. 
     *
     *  @return <code> true </code> if pool processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorNotification();


    /**
     *  Tests if a pool processor distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a pool processor distributor lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorDistributor();


    /**
     *  Tests if a pool processor distributor service is supported. 
     *
     *  @return <code> true </code> if pool processor distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorDistributorAssignment();


    /**
     *  Tests if a pool processor distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a pool processor distributor service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorSmartDistributor();


    /**
     *  Tests if a pool processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a pool processor rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorRuleLookup();


    /**
     *  Tests if a pool processor rule application service is supported. 
     *
     *  @return <code> true </code> if pool processor rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorRuleApplication();


    /**
     *  Tests if looking up pool processor enablers is supported. 
     *
     *  @return <code> true </code> if pool processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerLookup();


    /**
     *  Tests if querying pool processor enablers is supported. 
     *
     *  @return <code> true </code> if pool processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerQuery();


    /**
     *  Tests if searching pool processor enablers is supported. 
     *
     *  @return <code> true </code> if pool processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerSearch();


    /**
     *  Tests if a pool processor enabler administrative service is supported. 
     *
     *  @return <code> true </code> if pool processor enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerAdmin();


    /**
     *  Tests if a pool processor enabler notification service is supported. 
     *
     *  @return <code> true </code> if pool processor enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerNotification();


    /**
     *  Tests if a pool processor enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a pool processor enabler distributor 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerDistributor();


    /**
     *  Tests if a pool processor enabler distributor service is supported. 
     *
     *  @return <code> true </code> if pool processor enabler distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerDistributorAssignment();


    /**
     *  Tests if a pool processor enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a pool processor enabler distributor 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerSmartDistributor();


    /**
     *  Tests if a pool processor enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a processor enabler rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerRuleLookup();


    /**
     *  Tests if a pool processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if pool processor enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerRuleApplication();


    /**
     *  Tests if looking up broker constrainer is supported. 
     *
     *  @return <code> true </code> if broker constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerLookup();


    /**
     *  Tests if querying broker constrainer is supported. 
     *
     *  @return <code> true </code> if broker constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerQuery();


    /**
     *  Tests if searching broker constrainer is supported. 
     *
     *  @return <code> true </code> if broker constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerSearch();


    /**
     *  Tests if a broker constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if broker constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerAdmin();


    /**
     *  Tests if a broker constrainer notification service is supported. 
     *
     *  @return <code> true </code> if broker constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerNotification();


    /**
     *  Tests if a broker constrainer distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a broker constrainer distributor lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerDistributor();


    /**
     *  Tests if a broker constrainer distributor service is supported. 
     *
     *  @return <code> true </code> if broker constrainer distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerDistributorAssignment();


    /**
     *  Tests if a broker constrainer distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a broker constrainer distributor 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerSmartDistributor();


    /**
     *  Tests if a broker constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a broker constrainer rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerRuleLookup();


    /**
     *  Tests if a broker constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a broker constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerRuleApplication();


    /**
     *  Tests if looking up broker constrainer enablers is supported. 
     *
     *  @return <code> true </code> if broker constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerLookup();


    /**
     *  Tests if querying broker constrainer enablers is supported. 
     *
     *  @return <code> true </code> if broker constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerQuery();


    /**
     *  Tests if searching broker constrainer enablers is supported. 
     *
     *  @return <code> true </code> if broker constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerSearch();


    /**
     *  Tests if a broker constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if broker constrainer enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerAdmin();


    /**
     *  Tests if a broker constrainer enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if broker constrainer enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerNotification();


    /**
     *  Tests if a broker constrainer enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a broker constrainer enabler 
     *          distributor lookup service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerDistributor();


    /**
     *  Tests if a broker constrainer enabler distributor service is 
     *  supported. 
     *
     *  @return <code> true </code> if broker constrainer enabler distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerDistributorAssignment();


    /**
     *  Tests if a broker constrainer enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a broker constrainer enabler 
     *          distributor service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerSmartDistributor();


    /**
     *  Tests if a broker constrainer enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a broker constrainer enabler rule 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerRuleLookup();


    /**
     *  Tests if a broker constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if broker constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up broker processor is supported. 
     *
     *  @return <code> true </code> if broker processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorLookup();


    /**
     *  Tests if querying broker processor is supported. 
     *
     *  @return <code> true </code> if broker processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorQuery();


    /**
     *  Tests if searching broker processor is supported. 
     *
     *  @return <code> true </code> if broker processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorSearch();


    /**
     *  Tests if a broker processor administrative service is supported. 
     *
     *  @return <code> true </code> if broker processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorAdmin();


    /**
     *  Tests if a broker processor notification service is supported. 
     *
     *  @return <code> true </code> if broker processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorNotification();


    /**
     *  Tests if a broker processor distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a broker processor distributor lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorDistributor();


    /**
     *  Tests if a broker processor distributor service is supported. 
     *
     *  @return <code> true </code> if broker processor distributor assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorDistributorAssignment();


    /**
     *  Tests if a broker processor distributor lookup service is supported. 
     *
     *  @return <code> true </code> if a broker processor distributor service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorSmartDistributor();


    /**
     *  Tests if a broker processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a broker processor rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorRuleLookup();


    /**
     *  Tests if a broker processor rule application service is supported. 
     *
     *  @return <code> true </code> if broker processor rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorRuleApplication();


    /**
     *  Tests if looking up broker processor enablers is supported. 
     *
     *  @return <code> true </code> if broker processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerLookup();


    /**
     *  Tests if querying broker processor enablers is supported. 
     *
     *  @return <code> true </code> if broker processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerQuery();


    /**
     *  Tests if searching broker processor enablers is supported. 
     *
     *  @return <code> true </code> if broker processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerSearch();


    /**
     *  Tests if a broker processor enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if broker processor enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerAdmin();


    /**
     *  Tests if a broker processor enabler notification service is supported. 
     *
     *  @return <code> true </code> if broker processor enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerNotification();


    /**
     *  Tests if a broker processor enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a broker processor enabler distributor 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerDistributor();


    /**
     *  Tests if a broker processor enabler distributor service is supported. 
     *
     *  @return <code> true </code> if broker processor enabler distributor 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerDistributorAssignment();


    /**
     *  Tests if a broker processor enabler distributor lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a broker processor enabler distributor 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerSmartDistributor();


    /**
     *  Tests if a broker processor enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerRuleLookup();


    /**
     *  Tests if a broker processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if broker processor enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerRuleApplication();


    /**
     *  Gets the supported <code> QueueConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> QueueConstrainer 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  queueConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> QueueConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerRecordType(org.osid.type.Type queueConstrainerRecordType);


    /**
     *  Gets the supported <code> QueueConstrainer </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> QueueConstrainer 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainer </code> search record type 
     *  is supported. 
     *
     *  @param  queueConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueConstrainer </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerSearchRecordType(org.osid.type.Type queueConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> QueueConstrainerEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> QueueConstrainerEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainerEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  queueConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> QueueConstrainerEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerRecordType(org.osid.type.Type queueConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> QueueConstrainerEnabler </code> search 
     *  record interface types. 
     *
     *  @return a list containing the supported <code> QueueConstrainerEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainerEnabler </code> search 
     *  record interface type is supported. 
     *
     *  @param  queueConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerSearchRecordType(org.osid.type.Type queueConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> QueueProcessor </code> record interface 
     *  types. 
     *
     *  @return a list containing the supported <code> QueueProcessor </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessor </code> record interface type 
     *  is supported. 
     *
     *  @param  queueProcessorRecordType a <code> Type </code> indicating a 
     *          <code> QueueProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> queueProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorRecordType(org.osid.type.Type queueProcessorRecordType);


    /**
     *  Gets the supported <code> QueueProcessor </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> QueueProcessor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessor </code> search record 
     *  interface type is supported. 
     *
     *  @param  queueProcessorSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueProcessor </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorSearchRecordType(org.osid.type.Type queueProcessorSearchRecordType);


    /**
     *  Gets the supported <code> QueueProcessorEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> QueueProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessorEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  queueProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> QueueProcessorEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerRecordType(org.osid.type.Type queueProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> QueueProcessorEnabler </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> QueueProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessorEnabler </code> search record 
     *  interface type is supported. 
     *
     *  @param  queueProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueProcessorEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerSearchRecordType(org.osid.type.Type queueProcessorEnablerSearchRecordType);


    /**
     *  Gets the supported <code> PoolConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> PoolConstrainer </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolConstrainerRecordTypes();


    /**
     *  Tests if the given <code> PoolConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  poolConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> PoolConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerRecordType(org.osid.type.Type poolConstrainerRecordType);


    /**
     *  Gets the supported <code> PoolConstrainer </code> search record types. 
     *
     *  @return a list containing the supported <code> PoolConstrainer </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> PoolConstrainer </code> search record type 
     *  is supported. 
     *
     *  @param  poolConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> PoolConstrainer </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerSearchRecordType(org.osid.type.Type poolConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> PoolConstrainerEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> PoolConstrainerEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> PoolConstrainerEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  poolConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> PoolConstrainerEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerRecordType(org.osid.type.Type poolConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> PoolConstrainerEnabler </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> PoolConstrainerEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> PoolConstrainerEnabler </code> search record 
     *  interface type is supported. 
     *
     *  @param  poolConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> PoolConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolConstrainerEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolConstrainerEnablerSearchRecordType(org.osid.type.Type poolConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> PoolProcessor </code> record interface 
     *  types. 
     *
     *  @return a list containing the supported <code> PoolProcessor </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolProcessorRecordTypes();


    /**
     *  Tests if the given <code> PoolProcessor </code> record interface type 
     *  is supported. 
     *
     *  @param  poolProcessorRecordType a <code> Type </code> indicating a 
     *          <code> PoolProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> poolProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorRecordType(org.osid.type.Type poolProcessorRecordType);


    /**
     *  Gets the supported <code> PoolProcessor </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> PoolProcessor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> PoolProcessor </code> search record 
     *  interface type is supported. 
     *
     *  @param  poolProcessorSearchRecordType a <code> Type </code> indicating 
     *          a <code> PoolProcessor </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolProcessorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorSearchRecordType(org.osid.type.Type poolProcessorSearchRecordType);


    /**
     *  Gets the supported <code> PoolProcessorEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> PoolProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> PoolProcessorEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  poolProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> PoolProcessorEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolProcessorEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerRecordType(org.osid.type.Type poolProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> PoolProcessorEnabler </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> PoolProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getPoolProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> PoolProcessorEnabler </code> search record 
     *  interface type is supported. 
     *
     *  @param  poolProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> PoolProcessorEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          poolProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPoolProcessorEnablerSearchRecordType(org.osid.type.Type poolProcessorEnablerSearchRecordType);


    /**
     *  Gets the supported <code> BrokerConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> BrokerConstrainer 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerConstrainerRecordTypes();


    /**
     *  Tests if the given <code> BrokerConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  brokerConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> BrokerConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerRecordType(org.osid.type.Type brokerConstrainerRecordType);


    /**
     *  Gets the supported <code> BrokerConstrainer </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> BrokerConstrainer 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> BrokerConstrainer </code> search record type 
     *  is supported. 
     *
     *  @param  brokerConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> BrokerConstrainer </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerSearchRecordType(org.osid.type.Type brokerConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> BrokerConstrainerEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> 
     *          BrokerConstrainerEnabler </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> BrokerConstrainerEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  brokerConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> BrokerConstrainerEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerRecordType(org.osid.type.Type brokerConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> BrokerConstrainerEnabler </code> search 
     *  record interface types. 
     *
     *  @return a list containing the supported <code> 
     *          BrokerConstrainerEnabler </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> BrokerConstrainerEnabler </code> search 
     *  record interface type is supported. 
     *
     *  @param  brokerConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> BrokerConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerConstrainerEnablerSearchRecordType </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerConstrainerEnablerSearchRecordType(org.osid.type.Type brokerConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> BrokerProcessor </code> record interface 
     *  types. 
     *
     *  @return a list containing the supported <code> BrokerProcessor </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerProcessorRecordTypes();


    /**
     *  Tests if the given <code> BrokerProcessor </code> record interface 
     *  type is supported. 
     *
     *  @param  brokerProcessorRecordType a <code> Type </code> indicating a 
     *          <code> BrokerProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorRecordType(org.osid.type.Type brokerProcessorRecordType);


    /**
     *  Gets the supported <code> BrokerProcessor </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> BrokerProcessor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> BrokerProcessor </code> search record 
     *  interface type is supported. 
     *
     *  @param  brokerProcessorSearchRecordType a <code> Type </code> 
     *          indicating a <code> BrokerProcessor </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorSearchRecordType(org.osid.type.Type brokerProcessorSearchRecordType);


    /**
     *  Gets the supported <code> BrokerProcessorEnabler </code> record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> BrokerProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> BrokerProcessorEnabler </code> record 
     *  interface type is supported. 
     *
     *  @param  brokerProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> BrokerProcessorEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerRecordType(org.osid.type.Type brokerProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> BrokerProcessorEnabler </code> search record 
     *  interface types. 
     *
     *  @return a list containing the supported <code> BrokerProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBrokerProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> BrokerProcessorEnabler </code> search record 
     *  interface type is supported. 
     *
     *  @param  brokerProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> BrokerProcessorEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          brokerProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBrokerProcessorEnablerSearchRecordType(org.osid.type.Type brokerProcessorEnablerSearchRecordType);
}
