//
// org.osid.provisioning.rules.QueueConstrainer
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueConstrainer.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>A <code> QueueConstrainer </code> describes the rules for constraining 
 *  the provisioning requests in a queue. </p>
 */

public interface QueueConstrainer
    extends org.osid.OsidConstrainer {


    /**
     *  Tests if this queue limits the number of requests. 
     *
     *  @return <code> true </code> if a queue size limit is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasSizeLimit();


    /**
     *  Gets the size limit of the queue. 
     *
     *  @return the size limit 
     *  @throws org.osid.IllegalStateException <code> hasSizeLimit() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getSizeLimit();


    /**
     *  Tests if a provision must exist before entering this queue. 
     *
     *  @return <code> true </code> if a provision is required, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean requiresProvisions();


    /**
     *  Gets the pool <code> Ids </code> for the required provisions. 
     *
     *  @return the <code> Ids </code> of the pools 
     *  @throws org.osid.IllegalStateException <code> requiresProvisions() 
     *          </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRequiredProvisionPoolIds();


    /**
     *  Gets the pools for the required provisions. 
     *
     *  @return the pools 
     *  @throws org.osid.IllegalStateException <code> requiresProvisions() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.PoolList getRequiredProvisionPools()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the queue constrainer record corresponding to the given <code> 
     *  QueueConstrainer </code> record <code> Type. </code> This method is 
     *  used to retrieve an object implementing the requested record. The 
     *  <code> queueConstrainerRecordType </code> may be the <code> Type 
     *  </code> returned in <code> getRecordTypes() </code> or any of its 
     *  parents in a <code> Type </code> hierarchy where <code> 
     *  hasRecordType(queueConstrainerRecordType) </code> is <code> true 
     *  </code> . 
     *
     *  @param  queueConstrainerRecordType the type of queue constrainer 
     *          record to retrieve 
     *  @return the queue constrainer record 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(queueConstrainerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.QueueConstrainerRecord getQueueConstrainerRecord(org.osid.type.Type queueConstrainerRecordType)
        throws org.osid.OperationFailedException;
}
