//
// org.osid.provisioning.rules.QueueConstrainerAdminSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueConstrainerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session creates and removes queue constrainers. The data for 
 *  create and update is provided via the <code> QueueConstrainerForm. </code> 
 *  </p>
 */

public interface QueueConstrainerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Distributor </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Distributor Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDistributorId();


    /**
     *  Gets the <code> Distributor </code> associated with this session. 
     *
     *  @return the distributor 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.Distributor getDistributor()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create queue constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> QueueConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueConstrainer </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQueueConstrainer();


    /**
     *  Tests if this user can create a single <code> QueueConstrainer </code> 
     *  using the desired record types. While <code> 
     *  ProvisioningRulesManager.getQueueConstrainerRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  QueueConstrainer. </code> Providing an empty array tests if a <code> 
     *  QueueConstrainer </code> can be created with no records. 
     *
     *  @param  queueConstrainerRecordTypes array of queue constrainer record 
     *          types 
     *  @return <code> true </code> if <code> QueueConstrainer </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateQueueConstrainerWithRecordTypes(org.osid.type.Type[] queueConstrainerRecordTypes);


    /**
     *  Gets the queue constrainer form for creating new queue constrainers. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  queueConstrainerRecordTypes array of queue constrainer record 
     *          types 
     *  @return the queue constrainer form 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerForm getQueueConstrainerFormForCreate(org.osid.type.Type[] queueConstrainerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> QueueConstrainer. </code> 
     *
     *  @param  queueConstrainerForm the form for this <code> QueueConstrainer 
     *          </code> 
     *  @return the new <code> QueueConstrainer </code> 
     *  @throws org.osid.IllegalStateException <code> queueConstrainerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueConstrainerForm 
     *          </code> did not originate from <code> 
     *          getQueueConstrainerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainer createQueueConstrainer(org.osid.provisioning.rules.QueueConstrainerForm queueConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update queue constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> QueueConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueConstrainer </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateQueueConstrainers();


    /**
     *  Gets the queue constrainer form for updating an existing queue 
     *  constrainer. A new queue constrainer form should be requested for each 
     *  update transaction. 
     *
     *  @param  queueConstrainerId the <code> Id </code> of the <code> 
     *          QueueConstrainer </code> 
     *  @return the queue constrainer form 
     *  @throws org.osid.NotFoundException <code> queueConstrainerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerForm getQueueConstrainerFormForUpdate(org.osid.id.Id queueConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing queue constrainer. 
     *
     *  @param  queueConstrainerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> queueConstrainerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueConstrainerForm 
     *          </code> did not originate from <code> 
     *          getQueueConstrainerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateQueueConstrainer(org.osid.provisioning.rules.QueueConstrainerForm queueConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete queue constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> QueueConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueConstrainer </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteQueueConstrainers();


    /**
     *  Deletes a <code> QueueConstrainer. </code> 
     *
     *  @param  queueConstrainerId the <code> Id </code> of the <code> 
     *          QueueConstrainer </code> to remove 
     *  @throws org.osid.NotFoundException <code> queueConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteQueueConstrainer(org.osid.id.Id queueConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for queue 
     *  constrainers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueConstrainer </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageQueueConstrainerAliases();


    /**
     *  Adds a <code> Id </code> to a <code> QueueConstrainer </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> QueueConstrainer </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another queue constrainer. it 
     *  is reassigned to the given queue constrainer <code> Id. </code> 
     *
     *  @param  queueConstrainerId the <code> Id </code> of a <code> 
     *          QueueConstrainer </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> queueConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasQueueConstrainer(org.osid.id.Id queueConstrainerId, 
                                      org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
