//
// org.osid.provisioning.rules.QueueConstrainerQuery
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueConstrainerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This is the query for searching queue constrainers. Each method match 
 *  specifies a <code> AND </code> term while multiple invocations of the same 
 *  method produce a nested <code> OR. </code> </p>
 */

public interface QueueConstrainerQuery
    extends org.osid.OsidConstrainerQuery {


    /**
     *  Matches queues of the given size limit inclusive. 
     *
     *  @param  start start of range 
     *  @param  end end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSizeLimit(long start, long end, boolean match);


    /**
     *  Matches queues with any known size limit. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySizeLimit(boolean match);


    /**
     *  Clears the size limit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSizeLimitTerms();


    /**
     *  Matches constraints that require provisions. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequiresProvisions(boolean match);


    /**
     *  Clears the requires provisions query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiresProvisionsTerms();


    /**
     *  Sets the required provision pool <code> Id </code> for this query. 
     *
     *  @param  poolId a pool <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> poolId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRequiredProvisionPoolId(org.osid.id.Id poolId, 
                                             boolean match);


    /**
     *  Clears the required provision pool <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiredProvisionPoolIdTerms();


    /**
     *  Tests if a <code> PoolQuery </code> is available. 
     *
     *  @return <code> true </code> if a required provision pool query is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequiredProvisionPoolQuery();


    /**
     *  Gets the query for a <code> Pool. </code> Multiple retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @return the required provision pool query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRequiredProvisionPoolQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRequiredProvisionPoolQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.provisioning.PoolQuery getRequiredProvisionPoolQuery();


    /**
     *  Matches queues that have any required provision pool. 
     *
     *  @param  match <code> true </code> to match queues with any required 
     *          provision pool, <code> false </code> to match queues with no 
     *          required provision pool 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRequiredProvisionPool(boolean match);


    /**
     *  Clears the required provision pool query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRequiredProvisionPoolTerms();


    /**
     *  Matches mapped to a queue. 
     *
     *  @param  queueId the queue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledQueueId(org.osid.id.Id queueId, boolean match);


    /**
     *  Clears the queue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledQueueIdTerms();


    /**
     *  Tests if a <code> QueueQuery </code> is available. 
     *
     *  @return <code> true </code> if a queue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledQueueQuery();


    /**
     *  Gets the query for a queue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the queue query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledQueueQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledQueueQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.QueueQuery getRuledQueueQuery();


    /**
     *  Matches mapped to any queue. 
     *
     *  @param  match <code> true </code> for mapped to any queue, <code> 
     *          false </code> to match mapped to no queues 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledQueue(boolean match);


    /**
     *  Clears the queue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledQueueTerms();


    /**
     *  Matches mapped to the distributor. 
     *
     *  @param  distributorId the distributor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> distributorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributorId(org.osid.id.Id distributorId, boolean match);


    /**
     *  Clears the distributor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorIdTerms();


    /**
     *  Tests if a <code> DistributorQuery </code> is available. 
     *
     *  @return <code> true </code> if a distributor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDistributorQuery();


    /**
     *  Gets the query for a distributor. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the distributor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDistributorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDistributorQuery() </code> is <code> true. </code> 
     */

    public org.osid.provisioning.DistributorQuery getDistributorQuery();


    /**
     *  Clears the distributor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributorTerms();


    /**
     *  Gets the queue constrainer query record corresponding to the given 
     *  <code> QueueConstrainer </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  queueConstrainerRecordType a queue constrainer record type 
     *  @return the queue constrainer query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(queueConstrainerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.records.QueueConstrainerQueryRecord getQueueConstrainerQueryRecord(org.osid.type.Type queueConstrainerRecordType)
        throws org.osid.OperationFailedException;
}
