//
// org.osid.provisioning.rules.QueueConstrainerSearchSession
//
//     The OSID Java specification for org.osid.provisioning.rules.QueueConstrainerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.provisioning.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  QueueConstrainer </code> objects. The search query is constructed using 
 *  the <code> QueueConstraineryQuery. </code> </p> 
 *  
 *  <p> <code> getQueueConstrainersByQuery() </code> is the basic search 
 *  method and returns a list of <code> QueueConstrainers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getQueueConstrainersBySearch(). </code> It accepts a <code> 
 *  QueueConstrainerSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  provisioning. <code> getQueueConstrainersBySearch() </code> returns a 
 *  <code> QueueConstrainerSearchResults </code> that can be used to access 
 *  the resulting <code> QueueConstrainerList </code> or be used to perform a 
 *  search within the result set through <code> QueueConstrainerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated distributor view: searches include queue constrainer in 
 *      distributors of which this distributor is an ancestor in the 
 *      distributor hierarchy </li> 
 *      <li> isolated distributor view: searches are restricted to queue 
 *      constrainer in this distributor </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> QueueConstrainers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  QueueConstrainerQuery. </code> </p>
 */

public interface QueueConstrainerSearchSession
    extends org.osid.provisioning.rules.QueueConstrainerQuerySession {


    /**
     *  Gets a queue constrainer search. 
     *
     *  @return the queue constrainer search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerSearch getQueueConstrainerSearch();


    /**
     *  Gets a queue constrainer search order. The <code> 
     *  QueueConstrainerSearchOrder </code> is supplied to a <code> 
     *  QueueConstrainerSearch </code> to specify the ordering of results. 
     *
     *  @return the queue constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerSearchOrder getQueueConstrainerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  queueConstrainerQuery the queue constrainer query 
     *  @param  queueConstrainerSearch the queue constrainer search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> queueConstrainerQuery 
     *          </code> or <code> queueConstrainerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> queueConstrainerQuery 
     *          </code> or <code> queueConstrainerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerSearchResults getQueueConstrainersBySearch(org.osid.provisioning.rules.QueueConstrainerQuery queueConstrainerQuery, 
                                                                                                  org.osid.provisioning.rules.QueueConstrainerSearch queueConstrainerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a queue constrainer query from an inspector. The inspector is 
     *  available from a <code> QueueConstrainerSearchResults. </code> 
     *
     *  @param  queueConstrainerQueryInspector a queue constrainer query 
     *          inspector 
     *  @return the queue constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueConstrainerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.provisioning.rules.QueueConstrainerQuery getQueueConstrainerQueryFromInspector(org.osid.provisioning.rules.QueueConstrainerQueryInspector queueConstrainerQueryInspector);
}
