//
// org.osid.proxy.ProxyCondition
//
//     The OSID Java specification for org.osid.proxy.ProxyCondition.
//
// Copyright (C) 2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.proxy;


/**
 *  <p>A <code> ProxyCondition </code> is used to transfer external 
 *  information into a proxy. </p>
 */

public interface ProxyCondition
    extends org.osid.OsidCondition {


    /**
     *  Sets the effective agent <code> Id </code> to indicate acting on 
     *  behalf of. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> agentId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEffectiveAgentId(org.osid.id.Id agentId);


    /**
     *  Sets the effective date. 
     *
     *  @param  date a date 
     *  @param  rate the rate at which the clock should tick from the given 
     *          effective date. 0 is a clock that is fixed 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setEffectiveDate(java.util.Date date, 
                                 java.math.BigDecimal rate);


    /**
     *  Sets the language type. 
     *
     *  @param  languageType the language type 
     *  @throws org.osid.NullArgumentException <code> languageType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setLanguageType(org.osid.type.Type languageType);


    /**
     *  Sets the script type. 
     *
     *  @param  scriptType the script type 
     *  @throws org.osid.NullArgumentException <code> scriptType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setScriptType(org.osid.type.Type scriptType);


    /**
     *  Sets the calendar type. 
     *
     *  @param  calendarType the calendar type 
     *  @throws org.osid.NullArgumentException <code> calendarType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCalendarType(org.osid.type.Type calendarType);


    /**
     *  Sets the time type. 
     *
     *  @param  timeType the time type 
     *  @throws org.osid.NullArgumentException <code> timeType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setTimeType(org.osid.type.Type timeType);


    /**
     *  Sets the currency type. 
     *
     *  @param  currencyType the currency type 
     *  @throws org.osid.NullArgumentException <code> currencyType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCurrencyType(org.osid.type.Type currencyType);


    /**
     *  Sets the unit system type. 
     *
     *  @param  unitSystemType the unit system type 
     *  @throws org.osid.NullArgumentException <code> unitSystemType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setUnitSystemType(org.osid.type.Type unitSystemType);


    /**
     *  Sets the <code> DisplayText </code> format type. 
     *
     *  @param  formatType the format type 
     *  @throws org.osid.NullArgumentException <code> formatType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setFormatType(org.osid.type.Type formatType);


    /**
     *  Gets the proxy condition record corresponding to the given <code> 
     *  Proxy </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  proxyRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(proxyRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  proxyConditionType the type of proxy condition record to 
     *          retrieve 
     *  @return the proxy condition record 
     *  @throws org.osid.NullArgumentException <code> proxyConditionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(proxyConditionRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.proxy.records.ProxyConditionRecord getProxyConditionRecord(org.osid.type.Type proxyConditionType)
        throws org.osid.OperationFailedException;
}
