/**
 * <p>The Open Service Interface Definitions for the org.osid.proxy
 * service.</p>
 * 
 * <p>The Proxy OSID helps a consumer map external data, such as that received 
 * via a server request, into a Proxy that can be used with OSID proxy 
 * managers. Then purpose of this OSID is to modularize assumptions made about 
 * the input data into another OSID Provider, such as the authentication or 
 * localization information. </p> 
 * 
 * <p> The <code> Proxy </code> represents the <code> OsidResult </code> of an 
 * evaluation of the input <code> OsidCondition </code> performed by the Proxy 
 * OSID Provider. The resulting Proxy is meant to be passed to <code> 
 * OsidProxyManagers. </code> The Proxy OSID is the glue between the 
 * application server environment and the OSID services. </p> 
 * 
 * <p> The input data may be anything acceptable to a <code> ProxyCondition 
 * </code> record Type. The <code> ProxyCondition </code> record <code> Types 
 * </code> are aligned with the application server environment while the 
 * <code> Proxy </code> record <code> Types </code> are aligned with OSID 
 * Providers. This alignment poses various interoperability issues and as such 
 * it might be helpful to be very broad in what may be specified in a <code> 
 * ProxyCondition </code> so that this service may produce the variety of 
 * <code> Proxy </code> records needed by the services in the OSID 
 * environment. </p> 
 * 
 * <p> Some data is defined in the <code> ProxyCondition. </code> This in no 
 * way implies support of this input by an OSID Provider. The resulting <code> 
 * OsidSession </code> indicates what actually happened. </p> 
 * <h4> Example </h4> 
 * 
 * <p> An example using a specifier record for an http request: </p> 
 * 
 * <pre>
 *      
 *      
 *      ProxyCondition condition = proxySession.getProxyCondition();
 *      HttpRequestRecord record = condition.getProxyConditionRecord(httpRequestRecordType);
 *      record.setHttpRequest(servletRequest);
 *      
 *      Proxy proxy = proxySession.getProxy(condition);
 *      
 *              
 *      
 * </pre>
 * 
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2008 Massachusetts Institute of Technology. </p> 
 * 
 * <p> Copyright &copy; 2010 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.proxy;
