//
// org.osid.recipe.CookbookQueryInspector
//
//     The OSID Java specification for org.osid.recipe.CookbookQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This is the query inspector for searching for cook books. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface CookbookQueryInspector
    extends org.osid.OsidCatalogQueryInspector {


    /**
     *  Gets the recipe <code> Id </code> terms. 
     *
     *  @return the recipe <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getRecipeIdTerms();


    /**
     *  Gets the recipe terms. 
     *
     *  @return the recipe terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeQueryInspector[] getRecipeTerms();


    /**
     *  Gets the procedure <code> Id </code> terms. 
     *
     *  @return the procedure <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getProcedureIdTerms();


    /**
     *  Gets the procedure terms. 
     *
     *  @return the procedure terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureQueryInspector[] getProcedureTerms();


    /**
     *  Gets the direction <code> Id </code> terms. 
     *
     *  @return the direction <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDirectionIdTerms();


    /**
     *  Gets the direction terms. 
     *
     *  @return the direction terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionQueryInspector[] getDirectionTerms();


    /**
     *  Gets the ancestor cook book <code> Id </code> terms. 
     *
     *  @return the ancestor cook book <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getAncestorCookbookIdTerms();


    /**
     *  Gets the ancestor cook book terms. 
     *
     *  @return the ancestor cook book terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.CookbookQueryInspector[] getAncestorCookbookTerms();


    /**
     *  Gets the descendant cook book <code> Id </code> terms. 
     *
     *  @return the descendant cook book <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDescendantCookbookIdTerms();


    /**
     *  Gets the descendant cook book terms. 
     *
     *  @return the descendant cook book terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.CookbookQueryInspector[] getDescendantCookbookTerms();


    /**
     *  Gets the query inspector record corresponding to the given <code> 
     *  Cookbook </code> record <code> Type. </code> 
     *
     *  @param  cookbookRecordType a cook book record type 
     *  @return the cook book query inspector record 
     *  @throws org.osid.NullArgumentException <code> cookbookRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(cookbookRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.records.CookbookQueryInspectorRecord getCookbookQueryInspectorRecord(org.osid.type.Type cookbookRecordType)
        throws org.osid.OperationFailedException;
}
