//
// org.osid.recipe.CookbookSearchSession
//
//     The OSID Java specification for org.osid.recipe.CookbookSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session provides methods for searching <code> Cookbook </code> 
 *  objects. The search query is constructed using the <code> CookbookQuery. 
 *  </code> The cook book record <code> Type </code> also specifies the record 
 *  for the cook book query. </p> 
 *  
 *  <p> <code> getCookbooksByQuery() </code> is the basic search method and 
 *  returns a list of <code> Cookbook </code> elements. A more advanced search 
 *  may be performed with <code> getCookbooksBySearch(). </code> It accepts an 
 *  <code> CookbookSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCookbooksBySearch() </code> returns an <code> 
 *  CookbookSearchResults </code> that can be used to access the resulting 
 *  <code> CookbookList </code> or be used to perform a search within the 
 *  result set through <code> CookbookSearch. </code> </p> 
 *  
 *  <p> Cookbooks may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> CookbookQuery. </code> 
 *  The returns in this session may not be cast directly to these interfaces. 
 *  </p>
 */

public interface CookbookSearchSession
    extends org.osid.recipe.CookbookQuerySession {


    /**
     *  Gets a cook book search. 
     *
     *  @return the cook book search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.CookbookSearch getCookbookSearch();


    /**
     *  Gets a cook book search order. The <code> CookbookSearchOrder </code> 
     *  is supplied to an <code> CookbookSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the cook book search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.CookbookSearchOrder getCookbookSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  cookbookQuery the cook book query 
     *  @param  cookbookSearch the cook book search 
     *  @return the cook book search results 
     *  @throws org.osid.NullArgumentException <code> cookbookQuery </code> or 
     *          <code> cook books earch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> cookbookQuery </code> or 
     *          <code> cook books earch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.CookbookSearchResults getCookbooksBySearch(org.osid.recipe.CookbookQuery cookbookQuery, 
                                                                      org.osid.recipe.CookbookSearch cookbookSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a cook book query from an inspector. The inspector is available 
     *  from an <code> CookbookSearchResults. </code> 
     *
     *  @param  cookbookQueryInspector a cook book query inspector 
     *  @return the cook book query 
     *  @throws org.osid.NullArgumentException <code> cookbookQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> cookbookQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.CookbookQuery getCookbookQueryFromInspector(org.osid.recipe.CookbookQueryInspector cookbookQueryInspector);
}
