//
// org.osid.recipe.Direction
//
//     The OSID Java specification for org.osid.recipe.Direction.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>A <code> Direction </code> is an instruction. </p>
 */

public interface Direction
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Id </code> of the recipe. 
     *
     *  @return the recipe <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRecipeId();


    /**
     *  Gets the recipe. 
     *
     *  @return the recipe 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Recipe getRecipe()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Ids </code> of the procedure to execute in this 
     *  direction. 
     *
     *  @return the procedure <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getProcedureIds();


    /**
     *  Gets the procedures to execute in this direction. 
     *
     *  @return the procedures 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureList getProcedures()
        throws org.osid.OperationFailedException;


    /**
     *  Gets any ingredient <code> Ids </code> . 
     *
     *  @return the ingredient <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIngredientIds();


    /**
     *  Gets the required ingredients. 
     *
     *  @return the ingredients 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.IngredientList getIngredients()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the estimated time required for this direction. 
     *
     *  @return the estimated duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.Duration getEstimatedDuration();


    /**
     *  Gets any asset <code> Ids </code> to assist in carrying out this 
     *  direction. 
     *
     *  @return the asset <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssetIds();


    /**
     *  Gets any assets to assist in carrying out this direction. 
     *
     *  @return the assets 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.AssetList getAssets()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the direction record corresponding to the given <code> Direction 
     *  </code> record <code> Type. </code> This method is used to retrieve an 
     *  object implementing the requested record. The <code> 
     *  directionRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(directionRecordType) 
     *  </code> is <code> true </code> . 
     *
     *  @param  directionRecordType the type of direction record to retrieve 
     *  @return the direction record 
     *  @throws org.osid.NullArgumentException <code> directionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(directionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.records.DirectionRecord getDirectionRecord(org.osid.type.Type directionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
