//
// org.osid.recipe.DirectionAdminSession
//
//     The OSID Java specification for org.osid.recipe.DirectionAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session creates, updates, and deletes <code> Directions. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Direction, </code> a <code> DirectionForm </code> is requested using 
 *  <code> getDirectionFormForCreate() </code> specifying the desired recipe 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. The returned <code> DirectionForm </code> will indicate that 
 *  it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> DirectionForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> DirectionForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> DirectionForms </code> are requested to the <code> 
 *  Direction </code> <code> Id </code> that is to be updated using <code> 
 *  getDirectionFormForUpdate(). </code> Similarly, the <code> DirectionForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> DirectionForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Directions. </code> To unmap a 
 *  <code> Direction </code> from the current <code> Cookbook, </code> the 
 *  <code> DirectionCookbookAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Direction </code> itself 
 *  thus removing it from all known <code> Cookbook </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface DirectionAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Directions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Direction </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Direction </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDirections();


    /**
     *  Tests if this user can create a single <code> Direction </code> using 
     *  the desired record types. While <code> 
     *  RecipeManager.getDirectionRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Direction. </code> Providing 
     *  an empty array tests if a <code> Direction </code> can be created with 
     *  no records. 
     *
     *  @param  directionRecordTypes array of direction record types 
     *  @return <code> true </code> if <code> Direction </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> directionRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDirectionWithRecordTypes(org.osid.type.Type[] directionRecordTypes);


    /**
     *  Gets the direction form for creating new directions. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  recipeId a recipe <code> Id </code> 
     *  @param  directionRecordTypes array of direction record types 
     *  @return the direction form 
     *  @throws org.osid.NotFoundException <code> recipeId </code> Is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> or 
     *          <code> directionRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionForm getDirectionFormForCreate(org.osid.id.Id recipeId, 
                                                                   org.osid.type.Type[] directionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Direction. </code> 
     *
     *  @param  directionForm the form for this <code> Direction </code> 
     *  @return the new <code> Direction </code> 
     *  @throws org.osid.IllegalStateException <code> directionForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> directionForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> directionForm </code> did 
     *          not originate from <code> getDirectionFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Direction createDirection(org.osid.recipe.DirectionForm directionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Directions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Direction </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Direction </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateDirections();


    /**
     *  Gets the direction form for updating an existing direction. A new 
     *  direction form should be requested for each update transaction. 
     *
     *  @param  directionId the <code> Id </code> of the <code> Direction 
     *          </code> 
     *  @return the direction form 
     *  @throws org.osid.NotFoundException <code> directionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionForm getDirectionFormForUpdate(org.osid.id.Id directionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing direction. 
     *
     *  @param  directionForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> directionForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> directionForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> directionForm </code> did 
     *          not originate from <code> getDirectionFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDirection(org.osid.recipe.DirectionForm directionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Directions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Direction </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Direction </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteDirections();


    /**
     *  Deletes a <code> Direction. </code> 
     *
     *  @param  directionId the <code> Id </code> of the <code> Direction 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> directionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDirection(org.osid.id.Id directionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Directions. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Direction </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDirectionAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Direction </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Direction </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another direction, it is 
     *  reassigned to the given direction <code> Id. </code> 
     *
     *  @param  directionId the <code> Id </code> of a <code> Direction 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> directionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directionId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasDirection(org.osid.id.Id directionId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Ingedredients. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known changing an alias will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Ingredient </code> management 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageIngredients();


    /**
     *  Tests if this user can create a single <code> Ingredient </code> using 
     *  the desired record types. While <code> 
     *  RecipeManager.getIngreientRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Ingredient. </code> Providing 
     *  an empty array tests if an <code> Ingredient </code> can be created 
     *  with no records. 
     *
     *  @param  ingredientRecordTypes array of ingredient record types 
     *  @return <code> true </code> if <code> Ingredient </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ingredientRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateIngredientWithRecordTypes(org.osid.type.Type[] ingredientRecordTypes);


    /**
     *  Gets the ingredient form for creating new ingredients. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  directionId an ingredient <code> Id </code> 
     *  @param  ingredientRecordTypes array of ingredient record types 
     *  @return the ingredient form 
     *  @throws org.osid.NotFoundException <code> directionId </code> Is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directionId </code> or 
     *          <code> ingredientRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.IngredientForm getIngredientFormForCreate(org.osid.id.Id directionId, 
                                                                     org.osid.type.Type[] ingredientRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Ingredient. </code> 
     *
     *  @param  ingredientForm the form for this <code> Ingredient </code> 
     *  @return the new <code> Ingredient </code> 
     *  @throws org.osid.IllegalStateException <code> ingredientForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> ingredientForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> ingredientForm </code> 
     *          did not originate from <code> geIngredientFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Ingredient createIngredient(org.osid.recipe.IngredientForm ingredientForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the ingredient form for updating an existing ingredient. A new 
     *  ingredient form should be requested for each update transaction. 
     *
     *  @param  ingredientId the <code> Id </code> of the <code> Ingredient 
     *          </code> 
     *  @return the ingredient form 
     *  @throws org.osid.NotFoundException <code> ingredientId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> ingredientId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.IngredientForm getIngredientFormForUpdate(org.osid.id.Id ingredientId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing ingredient. 
     *
     *  @param  ingredientForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> ingredientForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> ingredientForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> ingredientForm </code> 
     *          did not originate from <code> getIngredientFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateIngredient(org.osid.recipe.IngredientForm ingredientForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes an <code> Ingredient. </code> 
     *
     *  @param  ingredientId the <code> Id </code> of the <code> Ingredient 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> ingredientId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> ingredientId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteIngredient(org.osid.id.Id ingredientId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> Directions. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known changing an alias will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Direction </code> ordering is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceDirections();


    /**
     *  Reorders directions in a recipe by moving the specified direction in 
     *  front of a reference direction. 
     *
     *  @param  directionId the <code> Id </code> of a <code> Direction 
     *          </code> 
     *  @param  recipeId the <code> Id </code> of a <code> Recipe </code> 
     *  @param  referenceId the reference direction <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> directionId, recipeId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          directionId </code> or <code> referenceId </code> not related 
     *          to <code> recipeId </code> 
     *  @throws org.osid.NullArgumentException <code> directionId, recipeId 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveDirectionAhead(org.osid.id.Id directionId, 
                                   org.osid.id.Id recipeId, 
                                   org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders directions in a recipe by moving the specified direction 
     *  behind a reference direction. 
     *
     *  @param  directionId the <code> Id </code> of a <code> Direction 
     *          </code> 
     *  @param  recipeId the <code> Id </code> of a <code> Recipe </code> 
     *  @param  referenceId the reference direction <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> directionId, recipeId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          directionId </code> or <code> referenceId </code> not related 
     *          to <code> recipeId </code> 
     *  @throws org.osid.NullArgumentException <code> directionId, recipeId 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveDirectionBehind(org.osid.id.Id directionId, 
                                    org.osid.id.Id recipeId, 
                                    org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of directions in a recipe. 
     *
     *  @param  directionIds the <code> Ids </code> for a set of <code> 
     *          Directions </code> 
     *  @param  recipeId the <code> Id </code> of a <code> Recipe </code> 
     *  @throws org.osid.NotFoundException <code> recipeId </code> not found 
     *          or, a <code> directionId </code> not related to <code> 
     *          recipeId </code> 
     *  @throws org.osid.NullArgumentException <code> directionIds </code> or 
     *          <code> recipeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderDirections(org.osid.id.Id[] directionIds, 
                                org.osid.id.Id recipeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
