//
// org.osid.recipe.DirectionLookupSession
//
//     The OSID Java specification for org.osid.recipe.DirectionLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session defines methods for retrieving directions. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated cook book view: All direction methods in this session 
 *      operate, retrieve and pertain to directions defined explicitly in the 
 *      current cookbook. Using an isolated view is useful for managing <code> 
 *      Directions </code> with the <code> DirectionAdminSession. </code> 
 *      </li> 
 *      <li> federated cook book view: All direction lookup methods in this 
 *      session operate, retrieve and pertain to all directions defined in 
 *      this cook book and any other directions implicitly available in this 
 *      cook book through cook book inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedCookbookView() </code> and <code> 
 *  useIsolatedCookbookView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p> 
 *  
 *  <p> Directions may have an additional records indicated by their 
 *  respective record types. The record may not be accessed through a cast of 
 *  the <code> Directions. </code> </p>
 */

public interface DirectionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Direction </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupDirections();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeDirectionView();


    /**
     *  A complete view of the <code> Direction </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryDirectionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include directions in cook books which are children of this cook book 
     *  in the cook book hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCookbookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this cook book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCookbookView();


    /**
     *  Gets the <code> Direction </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Direction 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Direction </code> and retained for compatibility. 
     *
     *  @param  directionId the <code> Id </code> of the <code> Direction 
     *          </code> to retrieve 
     *  @return the returned <code> Direction </code> 
     *  @throws org.osid.NotFoundException no <code> Direction </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> directionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Direction getDirection(org.osid.id.Id directionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DirectionList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  directions specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Directions </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  directionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Direction </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> directionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionList getDirectionsByIds(org.osid.id.IdList directionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DirectionList </code> corresponding to the given 
     *  direction genus <code> Type </code> which does not include directions 
     *  of types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known directions or an error 
     *  results. Otherwise, the returned list may contain only those 
     *  directions that are accessible through this session. 
     *
     *  @param  directionGenusType a direction genus type 
     *  @return the returned <code> Direction </code> list 
     *  @throws org.osid.NullArgumentException <code> directionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionList getDirectionsByGenusType(org.osid.type.Type directionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DirectionList </code> corresponding to the given 
     *  direction genus <code> Type </code> and include any additional 
     *  directions with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  directions or an error results. Otherwise, the returned list may 
     *  contain only those directions that are accessible through this 
     *  session. 
     *
     *  @param  directionGenusType a direction genus type 
     *  @return the returned <code> Direction </code> list 
     *  @throws org.osid.NullArgumentException <code> directionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionList getDirectionsByParentGenusType(org.osid.type.Type directionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DirectionList </code> containing the given direction 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known directions or an error results. Otherwise, the 
     *  returned list may contain only those directions that are accessible 
     *  through this session. 
     *
     *  @param  directionRecordType a direction record type 
     *  @return the returned <code> Direction </code> list 
     *  @throws org.osid.NullArgumentException <code> directionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionList getDirectionsByRecordType(org.osid.type.Type directionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> DirectionList </code> for the given recipe <code> Id. 
     *  </code> In plenary mode, the returned list contains all known 
     *  directions or an error results. Otherwise, the returned list may 
     *  contain only those directions that are accessible through this 
     *  session. 
     *
     *  @param  recipeId a recipe <code> Id </code> 
     *  @return the returned <code> Direction </code> list 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionList getDirectionsForRecipe(org.osid.id.Id recipeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all directions. <code> </code> In plenary mode, the returned list 
     *  contains all of the directions, including duplicates, or an error 
     *  results if an <code> Id </code> in the supplied list is not found or 
     *  inaccessible. Otherwise, inaccessible <code> Directions </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *
     *  @return the returned <code> Direction </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionList getDirections()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
