//
// org.osid.recipe.DirectionQuery
//
//     The OSID Java specification for org.osid.recipe.DirectionQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This is the query for searching directions. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface DirectionQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the recipe <code> Id </code> for this query. 
     *
     *  @param  recipeId the recipe <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRecipeId(org.osid.id.Id recipeId, boolean match);


    /**
     *  Clears the recipe <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipeIdTerms();


    /**
     *  Tests if a <code> RecipeQuery </code> is available. 
     *
     *  @return <code> true </code> if a recipe query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecipeQuery();


    /**
     *  Gets the query for a recipe. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the recipe query 
     *  @throws org.osid.UnimplementedException <code> supportsRecipeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.RecipeQuery getRecipeQuery();


    /**
     *  Clears the recipe query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRecipeTerms();


    /**
     *  Sets the procedure <code> Id </code> for this query. 
     *
     *  @param  procedureId the procedure <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProcedureId(org.osid.id.Id procedureId, boolean match);


    /**
     *  Clears the procedure <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcedureIdTerms();


    /**
     *  Tests if a <code> ProcedureQuery </code> is available. 
     *
     *  @return <code> true </code> if a procedure query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcedureQuery();


    /**
     *  Gets the query for a procedure. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the procedure query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.ProcedureQuery getProcedureQuery();


    /**
     *  Matches directions with any procedure. 
     *
     *  @param  match <code> true </code> to match directions with any 
     *          procedure, <code> false </code> to match directions with no 
     *          procedures 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProcedure(boolean match);


    /**
     *  Clears the procedure query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcedureTerms();


    /**
     *  Sets the ingredient <code> Id. </code> 
     *
     *  @param  ingredientId the ingredient <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> ingredientId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIngredientId(org.osid.id.Id ingredientId, boolean match);


    /**
     *  Clears the ingredient <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIngredientIdTerms();


    /**
     *  Tests if an <code> IngredientkQuery </code> is available. 
     *
     *  @return <code> true </code> if an ingredient query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIngredientQuery();


    /**
     *  Gets the query for an ingredient. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the ingredient query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIngredientItemQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIngredientQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.IngredientQuery getIngredientQuery();


    /**
     *  Matches directions with any ingredient. 
     *
     *  @param  match <code> true </code> to match directions with any 
     *          ingredient, <code> false </code> to match directions with no 
     *          ingredients 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIngredient(boolean match);


    /**
     *  Clears the ingredient query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIngredientTerms();


    /**
     *  Matches directions with an estimated duration between the given range 
     *  inclusive. 
     *
     *  @param  start starting duration 
     *  @param  end ending duration 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEstimatedDuration(org.osid.calendaring.Duration start, 
                                       org.osid.calendaring.Duration end, 
                                       boolean match);


    /**
     *  Matches directions with any estimated duration. 
     *
     *  @param  match <code> true </code> to match directions with any 
     *          estimated duration, <code> false </code> to match directions 
     *          with no estimated duration 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEstimatedDuration(boolean match);


    /**
     *  Clears the duration query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEstimatedDurationTerms();


    /**
     *  Sets the asset <code> Id </code> for this query. 
     *
     *  @param  assetId the asset <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assetId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssetId(org.osid.id.Id assetId, boolean match);


    /**
     *  Clears the asset <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssetIdTerms();


    /**
     *  Tests if an <code> AssetQuery </code> is available. 
     *
     *  @return <code> true </code> if an asset query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetQuery();


    /**
     *  Gets the query for an asset. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the asset query 
     *  @throws org.osid.UnimplementedException <code> supportsAssetQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetQuery getAssetQuery();


    /**
     *  Matches directions with any asset. 
     *
     *  @param  match <code> true </code> to match directions with any asset, 
     *          <code> false </code> to match directions with no assets 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAsset(boolean match);


    /**
     *  Clears the asset query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssetTerms();


    /**
     *  Sets the award <code> Id </code> for this query to match directions 
     *  assigned to cookbooks. 
     *
     *  @param  cookbookId a cook book <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCookbookId(org.osid.id.Id cookbookId, boolean match);


    /**
     *  Clears the cook book <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCookbookIdTerms();


    /**
     *  Tests if a <code> CookbookQuery </code> is available. 
     *
     *  @return <code> true </code> if a cook book query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCookbookQuery();


    /**
     *  Gets the query for a cookbook. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the cook book query 
     *  @throws org.osid.UnimplementedException <code> supportsCookbookQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookQuery() </code> is <code> true. </code> 
     */

    public org.osid.recipe.CookbookQuery getCookbookQuery();


    /**
     *  Clears the cook book query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCookbookTerms();


    /**
     *  Gets the direction query record corresponding to the given <code> 
     *  Direction </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  directionRecordType a direction record type 
     *  @return the direction query record 
     *  @throws org.osid.NullArgumentException <code> directionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(directionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.records.DirectionQueryRecord getDirectionQueryRecord(org.osid.type.Type directionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
