//
// org.osid.recipe.DirectionSearchSession
//
//     The OSID Java specification for org.osid.recipe.DirectionSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session provides methods for searching among <code> Direction 
 *  </code> objects. The search query is constructed using the <code> 
 *  DirectionQuery. </code> </p> 
 *  
 *  <p> <code> getDirectionsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Directions. </code> A more advanced search may be 
 *  performed with <code> getDirectionsBySearch(). </code> It accepts a <code> 
 *  DirectionSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getDirectionsBySearch() </code> returns a <code> 
 *  DirectionSearchResults </code> that can be used to access the resulting 
 *  <code> DirectionList </code> or be used to perform a search within the 
 *  result set through <code> DirectionSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated cook book view: searches include directions in cook 
 *      books of which this cook book is an ancestor in the cook book 
 *      hierarchy </li> 
 *      <li> isolated cook book view: searches are restricted to directions in 
 *      this cook books </li> 
 *  </ul>
 *  
 *  
 *  <p> Directions may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> DirectionQuery. 
 *  </code> </p>
 */

public interface DirectionSearchSession
    extends org.osid.recipe.DirectionQuerySession {


    /**
     *  Gets a direction search. 
     *
     *  @return the direction search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionSearch getDirectionSearch();


    /**
     *  Gets a direction search order. The <code> DirectionSearchOrder </code> 
     *  is supplied to a <code> DirectionSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the direction search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionSearchOrder getDirectionSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  directionQuery the direction query 
     *  @param  directionSearch the direction search 
     *  @return the direction search results 
     *  @throws org.osid.NullArgumentException <code> directionQuery </code> 
     *          or <code> directionSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> directionQuery </code> or 
     *          <code> directionSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionSearchResults getDirectionsBySearch(org.osid.recipe.DirectionQuery directionQuery, 
                                                                        org.osid.recipe.DirectionSearch directionSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a direction query. from an inspector. The inspector is available 
     *  from a <code> DirectionSearchResults. </code> 
     *
     *  @param  directionQueryInspector a direction query inspector 
     *  @return the direction query 
     *  @throws org.osid.NullArgumentException <code> directionQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> directionQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.DirectionQuery getDirectionQueryFromInspector(org.osid.recipe.DirectionQueryInspector directionQueryInspector);
}
