//
// org.osid.recipe.ProcedureAdminSession
//
//     The OSID Java specification for org.osid.recipe.ProcedureAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session creates, updates, and deletes <code> Procedures. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Procedure, </code> a <code> ProcedureForm </code> is requested using 
 *  <code> getProcedureFormForCreate() </code> specifying the desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  The returned <code> ProcedureForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> ProcedureForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  ProcedureForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> ProcedureForms </code> are requested to the <code> 
 *  Procedure </code> <code> Id </code> that is to be updated using <code> 
 *  getProcedureFormForUpdate(). </code> Similarly, the <code> ProcedureForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> ProcedureForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Procedures. </code> To unmap a 
 *  <code> Procedure </code> from the current <code> Cookbook, </code> the 
 *  <code> ProcedureCookbookAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Procedure </code> itself 
 *  thus removing it from all known <code> Cookbook </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ProcedureAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create procedures. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Procedure </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Procedure </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProcedures();


    /**
     *  Tests if this user can create a single <code> Procedure </code> using 
     *  the desired record types. While <code> 
     *  RecipeManager.getProcedureRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Procedure. </code> Providing 
     *  an empty array tests if a <code> Procedure </code> can be created with 
     *  no records. 
     *
     *  @param  procedureRecordTypes array of procedure record types 
     *  @return <code> true </code> if <code> Procedure </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> procedureRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateProcedureWithRecordTypes(org.osid.type.Type[] procedureRecordTypes);


    /**
     *  Gets the procedure form for creating new procedures. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  procedureRecordTypes array of procedure record types 
     *  @return the procedure form 
     *  @throws org.osid.NullArgumentException <code> procedureRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureForm getProcedureFormForCreate(org.osid.type.Type[] procedureRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Procedure. </code> 
     *
     *  @param  procedureForm the form for this <code> Procedure </code> 
     *  @return the new <code> Procedure </code> 
     *  @throws org.osid.IllegalStateException <code> procedureForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> procedureForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> procedureForm </code> did 
     *          not originate from <code> getProcedureFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Procedure createProcedure(org.osid.recipe.ProcedureForm procedureForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update procedures. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Procedure </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Procedure </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateProcedures();


    /**
     *  Tests if this user can update a specified <code> Procedure. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating the <code> Procedure 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not wish to offer update 
     *  operations to unauthorized users. 
     *
     *  @param  procedureId the <code> Id </code> of the <code> Procedure 
     *          </code> 
     *  @return <code> false </code> if procedure modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> procedureId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of an update 
     *          available. 
     */

    public boolean canUpdateProcedure(org.osid.id.Id procedureId);


    /**
     *  Gets the procedure form for updating an existing procedure. A new 
     *  procedure form should be requested for each update transaction. 
     *
     *  @param  procedureId the <code> Id </code> of the <code> Procedure 
     *          </code> 
     *  @return the procedure form 
     *  @throws org.osid.NotFoundException <code> procedureId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureForm getProcedureFormForUpdate(org.osid.id.Id procedureId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing procedure. 
     *
     *  @param  procedureForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> procedureForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> or 
     *          <code> procedureForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> procedureForm </code> did 
     *          not originate from <code> getProcedureFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateProcedure(org.osid.recipe.ProcedureForm procedureForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete procedures. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Procedure </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Procedure </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteProcedures();


    /**
     *  Tests if this user can delete a specified <code> Procedure. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting the <code> Procedure 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not wish to offer delete 
     *  operations to unauthorized users. 
     *
     *  @param  procedureId the <code> Id </code> of the <code> Procedure 
     *          </code> 
     *  @return <code> false </code> if deletion of this <code> Procedure 
     *          </code> is not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> procedureId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of a delete 
     *          available. 
     */

    public boolean canDeleteProcedure(org.osid.id.Id procedureId);


    /**
     *  Deletes a <code> Procedure. </code> 
     *
     *  @param  procedureId the <code> Id </code> of the <code> Procedure 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> procedureId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProcedure(org.osid.id.Id procedureId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Procedures </code> in this <code> Cookbook. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteProcedures()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Comnents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Procedure </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageProcedureAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Procedure </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Procedure </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another procedure, it is 
     *  reassigned to the given procedure <code> Id. </code> 
     *
     *  @param  procedureId the <code> Id </code> of a <code> Procedure 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> procedureId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> procedureId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasProcedure(org.osid.id.Id procedureId, 
                               org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
