//
// org.osid.recipe.ProcedureSearchSession
//
//     The OSID Java specification for org.osid.recipe.ProcedureSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session provides methods for searching <code> Procedure </code> 
 *  objects. The search query is constructed using the <code> ProcedureQuery. 
 *  </code> The procedure record <code> Type </code> also specifies the record 
 *  for the procedure query. </p> 
 *  
 *  <p> <code> getProceduresByQuery() </code> is the basic search method and 
 *  returns a list of <code> Cookbook </code> elements. A more advanced search 
 *  may be performed with <code> getProceduresBySearch(). </code> It accepts a 
 *  <code> ProcedureSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getProceduresBySearch() </code> returns a <code> 
 *  ProcedureSearchResults </code> that can be used to access the resulting 
 *  <code> ProcedureList </code> or be used to perform a search within the 
 *  result set through <code> ProcedureSearch. </code> </p> 
 *  
 *  <p> Procedures may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> ProcedureQuery. 
 *  </code> The returns in this session may not be cast directly to these 
 *  interfaces. </p>
 */

public interface ProcedureSearchSession
    extends org.osid.recipe.ProcedureQuerySession {


    /**
     *  Gets a procedure search. 
     *
     *  @return the procedure search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureSearch getProcedureSearch();


    /**
     *  Gets a procedure search order. The <code> ProcedureSearchOrder </code> 
     *  is supplied to a <code> ProcedureSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the procedure search order interface 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureSearchOrder getProcedureSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  procedureQuery the procedure query 
     *  @param  procedureSearch the procedure search 
     *  @return the procedure search results 
     *  @throws org.osid.NullArgumentException <code> procedureQuery </code> 
     *          or <code> procedureSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> procedureQuery </code> or 
     *          <code> procedureSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureSearchResults getProceduresBySearch(org.osid.recipe.ProcedureQuery procedureQuery, 
                                                                        org.osid.recipe.ProcedureSearch procedureSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a procedure query from an inspector. The inspector is available 
     *  from a <code> ProcedureSearchResults. </code> 
     *
     *  @param  procedureQueryInspector a procedure query inspector 
     *  @return the procedure query 
     *  @throws org.osid.NullArgumentException <code> procedureQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> procedureQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.ProcedureQuery getProcedureQueryFromInspector(org.osid.recipe.ProcedureQueryInspector procedureQueryInspector);
}
