//
// org.osid.recipe.RecipeAdminSession
//
//     The OSID Java specification for org.osid.recipe.RecipeAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session creates, updates, and deletes <code> Recipes. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Recipe, </code> a <code> RecipeForm </code> is requested using <code> 
 *  getRecipeFormForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. The 
 *  returned <code> RecipeForm </code> will indicate that it is to be used 
 *  with a create operation and can be used to examine metdata or validate 
 *  data prior to creation. Once the <code> RecipeForm </code> is submiited to 
 *  a create operation, it cannot be reused with another create operation 
 *  unless the first operation was unsuccessful. Each <code> RecipeForm 
 *  </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> RecipeForms </code> are requested to the <code> 
 *  Recipe </code> <code> Id </code> that is to be updated using <code> 
 *  getRecipeFormForUpdate(). </code> Similarly, the <code> RecipeForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> RecipeForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Recipes. </code> To unmap a <code> 
 *  Recipe </code> from the current <code> Cookbook, </code> the <code> 
 *  RecipeCookbookAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Recipe </code> itself thus 
 *  removing it from all known <code> Cookbook </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RecipeAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Recipes. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Recipe </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Recipe </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRecipes();


    /**
     *  Tests if this user can create a single <code> Recipe </code> using the 
     *  desired record types. While <code> 
     *  RecipeManager.getRecipeRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Recipe. </code> Providing an 
     *  empty array tests if a <code> Recipe </code> can be created with no 
     *  records. 
     *
     *  @param  recipeRecordTypes array of recipe record types 
     *  @return <code> true </code> if <code> Recipe </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> recipeRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRecipeWithRecordTypes(org.osid.type.Type[] recipeRecordTypes);


    /**
     *  Gets the recipe form for creating new recipes. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  recipeRecordTypes array of recipe record types 
     *  @return the recipe form 
     *  @throws org.osid.NullArgumentException <code> recipeRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeForm getRecipeFormForCreate(org.osid.type.Type[] recipeRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Recipe. </code> 
     *
     *  @param  recipeForm the form for this <code> Recipe </code> 
     *  @return the new <code> Recipe </code> 
     *  @throws org.osid.IllegalStateException <code> recipeForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> recipeForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> recipeForm </code> did 
     *          not originate from <code> getRecipeFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Recipe createRecipe(org.osid.recipe.RecipeForm recipeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Recipes. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Recipe </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Recipe </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRecipes();


    /**
     *  Gets the recipe form for updating an existing recipe. A new recipe 
     *  form should be requested for each update transaction. 
     *
     *  @param  recipeId the <code> Id </code> of the <code> Recipe </code> 
     *  @return the recipe form 
     *  @throws org.osid.NotFoundException <code> recipeId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeForm getRecipeFormForUpdate(org.osid.id.Id recipeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing recipe. 
     *
     *  @param  recipeForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> recipeForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> or 
     *          <code> recipeForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> recipeForm </code> did 
     *          not originate from <code> getRecipeFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRecipe(org.osid.recipe.RecipeForm recipeForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Recipes. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Recipe </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Recipe </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRecipes();


    /**
     *  Deletes a <code> Recipe. </code> 
     *
     *  @param  recipeId the <code> Id </code> of the <code> Recipe </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> recipeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRecipe(org.osid.id.Id recipeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Recipes. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Recipe </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRecipeAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Recipe </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Recipe </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another recipe, it is reassigned to the given 
     *  recipe <code> Id. </code> 
     *
     *  @param  recipeId the <code> Id </code> of a <code> Recipe </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> recipeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRecipe(org.osid.id.Id recipeId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
