//
// org.osid.recipe.RecipeQuerySession
//
//     The OSID Java specification for org.osid.recipe.RecipeQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe;


/**
 *  <p>This session provides methods for searching among <code> Recipe </code> 
 *  objects. The search query is constructed using the <code> RecipeQuery. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated cook book view: searches include recipes in cook books 
 *      of which this cook book is an ancestor in the cook book hierarchy 
 *      </li> 
 *      <li> isolated cook book view: searches are restricted to recipes in 
 *      this cook books </li> 
 *  </ul>
 *  
 *  
 *  <p> Recipes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> RecipeQuery. </code> 
 *  </p>
 */

public interface RecipeQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Cookbook </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Cookbook Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCookbookId();


    /**
     *  Gets the <code> Cookbook </code> associated with this session. 
     *
     *  @return the cookbook 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.Cookbook getCookbook()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Recipe </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchRecipes();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include recipes in cook book which are children of this cook book in 
     *  the cook book hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCookbookView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this cook book only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCookbookView();


    /**
     *  Gets a recipe query. 
     *
     *  @return the recipe query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeQuery getRecipeQuery();


    /**
     *  Gets a list of <code> Recipes </code> matching the given recipe query. 
     *
     *  @param  recipeQuery the recipe query 
     *  @return the returned <code> RecipeList </code> 
     *  @throws org.osid.NullArgumentException <code> recipeQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> recipeQuery </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.RecipeList getRecipesByQuery(org.osid.recipe.RecipeQuery recipeQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
