//
// org.osid.recipe.batch.DirectionBatchAdminSession
//
//     The OSID Java specification for org.osid.recipe.batch.DirectionBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Directions </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Direction, </code> a <code> DirectionForm </code> is requested using 
 *  <code> getDirectionFormsForCreate() </code> specifying the desired recipes 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. Each of the returned <code> DirectionForms </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once a <code> 
 *  DirectionForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> DirectionForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> DirectionForms </code> returned from <code> 
 *  getDirectionFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> DirectionForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  DirectionForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> DirectionForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  DirectionForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createDirections(), </code> errors specific to an individual <code> 
 *  DirectionForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> DirectionForm </code> through the <code> 
 *  DirectionForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> DirectionForms </code> are requested to the <code> 
 *  Direction </code> <code> Id </code> that is to be updated using <code> 
 *  getDirectionFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> DirectionForm </code> may be used to link the request. 
 *  Similarly, the <code> DirectionForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> DirectionForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> DirectionForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  DirectionForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateDirections(), </code> errors specific to an individual <code> 
 *  DirectionForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> DirectionForm </code> through the <code> 
 *  DirectionForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Directions </code> in bulk. To 
 *  unmap a <code> Direction </code> from the current <code> Cookbook, </code> 
 *  the <code> DirectionCookbookAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Direction </code> 
 *  itself thus removing it from all known <code> Cookbook </code> catalogs. 
 *  Bulk delete operations return the results in <code> DeleteResponses. 
 *  </code> </p>
 */

public interface DirectionBatchAdminSession
    extends org.osid.recipe.DirectionAdminSession {


    /**
     *  Gets the direction forms for creating a bunch of new directions. A 
     *  form is returned for each supplied recipe. 
     *
     *  @param  recipieIds a list of recipe <code> Ids </code> 
     *  @param  directionRecordTypes array of direction record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the direction forms 
     *  @throws org.osid.NotFoundException a <code> recipieId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> recipeIds </code> or 
     *          <code> directionRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.batch.DirectionBatchFormList getDirectionFormsForCreate(org.osid.id.IdList recipieIds, 
                                                                                   org.osid.type.Type[] directionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Directions. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  directionForms the direction forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> directionForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createDirections(org.osid.recipe.batch.DirectionBatchFormList directionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the direction forms for updating an existing set of directions. A 
     *  new direction form should be requested for each update transaction. 
     *
     *  @param  directionIds the <code> Ids </code> of the <code> Directions 
     *          </code> 
     *  @return the direction forms 
     *  @throws org.osid.NotFoundException a <code> directionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.batch.DirectionBatchFormList getDirectionFormsForUpdate(org.osid.id.IdList directionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing directions. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  directionForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> directionForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateDirections(org.osid.recipe.batch.DirectionBatchFormList directionForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Directions </code> in this <code> Cookbook </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllDirections()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes directions for the given <code> Ids. </code> 
     *
     *  @param  directionIds the <code> Ids </code> of the directions to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> directionIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteDirections(org.osid.id.IdList directionIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes directions for the given recipe. 
     *
     *  @param  recipeId the <code> Id </code> of a recipe 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> recipeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteDirectionsForRecipe(org.osid.id.Id recipeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Direction </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Direction </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another direction, it is reassigned to the given 
     *  direction <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasDirections(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the ingredient forms for creating a bunch of new ingredients. A 
     *  form is returned for each supplied recipe. 
     *
     *  @param  directionIds a list of direction <code> Ids </code> 
     *  @param  ingredientRecordTypes array of ingredient record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the ingredient forms 
     *  @throws org.osid.NotFoundException a <code> directionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> directionIds </code> or 
     *          <code> ingredientRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.batch.IngredientBatchFormList getIngredientFormsForCreate(org.osid.id.IdList directionIds, 
                                                                                     org.osid.type.Type[] ingredientRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Ingredients. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  ingredientForms the ingredient forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> ingredientForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createIngredients(org.osid.recipe.batch.IngredientBatchFormList ingredientForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the ingredient forms for updating an existing set of ingredients. 
     *  A new ingredient form should be requested for each update transaction. 
     *
     *  @param  ingredientIds the <code> Ids </code> of the <code> Ingredients 
     *          </code> 
     *  @return the ingredient forms 
     *  @throws org.osid.NotFoundException an <code> ingredientId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> ingredientIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recipe.batch.IngredientBatchFormList getIngredientFormsForUpdate(org.osid.id.IdList ingredientIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing ingredients. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  ingredientForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> ingredientForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateIngredients(org.osid.recipe.batch.IngredientBatchFormList ingredientForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Ingredients </code> in this <code> Cookbook </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllIngredients()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes ingredients for the given <code> Ids. </code> 
     *
     *  @param  ingredientsIds the <code> Ids </code> of the ingredients to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> ingredientIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIngredients(org.osid.id.IdList ingredientsIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes ingredients for the given direction. 
     *
     *  @param  directionId the <code> Id </code> of a direction 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> directionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIngredientsForDirection(org.osid.id.Id directionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
