//
// org.osid.recipe.batch.RecipeBatchManager
//
//     The OSID Java specification for org.osid.recipe.batch.RecipeBatchManager.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recipe.batch;


/**
 *  <p>The recipe batch manager provides access to recipe batch sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <p> <code> </code> 
 *  <ul>
 *      <li> <code> RecipeBatchAdminSession: </code> a session to create, 
 *      modify and delete <code> Recipes </code> in bulk </li> 
 *      <li> <code> DirectionBatchAdminSession: </code> a session to create, 
 *      modify and delete Directions in bulk <code> </code> </li> 
 *      <li> <code> ProcedureBatchAdminSession: </code> a session to create, 
 *      modify and delete <code> Procedures </code> in bulk </li> 
 *      <li> <code> CookbookBatchAdminSession: </code> a session to create, 
 *      modify and delete <code> Cookbook </code> in bulk </li> 
 *  </ul>
 *  </p>
 */

public interface RecipeBatchManager
    extends org.osid.OsidManager,
            org.osid.recipe.batch.RecipeBatchProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk recipe 
     *  administration service. 
     *
     *  @return a <code> RecipeBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeBatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.recipe.batch.RecipeBatchAdminSession getRecipeBatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk recipe 
     *  administration service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @return a <code> RecipeBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRecipeBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRecipeBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.batch.RecipeBatchAdminSession getRecipeBatchAdminSessionForCookbook(org.osid.id.Id cookbookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk direction 
     *  administration service. 
     *
     *  @return a <code> DirectionBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.batch.DirectionBatchAdminSession getDirectionBatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk direction 
     *  administration service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @return a <code> DirectionBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDirectionBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDirectionBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.batch.DirectionBatchAdminSession getDirectionBatchAdminSessionForCookbook(org.osid.id.Id cookbookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk procedure 
     *  administration service. 
     *
     *  @return a <code> ProcedureBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.batch.ProcedureBatchAdminSession getProcedureBatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk procedure 
     *  administration service for the given cookbook. 
     *
     *  @param  cookbookId the <code> Id </code> of the <code> Cookbook 
     *          </code> 
     *  @return a <code> ProcedureBatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Cookbook </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> cookbookId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcedureBatchAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcedureBatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.recipe.batch.ProcedureBatchAdminSession getProcedureBatchAdminSessionForCookbook(org.osid.id.Id cookbookId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the bulk cookbook 
     *  administration service. 
     *
     *  @return a <code> CookbookBatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCookbookBatchAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCookbookBatchAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.recipe.batch.CookbookBatchAdminSession getCookbookBatchAdminSession()
        throws org.osid.OperationFailedException;
}
