//
// org.osid.recognition.AcademyNotificationSession
//
//     The OSID Java specification for org.osid.recognition.AcademyNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Academy </code> objects. This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> Notifications are triggered with changes to the <code> Academy </code> 
 *  object itself. Adding and removing conferrals result in notifications 
 *  available from the notification session for conferrals. </p>
 */

public interface AcademyNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can register for <code> Academy </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForAcademyNotifications();


    /**
     *  Register for notifications of new academies. <code> 
     *  AcademyReceiver.newAcademies() </code> is invoked when a new <code> 
     *  Academy </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAcademies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new ancestor of the specified academy. <code> 
     *  AcademyReceiver.newAncestorAcademy() </code> is invoked when the 
     *  specified academy node gets a new ancestor. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *          node to monitor 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAcademyAncestors(org.osid.id.Id academyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  introduces a new descendant of the specified academy. <code> 
     *  AcademyReceiver.newDescendantAcademy() </code> is invoked when the 
     *  specified academy node gets a new descendant. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *          node to monitor 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAcademyDescendants(org.osid.id.Id academyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated academies. <code> 
     *  AcademyReceiver.changedAcademies() </code> is invoked when an academy 
     *  is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAcademies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated academy. <code> 
     *  AcademyReceiver.changedAcademies() </code> is invoked when the 
     *  specified academy is changed. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAcademy(org.osid.id.Id academyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted academies. <code> 
     *  AcademyReceiver.deletedAcademies() </code> is invoked when an academy 
     *  is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAcademies()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted academy. <code> 
     *  AcademyReceiver.deletedAcademies() </code> is invoked when the 
     *  specified academy is deleted. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAcademy(org.osid.id.Id academyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes an ancestor of the specified academy <code> 
     *  AcademyReceiver.deletedAncestor() </code> is invoked when the 
     *  specified academy node loses an ancestor. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAcademyAncestors(org.osid.id.Id academyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated hierarchy structure that 
     *  removes a descendant of the specified academy. <code> 
     *  AcademyReceiver.deletedDescendant() </code> is invoked when the 
     *  specified academy node loses a descendant. 
     *
     *  @param  academyId the <code> Id </code> of the <code> Academy </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAcademyDescendants(org.osid.id.Id academyId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
