//
// org.osid.recognition.AwardLookupSession
//
//     The OSID Java specification for org.osid.recognition.AwardLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session provides methods for retrieving <code> Award </code> 
 *  objects. The <code> Award </code> represents a collection of conferrals. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete view or is an error condition 
 *      </li> 
 *      <li> isolated academy view: All award methods in this session operate, 
 *      retrieve and pertain to awards defined explicitly in the current 
 *      academy. Using an isolated view is useful for managing awards with the 
 *      <code> AwardAdminSession. </code> </li> 
 *      <li> federated academy view: All award lookup methods in this session 
 *      operate, retrieve and pertain to all awards defined in this academy 
 *      and any other academies implicitly available in this academy through 
 *      academy inheritence. </li> 
 *  </ul>
 *  
 */

public interface AwardLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Academy </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Academy Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAcademyId();


    /**
     *  Gets the <code> Academy </code> associated with this session. 
     *
     *  @return the academy 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Academy getAcademy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Award </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAwards();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAwardView();


    /**
     *  A complete view of the <code> Award </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAwardView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include awards in academies which are children of this academy in the 
     *  academy hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAcademyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this academy only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAcademyView();


    /**
     *  Gets the <code> Award </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Award 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to an <code> 
     *  Award </code> and retained for compatibility. 
     *
     *  @param  awardId <code> Id </code> of the <code> Award </code> 
     *  @return the award 
     *  @throws org.osid.NotFoundException <code> awardId </code> not found 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.recognition.Award getAward(org.osid.id.Id awardId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  awards specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Awards </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  awardIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Award </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> awardIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AwardList getAwardsByIds(org.osid.id.IdList awardIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardList </code> corresponding to the given award 
     *  genus <code> Type </code> which does not include awards of genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known awards or an error results. 
     *  Otherwise, the returned list may contain only those awards that are 
     *  accessible through this session. 
     *
     *  @param  awardGenusType an award genus type 
     *  @return the returned <code> Award </code> list 
     *  @throws org.osid.NullArgumentException <code> awardGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AwardList getAwardsByGenusType(org.osid.type.Type awardGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardList </code> corresponding to the given award 
     *  genus <code> Type </code> and include any additional awards with genus 
     *  types derived from the specified <code> Type. </code> In plenary mode, 
     *  the returned list contains all known awards or an error results. 
     *  Otherwise, the returned list may contain only those awards that are 
     *  accessible through this session. 
     *
     *  @param  awardGenusType an award genus type 
     *  @return the returned <code> Award </code> list 
     *  @throws org.osid.NullArgumentException <code> awardGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AwardList getAwardsByParentGenusType(org.osid.type.Type awardGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AwardList </code> containing the given award record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known awards or an error results. Otherwise, the returned list may 
     *  contain only those awards that are accessible through this session. 
     *
     *  @param  awardRecordType an award record type 
     *  @return the returned <code> Award </code> list 
     *  @throws org.osid.NullArgumentException <code> awardRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AwardList getAwardsByRecordType(org.osid.type.Type awardRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Awards. </code> In plenary mode, the returned list 
     *  contains all known awards or an error results. Otherwise, the returned 
     *  list may contain only those awards that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> Awards </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.AwardList getAwards()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
