//
// org.osid.recognition.ConferralNotificationSession
//
//     The OSID Java specification for org.osid.recognition.ConferralNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Conferral </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p>
 */

public interface ConferralNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Academy </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Academy Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAcademyId();


    /**
     *  Gets the <code> Academy </code> associated with this session. 
     *
     *  @return the academy 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Academy getAcademy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Conferral </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForConferralNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include conferrals in academies which are children of this academy in 
     *  the academy hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAcademyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this academy only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAcademyView();


    /**
     *  Register for notifications of new conferrals. <code> 
     *  ConferralReceiver.newConferrals() </code> is invoked when a new <code> 
     *  Conferral </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewConferrals()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new conferrals for the given recipient 
     *  <code> Id. </code> <code> ConferralReceiver.newConferrals() </code> is 
     *  invoked when a new <code> Conferral </code> is created. 
     *
     *  @param  resourceId the <code> Id </code> of the recipient to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewConferralsForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new conferrals for the given reference 
     *  <code> Id. </code> <code> ConferralReceiver.newConferrals() </code> is 
     *  invoked when a new <code> Conferral </code> is created. 
     *
     *  @param  awardId the <code> Id </code> of the award to monitor 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewConferralsForAward(org.osid.id.Id awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new conferrals for the given convocation 
     *  <code> Id. </code> <code> ConferralReceiver.newConferrals() </code> is 
     *  invoked when a new <code> Conferral </code> is created. 
     *
     *  @param  convocationId the <code> Id </code> of the convocation to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewConferralsByConvocation(org.osid.id.Id convocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated conferrals. <code> 
     *  ConferralReceiver.changedConferrals() </code> is invoked when a 
     *  conferral is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedConferrals()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed conferrals for the given 
     *  recipient <code> Id. </code> <code> 
     *  ConferralReceiver.changedConferrals() </code> is invoked when a <code> 
     *  Conferral </code> for the recipient is changed. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedConferralsForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed conferrals for the given award 
     *  <code> Id. </code> <code> ConferralReceiver.changedConferrals() 
     *  </code> is invoked when a <code> Conferral </code> for the award is 
     *  changed. 
     *
     *  @param  awardId the <code> Id </code> of the award to monitor 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedConferralsForAward(org.osid.id.Id awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed conferrals for the given award 
     *  <code> Id. </code> <code> ConferralReceiver.changedConferrals() 
     *  </code> is invoked when a <code> Conferral </code> for the convocation 
     *  is changed. 
     *
     *  @param  convocationId the <code> Id </code> of the convocation to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedConferralsByConvocation(org.osid.id.Id convocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated conferral. <code> 
     *  ConferralReceiver.changedConferrals() </code> is invoked when the 
     *  specified conferral is changed. 
     *
     *  @param  conferralId the <code> Id </code> of the <code> Conferral 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> conferralId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedConferral(org.osid.id.Id conferralId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted conferrals. <code> 
     *  ConferralReceiver.deletedConferrals() </code> is invoked when a 
     *  conferral is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedConferrals()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted conferrals for the given 
     *  recipient <code> Id. </code> <code> 
     *  ConferralReceiver.deletedConferrals() </code> is invoked when a <code> 
     *  Conferral </code> for the recipient is deleted. 
     *
     *  @param  resourceId the <code> Id </code> of the recipient to monitor 
     *  @throws org.osid.NullArgumentException <code> recipientId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedConferralsForRecipient(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted conferrals for the given award 
     *  <code> Id. </code> <code> ConferralReceiver.deletedConferrals() 
     *  </code> is invoked when a <code> Conferral </code> for the award is 
     *  deleted. 
     *
     *  @param  awardId the <code> Id </code> of the award to monitor 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedConferralsForAward(org.osid.id.Id awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted conferrals for the given 
     *  convocation <code> Id. </code> <code> 
     *  ConferralReceiver.deletedConferrals() </code> is invoked when a <code> 
     *  Conferral </code> for the convocation is deleted. 
     *
     *  @param  convocationId the <code> Id </code> of the convocation to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedConferralsByConvocation(org.osid.id.Id convocationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted conferral. <code> 
     *  ConferralReceiver.deletedConferrals() </code> is invoked when the 
     *  specified conferral is deleted. 
     *
     *  @param  conferralId the <code> Id </code> of the <code> Conferral 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> conferralId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedConferral(org.osid.id.Id conferralId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
