//
// org.osid.recognition.ConferralSmartAcademySession
//
//     The OSID Java specification for org.osid.recognition.ConferralSmartAcademySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> ConferralQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Academy </code> to create a virtual 
 *  collection of <code> Conferrals. </code> The awards may be sequenced using 
 *  the <code> ConferralSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Academy </code> has a default query that matches any 
 *  conferral and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> ConferralQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  ConferralQuery. </code> </p>
 */

public interface ConferralSmartAcademySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Academy </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Academy Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAcademyId();


    /**
     *  Gets the <code> Academy </code> associated with this session. 
     *
     *  @return the <code> Academy </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Academy getAcademy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart academies. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart academy management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartAcademies();


    /**
     *  Gets a conferral query. 
     *
     *  @return the conferral query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralQuery getConferralQuery();


    /**
     *  Gets a conferral search order. 
     *
     *  @return the conferral search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralSearchOrder getConferralSearchOrder();


    /**
     *  Applies a conferral query to this academy. 
     *
     *  @param  conferralQuery the conferral query 
     *  @throws org.osid.NullArgumentException <code> conferralQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> conferralQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyConferralQuery(org.osid.recognition.ConferralQuery conferralQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a conferral query inspector for this academy. 
     *
     *  @return the conferral query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralQueryInspector inspectConferralQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a conferral search order to this academy. 
     *
     *  @param  conferralSearchOrder the conferral search order 
     *  @throws org.osid.NullArgumentException <code> conferralSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> conferralSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyConferralSequencing(org.osid.recognition.ConferralSearchOrder conferralSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a conferral query from an inspector. 
     *
     *  @param  conferralQueryInspector a query inspector 
     *  @return the conferral query 
     *  @throws org.osid.NullArgumentException <code> conferralQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> conferralQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConferralQuery getConferralQueryFromInspector(org.osid.recognition.ConferralQueryInspector conferralQueryInspector);
}
