//
// org.osid.recognition.ConvocationLookupSession
//
//     The OSID Java specification for org.osid.recognition.ConvocationLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This session defines methods for retrieving convocations. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated academy view: All convocation methods in this session 
 *      operate, retrieve and pertain to convocations defined explicitly in 
 *      the current academy. Using an isolated view is useful for managing 
 *      convocations with the <code> ConvocationAdminSession. </code> </li> 
 *      <li> federated academy view: All convocation lookup methods in this 
 *      session operate, retrieve and pertain to all convocations defined in 
 *      this academy and any other academies implicitly available in this 
 *      academy through academy inheritence. </li> 
 *      <li> active convocation view: All convocation lookup methods return 
 *      convocations where the convocation is active. </li> 
 *      <li> any status convocation view: Convocations of any status are 
 *      returned. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedAcademyView() </code> and <code> 
 *  useIsolatedAcademyView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface ConvocationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Academy </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Academy Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAcademyId();


    /**
     *  Gets the <code> Academy </code> associated with this session. 
     *
     *  @return the academy 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Academy getAcademy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup convocations. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if convocation lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupConvocations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeConvocationView();


    /**
     *  A complete view of the <code> Convocation </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryConvocationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include convocations in academies which are children of this academy 
     *  in the academy hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedAcademyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this academy only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedAcademyView();


    /**
     *  Only active convocations are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveConvocationView();


    /**
     *  All convocations of any status are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusConvocationView();


    /**
     *  Gets the <code> Convocation </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Convocation </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Convocation </code> and retained for 
     *  compatibility. 
     *
     *  @param  convocationId the <code> Id </code> of the <code> Convocation 
     *          </code> to retrieve 
     *  @return the returned <code> Convocation </code> 
     *  @throws org.osid.NotFoundException no <code> Convocation </code> found 
     *          with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> convocationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.Convocation getConvocation(org.osid.id.Id convocationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConvocationList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the convocations specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible convocations may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *
     *  @param  convocationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Convocation list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> convocationIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByIds(org.osid.id.IdList convocationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConvocationList </code> corresponding to the given 
     *  convocation genus <code> Type </code> which does not include 
     *  convocations of genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  convocations or an error results. Otherwise, the returned list may 
     *  contain only those convocations that are accessible through this 
     *  session. 
     *
     *  @param  convocationGenusType a convocation genus type 
     *  @return the returned <code> Convocation </code> list 
     *  @throws org.osid.NullArgumentException <code> convocationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByGenusType(org.osid.type.Type convocationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConvocationList </code> corresponding to the given 
     *  convocation genus <code> Type </code> and include any additional 
     *  convocations with genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known 
     *  convocations or an error results. Otherwise, the returned list may 
     *  contain only those convocations that are accessible through this 
     *  session. 
     *
     *  @param  convocationGenusType a convocation genus type 
     *  @return the returned <code> Convocation </code> list 
     *  @throws org.osid.NullArgumentException <code> convocationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByParentGenusType(org.osid.type.Type convocationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ConvocationList </code> containing the given convocation 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known convocations or an error results. Otherwise, the 
     *  returned list may contain only those convocations that are accessible 
     *  through this session. 
     *
     *  @param  convocationRecordType a convocation record type 
     *  @return the returned <code> Convocation </code> list 
     *  @throws org.osid.NullArgumentException <code> convocationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByRecordType(org.osid.type.Type convocationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of convocations with a date within the given date range 
     *  inclusive. In plenary mode, the returned list contains all known 
     *  convocations or an error results. Otherwise, the returned list may 
     *  contain only those convocations that are accessible through this 
     *  session. 
     *
     *  @param  from the starting date 
     *  @param  to the ending date 
     *  @return the returned <code> ConvocationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByDate(org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all convocations corresponding to an award <code> Id. 
     *  </code> In plenary mode, the returned list contains all known 
     *  convocations or an error results. Otherwise, the returned list may 
     *  contain only those convocations that are accessible through this 
     *  session. 
     *
     *  @param  awardId the <code> Id </code> of the award 
     *  @return the returned <code> ConvocationList </code> 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByAward(org.osid.id.Id awardId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all convocations corresponding to a time period <code> 
     *  Id. </code> In plenary mode, the returned list contains all known 
     *  convocations or an error results. Otherwise, the returned list may 
     *  contain only those convocations that are accessible through this 
     *  session. 
     *
     *  @param  timePeriodId the <code> Id </code> of the time period 
     *  @return the returned <code> ConvocationList </code> 
     *  @throws org.osid.NullArgumentException <code> timePeriod </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByTimePeriod(org.osid.id.Id timePeriodId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all convocations for a given provider. In plenary mode, 
     *  the returned list contains all known convocations or an error results. 
     *  Otherwise, the returned list may contain only those convocations that 
     *  are accessible through this session. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @return the returned <code> ConvocationList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocationsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all convocations. In plenary mode, the returned list contains all 
     *  known convocations or an error results. Otherwise, the returned list 
     *  may contain only those convocations that are accessible through this 
     *  session. 
     *
     *  @return a list of convocations 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.ConvocationList getConvocations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
