//
// org.osid.recognition.ConvocationQuery
//
//     The OSID Java specification for org.osid.recognition.ConvocationQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>This is the query for searching convocations. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ConvocationQuery
    extends org.osid.OsidGovernatorQuery {


    /**
     *  Sets an award <code> Id. </code> 
     *
     *  @param  awardId an award <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> awardId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAwardId(org.osid.id.Id awardId, boolean match);


    /**
     *  Clears the award <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAwardIdTerms();


    /**
     *  Tests if an <code> AwardQuery </code> is available. 
     *
     *  @return <code> true </code> if an award query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardQuery();


    /**
     *  Gets the query for an award query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the award query 
     *  @throws org.osid.UnimplementedException <code> supportsAwardQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAwardQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AwardQuery getAwardQuery();


    /**
     *  Matches convocations with any award. 
     *
     *  @param  match <code> true </code> to match convocations with any 
     *          award, <code> false </code> to match convocations with no 
     *          awards 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAward(boolean match);


    /**
     *  Clears the award terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAwardTerms();


    /**
     *  Matches the date between the given dates inclusive. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDate(org.osid.calendaring.DateTime from, 
                          org.osid.calendaring.DateTime to, boolean match);


    /**
     *  Matches convocations with any date. 
     *
     *  @param  match <code> true </code> to match convocations with any date, 
     *          <code> false </code> to match convocations with no date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDate(boolean match);


    /**
     *  Clears the date terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDateTerms();


    /**
     *  Sets a time period <code> Id. </code> 
     *
     *  @param  timePeriodId a time period <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> timePeriodId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimePeriodId(org.osid.id.Id timePeriodId, boolean match);


    /**
     *  Clears the time period <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodIdTerms();


    /**
     *  Tests if a <code> TimePeriodQuery </code> is available. 
     *
     *  @return <code> true </code> if a time period query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimePeriodQuery();


    /**
     *  Gets the query for a time period query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the time period query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimePeriodQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimePeriodQuery() </code> is <code> true. </code> 
     */

    public org.osid.calendaring.TimePeriodQuery getTimePeriodQuery();


    /**
     *  Matches any time period. 
     *
     *  @param  match <code> true </code> to match convocations with any time 
     *          period, <code> false </code> to match convocations with no 
     *          time period 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimePeriod(boolean match);


    /**
     *  Clears the time period terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimePeriodTerms();


    /**
     *  Sets the conferral <code> Id </code> for this query. 
     *
     *  @param  conferralId a conferral <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> conferralId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchConferralId(org.osid.id.Id conferralId, boolean match);


    /**
     *  Clears the conferral <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConferralIdTerms();


    /**
     *  Tests if a conferral query is available. 
     *
     *  @return <code> true </code> if a conferral query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralQuery();


    /**
     *  Gets the query for an award. 
     *
     *  @return the conferral query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsConferralQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsConferralQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.ConferralQuery getConferralQuery();


    /**
     *  Matches convocations with any conferral. 
     *
     *  @param  match <code> true </code> to match convocations with any 
     *          conferral, <code> false </code> to match convocations with no 
     *          conferrals 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyConferral(boolean match);


    /**
     *  Clears the conferral terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearConferralTerms();


    /**
     *  Sets the award <code> Id </code> for this query to match convocations 
     *  assigned to academies. 
     *
     *  @param  academyId an academy <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> academyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAcademyId(org.osid.id.Id academyId, boolean match);


    /**
     *  Clears the academy <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAcademyIdTerms();


    /**
     *  Tests if an <code> AcademyQuery </code> is available. 
     *
     *  @return <code> true </code> if an academy query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademyQuery();


    /**
     *  Gets the query for an academy query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the academy query 
     *  @throws org.osid.UnimplementedException <code> supportsAcademyQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAcademyQuery() </code> is <code> true. </code> 
     */

    public org.osid.recognition.AcademyQuery getAcademyQuery();


    /**
     *  Clears the academy terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAcademyTerms();


    /**
     *  Gets the convocation query record corresponding to the given <code> 
     *  Convocation </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  convocationRecordType a convocation record type 
     *  @return the convocation query record 
     *  @throws org.osid.NullArgumentException <code> convocationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(convocationRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.recognition.records.ConvocationQueryRecord getConvocationQueryRecord(org.osid.type.Type convocationRecordType)
        throws org.osid.OperationFailedException;
}
