//
// org.osid.recognition.RecognitionProfile
//
//     The OSID Java specification for org.osid.recognition.RecognitionProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.recognition;


/**
 *  <p>The recognition profile describes the interoperability among 
 *  recognition services. </p>
 */

public interface RecognitionProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any award federation is exposed. Federation is exposed when a 
     *  specific award may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of awards 
     *  appears as a single award. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a conferral lookup service. 
     *
     *  @return <code> true </code> if conferral lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralLookup();


    /**
     *  Tests if querying conferrals is available. 
     *
     *  @return <code> true </code> if conferral query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralQuery();


    /**
     *  Tests if searching for conferrals is available. 
     *
     *  @return <code> true </code> if conferral search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralSearch();


    /**
     *  Tests if searching for conferrals is available. 
     *
     *  @return <code> true </code> if conferral search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralAdmin();


    /**
     *  Tests if conferral notification is available. 
     *
     *  @return <code> true </code> if conferral notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralNotification();


    /**
     *  Tests if a conferral to academy lookup session is available. 
     *
     *  @return <code> true </code> if conferral academy lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralAcademy();


    /**
     *  Tests if a conferral to academy assignment session is available. 
     *
     *  @return <code> true </code> if conferral academy assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralAcademyAssignment();


    /**
     *  Tests if a conferral smart academy session is available. 
     *
     *  @return <code> true </code> if conferral smart academy is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralSmartAcademy();


    /**
     *  Tests for the availability of an award lookup service. 
     *
     *  @return <code> true </code> if award lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardLookup();


    /**
     *  Tests if querying awards is available. 
     *
     *  @return <code> true </code> if award query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardQuery();


    /**
     *  Tests if searching for awards is available. 
     *
     *  @return <code> true </code> if award search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardSearch();


    /**
     *  Tests for the availability of an award administrative service for 
     *  creating and deleting awards. 
     *
     *  @return <code> true </code> if award administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardAdmin();


    /**
     *  Tests for the availability of an award notification service. 
     *
     *  @return <code> true </code> if award notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAwardNotification();


    /**
     *  Tests if an award to academy lookup session is available. 
     *
     *  @return <code> true </code> if award academy lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardAcademy();


    /**
     *  Tests if an award to academy assignment session is available. 
     *
     *  @return <code> true </code> if award academy assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardAcademyAssignment();


    /**
     *  Tests if an award smart academy session is available. 
     *
     *  @return <code> true </code> if award smart academy is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardSmartAcademy();


    /**
     *  Tests for the availability of a convocation service for getting 
     *  available convocations for a resource. 
     *
     *  @return <code> true </code> if convocation is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocation();


    /**
     *  Tests for the availability of a convocation lookup service. 
     *
     *  @return <code> true </code> if convocation lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationLookup();


    /**
     *  Tests if querying convocations is available. 
     *
     *  @return <code> true </code> if convocation query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationQuery();


    /**
     *  Tests if searching for convocations is available. 
     *
     *  @return <code> true </code> if convocation search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationSearch();


    /**
     *  Tests if searching for convocations is available. 
     *
     *  @return <code> true </code> if convocation search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationAdmin();


    /**
     *  Tests if convocation notification is available. 
     *
     *  @return <code> true </code> if convocation notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationNotification();


    /**
     *  Tests if a convocation to academy lookup session is available. 
     *
     *  @return <code> true </code> if convocation academy lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationAcademy();


    /**
     *  Tests if a convocation to academy assignment session is available. 
     *
     *  @return <code> true </code> if convocation academy assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationAcademyAssignment();


    /**
     *  Tests if a convocation smart academy session is available. 
     *
     *  @return <code> true </code> if convocation smart academy is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationSmartAcademy();


    /**
     *  Tests for the availability of an academy lookup service. 
     *
     *  @return <code> true </code> if academy lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademyLookup();


    /**
     *  Tests if querying academies is available. 
     *
     *  @return <code> true </code> if academy query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademyQuery();


    /**
     *  Tests if searching for academies is available. 
     *
     *  @return <code> true </code> if academy search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademySearch();


    /**
     *  Tests for the availability of an academy administrative service for 
     *  creating and deleting academies. 
     *
     *  @return <code> true </code> if academy administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademyAdmin();


    /**
     *  Tests for the availability of an academy notification service. 
     *
     *  @return <code> true </code> if academy notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAcademyNotification();


    /**
     *  Tests for the availability of an academy hierarchy traversal service. 
     *
     *  @return <code> true </code> if academy hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademyHierarchy();


    /**
     *  Tests for the availability of an academy hierarchy design service. 
     *
     *  @return <code> true </code> if academy hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAcademyHierarchyDesign();


    /**
     *  Tests for the availability of a recognition batch service. 
     *
     *  @return <code> true </code> if a recognition batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRecognitionBatch();


    /**
     *  Gets the supported <code> Conferral </code> record types. 
     *
     *  @return a list containing the supported conferral record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getConferralRecordTypes();


    /**
     *  Tests if the given <code> Conferral </code> record type is supported. 
     *
     *  @param  conferralRecordType a <code> Type </code> indicating a <code> 
     *          Conferral </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> conferralRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralRecordType(org.osid.type.Type conferralRecordType);


    /**
     *  Gets the supported conferral search record types. 
     *
     *  @return a list containing the supported conferral search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getConferralSearchRecordTypes();


    /**
     *  Tests if the given conferral search record type is supported. 
     *
     *  @param  conferralSearchRecordType a <code> Type </code> indicating a 
     *          conferral record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          conferralSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConferralSearchRecordType(org.osid.type.Type conferralSearchRecordType);


    /**
     *  Gets the supported <code> Award </code> record types. 
     *
     *  @return a list containing the supported award record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAwardRecordTypes();


    /**
     *  Tests if the given <code> Award </code> record type is supported. 
     *
     *  @param  awardRecordType a <code> Type </code> indicating a <code> 
     *          Award </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> awardRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardRecordType(org.osid.type.Type awardRecordType);


    /**
     *  Gets the supported award search record types. 
     *
     *  @return a list containing the supported award search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAwardSearchRecordTypes();


    /**
     *  Tests if the given award search record type is supported. 
     *
     *  @param  awardSearchRecordType a <code> Type </code> indicating an 
     *          award record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> awardSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAwardSearchRecordType(org.osid.type.Type awardSearchRecordType);


    /**
     *  Gets the supported <code> Convocation </code> record types. 
     *
     *  @return a list containing the supported convocation record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getConvocationRecordTypes();


    /**
     *  Tests if the given <code> Convocation </code> record type is 
     *  supported. 
     *
     *  @param  convocationRecordType a <code> Type </code> indicating a 
     *          <code> Convocation </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> convocationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationRecordType(org.osid.type.Type convocationRecordType);


    /**
     *  Gets the supported convocation search record types. 
     *
     *  @return a list containing the supported convocation search record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getConvocationSearchRecordTypes();


    /**
     *  Tests if the given convocation search record type is supported. 
     *
     *  @param  convocationSearchRecordType a <code> Type </code> indicating a 
     *          convocation record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          convocationSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsConvocationSearchRecordType(org.osid.type.Type convocationSearchRecordType);


    /**
     *  Gets the supported academy record types. 
     *
     *  @return a list containing the supported academy record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAcademyRecordTypes();


    /**
     *  Tests if the given academy record type is supported. 
     *
     *  @param  academyRecordType a <code> Type </code> indicating an academy 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> academyRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademyRecordType(org.osid.type.Type academyRecordType);


    /**
     *  Gets the supported academy search record types. 
     *
     *  @return a list containing the supported academy search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAcademySearchRecordTypes();


    /**
     *  Tests if the given academy search record type is supported. 
     *
     *  @param  academySearchRecordType a <code> Type </code> indicating an 
     *          academy record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> academySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAcademySearchRecordType(org.osid.type.Type academySearchRecordType);
}
