//
// org.osid.relationship.FamilyQuery
//
//     The OSID Java specification for org.osid.relationship.FamilyQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This is the query interface for searching for families. Each method 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface FamilyQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Matches a relationship <code> Id. </code> 
     *
     *  @param  relationshipId a relationship <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRelationshipId(org.osid.id.Id relationshipId, 
                                    boolean match);


    /**
     *  Clears the relationship <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelationshipIdTerms();


    /**
     *  Tests if a relationship query is available. 
     *
     *  @return <code> true </code> if a relationship query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipQuery();


    /**
     *  Gets the query interface for a relationship. 
     *
     *  @return the relationship query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipQuery getRelationshipQuery();


    /**
     *  Matches families with any relationship. 
     *
     *  @param  match <code> true </code> to match families with any 
     *          relationship, <code> false </code> to match families with no 
     *          relationship 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRelationship(boolean match);


    /**
     *  Clears the relationship terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRelationshipTerms();


    /**
     *  Sets the family <code> Id </code> for this query to match families 
     *  that have the specified family as an ancestor. 
     *
     *  @param  familyId a family <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorFamilyId(org.osid.id.Id familyId, boolean match);


    /**
     *  Clears the ancestor family <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorFamilyIdTerms();


    /**
     *  Tests if a <code> FamilyQuery </code> is available. 
     *
     *  @return <code> true </code> if a family query interface is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorFamilyQuery();


    /**
     *  Gets the query interface for a family. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the family query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorFamilyQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorFamilyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.FamilyQuery getAncestorFamilyQuery();


    /**
     *  Matches families with any ancestor. 
     *
     *  @param  match <code> true </code> to match families with any ancestor, 
     *          <code> false </code> to match root families 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorFamily(boolean match);


    /**
     *  Clears the ancestor family terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorFamilyTerms();


    /**
     *  Sets the family <code> Id </code> for this query to match families 
     *  that have the specified family as a descednant. 
     *
     *  @param  familyId a family <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantFamilyId(org.osid.id.Id familyId, boolean match);


    /**
     *  Clears the descendant family <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantFamilyIdTerms();


    /**
     *  Tests if a <code> FamilyQuery </code> is available. 
     *
     *  @return <code> true </code> if a family query interface is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantFamilyQuery();


    /**
     *  Gets the query interface for a family. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the family query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantFamilyQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantFamilyQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.FamilyQuery getDescendantFamilyQuery();


    /**
     *  Matches families with any decendant. 
     *
     *  @param  match <code> true </code> to match families with any 
     *          decendants, <code> false </code> to match leaf families 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantFamily(boolean match);


    /**
     *  Clears the descendant family terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantFamilyTerms();


    /**
     *  Gets the family query record corresponding to the given <code> Family 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  familyRecordType a family record type 
     *  @return the family query record 
     *  @throws org.osid.NullArgumentException <code> familyRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(familyRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.records.FamilyQueryRecord getFamilyQueryRecord(org.osid.type.Type familyRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
