//
// org.osid.relationship.RelationshipAdminSession
//
//     The OSID Java specification for org.osid.relationship.RelationshipAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This session creates, updates, and deletes <code> Relationships. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Relationship, </code> a <code> RelationshipForm </code> is requested using 
 *  <code> getRelationshipFormForCreate() </code> specifying the desired peers 
 *  and record <code> Types </code> or none if no record <code> Types </code> 
 *  are needed. The returned <code> RelationshipForm </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> 
 *  RelationshipForm </code> is submiited to a create operation, it cannot be 
 *  reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> RelationshipForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> RelationshipForms </code> are requested to the 
 *  <code> Relationship </code> <code> Id </code> that is to be updated using 
 *  <code> getRelationshipFormForUpdate(). </code> Similarly, the <code> 
 *  RelationshipForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  RelationshipForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Relationships. </code> To unmap a 
 *  <code> Relationship </code> from the current <code> Family, </code> the 
 *  <code> RelationshipFamilyAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Relationship </code> itself 
 *  thus removing it from all known <code> Family </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RelationshipAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Familt </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Family Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFamilyId();


    /**
     *  Gets the <code> Family </code> associated with this session. 
     *
     *  @return the family 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Family getFamily()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Relationships </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Relationship </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Relationship </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRelationships();


    /**
     *  Tests if this user can create a single <code> Relationship </code> 
     *  using the desired record types. While <code> 
     *  RelationshipManager.getRelationshipRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Relationship. 
     *  </code> Providing an empty array tests if a <code> Relationship 
     *  </code> can be created with no records. 
     *
     *  @param  relationshipRecordTypes array of relationship record types 
     *  @return <code> true </code> if <code> Relationship </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> relationshipRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRelationshipWithRecordTypes(org.osid.type.Type[] relationshipRecordTypes);


    /**
     *  Gets the relationship form for creating new relationships. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  sourceId <code> Id </code> of a peer 
     *  @param  destinationId <code> Id </code> of the related peer 
     *  @param  relationshipRecordTypes array of relationship record types 
     *  @return the relationship form 
     *  @throws org.osid.NotFoundException <code> sourceId </code> or <code> 
     *          destinationId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> or 
     *          <code> destinationId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          recod types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipForm getRelationshipFormForCreate(org.osid.id.Id sourceId, 
                                                                               org.osid.id.Id destinationId, 
                                                                               org.osid.type.Type[] relationshipRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Relationship. </code> 
     *
     *  @param  relationshipForm the form for this <code> Relationship </code> 
     *  @return the new <code> Relationship </code> 
     *  @throws org.osid.IllegalStateException <code> relationshipForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> relationshipForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relationshipForm </code> 
     *          did not originate from <code> getRelationshipFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Relationship createRelationship(org.osid.relationship.RelationshipForm relationshipForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Relationships. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Relationship </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Relationship </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRelationships();


    /**
     *  Gets the relationship form for updating an existing relationship. A 
     *  new relationship form should be requested for each update transaction. 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @return the relationship form 
     *  @throws org.osid.NotFoundException <code> relationshipId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipForm getRelationshipFormForUpdate(org.osid.id.Id relationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing relationship. 
     *
     *  @param  relationshipForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> relationshipForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> relationshipForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relationshipForm </code> 
     *          did not originate from <code> getRelationshipFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRelationship(org.osid.relationship.RelationshipForm relationshipForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Relationships. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Relationship </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Relationship </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRelationships();


    /**
     *  Deletes a <code> Relationship. </code> 
     *
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> to remove 
     *  @throws org.osid.NotFoundException <code> relationshipId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRelationship(org.osid.id.Id relationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Relationships. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Relationship </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRelationshipAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Relationship </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Relationship </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another relationship, it is 
     *  reassigned to the given relationship <code> Id. </code> 
     *
     *  @param  relationshipId the <code> Id </code> of a <code> Relationship 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> relationship </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRelationship(org.osid.id.Id relationshipId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
