//
// org.osid.relationship.RelationshipProfile
//
//     The OSID Java specification for org.osid.relationship.RelationshipProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>The relationship profile describes the interoperability among 
 *  relationship services. </p>
 */

public interface RelationshipProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any family federation is exposed. Federation is exposed when 
     *  a specific family may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  families appears as a single family. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up relationships is supported. 
     *
     *  @return <code> true </code> if relationship lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipLookup();


    /**
     *  Tests if querying relationships is supported. 
     *
     *  @return <code> true </code> if relationship query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipQuery();


    /**
     *  Tests if searching relationships is supported. 
     *
     *  @return <code> true </code> if relationship search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipSearch();


    /**
     *  Tests if relationship administrative service is supported. 
     *
     *  @return <code> true </code> if relationship administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipAdmin();


    /**
     *  Tests if a relationship notification service is supported. 
     *
     *  @return <code> true </code> if relationship notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipNotification();


    /**
     *  Tests if a relationship family cataloging service is supported. 
     *
     *  @return <code> true </code> if relationship families are supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipFamily();


    /**
     *  Tests if a relationship cataloging service is supported. A 
     *  relationship cataloging service maps relationships to families. 
     *
     *  @return <code> true </code> if relationship families are supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipFamilyAssignment();


    /**
     *  Tests if a relationship smart family cataloging service is supported. 
     *
     *  @return <code> true </code> if relationship smart families are 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipSmartFamily();


    /**
     *  Tests if looking up families is supported. 
     *
     *  @return <code> true </code> if family lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilyLookup();


    /**
     *  Tests if querying families is supported. 
     *
     *  @return <code> true </code> if family query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilyQuery();


    /**
     *  Tests if searching families is supported. 
     *
     *  @return <code> true </code> if family search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilySearch();


    /**
     *  Tests if family <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if family administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilyAdmin();


    /**
     *  Tests if a family notification service is supported. 
     *
     *  @return <code> true </code> if family notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilyNotification();


    /**
     *  Tests for the availability of a family hierarchy traversal service. 
     *
     *  @return <code> true </code> if family hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsFamilyHierarchy();


    /**
     *  Tests for the availability of a family hierarchy design service. 
     *
     *  @return <code> true </code> if family hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilyHierarchyDesign();


    /**
     *  Tests for the availability of a relationship batch service. 
     *
     *  @return <code> true </code> if a relationship batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipBatch();


    /**
     *  Tests if a relationship rules service is supported. 
     *
     *  @return <code> true </code> if relationship rules service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipRules();


    /**
     *  Gets the supported <code> Relationship </code> record types. 
     *
     *  @return a list containing the supported <code> Relationship </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelationshipRecordTypes();


    /**
     *  Tests if the given <code> Relationship </code> record type is 
     *  supported. 
     *
     *  @param  relationshipRecordType a <code> Type </code> indicating a 
     *          <code> Relationship </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> relationshipRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipRecordType(org.osid.type.Type relationshipRecordType);


    /**
     *  Gets the supported <code> Relationship </code> search record types. 
     *
     *  @return a list containing the supported <code> Relationship </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRelationshipSearchRecordTypes();


    /**
     *  Tests if the given <code> Relationship </code> search record type is 
     *  supported. 
     *
     *  @param  relationshipSearchRecordType a <code> Type </code> indicating 
     *          a <code> Relationship </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRelationshipSearchRecordType(org.osid.type.Type relationshipSearchRecordType);


    /**
     *  Gets the supported <code> Family </code> record types. 
     *
     *  @return a list containing the supported <code> Family </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFamilyRecordTypes();


    /**
     *  Tests if the given <code> Family </code> record type is supported. 
     *
     *  @param  familyRecordType a <code> Type </code> indicating a <code> 
     *          Family </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> familyRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilyRecordType(org.osid.type.Type familyRecordType);


    /**
     *  Gets the supported <code> Family </code> search record types. 
     *
     *  @return a list containing the supported <code> Family </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFamilySearchRecordTypes();


    /**
     *  Tests if the given <code> Family </code> search record type is 
     *  supported. 
     *
     *  @param  familySearchRecordType a <code> Type </code> indicating a 
     *          <code> Family </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> familySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilySearchRecordType(org.osid.type.Type familySearchRecordType);
}
