//
// org.osid.relationship.RelationshipQueryInspector
//
//     The OSID Java specification for org.osid.relationship.RelationshipQueryInspector.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This is the query inspector for examining relationship queries. </p>
 */

public interface RelationshipQueryInspector
    extends org.osid.OsidRelationshipQueryInspector {


    /**
     *  Gets the peer <code> Id </code> terms. 
     *
     *  @return the peer <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getSourceIdTerms();


    /**
     *  Gets the other peer <code> Id </code> terms. 
     *
     *  @return the other peer <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getDestinationIdTerms();


    /**
     *  Gets the same peer terms. 
     *
     *  @return the same peer terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getSamePeerIdTerms();


    /**
     *  Gets the family <code> Id </code> terms. 
     *
     *  @return the family <code> Id </code> terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getFamilyIdTerms();


    /**
     *  Gets the family terms. 
     *
     *  @return the family terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.FamilyQueryInspector[] getFamilyTerms();


    /**
     *  Gets the relationship query inspector record corresponding to the 
     *  given <code> Relationship </code> record <code> Type. </code> 
     *
     *  @param  relationshipRecordType a relationship record type 
     *  @return the relationship query inspector record 
     *  @throws org.osid.NullArgumentException <code> relationshipRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(relationshipRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.records.RelationshipQueryInspectorRecord getRelationshipQueryInspectorRecord(org.osid.type.Type relationshipRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
