//
// org.osid.relationship.RelationshipSearchSession
//
//     The OSID Java specification for org.osid.relationship.RelationshipSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship;


/**
 *  <p>This session provides methods for searching among <code> Relationship 
 *  </code> objects. The search query is constructed using the <code> 
 *  Relationship. </code> </p> 
 *  
 *  <p> <code> getRelationshipsByQuery() </code> is the basic search method 
 *  and returns a list of <code> Relationships. </code> A more advanced search 
 *  may be performed with <code> getRelationshipsBySearch(). </code> It 
 *  accepts a <code> RelationshipSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as ordering. <code> getRelationshipsBySearch() </code> returns a 
 *  <code> RelationshipSearchResults </code> that can be used to access the 
 *  resulting <code> RelationshipList </code> or be used to perform a search 
 *  within the result set through <code> RelationshipSearch. </code> </p> 
 *  
 *  <p> Relationships may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  RelationshipQuery. </code> </p>
 */

public interface RelationshipSearchSession
    extends org.osid.relationship.RelationshipQuerySession {


    /**
     *  Gets a relationship search. 
     *
     *  @return the relationship search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipSearch getRelationshipSearch();


    /**
     *  Gets a relationship search order. The <code> RelationshipSearchOrder 
     *  </code> is supplied to a <code> RelationshipSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the relationship search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipSearchOrder getRelationshipSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  relationshipQuery the relationship query 
     *  @param  relationshipSearch the relationship search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> relationshipQuery 
     *          </code> or <code> relationshipSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relationshipQuery </code> 
     *          or <code> relationshipSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipSearchResults getRelationshipsBySearch(org.osid.relationship.RelationshipQuery relationshipQuery, 
                                                                                    org.osid.relationship.RelationshipSearch relationshipSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relationship query from an inspector. The inspector is 
     *  available from a <code> RelationshipSearchResults. </code> 
     *
     *  @param  relationshipQueryInspector a relationship query inspector 
     *  @return the relationship query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          relationshipQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.RelationshipQuery getRelationshipQueryFromInspector(org.osid.relationship.RelationshipQueryInspector relationshipQueryInspector);
}
