//
// org.osid.relationship.batch.RelationshipBatchAdminSession
//
//     The OSID Java specification for org.osid.relationship.batch.RelationshipBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Relationships </code> 
 *  in bulk. The data for create and update is provided by the consumer via 
 *  the form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Relationship, </code> a <code> RelationshipForm </code> is requested using 
 *  <code> getRelationshipFormsForCreate() </code> specifying the desired 
 *  relationship peers and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. Each of the returned <code> 
 *  RelationshipForms </code> will indicate that it is to be used with a 
 *  create operation and can be used to examine metdata or validate data prior 
 *  to creation. Once a <code> RelationshipForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> RelationshipForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> RelationshipForms </code> returned from <code> 
 *  getRelationshipFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> 
 *  RelationshipForm. </code> In the case where there may be duplicates, any 
 *  <code> RelationshipForm </code> of the same peer <code> Ids </code> may be 
 *  used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> RelationshipForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  RelationshipForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire create operation are returned from 
 *  <code> createRelationships(), </code> errors specific to an individual 
 *  <code> RelationshipForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> RelationshipForm </code> through the <code> 
 *  RelationshipForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> RelationshipForms </code> are requested to the 
 *  <code> Relationship </code> <code> Id </code> that is to be updated using 
 *  <code> getRelationshipFormsForUpdate() </code> where the reference <code> 
 *  Id </code> in the <code> RelationshipForm </code> may be used to link the 
 *  request. Similarly, the <code> RelationshipForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> RelationshipForm </code> can only be 
 *  used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> RelationshipForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  RelationshipForm, </code> although the ordering is not defined. Only 
 *  errors that pertain to the entire update operation are returned from 
 *  <code> updateRelationships(), </code> errors specific to an individual 
 *  <code> RelationshipForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> RelationshipForm </code> through the <code> 
 *  RelationshipForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Relationships </code> in bulk. To 
 *  unmap a <code> Relationship </code> from the current <code> Family, 
 *  </code> the <code> RelationshipFamilyAssignmentSession </code> should be 
 *  used. These delete operations attempt to remove the <code> Relationship 
 *  </code> itself thus removing it from all known <code> Family </code> 
 *  catalogs. Bulk delete operations return the results in <code> 
 *  DeleteResponses. </code> </p>
 */

public interface RelationshipBatchAdminSession
    extends org.osid.relationship.RelationshipAdminSession {


    /**
     *  Gets the relationship forms for creating a bunch of new relationships. 
     *  A form is returned for each set of relationship peers. 
     *
     *  @param  peers a list of relationship peers 
     *  @param  relationshipRecordTypes array of relationship record types to 
     *          be included in each create operation or an empty list if none 
     *  @return the relationship forms 
     *  @throws org.osid.NotFoundException a node is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          relationshipRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.batch.RelationshipBatchFormList getRelationshipFormsForCreate(org.osid.relationship.batch.RelationshipPeerList peers, 
                                                                                               org.osid.type.Type[] relationshipRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Relationships. </code> This method returns 
     *  an error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  relationshipForms the relationship forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> relationshipForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createRelationships(org.osid.relationship.batch.RelationshipBatchFormList relationshipForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the relationship forms for updating an existing set of 
     *  relationships. A new relationship form should be requested for each 
     *  update transaction. 
     *
     *  @param  relationshipIds the <code> Ids </code> of the <code> 
     *          Relationship </code> 
     *  @return the relationship form 
     *  @throws org.osid.NotFoundException a <code> relationshipId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> relationshipIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.batch.RelationshipBatchFormList getRelationshipFormsForUpdate(org.osid.id.IdList relationshipIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing relationships. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  relationshipForms the form containing the elements to be 
     *          updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> relationshipForms 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateRelationships(org.osid.relationship.batch.RelationshipBatchFormList relationshipForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Relationships </code> in this <code> Family </code> 
     *  . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllRelationships()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relationships for the given <code> Ids. </code> 
     *
     *  @param  relationshipIds the <code> Ids </code> of the relationships to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> relationshipIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRelationships(org.osid.id.IdList relationshipIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relationships for the given source. 
     *
     *  @param  sourceId the <code> Id </code> of a peer 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRelationshipsForSourceId(org.osid.id.Id sourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relationships for the given destination node. 
     *
     *  @param  destinationId the <code> Id </code> of a peer 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> destinationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRelationshipsForDestinationId(org.osid.id.Id destinationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes relationships ineffective before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveRelationshipsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Relationship </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Relationship </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another relationship, it is reassigned to the 
     *  given relationship <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasRelationships(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
