//
// org.osid.relationship.rules.RelationshipEnablerLookupSession
//
//     The OSID Java specification for org.osid.relationship.rules.RelationshipEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  RelationshipEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated family view: All relationship enabler methods in this 
 *      session operate, retrieve and pertain to relationship enablers defined 
 *      explicitly in the current family. Using an isolated view is useful for 
 *      managing <code> RelationshipEnablers </code> with the <code> 
 *      RelationshipEnablerAdminSession. </code> </li> 
 *      <li> federated family view: All relationship enabler methods in this 
 *      session operate, retrieve and pertain to all relationship enablers 
 *      defined in this family and any other relationship enablers implicitly 
 *      available in this family through family inheritence. </li> 
 *      <li> active relationship enabler view: All relationship enabler lookup 
 *      methods return active relationship enablers. </li> 
 *      <li> any status relationship enabler view: Relationship enablers of 
 *      any active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 */

public interface RelationshipEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Family </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Family Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFamilyId();


    /**
     *  Gets the <code> Family </code> associated with this session. 
     *
     *  @return the family 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Family getFamily()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> RelationshipEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRelationshipEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRelationshipEnablerView();


    /**
     *  A complete view of the <code> RelationshipEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRelationshipEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include relationship enablers in families which are children of this 
     *  family in the family hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFamilyView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this family only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFamilyView();


    /**
     *  Only active relationship enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveRelationshipEnablerView();


    /**
     *  All active and insactive relationship enablers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusRelationshipEnablerView();


    /**
     *  Gets the <code> RelationshipEnabler </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  RelationshipEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> RelationshipEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @param  relationshipEnablerId <code> Id </code> of the <code> 
     *          RelationshipEnabler </code> 
     *  @return the relationship enabler 
     *  @throws org.osid.NotFoundException <code> relationshipEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnabler getRelationshipEnabler(org.osid.id.Id relationshipEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relationship enablers specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> RelationshipEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @param  relationshipEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> RelationshipEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerList getRelationshipEnablersByIds(org.osid.id.IdList relationshipEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipEnablerList </code> corresponding to the 
     *  given relationship enabler genus <code> Type </code> which does not 
     *  include relationship enablers of genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationship enablers or an error results. Otherwise, the returned 
     *  list may contain only those relationship enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @param  relationshipEnablerGenusType a relationship enabler genus type 
     *  @return the returned <code> RelationshipEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerList getRelationshipEnablersByGenusType(org.osid.type.Type relationshipEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipEnablerList </code> corresponding to the 
     *  given relationship enabler genus <code> Type </code> and include any 
     *  additional relationship enablers with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationship enablers or an error results. Otherwise, the returned 
     *  list may contain only those relationship enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @param  relationshipEnablerGenusType a relationship enabler genus type 
     *  @return the returned <code> RelationshipEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerList getRelationshipEnablersByParentGenusType(org.osid.type.Type relationshipEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipEnablerList </code> containing the given 
     *  relationship enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationship enablers or an error results. Otherwise, the returned 
     *  list may contain only those relationship enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @param  relationshipEnablerRecordType a relationship enabler record 
     *          type 
     *  @return the returned <code> RelationshipEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerList getRelationshipEnablersByRecordType(org.osid.type.Type relationshipEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range for any agent. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationship enablers or an error results. Otherwise, the returned 
     *  list may contain only those relationship enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> RelationshipEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerList getRelationshipEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RelationshipEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range and evaluated against the given agent. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationship enablers or an error results. Otherwise, the returned 
     *  list may contain only those relationship enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> RelationshipEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerList getRelationshipEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> RelationshipEnablers. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  relationship enablers or an error results. Otherwise, the returned 
     *  list may contain only those relationship enablers that are accessible 
     *  through this session. 
     *  
     *  In active mode, relationship enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive relationship 
     *  enablers are returned. 
     *
     *  @return the returned <code> RelationshipEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerList getRelationshipEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
