//
// org.osid.relationship.rules.RelationshipEnablerQuery
//
//     The OSID Java specification for org.osid.relationship.rules.RelationshipEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.rules;


/**
 *  <p>This is the query for searching relationship enablers. Each method 
 *  match specifies an <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface RelationshipEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the relationship. 
     *
     *  @param  relationshipId the relationship <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> relationshipId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledRelationshipId(org.osid.id.Id relationshipId, 
                                         boolean match);


    /**
     *  Clears the relationship <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledRelationshipIdTerms();


    /**
     *  Tests if a <code> RelationshipQuery </code> is available. 
     *
     *  @return <code> true </code> if a relationship query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledRelationshipQuery();


    /**
     *  Gets the query for a relationship. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the relationship query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledRelationshipQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledRelationshipQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.RelationshipQuery getRuledRelationshipQuery();


    /**
     *  Matches enablers mapped to any relationship. 
     *
     *  @param  match <code> true </code> for enablers mapped to any 
     *          relationship, <code> false </code> to match enablers mapped to 
     *          no relationship 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledRelationship(boolean match);


    /**
     *  Clears the relationship query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledRelationshipTerms();


    /**
     *  Matches enablers mapped to a family. 
     *
     *  @param  familyId the family <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFamilyId(org.osid.id.Id familyId, boolean match);


    /**
     *  Clears the family <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFamilyIdTerms();


    /**
     *  Tests if a <code> FamilyQuery </code> is available. 
     *
     *  @return <code> true </code> if a family query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFamilyQuery();


    /**
     *  Gets the query for a family. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the family query 
     *  @throws org.osid.UnimplementedException <code> supportsFamilyQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFamilyQuery() </code> is <code> true. </code> 
     */

    public org.osid.relationship.FamilyQuery getFamilyQuery();


    /**
     *  Clears the family query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFamilyTerms();


    /**
     *  Gets the relationship enabler query record corresponding to the given 
     *  <code> RelationshipEnabler </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  relationshipEnablerRecordType a relationship enabler record 
     *          type 
     *  @return the relationship enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(relationshipEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.records.RelationshipEnablerQueryRecord getRelationshipEnablerQueryRecord(org.osid.type.Type relationshipEnablerRecordType)
        throws org.osid.OperationFailedException;
}
