//
// org.osid.relationship.rules.RelationshipEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.relationship.rules.RelationshipEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.rules;


/**
 *  <p>This session provides methods to apply <code> RelationshipEnablers 
 *  </code> to <code> Relationships. </code> A <code> Relationship </code> 
 *  with multiple <code> RelationshipEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> Relationship. 
 *  </code> </p>
 */

public interface RelationshipEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Family </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Family Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFamilyId();


    /**
     *  Gets the <code> Family </code> associated with this session. 
     *
     *  @return the family 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.Family getFamily()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter relationship enabler/relationship 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRelationshipEnablers();


    /**
     *  Adds an existing <code> RelationshipEnabler </code> to a <code> 
     *  Relationship. </code> 
     *
     *  @param  relationshipEnablerId the <code> Id </code> of the <code> 
     *          RelationshipEnabler </code> 
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @throws org.osid.AlreadyExistsException <code> relationshipEnablerId 
     *          </code> is already applied to <code> relationshipId </code> 
     *  @throws org.osid.NotFoundException <code> relationshipEnablerId 
     *          </code> or <code> relationshipId </code> not found 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerId 
     *          </code> or <code> relationshipId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRelationshipEnablerToRelationship(org.osid.id.Id relationshipEnablerId, 
                                                        org.osid.id.Id relationshipId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RelationshipEnabler </code> from a <code> 
     *  Relationship. </code> 
     *
     *  @param  relationshipEnablerId the <code> Id </code> of the <code> 
     *          RelationshipEnabler </code> 
     *  @param  relationshipId the <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @throws org.osid.NotFoundException <code> relationshipEnablerId 
     *          </code> or <code> relationshipId </code> not found or <code> 
     *          relationshipEnablerId </code> not applied to <code> 
     *          relationshipId </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerId 
     *          </code> or <code> relationshipId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRelationshipEnablerFromRelationship(org.osid.id.Id relationshipEnablerId, 
                                                            org.osid.id.Id relationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> RelationshipEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RelationshipEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceRelationshipEnablers();


    /**
     *  Reorders relationship enablers for a relationship by moving the 
     *  specified relationship enabler in front of a reference relationship 
     *  enabler. 
     *
     *  @param  relationshipEnablerId the <code> Id </code> of a <code> 
     *          RelationshipnEnabler </code> 
     *  @param  relationshipId the <code> Id </code> of a <code> Relationship 
     *          </code> 
     *  @param  referenceId the reference relationship enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> relationshipEnablerId, 
     *          relationshipId, </code> or <code> referenceId </code> not 
     *          found or, <code> relationshipnEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> relationshipId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerId, 
     *          relationshipId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRelationshipEnablerAhead(org.osid.id.Id relationshipEnablerId, 
                                             org.osid.id.Id relationshipId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders relationship enablers for a relationship by moving the 
     *  specified relationship enabler behind a reference relationship 
     *  enabler. 
     *
     *  @param  relationshipEnablerId the <code> Id </code> of a <code> 
     *          RelationshipnEnabler </code> 
     *  @param  relationshipId the <code> Id </code> of a <code> Relationship 
     *          </code> 
     *  @param  referenceId the reference relationship enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> relationshipEnablerId, 
     *          relationshipId, </code> or <code> referenceId </code> not 
     *          found or, <code> relationshipnEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> relationshipId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerId, 
     *          relationshipId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRelationshipEnablerBehind(org.osid.id.Id relationshipEnablerId, 
                                              org.osid.id.Id relationshipId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of relationship enablers for a relationship. 
     *
     *  @param  relationshipEnablerIds the <code> Ids </code> for a set of 
     *          <code> RelationshipnEnablers </code> 
     *  @param  relationshipId the <code> Id </code> of a <code> Relationship 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> relationshipId </code> not 
     *          found or, an <code> relationshipEnablerId </code> not related 
     *          to <code> relationshipId </code> 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerIds 
     *          </code> or <code> relationshipId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderRelationshipEnablers(org.osid.id.Id[] relationshipEnablerIds, 
                                          org.osid.id.Id relationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
