//
// org.osid.relationship.rules.RelationshipEnablerSearchSession
//
//     The OSID Java specification for org.osid.relationship.rules.RelationshipEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  RelationshipEnabler </code> objects. The search query is constructed using 
 *  the <code> RelationshipEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getRelationshipEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> RelationshipEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getRelationshipEnablersBySearch(). </code> It accepts a <code> 
 *  RelationshipEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRelationshipEnablersBySearch() </code> returns a 
 *  <code> RelationshipEnablerSearchResults </code> that can be used to access 
 *  the resulting <code> RelationshipEnablerList </code> or be used to perform 
 *  a search within the result set through <code> RelationshipEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated relationship view: searches include relationship 
 *      enablers in relationships of which this relationship is an ancestor in 
 *      the relationship hierarchy </li> 
 *      <li> isolated relationship view: searches are restricted to 
 *      relationship enablers in this relationship </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> RelationshipEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> RelationshipEnablerQuery. </code> </p>
 */

public interface RelationshipEnablerSearchSession
    extends org.osid.relationship.rules.RelationshipEnablerQuerySession {


    /**
     *  Gets a relationship enabler search. 
     *
     *  @return the relationship enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerSearch getRelationshipEnablerSearch();


    /**
     *  Gets a relationship enabler search order. The <code> 
     *  RelationshipEnablerSearchOrder </code> is supplied to a <code> 
     *  RelationshipEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the relationship enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerSearchOrder getRelationshipEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  relationshipEnablerQuery the relationship enabler query 
     *  @param  relationshipEnablerSearch the relationship enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> relationshipEnablerQuery 
     *          </code> or <code> relationshipEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> relationshipEnablerQuery 
     *          </code> or <code> relationshipEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerSearchResults getRelationshipEnablersBySearch(org.osid.relationship.rules.RelationshipEnablerQuery relationshipEnablerQuery, 
                                                                                                        org.osid.relationship.rules.RelationshipEnablerSearch relationshipEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a relationship enabler query from an inspector. The inspector is 
     *  available from a <code> RelationshipEnablerSearchResults. </code> 
     *
     *  @param  relationshipEnablerQueryInspector a relationship enabler query 
     *          inspector 
     *  @return the relationship enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          relationshipEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.relationship.rules.RelationshipEnablerQuery getRelationshipEnablerQueryFromInspector(org.osid.relationship.rules.RelationshipEnablerQueryInspector relationshipEnablerQueryInspector);
}
