//
// org.osid.relationship.rules.RelationshipRulesManager
//
//     The OSID Java specification for org.osid.relationship.rules.RelationshipRulesManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.relationship.rules;


/**
 *  <p>The relationship rules manager provides access to relationship rules 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RelationshipEnablerLookupSession: </code> a session to 
 *      retrieve relationship enablers </li> 
 *      <li> <code> RelationshipEnablerQuerySession: </code> a session to 
 *      query for relationship enablers </li> 
 *      <li> <code> RelationshipEnablerSearchSession: </code> a session to 
 *      search for relationship enablers </li> 
 *      <li> <code> RelationshipEnablerAdminSession: </code> a session to 
 *      create and delete relationship enablers </li> 
 *      <li> <code> RelationshipEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to relationship enabler changes 
 *      </li> 
 *      <li> <code> RelationshipEnablerFamilySession: </code> a session to 
 *      look up relationship enabler family mappings </li> 
 *      <li> <code> RelationshipEnablerFamilyAssignmentSession: </code> a 
 *      session to manage relationship enabler to family mappings </li> 
 *      <li> <code> RelationshipEnablerSmartFamilySession: </code> a session 
 *      to manage dynamic families of relationship enablers </li> 
 *      <li> <code> RelationshipEnablerRuleLookupSession: </code> a session to 
 *      look up relationship enabler to relationship mappings </li> 
 *      <li> <code> RelationshipEnablerRuleApplicationSession: </code> a 
 *      session to apply relationship enablers to relationships </li> 
 *  </ul>
 *  
 */

public interface RelationshipRulesManager
    extends org.osid.OsidManager,
            org.osid.relationship.rules.RelationshipRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler lookup service. 
     *
     *  @return a <code> RelationshipEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerLookupSession getRelationshipEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler lookup service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerLookupSession getRelationshipEnablerLookupSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler query service. 
     *
     *  @return a <code> RelationshipEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerQuerySession getRelationshipEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler query service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerQuerySession getRelationshipEnablerQuerySessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler search service. 
     *
     *  @return a <code> RelationshipEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerSearchSession getRelationshipEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enablers earch service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerSearchSession getRelationshipEnablerSearchSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler administration service. 
     *
     *  @return a <code> RelationshipEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerAdminSession getRelationshipEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler administration service for the given family. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerAdminSession getRelationshipEnablerAdminSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler notification service. 
     *
     *  @param  relationshipEnablerReceiver the notification callback 
     *  @return a <code> RelationshipEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerNotificationSession getRelationshipEnablerNotificationSession(org.osid.relationship.rules.RelationshipEnablerReceiver relationshipEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler notification service for the given family. 
     *
     *  @param  relationshipEnablerReceiver the notification callback 
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no family found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          relationshipEnablerReceiver </code> or <code> familyId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerNotificationSession getRelationshipEnablerNotificationSessionForFamily(org.osid.relationship.rules.RelationshipEnablerReceiver relationshipEnablerReceiver, 
                                                                                                                                 org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup relationship enabler 
     *  family mappings for relationship enablers. 
     *
     *  @return a <code> RelationshipEnablerRelationshipSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerFamily() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerFamily() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerFamilySession getRelationshipEnablerFamilySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  relationship enablers to families. 
     *
     *  @return a <code> RelationshipEnablerFamilyAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerFamilyAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerFamilyAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerFamilyAssignmentSession getRelationshipEnablerFamilyAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage relationship enabler 
     *  smart families. 
     *
     *  @param  familyId the Id of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerSmartFamilySession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerSmartFamily() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerSmartFamily() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerSmartFamilySession getRelationshipEnablerSmartFamilySession(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler mapping lookup service for looking up the rules applied to the 
     *  relationship. 
     *
     *  @return a <code> RelationshipEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerRuleLookupSession getRelationshipEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler mapping lookup service for the given relationship for looking 
     *  up rules applied to a relationship. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerRuleLookupSession getRelationshipEnablerRuleLookupSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler assignment service to apply enablers to relationships. 
     *
     *  @return a <code> RelationshipEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerRuleApplicationSession getRelationshipEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the relationship 
     *  enabler assignment service for the given relationship to apply 
     *  enablers to relationships. 
     *
     *  @param  familyId the <code> Id </code> of the <code> Family </code> 
     *  @return a <code> RelationshipEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Family </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> familyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRelationshipEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRelationshipEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.relationship.rules.RelationshipEnablerRuleApplicationSession getRelationshipEnablerRuleApplicationSessionForFamily(org.osid.id.Id familyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
