//
// org.osid.repository.AssetCompositionDesignSession
//
//     The OSID Java specification for org.osid.repository.AssetCompositionDesignSession.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This session provides the means for adding assets to an asset 
 *  composiiton. The asset is identified inside a composition using its own 
 *  Id. To add the same asset to the composition, multiple compositions should 
 *  be used and placed at the same level in the <code> Composition </code> 
 *  hierarchy. </p>
 */

public interface AssetCompositionDesignSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the <code> Repository </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage mapping of <code> Assets </code> to 
     *  <code> Compositions. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  all methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as an application hint that may opt not to 
     *  offer composition operations. 
     *
     *  @return <code> false </code> if asset composiion is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canComposeAssets();


    /**
     *  Appends an asset to a composition. 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  compositionId <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> assetId </code> already 
     *          part <code> compositionId </code> 
     *  @throws org.osid.NotFoundException <code> assetId </code> or <code> 
     *          compositionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> compositionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addAsset(org.osid.id.Id assetId, org.osid.id.Id compositionId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders assets in a composition by moving the specified asset in 
     *  front of a reference asset. 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  compositionId <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @param  referenceId <code> Id </code> of the reference <code> Asset 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> assetId </code> or <code> 
     *          referenceId </code> <code> not found in compositionId </code> 
     *  @throws org.osid.NullArgumentException <code> assetId, referenceId 
     *          </code> or <code> compositionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAssetAhead(org.osid.id.Id assetId, 
                               org.osid.id.Id compositionId, 
                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders assets in a composition by moving the specified asset behind 
     *  of a reference asset. 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  compositionId <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @param  referenceId <code> Id </code> of the reference <code> Asset 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> assetId </code> or <code> 
     *          referenceId </code> <code> not found in compositionId </code> 
     *  @throws org.osid.NullArgumentException <code> assetId, referenceId 
     *          </code> or <code> compositionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveAssetBehind(org.osid.id.Id assetId, 
                                org.osid.id.Id compositionId, 
                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of assets in a composition. 
     *
     *  @param  assetIds <code> Ids </code> for a set of <code> Assets </code> 
     *  @param  compositionId <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> compositionId </code> not 
     *          found or, an <code> assetId </code> not related to <code> 
     *          compositionId </code> 
     *  @throws org.osid.NullArgumentException <code> instructionIds </code> 
     *          or <code> agendaId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderAssets(org.osid.id.Id[] assetIds, 
                            org.osid.id.Id compositionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Asset </code> from a <code> Composition. </code> 
     *
     *  @param  assetId <code> Id </code> of the <code> Asset </code> 
     *  @param  compositionId <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> assetId </code> <code> not 
     *          found in compositionId </code> 
     *  @throws org.osid.NullArgumentException <code> assetId </code> or 
     *          <code> compositionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization fauilure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeAsset(org.osid.id.Id assetId, 
                            org.osid.id.Id compositionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
