//
// org.osid.repository.AssetContent
//
//     The OSID Java specification for org.osid.repository.AssetContent.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p><code> AssetContent </code> represents a version of content represented 
 *  by an <code> Asset. </code> Although <code> AssetContent </code> is a 
 *  separate <code> OsidObject </code> with its own <code> Id </code> to 
 *  distuinguish it from other content inside an <code> Asset, AssetContent 
 *  </code> can only be accessed through an <code> Asset. </code> </p> 
 *  
 *  <p> Once an <code> Asset </code> is selected, multiple contents should be 
 *  negotiated using the size, fidelity, accessibility requirements or 
 *  application evnironment. </p>
 */

public interface AssetContent
    extends org.osid.OsidObject,
            org.osid.Subjugateable {


    /**
     *  Gets the <code> Asset Id </code> corresponding to this content. 
     *
     *  @return the asset <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssetId();


    /**
     *  Gets the <code> Asset </code> corresponding to this content. 
     *
     *  @return the asset 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Asset getAsset();


    /**
     *  Gets the accessibility types associated with this content. 
     *
     *  @return list of content accessibility types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAccessibilityTypes();


    /**
     *  Tests if a data length is available. 
     *
     *  @return <code> true </code> if a length is available for this content, 
     *          <code> false </code> otherwise. 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDataLength();


    /**
     *  Gets the length of the data represented by this content in bytes. 
     *
     *  @return the length of the data stream 
     *  @throws org.osid.IllegalStateException <code> hasDataLength() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getDataLength();


    /**
     *  Gets the asset content data. 
     *
     *  @return the length of the content data 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transport.DataInputStream getData()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if a URL is associated with this content. 
     *
     *  @return <code> true </code> if a URL is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasURL();


    /**
     *  Gets the URL associated with this content for web-based retrieval. 
     *
     *  @return the url for this data 
     *  @throws org.osid.IllegalStateException <code> hasURL() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public String getURL();


    /**
     *  Gets the asset content record corresponding to the given <code> 
     *  AssetContent </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  assetRecordType </code> may be the <code> Type </code> returned in 
     *  <code> getRecordTypes() </code> or any of its parents in a <code> Type 
     *  </code> hierarchy where <code> hasRecordType(assetRecordType) </code> 
     *  is <code> true </code> . 
     *
     *  @param  assetContentContentRecordType the type of the record to 
     *          retrieve 
     *  @return the asset content record 
     *  @throws org.osid.NullArgumentException <code> assetContentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assetContentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.records.AssetContentRecord getAssetContentRecord(org.osid.type.Type assetContentContentRecordType)
        throws org.osid.OperationFailedException;
}
