//
// org.osid.repository.AssetContentQuery
//
//     The OSID Java specification for org.osid.repository.AssetContentQuery.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This is the query for searching asset contents. Each method forms an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface AssetContentQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the accessibility types for this query. Supplying multiple types 
     *  behaves like a boolean OR among the elements. 
     *
     *  @param  accessibilityType an accessibilityType 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> accessibilityType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAccessibilityType(org.osid.type.Type accessibilityType, 
                                       boolean match);


    /**
     *  Matches asset content that has any accessibility type. 
     *
     *  @param  match <code> true </code> to match content with any 
     *          accessibility type, <code> false </code> to match content with 
     *          no accessibility type 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAccessibilityType(boolean match);


    /**
     *  Clears the accessibility terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAccessibilityTypeTerms();


    /**
     *  Matches content whose length of the data in bytes are inclusive of the 
     *  given range. 
     *
     *  @param  low low range 
     *  @param  high high range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDataLength(long low, long high, boolean match);


    /**
     *  Matches content that has any data length. 
     *
     *  @param  match <code> true </code> to match content with any data 
     *          length, <code> false </code> to match content with no data 
     *          length 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDataLength(boolean match);


    /**
     *  Clears the data length terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDataLengthTerms();


    /**
     *  Matches data in this content. 
     *
     *  @param  data list of matching strings 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @param  partial <code> true </code> for a partial match, <code> false 
     *          </code> for a complete match 
     *  @throws org.osid.NullArgumentException <code> data </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchData(byte[] data, boolean match, boolean partial);


    /**
     *  Matches content that has any data. 
     *
     *  @param  match <code> true </code> to match content with any data, 
     *          <code> false </code> to match content with no data 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyData(boolean match);


    /**
     *  Clears the data terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDataTerms();


    /**
     *  Sets the url for this query. Supplying multiple strings behaves like a 
     *  boolean <code> OR </code> among the elements each which must 
     *  correspond to the <code> stringMatchType. </code> 
     *
     *  @param  url url string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> url </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> url </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(url) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchURL(String url, org.osid.type.Type stringMatchType, 
                         boolean match);


    /**
     *  Matches content that has any url. 
     *
     *  @param  match <code> true </code> to match content with any url, 
     *          <code> false </code> to match content with no url 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyURL(boolean match);


    /**
     *  Clears the url terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearURLTerms();


    /**
     *  Gets the asset content query record corresponding to the given <code> 
     *  AssetContent </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  assetContentRecordType an asset content record type 
     *  @return the asset content query record 
     *  @throws org.osid.NullArgumentException <code> assetContentRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assetContentRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.records.AssetContentQueryRecord getAssetContentQueryRecord(org.osid.type.Type assetContentRecordType)
        throws org.osid.OperationFailedException;
}
