//
// org.osid.repository.AssetQuery
//
//     The OSID Java specification for org.osid.repository.AssetQuery.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>This is the query for searching assets. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> The query record is identified by the <code> 
 *  Asset Type. </code> </p>
 */

public interface AssetQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidAggregateableQuery,
            org.osid.OsidSourceableQuery {


    /**
     *  Adds a title for this query. 
     *
     *  @param  title title string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> title </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> title </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTitle(String title, org.osid.type.Type stringMatchType, 
                           boolean match);


    /**
     *  Matches a title that has any value. 
     *
     *  @param  match <code> true </code> to match assets with any title, 
     *          <code> false </code> to match assets with no title 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTitle(boolean match);


    /**
     *  Clears the title terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTitleTerms();


    /**
     *  Matches assets marked as public domain. 
     *
     *  @param  publicDomain public domain flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPublicDomain(boolean publicDomain);


    /**
     *  Matches assets with any public domain value. 
     *
     *  @param  match <code> true </code> to match assets with any public 
     *          domain value, <code> false </code> to match assets with no 
     *          public domain value 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPublicDomain(boolean match);


    /**
     *  Clears the public domain terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublicDomainTerms();


    /**
     *  Adds a copyright for this query. 
     *
     *  @param  copyright copyright string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> copyright </code> not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> copyright </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCopyright(String copyright, 
                               org.osid.type.Type stringMatchType, 
                               boolean match);


    /**
     *  Matches assets with any copyright statement. 
     *
     *  @param  match <code> true </code> to match assets with any copyright 
     *          value, <code> false </code> to match assets with no copyright 
     *          value 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCopyright(boolean match);


    /**
     *  Clears the copyright terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCopyrightTerms();


    /**
     *  Adds a copyright registration for this query. 
     *
     *  @param  registration copyright registration string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> registration </code> 
     *          not of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> registration </code> or 
     *          <code> stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCopyrightRegistration(String registration, 
                                           org.osid.type.Type stringMatchType, 
                                           boolean match);


    /**
     *  Matches assets with any copyright registration. 
     *
     *  @param  match <code> true </code> to match assets with any copyright 
     *          registration value, <code> false </code> to match assets with 
     *          no copyright registration value 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCopyrightRegistration(boolean match);


    /**
     *  Clears the copyright registration terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCopyrightRegistrationTerms();


    /**
     *  Matches assets marked as distributable. 
     *
     *  @param  distributable distribute verbatim rights flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributeVerbatim(boolean distributable);


    /**
     *  Clears the distribute verbatim terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributeVerbatimTerms();


    /**
     *  Matches assets that whose alterations can be distributed. 
     *
     *  @param  alterable distribute alterations rights flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributeAlterations(boolean alterable);


    /**
     *  Clears the distribute alterations terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributeAlterationsTerms();


    /**
     *  Matches assets that can be distributed as part of other compositions. 
     *
     *  @param  composable distribute compositions rights flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistributeCompositions(boolean composable);


    /**
     *  Clears the distribute compositions terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistributeCompositionsTerms();


    /**
     *  Sets the source <code> Id </code> for this query. 
     *
     *  @param  sourceId the source <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> sourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSourceId(org.osid.id.Id sourceId, boolean match);


    /**
     *  Clears the source <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for the source. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSourceQuery();


    /**
     *  Gets the query for the source. Multiple queries can be retrieved for a 
     *  nested <code> OR </code> term. 
     *
     *  @return the source query 
     *  @throws org.osid.UnimplementedException <code> supportsSourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getSourceQuery();


    /**
     *  Matches assets with any source. 
     *
     *  @param  match <code> true </code> to match assets with any source, 
     *          <code> false </code> to match assets with no sources 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySource(boolean match);


    /**
     *  Clears the source terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSourceTerms();


    /**
     *  Match assets that are created between the specified time period. 
     *
     *  @param  start start time of the query 
     *  @param  end end time of the query 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is les 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCreatedDate(org.osid.calendaring.DateTime start, 
                                 org.osid.calendaring.DateTime end, 
                                 boolean match);


    /**
     *  Matches assets with any creation time. 
     *
     *  @param  match <code> true </code> to match assets with any created 
     *          time, <code> false </code> to match assets with no cerated 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCreatedDate(boolean match);


    /**
     *  Clears the created time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCreatedDateTerms();


    /**
     *  Marks assets that are marked as published. 
     *
     *  @param  published published flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPublished(boolean published);


    /**
     *  Clears the published terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublishedTerms();


    /**
     *  Match assets that are published between the specified time period. 
     *
     *  @param  start start time of the query 
     *  @param  end end time of the query 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is les 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPublishedDate(org.osid.calendaring.DateTime start, 
                                   org.osid.calendaring.DateTime end, 
                                   boolean match);


    /**
     *  Matches assets with any published time. 
     *
     *  @param  match <code> true </code> to match assets with any published 
     *          time, <code> false </code> to match assets with no published 
     *          time 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPublishedDate(boolean match);


    /**
     *  Clears the published time terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPublishedDateTerms();


    /**
     *  Adds a principal credit string for this query. 
     *
     *  @param  credit credit string to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> credit </code> not of 
     *          <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> credit </code> or <code> 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPrincipalCreditString(String credit, 
                                           org.osid.type.Type stringMatchType, 
                                           boolean match);


    /**
     *  Matches a principal credit string that has any value. 
     *
     *  @param  match <code> true </code> to match assets with any principal 
     *          credit string, <code> false </code> to match assets with no 
     *          principal credit string 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyPrincipalCreditString(boolean match);


    /**
     *  Clears the principal credit string terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPrincipalCreditStringTerms();


    /**
     *  Match assets that whose coverage falls between the specified time 
     *  period inclusive. 
     *
     *  @param  start start time of the query 
     *  @param  end end time of the query 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> end </code> is less 
     *          than <code> start </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTemporalCoverage(org.osid.calendaring.DateTime start, 
                                      org.osid.calendaring.DateTime end, 
                                      boolean match);


    /**
     *  Matches assets with any temporal coverage. 
     *
     *  @param  match <code> true </code> to match assets with any temporal 
     *          coverage, <code> false </code> to match assets with no 
     *          temporal coverage 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTemporalCoverage(boolean match);


    /**
     *  Clears the temporal coverage terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTemporalCoverageTerms();


    /**
     *  Sets the location <code> Id </code> for this query of spatial 
     *  coverage. 
     *
     *  @param  locationId the location <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> locationId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchLocationId(org.osid.id.Id locationId, boolean match);


    /**
     *  Clears the location <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationIdTerms();


    /**
     *  Tests if a <code> LocationQuery </code> is available for the provider. 
     *
     *  @return <code> true </code> if a location query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLocationQuery();


    /**
     *  Gets the query for a location. Multiple queries can be retrieved for a 
     *  nested <code> OR </code> term. 
     *
     *  @return the location query 
     *  @throws org.osid.UnimplementedException <code> supportsLocationQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsLocationQuery() </code> is <code> true. </code> 
     */

    public org.osid.mapping.LocationQuery getLocationQuery();


    /**
     *  Matches assets with any provider. 
     *
     *  @param  match <code> true </code> to match assets with any location, 
     *          <code> false </code> to match assets with no locations 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyLocation(boolean match);


    /**
     *  Clears the location terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearLocationTerms();


    /**
     *  Matches assets that are contained within the given spatial unit. 
     *
     *  @param  spatialUnit the spatial unit 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> spatialUnit </code> is 
     *          not suppoted 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSpatialCoverage(org.osid.mapping.SpatialUnit spatialUnit, 
                                     boolean match);


    /**
     *  Clears the spatial coverage terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpatialCoverageTerms();


    /**
     *  Matches assets that overlap or touch the given spatial unit. 
     *
     *  @param  spatialUnit the spatial unit 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> spatialUnit </code> is 
     *          <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> spatialUnit </code> is 
     *          not suppoted 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSpatialCoverageOverlap(org.osid.mapping.SpatialUnit spatialUnit, 
                                            boolean match);


    /**
     *  Matches assets with no spatial coverage. 
     *
     *  @param  match <code> true </code> to match assets with any spatial 
     *          coverage, <code> false </code> to match assets with no spatial 
     *          coverage 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySpatialCoverage(boolean match);


    /**
     *  Clears the spatial coverage overlap terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSpatialCoverageOverlapTerms();


    /**
     *  Sets the asset content <code> Id </code> for this query. 
     *
     *  @param  assetContentId the asset content <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> assetContentId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAssetContentId(org.osid.id.Id assetContentId, 
                                    boolean match);


    /**
     *  Clears the asset content <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssetContentIdTerms();


    /**
     *  Tests if an <code> AssetContentQuery </code> is available. 
     *
     *  @return <code> true </code> if an asset content query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAssetContentQuery();


    /**
     *  Gets the query for the asset content. Multiple queries can be 
     *  retrieved for a nested <code> OR </code> term. 
     *
     *  @return the asset contents query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetContentQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetContentQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetContentQuery getAssetContentQuery();


    /**
     *  Matches assets with any content. 
     *
     *  @param  match <code> true </code> to match assets with any content, 
     *          <code> false </code> to match assets with no content 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAssetContent(boolean match);


    /**
     *  Clears the asset content terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAssetContentTerms();


    /**
     *  Sets the composition <code> Id </code> for this query to match assets 
     *  that are a part of the composition. 
     *
     *  @param  compositionId the composition <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCompositionId(org.osid.id.Id compositionId, boolean match);


    /**
     *  Clears the composition <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompositionIdTerms();


    /**
     *  Tests if a <code> CompositionQuery </code> is available. 
     *
     *  @return <code> true </code> if a composition query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionQuery();


    /**
     *  Gets the query for a composition. Multiple queries can be retrieved 
     *  for a nested <code> OR </code> term. 
     *
     *  @return the composition query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.CompositionQuery getCompositionQuery();


    /**
     *  Matches assets with any composition mappings. 
     *
     *  @param  match <code> true </code> to match assets with any 
     *          composition, <code> false </code> to match assets with no 
     *          composition mappings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyComposition(boolean match);


    /**
     *  Clears the composition terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCompositionTerms();


    /**
     *  Sets the repository <code> Id </code> for this query. 
     *
     *  @param  repositoryId the repository <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRepositoryId(org.osid.id.Id repositoryId, boolean match);


    /**
     *  Clears the repository <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRepositoryIdTerms();


    /**
     *  Tests if a <code> RepositoryQuery </code> is available. 
     *
     *  @return <code> true </code> if a repository query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRepositoryQuery();


    /**
     *  Gets the query for a repository. Multiple queries can be retrieved for 
     *  a nested <code> OR </code> term. 
     *
     *  @return the repository query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.RepositoryQuery getRepositoryQuery();


    /**
     *  Clears the repository terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRepositoryTerms();


    /**
     *  Gets the asset query record corresponding to the given <code> Asset 
     *  </code> record <code> Type. </code> Multiuple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @param  assetRecordType an asset record type 
     *  @return the asset query record 
     *  @throws org.osid.NullArgumentException <code> assetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assetRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.records.AssetQueryRecord getAssetQueryRecord(org.osid.type.Type assetRecordType)
        throws org.osid.OperationFailedException;
}
