//
// org.osid.repository.AssetSearchOrder
//
//     The OSID Java specification for org.osid.repository.AssetSearchOrder.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface AssetSearchOrder
    extends org.osid.OsidObjectSearchOrder,
            org.osid.OsidAggregateableSearchOrder,
            org.osid.OsidSourceableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by asset title. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTitle(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for grouping the result set by published 
     *  domain. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPublicDomain(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for grouping the result set by copyright. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCopyright(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for grouping the result set by copyright 
     *  registration. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCopyrightRegistration(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for grouping the result set by the ability to 
     *  distribute copies. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDistributeVerbatim(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for grouping the result set by the ability to 
     *  distribute alterations. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDistributeAlterations(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for grouping the result set by the ability to 
     *  distribute compositions. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDistributeCompositions(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by asset source. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBySource(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a source order interface is available. 
     *
     *  @return <code> true </code> if a source search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSourceSearchOrder();


    /**
     *  Gets the source order. 
     *
     *  @return the resource search order for the source 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSourceSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSourceSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceSearchOrder getSourceSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by created date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCreatedDate(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for grouping the result set by published 
     *  status. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPublished(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by published date. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPublishedDate(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the principal 
     *  credit string. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByPrincipalCreditString(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by temporal 
     *  coverage. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByTemporalCoverage(org.osid.SearchOrderStyle style);


    /**
     *  Gets the asset search order record corresponding to the given asset 
     *  record <code> Type. </code> Multiple retrievals return the same 
     *  underlying object. 
     *
     *  @param  assetRecordType an asset record type 
     *  @return the asset search order record 
     *  @throws org.osid.NullArgumentException <code> assetRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(assetRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.records.AssetSearchOrderRecord getAssetSearchOrderRecord(org.osid.type.Type assetRecordType)
        throws org.osid.OperationFailedException;
}
