//
// org.osid.repository.RepositoryProxyManager
//
//     The OSID Java specification for org.osid.repository.RepositoryProxyManager.
//
// Copyright (C) 2002-2004, 2007-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010-2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository;


/**
 *  <p>The repository manager provides access to asset lookup and creation 
 *  session and provides interoperability tests for various aspects of this 
 *  service. Methods in this manager support the passing of a <code> Proxy 
 *  </code> for the purposes of passing information from a server environment. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> AssetLookupSession: </code> a session to retrieve assets 
 *      </li> 
 *      <li> <code> AssetQuerySession: </code> a session to query assets </li> 
 *      <li> <code> AssetSearchSession: </code> a session to search for assets 
 *      </li> 
 *      <li> <code> AssetAdminSession: </code> a session to create and delete 
 *      assets </li> 
 *      <li> <code> AssetNotificationSession: </code> a session to receive 
 *      notifications pertaining to asset changes </li> 
 *      <li> <code> AssetRepositorySession: </code> a session to look up asset 
 *      to repository mappings </li> 
 *      <li> <code> AssetRepositoryAssignmentSession: </code> a session to 
 *      manage asset to repository mappings </li> 
 *      <li> <code> AssetSmartRepositorySession: </code> a session to manage 
 *      dynamic repositories of assets </li> 
 *      <li> <code> AssetTemporalSession: </code> a session to access the 
 *      temporal coverage of an asset </li> 
 *      <li> <code> AssetTemporalAssignmentSession: </code> a session to 
 *      manage the temporal coverage of an asset </li> 
 *      <li> <code> AssetSpatialSession: </code> a session to access the 
 *      spatial coverage of an asset </li> 
 *      <li> <code> AssetSpatialAssignmentSession: </code> a session to manage 
 *      the spatial coverage of an asset </li> 
 *      <li> <code> AssetCompositionSession: </code> a session to look up 
 *      asset composition mappings </li> 
 *      <li> <code> AssetCompositionDesignSession: </code> a session to map 
 *      assets to compositions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CompositionLookupSession: a </code> session to retrieve 
 *      compositions </li> 
 *      <li> <code> CompositionQuerySession: </code> a session to query 
 *      compositions </li> 
 *      <li> <code> CompositionSearchSession: </code> a session to search for 
 *      compositions </li> 
 *      <li> <code> CompositionAdminSession: </code> a session to create, 
 *      update and delete compositions </li> 
 *      <li> <code> CompositionNotificationSession: </code> a session to 
 *      receive notifications pertaining to changes in compositions </li> 
 *      <li> <code> CompositionRepositorySession: </code> a session to 
 *      retrieve composition repository mappings </li> 
 *      <li> <code> CompositionRepositoryAssignmentSession: </code> a session 
 *      to manage composition repository mappings </li> 
 *      <li> <code> CompositionSmartRepositorySession: </code> a session to 
 *      manage dynamic repositories of compositions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RepositoryLookupSession: a </code> session to retrieve 
 *      repositories </li> 
 *      <li> <code> RepositoryQuerySession: </code> a session to query 
 *      repositories </li> 
 *      <li> <code> RepositorySearchSession: </code> a session to search for 
 *      repositories </li> 
 *      <li> <code> RepositoryAdminSession: </code> a session to create, 
 *      update and delete repositories </li> 
 *      <li> <code> RepositoryNotificationSession: </code> a session to 
 *      receive notifications pertaining to changes in repositories </li> 
 *      <li> <code> RepositoryHierarchySession: </code> a session to traverse 
 *      repository hierarchies </li> 
 *      <li> <code> RepositoryHierarchyDesignSession: </code> a session to 
 *      manage repository hierarchies </li> 
 *  </ul>
 *  
 */

public interface RepositoryProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.repository.RepositoryProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the asset lookup 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetLookup() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetLookupSession getAssetLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the asset lookup 
     *  service for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAssetLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetLookupSession getAssetLookupSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the asset query 
     *  service. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetQuerySession getAssetQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the asset query 
     *  service for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAssetQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetQuerySession getAssetQuerySessionForRepository(org.osid.id.Id repositoryId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an asset search session. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetSearch() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetSearchSession getAssetSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an asset search session for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsAssetSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetSearchSession getAssetSearchSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                     org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets an asset administration session for creating, updating and 
     *  deleting assets. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetAdmin() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetAdminSession getAssetAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an asset administration session for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetAdminSession getAssetAdminSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                   org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to asset 
     *  changes. 
     *
     *  @param  assetReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return an <code> AssetNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> assetReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetNotificationSession getAssetNotificationSession(org.osid.repository.AssetReceiver assetReceiver, 
                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the asset notification session for the given repository. 
     *
     *  @param  assetReceiver the notification callback 
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> assetReceiver, 
     *          repositoryId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetNotificationSession getAssetNotificationSessionForRepository(org.osid.repository.AssetReceiver assetReceiver, 
                                                                                                 org.osid.id.Id repositoryId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving asset to repository mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetRepositorySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetRepository() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetRepository() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetRepositorySession getAssetRepositorySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning asset to repository mappings. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetRepositoryAsignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetRepositoryAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetRepositoryAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.repository.AssetRepositoryAssignmentSession getAssetRepositoryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets an asset smart repository session for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetSmartRepositorySession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetSmartRepository() </code> <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetSmartRepository() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetSmartRepositorySession getAssetSmartRepositorySession(org.osid.id.Id repositoryId, 
                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving temporal coverage of an asset. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetTemporalSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetTemporal() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetTemporal() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetTemporalSession getAssetTemporalSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving temporal coverage of an asset for the 
     *  given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetTemporalSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetTemporal() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetTemporal() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetTemporalSession getAssetTemporalSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                         org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning temporal coverage to an asset. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetTemporalAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetTemporalAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetTemporalAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetTemporalAssignmentSession getAssetTemporalAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning temporal coverage of an asset for the 
     *  given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetTemporalAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetTemporalAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetTemporalAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetTemporalAssignmentSession getAssetTemporalAssignmentSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving spatial coverage of an asset. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetSpatialSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSpatialAssets() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSpatialAssets() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetSpatialSession getAssetSpatialSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving spatial coverage of an asset for the 
     *  given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetSpatialSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAssetSpatial() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetSpatial() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetSpatialSession getAssetSpatialSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                       org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning spatial coverage to an asset. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetSpatialAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetSpatialAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetSpatialAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetSpatialAssignmentSession getAssetSpatialAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning spatial coverage of an asset for the 
     *  given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return an <code> AssetSpatialAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetSpatialAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetSpatialAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetSpatialAssignmentSession getAssetSpatialAssignmentSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving asset compositions. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetCompositionSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetComposition() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetComposition() </code> is <code> true. </code> 
     */

    public org.osid.repository.AssetCompositionSession getAssetCompositionSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for creating asset compositions. 
     *
     *  @param  proxy a proxy 
     *  @return an <code> AssetCompositionDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAssetCompositionDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAssetCompositionDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.AssetCompositionDesignSession getAssetCompositionDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return the new <code> CompositionLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionLookupSession getCompositionLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the composition 
     *  lookup service for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return the new <code> CompositionLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionLookupSession getCompositionLookupSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a composition query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.CompositionSearchSession getCompositionQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a composition query session for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionQuerySession getCompositionQuerySessionForRepository(org.osid.id.Id repositoryId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a composition search session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionSearchSession getCompositionSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a composition search session for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionSearchSession getCompositionSearchSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a composition administration session for creating, updating and 
     *  deleting compositions. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionAdmin() </code> is <code> true. </code> 
     */

    public org.osid.repository.CompositionAdminSession getCompositionAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a composiiton administrative session for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionAdminSession getCompositionAdminSessionForRepository(org.osid.id.Id repositoryId, 
                                                                                               org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  composition changes. 
     *
     *  @param  compositionReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> compositionReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionNotificationSession getCompositionNotificationSession(org.osid.repository.CompositionReceiver compositionReceiver, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the composition notification session for the given repository. 
     *
     *  @param  compositionReceiver the notification callback 
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> compositionReceiver, 
     *          repositoryId </code> or <code> proxy </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionNotificationSession getCompositionNotificationSessionForRepository(org.osid.repository.CompositionReceiver compositionReceiver, 
                                                                                                             org.osid.id.Id repositoryId, 
                                                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving composition to repository mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionRepositorySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionRepository() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionRepository() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.CompositionRepositorySession getCompositionRepositorySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning composition to repository mappings. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> CompositionRepositoryAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionRepositoryAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionRepositoryAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.repository.CompositionRepositoryAssignmentSession getCompositionRepositoryAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a composition smart repository session for the given repository. 
     *
     *  @param  repositoryId the <code> Id </code> of the repository 
     *  @param  proxy a proxy 
     *  @return a <code> CompositionSmartRepositorySession </code> 
     *  @throws org.osid.NotFoundException <code> repositoryId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> repositoryId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCompositionSmartRepository() </code> <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCompositionSmartRepository() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.repository.CompositionSmartRepositorySession getCompositionSmartRepositorySession(org.osid.id.Id repositoryId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the repository lookup session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RepositoryLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryLookup() </code> is <code> true. </code> 
     */

    public org.osid.repository.RepositoryLookupSession getRepositoryLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the repository query session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RepositoryQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryQuery() </code> is <code> true. </code> 
     */

    public org.osid.repository.RepositoryQuerySession getRepositoryQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the repository search session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RepositorySearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositorySearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositorySearch() </code> is <code> true. </code> 
     */

    public org.osid.repository.RepositorySearchSession getRepositorySearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the repository administrative session for creating, updating and 
     *  deleteing repositories. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RepositoryAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryAdmin() </code> is <code> true. </code> 
     */

    public org.osid.repository.RepositoryAdminSession getRepositoryAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscribing to changes to a 
     *  repository. 
     *
     *  @param  repositoryReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> RepositoryNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> repositoryReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.RepositoryNotificationSession getRepositoryNotificationSession(org.osid.repository.RepositoryReceiver repositoryReceiver, 
                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the repository hierarchy traversal session. 
     *
     *  @param  proxy a proxy 
     *  @return <code> a RepositoryHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.repository.RepositoryHierarchySession getRepositoryHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the repository hierarchy design session. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RepostoryHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryHierarchyDesign() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.repository.RepositoryHierarchyDesignSession getRepositoryHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> RepositoryBatchProxyManager. </code> 
     *
     *  @return a <code> RepostoryBatchProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryBatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryBatch() </code> is <code> true. </code> 
     */

    public org.osid.repository.batch.RepositoryBatchProxyManager getRepositoryBatchProxyManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> RepositoryRulesProxyManager. </code> 
     *
     *  @return a <code> RepostoryRulesProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRepositoryRules() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRepositoryRules() </code> is <code> true. </code> 
     */

    public org.osid.repository.rules.RepositoryRulesProxyManager getRepositoryRulesProxyManager()
        throws org.osid.OperationFailedException;
}
