/**
 * <p>The Open Service Interface Definitions for the org.osid.repository
 * service.</p>
 * 
 * <p>The Repository OSID provides the service of finding and managing digital 
 * assets. </p> 
 * <h4> Assets </h4> 
 * 
 * <p> An <code> Asset </code> represents a unit of content, whether it be an 
 * image, a video, an application document or some text. The Asset defines a 
 * core set of definitions applicable to digital content, such as copyright 
 * and publisher, and allows for a type specification to be appended as with 
 * other <code> OsidObjects. </code> </p> 
 * 
 * <p> Asset content, such as a document, is defined such that there may be 
 * multiple formats contained with the same asset. A document may be 
 * accessible in both PDF and MS Word, but is the same document, for example. 
 * An image may have both a large size and a thumbnail version. Generally, an 
 * asset contains more than one version of content when it is left to the 
 * application to decide which is most appropriate. </p> 
 * 
 * <p> The <code> Asset </code> <code> Type </code> may define methods in 
 * common throughout the content variations. An example asset is one whose 
 * content <code> Types </code> are "Quicktime" and "MPEG", but the <code> 
 * Asset </code> <code> Type </code> is "movie" and defines methods that 
 * describe the move aside from the formats. This "double" Type hierarchy 
 * stemming from the asset requires more care in defining interfaces. </p> 
 * 
 * <p> <code> Assets </code> also have "credits" which define the authors, 
 * editors, creators, performers, producers or any other "role", identified 
 * with a role <code> Type, </code> with the production of the asset. These 
 * are managed externally to the asset through another <code> OsidSession. 
 * </code> </p> 
 * 
 * <p> Through additional optional <code> OsidSessions, </code> the <code> 
 * Asset </code> can be "extended" to offer temporal information. An asset may 
 * pertain to a date, a period of time, or a series of dates and periods. This 
 * mechanism is to offer the ability to search for assets pertaining to a 
 * desired date range without requiring understanding of a <code> Type. 
 * </code> </p> 
 * 
 * <p> Similarly, the <code> Asset </code> can also map to spatial 
 * information. A photograph may be "geotagged" with the GPS coordinates where 
 * it was taken, a conical shape in stellar coordinates could be described for 
 * an astronimocal image, or there may be a desire to may a historical book to 
 * the spatial coordinates of Boston and Philadelphia. Unlike temporal 
 * mappings, the definition of the spatial coordinate is left to a spatial 
 * Type to define. The Repository OSID simply manages spatial mappings to the 
 * Asset. </p> 
 * <h4> Asset Tagging </h4> 
 * 
 * <p> <code> Assets </code> may also relate to Ontology OSID <code> Subjects. 
 * </code> The <code> Subject </code> provides the ability to normalize 
 * information related to subject matter across the <code> Assets </code> to 
 * simplify management and provide a more robust searching mechanism. For 
 * example, with a photograph of the Empire State Building, one may wish to 
 * describe that it was designed by Shreve, Lamb and Harmon and completed in 
 * 1931. The information about the building itself can be described using a 
 * <code> Subject </code> and related to the photograph, and any other 
 * photograph that captures the building. The <code> Asset </code> <code> Type 
 * </code> for the photograph may simply be "photograph" and doesn't attempt 
 * to describe a building, while the <code> AssetContent </code> <code> Type 
 * </code> is "image/jpeg". </p> 
 * 
 * <p> An application performing a search for Empire State Building can be 
 * execute the search over the <code> Subjects, </code> and once the user has 
 * narrowed the subject area, then the related Assets can be retrieved, and 
 * from there negotiate the content. </p> 
 * 
 * <p> A provider wishing to construct a simple inventory database of 
 * buildings in New York may decide to do so using the Resource OSID. The 
 * <code> Resource </code> <code> Type </code> may describe the construction 
 * dates, height, location, style and architects of buildings. The <code> Type 
 * </code> may also include a means of getting a reference image using the 
 * <code> Asset </code> interface. Since there is no explicit relationship 
 * between <code> Subject </code> and <code> Resource, </code> the <code> 
 * Resource </code> can be adapted to the <code> Subject </code> interface 
 * (mapping a <code> buildingResourceType </code> to a <code> 
 * buildingSubjectType </code> ) to use the same data for <code> Subject 
 * </code> to <code> Asset </code> mappings and searching. </p> 
 * <h4> Asset Compositions </h4> 
 * 
 * <p> Asset compositions can be created using the <code> Composition </code> 
 * interface. A <code> Composition </code> is a group of <code> Assets </code> 
 * and compositions may be structured into a hierarchy for the purpose of 
 * "building" larger content. A content management system may make use of this 
 * interface to construct a web page. The <code> Composition </code> hierarchy 
 * may map into an XHTML structure and each <code> Asset </code> represent an 
 * image or a link in the document. However, the produced web page at a given 
 * URL may be represented by another single <code> Asset </code> that whose 
 * content has both the URL and the XHTML stream. </p> 
 * 
 * <p> Another example is an IMS Common Cartridge. The <code> Composition 
 * </code> may be used to produce the zip file cartridge, but consumers may 
 * access the zip file via an <code> Asset </code> . </p> 
 * <h4> Repository Cataloging </h4> 
 * 
 * <p> Finally, <code> Assets </code> and <code> Compositions </code> may be 
 * categorized into <code> Repository </code> objects. A <code> Repository 
 * </code> is a catalog-like interface to help organize assets and subject 
 * matter. Repositories may be organized into hierarchies for organization or 
 * federation purposes. </p> 
 * 
 * <p> This number of service aspects to this Repository OSID produce a large 
 * number of definitions. It is recommended to use the <code> 
 * RepositoryManager </code> definition to select a single <code> OsidSession 
 * </code> of interest, and work that definition through its dependencies 
 * before tackling another aspect. </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Repository OSID includes a rules subpackage for managing dynamic 
 * compositions. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2002-2004, 2007-2008 Massachusetts Institute of 
 * Technology. </p> 
 * 
 * <p> Copyright &copy; 2010-2011 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may nodify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.repository;
