//
// org.osid.repository.rules.CompositionEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.repository.rules.CompositionEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository.rules;


/**
 *  <p>This session provides methods to retrieve <code> CompositionEnabler 
 *  </code> to <code> Composition </code> mappings. A <code> Composition 
 *  </code> with multiple <code> CompositionEnablers </code> means any 
 *  positive rule evaluation across the enablers result in a visible <code> 
 *  Composition </code> node. <code> </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated repository view: All methods in this session operate, 
 *      retrieve and pertain composition enablers defined explicitly in the 
 *      current repository. </li> 
 *      <li> federated repository view: All methods in this session operate, 
 *      retrieve and pertain to all composition enablers defined in this 
 *      repository and any other repository enablers implicitly available in 
 *      this repository through repository inheritence. </li> 
 *  </ul>
 *  
 */

public interface CompositionEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Repository </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Repository Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRepositoryId();


    /**
     *  Gets the <code> Repository </code> associated with this session. 
     *
     *  @return the repository 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.Repository getRepository()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of composition 
     *  enabler/composition mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupCompositionEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeCompositionEnablerRuleView();


    /**
     *  A complete view of the <code> CompositionEnabler </code> and <code> 
     *  Composition </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryCompositionEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include composition enablers in repositories which are children of 
     *  this repository in the repository hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedRepositoryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this repository only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedRepositoryView();


    /**
     *  Gets the <code> CompositionEnabler Id </code> associated with a <code> 
     *  Composition. </code> 
     *
     *  @param   compositionId <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @return the composition enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> compositionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCompositionEnablerIdsForComposition(org.osid.id.Id  compositionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> CompositionEnabler </code> associated with a <code> 
     *  Composition. </code> 
     *
     *  @param  compositionId <code> Id </code> of the <code> Composition 
     *          </code> 
     *  @return the composition enablers 
     *  @throws org.osid.NotFoundException <code> compositionId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> compositionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerList getCompositionEnablersForComposition(org.osid.id.Id compositionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Composition </code> <code> Ids </code> mapped to a 
     *  <code> CompositionEnabler. </code> 
     *
     *  @param  compositionEnablerId <code> Id </code> of a <code> 
     *          CompositionEnabler </code> 
     *  @return list of composition <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> compositionEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> compositionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getCompositionIdsByCompositionEnabler(org.osid.id.Id compositionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Compositions </code> mapped to a <code> 
     *  CompositionEnabler. </code> 
     *
     *  @param  compositionEnablerId <code> Id </code> of a <code> 
     *          CompositionEnabler </code> 
     *  @return list of compositions 
     *  @throws org.osid.NotFoundException <code> compositionEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> compositionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.CompositionList getCompositionsByCompositionEnabler(org.osid.id.Id compositionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
