//
// org.osid.repository.rules.CompositionEnablerSearchSession
//
//     The OSID Java specification for org.osid.repository.rules.CompositionEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  CompositionEnabler </code> objects. The search query is constructed using 
 *  the <code> CompositionEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getCompositionEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> CompositionEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getCompositionEnablersBySearch(). </code> It accepts a <code> 
 *  CompositionEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getCompositionEnablersBySearch() </code> returns a <code> 
 *  CompositionEnablerSearchResults </code> that can be used to access the 
 *  resulting <code> CompositionEnablerList </code> or be used to perform a 
 *  search within the result set through <code> CompositionEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated composition view: searches include composition enablers 
 *      in compositions of which this composition is an ancestor in the 
 *      composition hierarchy </li> 
 *      <li> isolated composition view: searches are restricted to composition 
 *      enablers in this composition </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> CompositionEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> CompositionEnablerQuery. </code> </p>
 */

public interface CompositionEnablerSearchSession
    extends org.osid.repository.rules.CompositionEnablerQuerySession {


    /**
     *  Gets a composition enabler search. 
     *
     *  @return the composition enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerSearch getCompositionEnablerSearch();


    /**
     *  Gets a composition enabler search order. The <code> 
     *  CompositionEnablerSearchOrder </code> is supplied to a <code> 
     *  CompositionEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the composition enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerSearchOrder getCompositionEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  compositionEnablerQuery the composition enabler query 
     *  @param  compositionEnablerSearch the composition enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> compositionEnablerQuery 
     *          </code> or <code> compositionEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> compositionEnablerQuery 
     *          </code> or <code> compositionEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerSearchResults getCompositionEnablersBySearch(org.osid.repository.rules.CompositionEnablerQuery compositionEnablerQuery, 
                                                                                                    org.osid.repository.rules.CompositionEnablerSearch compositionEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a composition enabler query from an inspector. The inspector is 
     *  available from a <code> CompositionEnablerSearchResults. </code> 
     *
     *  @param  compositionEnablerQueryInspector a composition enabler query 
     *          inspector 
     *  @return the composition enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          compositionEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.repository.rules.CompositionEnablerQuery getCompositionEnablerQueryFromInspector(org.osid.repository.rules.CompositionEnablerQueryInspector compositionEnablerQueryInspector);
}
