//
// org.osid.repository.rules.RepositoryRulesProfile
//
//     The OSID Java specification for org.osid.repository.rules.RepositoryRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.repository.rules;


/**
 *  <p>The repository rules profile describes the interoperability among 
 *  repository rules services. </p>
 */

public interface RepositoryRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up composition enablers is supported. 
     *
     *  @return <code> true </code> if composition enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerLookup();


    /**
     *  Tests if querying composition enablers is supported. 
     *
     *  @return <code> true </code> if composition enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerQuery();


    /**
     *  Tests if searching composition enablers is supported. 
     *
     *  @return <code> true </code> if composition enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerSearch();


    /**
     *  Tests if a composition enabler administrative service is supported. 
     *
     *  @return <code> true </code> if composition enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerAdmin();


    /**
     *  Tests if a composition enabler notification service is supported. 
     *
     *  @return <code> true </code> if composition enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerNotification();


    /**
     *  Tests if a composition enabler repository lookup service is supported. 
     *
     *  @return <code> true </code> if a repository enabler composition lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerRepository();


    /**
     *  Tests if a composition enabler repository service is supported. 
     *
     *  @return <code> true </code> if composition enabler repository 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerRepositoryAssignment();


    /**
     *  Tests if a composition enabler repository lookup service is supported. 
     *
     *  @return <code> true </code> if a composition enabler repository 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerSmartRepository();


    /**
     *  Tests if a composition enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a composition enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerRuleLookup();


    /**
     *  Tests if a composition enabler rule application service is supported. 
     *
     *  @return <code> true </code> if composition enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerRuleApplication();


    /**
     *  Gets the supported <code> CompositionEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> CompositionEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCompositionEnablerRecordTypes();


    /**
     *  Tests if the given <code> CompositionEnabler </code> record type is 
     *  supported. 
     *
     *  @param  compositionEnablerRecordType a <code> Type </code> indicating 
     *          a <code> CompositionEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerRecordType(org.osid.type.Type compositionEnablerRecordType);


    /**
     *  Gets the supported <code> CompositionEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> CompositionEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCompositionEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> CompositionEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  compositionEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> CompositionEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          compositionEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompositionEnablerSearchRecordType(org.osid.type.Type compositionEnablerSearchRecordType);
}
