//
// org.osid.resource.BinHierarchySession
//
//     The OSID Java specification for org.osid.resource.BinHierarchySession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> Bin 
 *  </code> objects. Each node in the hierarchy is a unique <code> Bin. 
 *  </code> The hierarchy may be traversed recursively to establish the tree 
 *  structure through <code> getParentBins() </code> and <code> 
 *  getChildBins(). </code> To relate these <code> Ids </code> to another 
 *  OSID, <code> getBinNodes() </code> can be used for retrievals that can be 
 *  used for bulk lookups in other OSIDs. Any <code> Bin </code> available in 
 *  the Resource OSID is known to this hierarchy but does not appear in the 
 *  hierarchy traversal until added as a root node or a child of another node. 
 *  </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentBins() </code> or <code> getChildBins() </code> in lieu 
 *  of a <code> PERMISSION_DENIED </code> error that may disrupt the traversal 
 *  through authorized pathways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: bin elements may be silently omitted or 
 *      re-ordered </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *  </ul>
 *  
 */

public interface BinHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getBinHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  an application that may not offer traversal functions to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessBinHierarchy();


    /**
     *  The returns from the bin methods may omit or translate elements based 
     *  on this session, such as authorization, and not result in an error. 
     *  This view is used when greater interoperability is desired at the 
     *  expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBinView();


    /**
     *  A complete view of the <code> Bin </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBinView();


    /**
     *  Gets the root bin <code> Ids </code> in this hierarchy. 
     *
     *  @return the root bin <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootBinIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root bins in the bin hierarchy. A node with no parents is an 
     *  orphan. While all bin <code> Ids </code> are known to the hierarchy, 
     *  an orphan does not appear in the hierarchy unless explicitly added as 
     *  a root node or child of another node. 
     *
     *  @return the root bins 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resource.BinList getRootBins()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> Bin </code> has any parents. 
     *
     *  @param  binId the <code> Id </code> of a bin 
     *  @return <code> true </code> if the bin has parents, <code> false 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentBins(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of a bin. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  binId the <code> Id </code> of a bin 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> binId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfBin(org.osid.id.Id id, org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given bin. 
     *
     *  @param  binId the <code> Id </code> of a bin 
     *  @return the parent <code> Ids </code> of the bin 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentBinIds(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given bin. 
     *
     *  @param  binId the <code> Id </code> to query 
     *  @return the parents of the bin 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.BinList getParentBins(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of a bin. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  binId the <code> Id </code> of a bin 
     *  @return <code> true </code> if this <code> id </code> is an ancestor 
     *          of <code> binId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfBin(org.osid.id.Id id, org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a bin has any children. 
     *
     *  @param  binId the <code> Id </code> of a bin 
     *  @return <code> true </code> if the <code> binId </code> has children, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildBins(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a bin is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  binId the <code> Id </code> of a bin 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> binId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfBin(org.osid.id.Id id, org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given bin . 
     *
     *  @param  binId the <code> Id </code> to query 
     *  @return the children of the bin 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildBinIds(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given bin. 
     *
     *  @param  binId the <code> Id </code> to query 
     *  @return the children of the bin 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.BinList getChildBins(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of a bin. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  binId the <code> Id </code> of a bin 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> binId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfBin(org.osid.id.Id id, org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given bin. 
     *
     *  @param  binId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the node. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the node. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given node, <code> false </code> to omit the siblings 
     *  @return a bin node 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getBinNodeIds(org.osid.id.Id binId, 
                                                 long ancestorLevels, 
                                                 long descendantLevels, 
                                                 boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given bin. 
     *
     *  @param  binId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the node. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the node. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given node, <code> false </code> to omit the siblings 
     *  @return a bin node 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.BinNode getBinNodes(org.osid.id.Id binId, 
                                                 long ancestorLevels, 
                                                 long descendantLevels, 
                                                 boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
