//
// org.osid.resource.GroupAssignmentSession
//
//     The OSID Java specification for org.osid.resource.GroupAssignmentSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session provides methods to re-assign <code> Resources </code> to 
 *  group <code> Resources. </code> </p>
 */

public interface GroupAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the <code> Bin </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can change resource group mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer assignment operations. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignResources();


    /**
     *  Tests if this user can assign members to the given group. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignResourcesToGroup(org.osid.id.Id resourceId);


    /**
     *  Adds an existing <code> Resource </code> to a <code> Resource </code> 
     *  group. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @param  resourceGroupId the <code> Id </code> of the <code> Resource 
     *          </code> group 
     *  @throws org.osid.AlreadyExistsException <code> resourceId </code> is 
     *          already part of <code> resourceGroupId </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          resourceGroupId </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> resourceGroupId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignResourceToGroup(org.osid.id.Id resourceId, 
                                      org.osid.id.Id resourceGroupId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Resource </code> from a <code> Resource </code> 
     *  group. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @param  resourceGroupId the <code> Id </code> of the <code> Repository 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> resourceId or 
     *          resourceGroupId </code> not found or <code> resourceId </code> 
     *          not part of <code> resourceGroupId </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId or 
     *          resourceGroupId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignResourceFromGroup(org.osid.id.Id resourceId, 
                                          org.osid.id.Id resourceGroupId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
