//
// org.osid.resource.GroupSession
//
//     The OSID Java specification for org.osid.resource.GroupSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session provides methods to retrieve <code> Resource </code> to 
 *  <code> Group </code> mappings. A <code> Resource </code> may appear in 
 *  multiple resource groups. A group is also represented by a resource 
 *  itself. </p>
 */

public interface GroupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the <code> Bin </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of resource members. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known lookup methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up members is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupResourceMembers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeResourceView();


    /**
     *  A complete view of the <code> Resource </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryResourceView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include resources in bins which are children of this bin in the bin 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBinView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts resources to this bin only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBinView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include resources in groups which are children of the specified group 
     *  in the group hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGroupView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to the specified group only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGroupView();


    /**
     *  Gets the list of <code> Resource </code> <code> Ids </code> associated 
     *  with a <code> Resource. </code> In a federated view, resources for 
     *  child groups are included. 
     *
     *  @param  groupResourceId <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @return list of member resource <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> groupResourceId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> groupResourceId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResourceIdsByGroup(org.osid.id.Id groupResourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Resources </code> associated with a <code> 
     *  Resource. </code> In a federated view, resources for child groups are 
     *  included. 
     *
     *  @param  groupResourceId <code> Id </code> of the <code> Resource 
     *          </code> 
     *  @return list of resourcememembers 
     *  @throws org.osid.NotFoundException <code> groupResourceId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> groupResourceId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getResourcesByGroup(org.osid.id.Id groupResourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Resource Ids </code> corresponding to a list 
     *  of <code> Resource </code> objects. 
     *
     *  @param  groupResourceIds list of resource <code> Ids </code> 
     *  @return list of resource <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> groupResourceIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResourceIdsByGroups(org.osid.id.IdList groupResourceIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Resources </code> corresponding to a list of 
     *  <code> Resource </code> objects. 
     *
     *  @param  groupResourceIds list of resource <code> Ids </code> 
     *  @return list of resources 
     *  @throws org.osid.NullArgumentException <code> groupResourceIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getResourcesByGroups(org.osid.id.IdList groupResourceIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Resource </code> <code> Ids </code> mapped to 
     *  a <code> Resource. </code> 
     *
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return list of group resource <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getGroupIdsByResource(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Resource </code> objects mapped to a <code> 
     *  Resource. </code> 
     *
     *  @param  resourceId <code> Id </code> of a <code> Resource </code> 
     *  @return list of group resources 
     *  @throws org.osid.NotFoundException <code> resourceId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getGroupsByResource(org.osid.id.Id resourceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
