//
// org.osid.resource.ResourceManager
//
//     The OSID Java specification for org.osid.resource.ResourceManager.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>The resource manager provides access to resource lookup and creation 
 *  sessions and provides interoperability tests for various aspects of this 
 *  service. The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ResourceLookupSession: </code> a session to retrieve 
 *      resources </li> 
 *      <li> <code> ResourceQuerySession: </code> a session to query resources 
 *      </li> 
 *      <li> <code> ResourceSearchSession: </code> a session to search for 
 *      resources </li> 
 *      <li> <code> ResourceAdminSession: </code> a session to create and 
 *      delete resources </li> 
 *      <li> <code> ResourceNotificationSession: </code> a session to receive 
 *      notifications pertaining to resource changes </li> 
 *      <li> <code> ResourceBinSession: </code> a session to look up resource 
 *      to bin mappings </li> 
 *      <li> <code> ResourceBinAssignmentSession: </code> a session to manage 
 *      resource to bin mappings </li> 
 *      <li> <code> ResourceSmartBinSession: </code> a session to manage smart 
 *      resource bins </li> 
 *      <li> <code> MembershipSession: </code> a session to query memberships 
 *      </li> 
 *      <li> <code> GroupSession: </code> a session to retrieve group 
 *      memberships </li> 
 *      <li> <code> GroupAssignmentSession: </code> a session to manage groups 
 *      </li> 
 *      <li> <code> GroupNotificationSession: </code> a session to retrieve 
 *      notifications on changes to group membership </li> 
 *      <li> <code> GroupHierarchySession: </code> a session to view a group 
 *      hierarchy </li> 
 *      <li> <code> RsourceAgentSession: </code> a session to retrieve <code> 
 *      Resource </code> and <code> Agent </code> mappings </li> 
 *      <li> <code> ResourceAgentAssignmentSession: </code> a session to 
 *      manage <code> Resource </code> and <code> Agent </code> mappings </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ResourceRelationshipLookupSession: </code> a session to 
 *      retrieve resource relationships </li> 
 *      <li> <code> ResourceRelationshipQuerySession: </code> a session to 
 *      query for resource relationships </li> 
 *      <li> <code> ResourceRelationshipSearchSession: </code> a session to 
 *      search for resource relationships </li> 
 *      <li> <code> ResourceRelationshipAdminSession: </code> a session to 
 *      create and delete resource relationships </li> 
 *      <li> <code> ResourceRelationshipNotificationSession: </code> a session 
 *      to receive notifications pertaining to resource relationshipchanges 
 *      </li> 
 *      <li> <code> ResourceRelationshipBinSession: </code> a session to look 
 *      up resource relationship to bin mappings </li> 
 *      <li> <code> ResourceRelationshipBinAssignmentSession: </code> a 
 *      session to manage resource relationship to bin mappings </li> 
 *      <li> <code> ResourceRelationshipSmartBinSession: </code> a session to 
 *      manage smart resource relationship bins </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BinLookupSession: a </code> session to retrieve bins </li> 
 *      <li> <code> BinQuerySession: </code> a session to query bins </li> 
 *      <li> <code> BinSearchSession: </code> a session to search for bins 
 *      </li> 
 *      <li> <code> BinAdminSession: </code> a session to create, update and 
 *      delete bins </li> 
 *      <li> <code> BinNotificationSession: </code> a session to receive 
 *      notifications pertaining to changes in bins </li> 
 *      <li> <code> BinHierarchySession: </code> a session to traverse bin 
 *      hierarchies </li> 
 *      <li> <code> BinHierarchyDesignSession: </code> a session to manage bin 
 *      hierarchies </li> 
 *  </ul>
 *  
 */

public interface ResourceManager
    extends org.osid.OsidManager,
            org.osid.resource.ResourceProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  lookup service. 
     *
     *  @return <code> a ResourceLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceLookup() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceLookupSession getResourceLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  lookup service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return <code> a ResourceLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceLookupSession getResourceLookupSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a resource query session. 
     *
     *  @return <code> a ResourceQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuerySession getResourceQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a resource query session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return <code> a ResourceQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuerySession getResourceQuerySessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a resource search session. 
     *
     *  @return <code> a ResourceSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceSearch() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceSearchSession getResourceSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a resource search session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return <code> a ResourceSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceSearchSession getResourceSearchSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a resource administration session for creating, updating and 
     *  deleting resources. 
     *
     *  @return <code> a ResourceAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResourceAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceAdmin() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceAdminSession getResourceAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a resource administration session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return <code> a ResourceAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResourceAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceAdminSession getResourceAdminSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to resource 
     *  changes. 
     *
     *  @param  resourceReceiver the notification callback 
     *  @return <code> a ResourceNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> resourceReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceNotificationSession getResourceNotificationSession(org.osid.resource.ResourceReceiver resourceReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resource notification session for the given bin. 
     *
     *  @param  resourceReceiver the notification callback 
     *  @param  binId the <code> Id </code> of the bin 
     *  @return <code> a ResourceNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceReceiver </code> 
     *          or <code> binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceNotificationSession getResourceNotificationSessionForBin(org.osid.resource.ResourceReceiver resourceReceiver, 
                                                                                              org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving resource to bin mappings. 
     *
     *  @return a <code> ResourceBinSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResourceBin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceBin() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceBinSession getResourceBinSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning resource to bin mappings. 
     *
     *  @return a <code> ResourceBinAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceBinAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceBinAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceBinAssignmentSession getResourceBinAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic resource bins. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return a <code> ResourceSmartBinSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceSmartBin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceSmartBin() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceSmartBinSession getResourceSmartBinSession(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for querying memberships. 
     *
     *  @return a <code> MembershipSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMembership() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportMembership() </code> is <code> true. </code> 
     */

    public org.osid.resource.MembershipSession getMembershipSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a resource membership session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return <code> a MembershipSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsMembership() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMembership() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.MembershipSession getMembershipSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving gropup memberships. 
     *
     *  @return a <code> GroupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsGroup() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroup() </code> is <code> true. </code> 
     */

    public org.osid.resource.GroupSession getGroupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a group session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return a <code> GroupSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsGroup() </code> 
     *          or <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.GroupSession getGroupSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning resources to groups. 
     *
     *  @return a <code> GroupAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGroupAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroupAssignment() </code> is <code> true. </code> 
     */

    public org.osid.resource.GroupAssignmentSession getGroupAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a group assignment session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return a <code> GroupAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGroupAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroupAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.GroupAssignmentSession getGroupAssignmentSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to resource 
     *  changes. 
     *
     *  @param  groupRceeiver the notification callback 
     *  @return <code> a GroupNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> groupReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGroupNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroupNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.GroupNotificationSession getGroupNotificationSession(org.osid.resource.GroupReceiver groupRceeiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the group notification session for the given bin. 
     *
     *  @param  groupRceeiver the notification callback 
     *  @param  binId the <code> Id </code> of the bin 
     *  @return <code> a GroupNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> groupReceiver </code> or 
     *          <code> binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGroupNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroupNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.GroupNotificationSession getGroupNotificationSessionForBin(org.osid.resource.GroupReceiver groupRceeiver, 
                                                                                        org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a session for retrieving gropup hierarchies. 
     *
     *  @return <code> a GroupHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGroupHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroupHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.resource.GroupHierarchySession getGroupHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a group hierarchy session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return a <code> GroupHierarchySession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGroupHierarchy() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGroupHierarchy() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.GroupHierarchySession getGroupHierarchySessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving resource agent mappings. 
     *
     *  @return a <code> ResourceAgentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResourceAgent() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceAgent() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceAgentSession getResourceAgentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a resource agent session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return a <code> ResourceAgentSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResourceAgent() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceAgent() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceAgentSession getResourceAgentSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning agents to resources. 
     *
     *  @return a <code> ResourceAgentAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceAgentAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceAgentAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceAgentAssignmentSession getResourceAgentAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a resource agent session for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return a <code> ResourceAgentAssignmentSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceAgentAssignment() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceAgentAssignment() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceAgentAssignmentSession getResourceAgentAssignmentSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship lookup service. 
     *
     *  @return a <code> ResourceRelationshipLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.ResourceRelationshipLookupSession getResourceRelationshipLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship lookup service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> ResourceRelationshipLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.resource.ResourceRelationshipLookupSession getResourceRelationshipLookupSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship query service. 
     *
     *  @return a <code> ResourceRelationshipQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.ResourceRelationshipQuerySession getResourceRelationshipQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship query service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> ResourceRelationshipQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Bin </code> found by the 
     *          given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.resource.ResourceRelationshipQuerySession getResourceRelationshipQuerySessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship search service. 
     *
     *  @return a <code> ResourceRelationshipSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.ResourceRelationshipSearchSession getResourceRelationshipSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship search service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> ResourceRelationshipSearchSession </code> 
     *  @throws org.osid.NotFoundException no bin found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.resource.ResourceRelationshipSearchSession getResourceRelationshipSearchSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship administration service. 
     *
     *  @return a <code> ResourceRelationshipAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.ResourceRelationshipAdminSession getResourceRelationshipAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship administration service for the given bin. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> ResourceRelationshipAdminSession </code> 
     *  @throws org.osid.NotFoundException no bin found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.resource.ResourceRelationshipAdminSession getResourceRelationshipAdminSessionForBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship notification service. 
     *
     *  @param  resourceRelationshipReceiver the notification callback 
     *  @return a <code> ResourceRelationshipNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resource.ResourceRelationshipNotificationSession getResourceRelationshipNotificationSession(org.osid.resource.ResourceRelationshipReceiver resourceRelationshipReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the resource 
     *  relationship notification service for the given bin. 
     *
     *  @param  resourceRelationshipReceiver the notification callback 
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return a <code> ResourceRelationshipNotificationSession </code> 
     *  @throws org.osid.NotFoundException no bin found by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipReceiver </code> or <code> binId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshiptNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.resource.ResourceRelationshipNotificationSession getResourceRelationshipNotificationSessionForBin(org.osid.resource.ResourceRelationshipReceiver resourceRelationshipReceiver, 
                                                                                                                      org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving resource relationship to bin mappings. 
     *
     *  @return a <code> ResourceRelationshipBinSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipBin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipBin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceRelationshipBinSession getResourceRelationshipBinSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning resource relationships to bin mappings. 
     *
     *  @return a <code> ResourceRelationshipBinAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipBinAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipBinAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.resource.ResourceRelationshipBinAssignmentSession getResourceRelationshipBinAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic resource relationship bins. 
     *
     *  @param  binId the <code> Id </code> of the bin 
     *  @return a <code> ResourceRelationshipSmartBinSession </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceRelationshipSmartBin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceRelationshipSmartBin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.ResourceRelationshipSmartBinSession getResourceRelationshipSmartBinSession(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the bin lookup session. 
     *
     *  @return a <code> BinLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBinLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinLookup() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinLookupSession getBinLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the bin query session. 
     *
     *  @return a <code> BinQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBinQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinQuerySession getBinQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the bin search session. 
     *
     *  @return a <code> BinSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBinSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinSearch() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinSearchSession getBinSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the bin administrative session for creating, updating and 
     *  deleteing bins. 
     *
     *  @return a <code> BinAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBinAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinAdmin() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinAdminSession getBinAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscribing to changes to a bin. 
     *
     *  @param  binReceiver the notification callback 
     *  @return a <code> BinNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> binReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBinNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinNotification() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinNotificationSession getBinNotificationSession(org.osid.resource.BinReceiver binReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the bin hierarchy traversal session. 
     *
     *  @return <code> a BinHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBinHierarchy() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinHierarchySession getBinHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the bin hierarchy design session. 
     *
     *  @return a <code> BinHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBinHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.BinHierarchyDesignSession getBinHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ResourceBatchManager. </code> 
     *
     *  @return a <code> ResourceBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsResourceBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceBatch() </code> is <code> true. </code> 
     */

    public org.osid.resource.batch.ResourceBatchManager getResourceBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> ResourceDemographicManager. </code> 
     *
     *  @return a <code> ResourceDemographicManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResourceDemographic() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceDemographic() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.demographic.ResourceDemographicManager getResourceDemographicManager()
        throws org.osid.OperationFailedException;
}
