//
// org.osid.resource.ResourceProfile
//
//     The OSID Java specification for org.osid.resource.ResourceProfile.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>The resource profile describes interoperability among resource 
 *  services. </p>
 */

public interface ResourceProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if federation is visible. 
     *
     *  @return <code> true </code> if visible federation is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if resource lookup is supported. 
     *
     *  @return <code> true </code> if resource lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceLookup();


    /**
     *  Tests if resource query is supported. 
     *
     *  @return <code> true </code> if resource query is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Tests if resource search is supported. 
     *
     *  @return <code> true </code> if resource search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceSearch();


    /**
     *  Tests if resource administration is supported. 
     *
     *  @return <code> true </code> if resource administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceAdmin();


    /**
     *  Tests if resource notification is supported. Messages may be sent when 
     *  resources are created, modified, or deleted. 
     *
     *  @return <code> true </code> if resource notification is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceNotification();


    /**
     *  Tests if retrieving mappings of resource and bins is supported. 
     *
     *  @return <code> true </code> if resource bin mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceBin();


    /**
     *  Tests if managing mappings of resource and bins is supported. 
     *
     *  @return <code> true </code> if resource bin assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceBinAssignment();


    /**
     *  Tests if resource smart bins are available. 
     *
     *  @return <code> true </code> if resource smart bins are supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceSmartBin();


    /**
     *  Tests if membership queries are supported. 
     *
     *  @return <code> true </code> if membership queries are supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMembership();


    /**
     *  Tests if group resources are supported. 
     *
     *  @return <code> true </code> if group resources are supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGroup();


    /**
     *  Tests if group resource assignment is supported. 
     *
     *  @return <code> true </code> if group resource assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGroupAssignment();


    /**
     *  Tests if group resource notification is supported. 
     *
     *  @return <code> true </code> if group resource notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGroupNotification();


    /**
     *  Tests if a group resource hierarchy service is supported. 
     *
     *  @return <code> true </code> if group resource hierarchy is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGroupHierarchy();


    /**
     *  Tests if retrieving mappings of resource and agents is supported. 
     *
     *  @return <code> true </code> if resource agent mapping retrieval is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceAgent();


    /**
     *  Tests if managing mappings of resources and agents is supported. 
     *
     *  @return <code> true </code> if resource agent assignment is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceAgentAssignment();


    /**
     *  Tests if looking up resource relationships is supported. 
     *
     *  @return <code> true </code> if resource relationships lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipLookup();


    /**
     *  Tests if querying resource relationships is supported. 
     *
     *  @return <code> true </code> if resource relationships query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipQuery();


    /**
     *  Tests if searching resource relationships is supported. 
     *
     *  @return <code> true </code> if resource relationships search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipSearch();


    /**
     *  Tests if a resource relationships <code> </code> administrative 
     *  service is supported. 
     *
     *  @return <code> true </code> if resource relationships administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipAdmin();


    /**
     *  Tests if a resource relationships <code> </code> notification service 
     *  is supported. 
     *
     *  @return <code> true </code> if resource relationships notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipNotification();


    /**
     *  Tests if retrieving mappings of resource relationships and bins is 
     *  supported. 
     *
     *  @return <code> true </code> if resource relationship bin mapping 
     *          retrieval is supported <code> , </code> <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipBin();


    /**
     *  Tests if managing mappings of resource relationships and bins is 
     *  supported. 
     *
     *  @return <code> true </code> if resource relationship bin assignment is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipBinAssignment();


    /**
     *  Tests if resource relationship smart bins are available. 
     *
     *  @return <code> true </code> if resource relationship smart bins are 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipSmartBin();


    /**
     *  Tests if bin lookup is supported. 
     *
     *  @return <code> true </code> if bin lookup is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinLookup();


    /**
     *  Tests if bin query is supported. 
     *
     *  @return <code> true </code> if bin query is supported <code> , </code> 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinQuery();


    /**
     *  Tests if bin search is supported. 
     *
     *  @return <code> true </code> if bin search is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinSearch();


    /**
     *  Tests if bin administration is supported. 
     *
     *  @return <code> true </code> if bin administration is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinAdmin();


    /**
     *  Tests if bin notification is supported. Messages may be sent when 
     *  <code> Bin </code> objects are created, deleted or updated. 
     *  Notifications for resources within bins are sent via the resource 
     *  notification session. 
     *
     *  @return <code> true </code> if bin notification is supported <code> , 
     *          </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinNotification();


    /**
     *  Tests if a bin hierarchy traversal is supported. 
     *
     *  @return <code> true </code> if a bin hierarchy traversal is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinHierarchy();


    /**
     *  Tests if a bin hierarchy design is supported. 
     *
     *  @return <code> true </code> if a bin hierarchy design is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinHierarchyDesign();


    /**
     *  Tests if a resource batch service is available. 
     *
     *  @return <code> true </code> if a resource batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceBatch();


    /**
     *  Tests if a resource demographic service is available. 
     *
     *  @return <code> true </code> if a resource demographic service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceDemographic();


    /**
     *  Gets all the resource record types supported. 
     *
     *  @return the list of supported resource record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResourceRecordTypes();


    /**
     *  Tests if a given resource record type is supported. 
     *
     *  @param  resourceRecordType the resource type 
     *  @return <code> true </code> if the resource record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> resourceRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRecordType(org.osid.type.Type resourceRecordType);


    /**
     *  Gets all the resource search record types supported. 
     *
     *  @return the list of supported resource search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResourceSearchRecordTypes();


    /**
     *  Tests if a given resource search type is supported. 
     *
     *  @param  resourceSearchRecordType the resource search type 
     *  @return <code> true </code> if the resource search record type is 
     *          supported <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> resourceSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceSearchRecordType(org.osid.type.Type resourceSearchRecordType);


    /**
     *  Gets the supported <code> ResourceRelationship </code> record types. 
     *
     *  @return a list containing the supported <code> ResourceRelationship 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResourceRelationshipRecordTypes();


    /**
     *  Tests if the given <code> ResourceRelationship </code> record type is 
     *  supported. 
     *
     *  @param  resourceRelationshipRecordType a <code> Type </code> 
     *          indicating a <code> ResourceRelationship </code> record type 
     *  @return <code> true </code> if the given type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipRecordType(org.osid.type.Type resourceRelationshipRecordType);


    /**
     *  Gets the supported <code> ResourceRelationship </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> ResourceRelationship 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResourceRelationshipSearchRecordTypes();


    /**
     *  Tests if the given <code> ResourceRelationship </code> search record 
     *  type is supported. 
     *
     *  @param  resourceRelationshipSearchRecordType a <code> Type </code> 
     *          indicating a <code> ResourceRelationship </code> search record 
     *          type 
     *  @return <code> true </code> if the given Type is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceRelationshipSearchRecordType(org.osid.type.Type resourceRelationshipSearchRecordType);


    /**
     *  Gets all the bin record types supported. 
     *
     *  @return the list of supported bin record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBinRecordTypes();


    /**
     *  Tests if a given bin record type is supported. 
     *
     *  @param  binRecordType the bin record type 
     *  @return <code> true </code> if the bin record type is supported <code> 
     *          , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> binRecordType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinRecordType(org.osid.type.Type binRecordType);


    /**
     *  Gets all the bin search record types supported. 
     *
     *  @return the list of supported bin search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBinSearchRecordTypes();


    /**
     *  Tests if a given bin search record type is supported. 
     *
     *  @param  binSearchRecordType the bin search record type 
     *  @return <code> true </code> if the bin search record type is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> binSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinSearchRecordType(org.osid.type.Type binSearchRecordType);
}
