//
// org.osid.resource.ResourceRelationshipAdminSession
//
//     The OSID Java specification for org.osid.resource.ResourceRelationshipAdminSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session creates, updates, and deletes <code> 
 *  ResourceRelationships. </code> The data for create and update is provided 
 *  by the consumer via the form object. <code> OsidForms </code> are 
 *  requested for each create or update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  ResourceRelationship, </code> a <code> ResourceRelationshipForm </code> is 
 *  requested using <code> geResourceRelationshipFormForCreate() </code> 
 *  specifying the <code> nodes </code> and desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> ResourceRelationshipForm </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once the <code> ResourceRelationshipForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> ResourceRelationshipForm </code> corresponds to an attempted 
 *  transaction. </p> 
 *  
 *  <p> For updates, <code> ResourceRelationshipForms </code> are requested to 
 *  the <code> ResourceRelationship </code> <code> Id </code> that is to be 
 *  updated using <code> getResourceRelationshipFormForUpdate(). </code> 
 *  Similarly, the <code> ResourceRelationshipForm </code> has metadata about 
 *  the data that can be updated and it can perform validation before 
 *  submitting the update. The <code> ResourceRelationshipForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> ResourceRelationships. </code> To 
 *  unmap s <code> ResourceRelationship </code> from the current <code> Bin, 
 *  </code> the <code> ResourceRelationshipBinAssignmentSession </code> should 
 *  be used. These delete operations attempt to remove the <code> 
 *  ResourceRelationship </code> itself thus removing it from all known <code> 
 *  Bin </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface ResourceRelationshipAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the bin 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> ResourceRelationships. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known creating a <code> 
     *  ResourceRelationship </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ResourceRelationship </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateResourceRelationships();


    /**
     *  Tests if this user can create a single <code> ResourceRelationship 
     *  </code> using the desired record types. While <code> 
     *  ResourceManager.getResourceRelationshipRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  ResourceRelationship. </code> Providing an empty array tests if a 
     *  <code> ResourceRelationship </code> can be created with no records. 
     *
     *  @param  resourceRelationshipRecordTypes array of resource relationship 
     *          types 
     *  @return <code> true </code> if <code> ResourceRelationship </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateResourceRelationshipWithRecordTypes(org.osid.type.Type[] resourceRelationshipRecordTypes);


    /**
     *  Gets the relationship form for creating new relationships. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  sourceResourceId the <code> Id </code> of the source <code> 
     *          Resource </code> 
     *  @param  destinationResourceId the <code> Id </code> of the destination 
     *          <code> Resource </code> 
     *  @param  resourceRelationshipRecordTypes array of resource relationship 
     *          types 
     *  @return the relationship form 
     *  @throws org.osid.NotFoundException <code> sourceResourceId </code> or 
     *          <code> destinationResourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> peerResourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipForm getResourceRelationshipFormForCreate(org.osid.id.Id sourceResourceId, 
                                                                                           org.osid.id.Id destinationResourceId, 
                                                                                           org.osid.type.Type[] resourceRelationshipRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> ResourceRelationship. </code> 
     *
     *  @param  resourceRelationshipForm the form for this <code> 
     *          ResourceRelationship </code> 
     *  @return the new <code> ResourceRelationship </code> 
     *  @throws org.osid.IllegalStateException <code> resourceRelationshipForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          peerResourceId </code> or <code> resourceRelationshipForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> resourceRelationshipForm 
     *          </code> did not originate from <code> 
     *          getResourceRelationshipFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationship createResourceRelationship(org.osid.resource.ResourceRelationshipForm resourceRelationshipForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> ResourceRelationships. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating a <code> 
     *  ResourceRelationship </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if relationship modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateResourceRelationships();


    /**
     *  Gets the relationship form for updating an existing relationship. A 
     *  new relationship form should be requested for each update transaction. 
     *
     *  @param  resourceRelationshipId the <code> Id </code> of the <code> 
     *          ResourceRelationship </code> 
     *  @return the relationship form 
     *  @throws org.osid.NotFoundException <code> resourceRelationshipId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipForm getResourceRelationshipFormForUpdate(org.osid.id.Id resourceRelationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing relationship. 
     *
     *  @param  resourceRelationshipForm the form containing the elements to 
     *          be updated 
     *  @throws org.osid.IllegalStateException <code> resourceRelationshipForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> resourceRelationshipForm 
     *          </code> did not originate from <code> 
     *          getResourceRelationshipFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateResourceRelationship(org.osid.resource.ResourceRelationshipForm resourceRelationshipForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> ResourceRelationships. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known deleting a <code> 
     *  ResourceRelationship </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ResourceRelationship </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteResourceRelationships();


    /**
     *  Deletes the <code> ResourceRelationship </code> identified by the 
     *  given <code> Id. </code> 
     *
     *  @param  resourceRelationshipId the <code> Id </code> of the <code> 
     *          ResourceRelationship </code> to delete 
     *  @throws org.osid.NotFoundException a <code> ResourceRelationship 
     *          </code> was not found identified by the given <code> Id 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteResourceRelationship(org.osid.id.Id resourceRelationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  ResourceRelationships. </code> A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  changing an alias will result in a <code> PERMISSION_DENIED. </code> 
     *  This is intended as a hint to an application that may opt not to offer 
     *  alias operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> ResourceRelationship </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageResourceRelationshipAliases();


    /**
     *  Adds an <code> Id </code> to a <code> ResourceRelationship </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> ResourceRelationship </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  resource relationshp, it is reassigned to the given resource 
     *  relationship <code> Id. </code> 
     *
     *  @param  resourceRelationshipId the <code> Id </code> of a <code> 
     *          ResourceRelationship </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> resourceRelationshipId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasResourceRelationship(org.osid.id.Id resourceRelationshipId, 
                                          org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
