//
// org.osid.resource.ResourceRelationshipBinAssignmentSession
//
//     The OSID Java specification for org.osid.resource.ResourceRelationshipBinAssignmentSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session provides methods to re-assign <code> ResourceRelationships 
 *  </code> to <code> Bins. </code> A <code> ResourceRelationship </code> may 
 *  map to multiple <code> Bin </code> objects and removing the last reference 
 *  to a <code> ResourceRelationship </code> is the equivalent of deleting it. 
 *  Each <code> Bin </code> may have its own authorizations governing who is 
 *  allowed to operate on it. </p> 
 *  
 *  <p> Moving or adding a reference of a <code> ResourceRelationship </code> 
 *  to another <code> Bin </code> is not a copy operation (eg: does not change 
 *  its <code> Id </code> ). </p>
 */

public interface ResourceRelationshipBinAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter resource relationship/bin mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignResourceRelationships();


    /**
     *  Tests if this user can alter resource relationship/bin mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED </code> . This is intended 
     *  as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignResourceRelationshipsToBin(org.osid.id.Id binId);


    /**
     *  Gets a list of bins including and under the given bin node in which 
     *  any resource relationship can be assigned. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @return list of assignable bin <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBinIds(org.osid.id.Id binId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of bins including and under the given bin node in which a 
     *  specific resource relationship can be assigned. 
     *
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @param  resourceRelationshipId the <code> Id </code> of the <code> 
     *          ResourceRelationship </code> 
     *  @return list of assignable bin <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> binId </code> or <code> 
     *          resourceRelationshipId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableBinIdsForResourceRelationship(org.osid.id.Id binId, 
                                                                         org.osid.id.Id resourceRelationshipId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> ResourceRelationship </code> to a <code> Bin. 
     *  </code> 
     *
     *  @param  resourceRelationshipId the <code> Id </code> of the <code> 
     *          ResourceRelationship </code> 
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @throws org.osid.AlreadyExistsException <code> resourceRelationshipId 
     *          </code> is already assigned to <code> binId </code> 
     *  @throws org.osid.NotFoundException <code> resourceRelationshipId 
     *          </code> or <code> binId </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> or <code> binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignResourceRelationshipToBin(org.osid.id.Id resourceRelationshipId, 
                                                org.osid.id.Id binId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ResourceRelationship </code> from a <code> Bin. 
     *  </code> 
     *
     *  @param  resourceRelationshipId the <code> Id </code> of the <code> 
     *          ResourceRelationship </code> 
     *  @param  binId the <code> Id </code> of the <code> Bin </code> 
     *  @throws org.osid.NotFoundException <code> resourceRelationshipId 
     *          </code> or <code> binId </code> not found or <code> 
     *          resourceRelationshipId </code> not assigned to <code> binId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> or <code> binId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignResourceRelationshipFromBin(org.osid.id.Id resourceRelationshipId, 
                                                    org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
