//
// org.osid.resource.ResourceRelationshipBinSession
//
//     The OSID Java specification for org.osid.resource.ResourceRelationshipBinSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session provides methods to retrieve <code> ResourceRelationship 
 *  </code> to <code> Bin </code> mappings. A <code> Resource </code> may 
 *  appear in multiple <code> Bins. </code> Each <code> Bin </code> may have 
 *  its own authorizations governing who is allowed to look at it. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface ResourceRelationshipBinSession
    extends org.osid.OsidSession {


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBinView();


    /**
     *  A complete view of the <code> Resource </code> and <code> Bin </code> 
     *  returns is desired. Methods will return what is requested or result in 
     *  an error. This view is used when greater precision is desired at the 
     *  expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBinView();


    /**
     *  Tests if this user can perform lookups of resource relationship/bin 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupResourceRelationshipBinMappings();


    /**
     *  Gets the list of <code> ResourceRelationship </code> <code> Ids 
     *  </code> associated with a <code> Bin. </code> 
     *
     *  @param  binId <code> Id </code> of a <code> Bin </code> 
     *  @return list of related resource relationship <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResourceRelationshipIdsByBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> ResourceRelationships </code> associated with 
     *  a <code> Bin. </code> 
     *
     *  @param  binId <code> Id </code> of a <code> Bin </code> 
     *  @return list of related resource relationship 
     *  @throws org.osid.NotFoundException <code> binId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByBin(org.osid.id.Id binId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> ResourceRelationship Ids </code> corresponding 
     *  to a list of <code> Bin </code> objects. 
     *
     *  @param  binIds list of bin <code> Ids </code> 
     *  @return list of resource relationship <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> binIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getResourceRelationshipsIdsByBins(org.osid.id.IdList binIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> ResourceRelationships </code> corresponding to 
     *  a list of <code> Bins. </code> 
     *
     *  @param  binIds list of bin <code> Ids </code> 
     *  @return list of resource relationships 
     *  @throws org.osid.NullArgumentException <code> binIds </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByBins(org.osid.id.IdList binIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Bin </code> <code> Ids </code> mapped to a 
     *  <code> ResourceRelationship. </code> 
     *
     *  @param  resourceRelationshipId <code> Id </code> of a <code> 
     *          ResourceRelationship </code> 
     *  @return list of bin <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> resourceRelationshipId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getBinIdsByResourceRelationship(org.osid.id.Id resourceRelationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the list of <code> Bin </code> objects mapped to a <code> 
     *  ResourceRelationship. </code> 
     *
     *  @param  resourceRelationshipId <code> Id </code> of a <code> 
     *          ResourceRelationship </code> 
     *  @return list of bins 
     *  @throws org.osid.NotFoundException <code> resourceRelationshipId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.BinList getBinsByResourceRelationship(org.osid.id.Id resourceRelationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
