//
// org.osid.resource.ResourceRelationshipLookupSession
//
//     The OSID Java specification for org.osid.resource.ResourceRelationshipLookupSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session provides methods for examining resource relationships. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated bin view: All relationship methods in this session 
 *      operate, retrieve and pertain to relationships defined explicitly in 
 *      the current bin. Using an isolated view is useful for managing 
 *      relationships with the <code> ResourceRelationshipAdminSession. 
 *      </code> </li> 
 *      <li> federated bin view: All relationship methods in this session 
 *      operate, retrieve and pertain to all relationships defined in this bin 
 *      and any other catalogs implicitly available in this bin through bin 
 *      inheritence. </li> 
 *      <li> effective resource relationship view: All resource relationship 
 *      lookup methods return resource relationships where the current date 
 *      falls in between the effective dates inclusive. </li> 
 *      <li> any resource relationship view: Resource relationships of any 
 *      effective date are returned from methods. </li> 
 *  </ul>
 *  
 */

public interface ResourceRelationshipLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the <code> Bin </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can access resource relationships. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer relationship operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupResourceRelationships();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeResourceRelationshipView();


    /**
     *  A complete view of the resource relationship returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryResourceRelationshipView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include relationships in bins which are children of this bin in the 
     *  bin hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBinView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts relationships to this bin only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBinView();


    /**
     *  Only resource relationships whose effective dates are current are 
     *  returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveResourceRelationshipView();


    /**
     *  All resource relationships of any effective dates are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveResourceRelationshipView();


    /**
     *  Gets the <code> ResourceRelationship </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Relationship </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Relationship </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  resourceRelationshipId <code> Id </code> of the <code> 
     *          Relationship </code> 
     *  @return the relationship 
     *  @throws org.osid.NotFoundException <code> resourceRelationshipId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resource.ResourceRelationship getResourceRelationship(org.osid.id.Id resourceRelationshipId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ResourceRelationshipList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  relationships specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Relationships </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  resourceRelationshipIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> ResourceRelationship </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> resourceRelationshipIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByIds(org.osid.id.IdList resourceRelationshipIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the resource relationships for the given resource relationship 
     *  genus type. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> relationshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByGenusType(org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the reource relationships for the given resource relationship 
     *  genus type and include any relationships with a genus type derived 
     *  from the specified genus type. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> relationshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByParentGenusType(org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the resource relationships for the given resource relationship 
     *  record type. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  relationshipRecordType a relationship record type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> relationshipRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByRecordType(org.osid.type.Type relationshipRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the resource relationships effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective in addition to being effective during the given 
     *  dates. In any effective mode, effective resource relationships and 
     *  those currently expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsOnDate(org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ResourceRelationships </code> of a resource. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  sourceResourceId <code> Id </code> of a <code> Resource 
     *          </code> 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceResourceId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsForSourceResource(org.osid.id.Id sourceResourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of resource relationships for a resource and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  resource relationships or an error results. Otherwise, the returned 
     *  list may contain only those resource relationships that are accessible 
     *  through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective in addition to being effective during the given 
     *  dates. In any effective mode, effective resource relationships and 
     *  those currently expired are returned. 
     *
     *  @param  sourceResourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceResourceId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsForSourceResourceOnDate(org.osid.id.Id sourceResourceId, 
                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ResourceRelationships </code> of a resource of 
     *  relationship genus type that includes any genus type derived from the 
     *  given one. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  sourceResourceId <code> Id </code> of a <code> Resource 
     *          </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceResourceId </code> 
     *          or <code> relationshipGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByGenusTypeForSourceResource(org.osid.id.Id sourceResourceId, 
                                                                                                           org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of resource relationships of a given genus type for a 
     *  resource and effective during the entire given date range inclusive 
     *  but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  resource relationships or an error results. Otherwise, the returned 
     *  list may contain only those resource relationships that are accessible 
     *  through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective in addition to being effective during the given 
     *  dates. In any effective mode, effective resource relationships and 
     *  those currently expired are returned. 
     *
     *  @param  sourceResourceId a resource <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceResourceId, 
     *          relationshipGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByGenusTypeForSourceResourceOnDate(org.osid.id.Id sourceResourceId, 
                                                                                                                 org.osid.type.Type relationshipGenusType, 
                                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ResourceRelationships </code> of a resource. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  destinationResourceId <code> Id </code> of a <code> Resource 
     *          </code> 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> destinationResourceId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsForDestinationResource(org.osid.id.Id destinationResourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of resource relationships for a resource and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  resource relationships or an error results. Otherwise, the returned 
     *  list may contain only those resource relationships that are accessible 
     *  through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective in addition to being effective during the given 
     *  dates. In any effective mode, effective resource relationships and 
     *  those currently expired are returned. 
     *
     *  @param  sourceResourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> destinationResourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsForDestinationResourceOnDate(org.osid.id.Id sourceResourceId, 
                                                                                                           org.osid.calendaring.DateTime from, 
                                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ResourceRelationships </code> of a resource of 
     *  relationship genus type that includes any genus type derived from the 
     *  given one. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  destinationResourceId <code> Id </code> of a <code> Resource 
     *          </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> destinationResourceId 
     *          </code> or <code> relationshipGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByGenusTypeForDestinationResource(org.osid.id.Id destinationResourceId, 
                                                                                                                org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of resource relationships of a given genus type for a 
     *  resource and effective during the entire given date range inclusive 
     *  but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  resource relationships or an error results. Otherwise, the returned 
     *  list may contain only those resource relationships that are accessible 
     *  through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective in addition to being effective during the given 
     *  dates. In any effective mode, effective resource relationships and 
     *  those currently expired are returned. 
     *
     *  @param  destinationResourceId a resource <code> Id </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> destinationResourceId, 
     *          relationshipGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByGenusTypeForDestinationResourceOnDate(org.osid.id.Id destinationResourceId, 
                                                                                                                      org.osid.type.Type relationshipGenusType, 
                                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ResourceRelationships </code> given two resources. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  sourceResourceId <code> Id </code> of a <code> Resource 
     *          </code> 
     *  @param  destinationResourceId <code> Id </code> of another <code> 
     *          Resource </code> 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceRelationshipId 
     *          </code> or <code> destinationRelationshipId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsForResources(org.osid.id.Id sourceResourceId, 
                                                                                           org.osid.id.Id destinationResourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of resource relationships for a two peer resources and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  resource relationships or an error results. Otherwise, the returned 
     *  list may contain only those resource relationships that are accessible 
     *  through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective in addition to being effective during the given 
     *  dates. In any effective mode, effective resource relationships and 
     *  those currently expired are returned. 
     *
     *  @param  sourceResourceId a resource <code> Id </code> 
     *  @param  destinationResourceId <code> Id </code> of another <code> 
     *          Resource </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceResourceId, 
     *          destinationResourceId, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsForResourcesOnDate(org.osid.id.Id sourceResourceId, 
                                                                                                 org.osid.id.Id destinationResourceId, 
                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> ResourceRelationships </code> given two resources and 
     *  a relationship genus type which includes any genus types derived from 
     *  the given genus type. 
     *  
     *  In plenary mode, the returned list contains all known relationships or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  relationships that are accessible through this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @param  sourceResourceId <code> Id </code> of a <code> Resource 
     *          </code> 
     *  @param  destinationResourceId <code> Id </code> of another <code> 
     *          Resource </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @return the relationships 
     *  @throws org.osid.NullArgumentException <code> sourceResourceId, 
     *          destinationResourceId, </code> or <code> relatonshipGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByGenusTypeForResources(org.osid.id.Id sourceResourceId, 
                                                                                                      org.osid.id.Id destinationResourceId, 
                                                                                                      org.osid.type.Type relationshipGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of resource relationships of a given genus type for a two 
     *  peer resources and effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known resource 
     *  relationships or an error results. Otherwise, the returned list may 
     *  contain only those resource relationships that are accessible through 
     *  this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective in addition to being effective during the given 
     *  dates. In any effective mode, effective resource relationships and 
     *  those currently expired are returned. 
     *
     *  @param  sourceResourceId a resource <code> Id </code> 
     *  @param  destinationResourceId <code> Id </code> of another <code> 
     *          Resource </code> 
     *  @param  relationshipGenusType a relationship genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the relationships 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> sourceResourceId, 
     *          destinationResourceId, relationshipGenusType, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationshipsByGenusTypeForResourcesOnDate(org.osid.id.Id sourceResourceId, 
                                                                                                            org.osid.id.Id destinationResourceId, 
                                                                                                            org.osid.type.Type relationshipGenusType, 
                                                                                                            org.osid.calendaring.DateTime from, 
                                                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ResourceRelationships. </code> 
     *  
     *  In plenary mode, the returned list contains all known resource 
     *  relationships or an error results. Otherwise, the returned list may 
     *  contain only those resource relationships that are accessible through 
     *  this session. 
     *  
     *  In effective mode, resource relationships are returned that are 
     *  currently effective. In any effective mode, effective resource 
     *  relationships and those currently expired are returned. 
     *
     *  @return the relationships 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipList getResourceRelationships()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
