//
// org.osid.resource.ResourceRelationshipQuery
//
//     The OSID Java specification for org.osid.resource.ResourceRelationshipQuery.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This is the query for searching resource relationships. Each method 
 *  match request produces an <code> AND </code> term while multiple 
 *  invocations of a method produces a nested <code> OR. </code> </p>
 */

public interface ResourceRelationshipQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSourceResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSourceResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for querying 
     *  resources. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSourceResourceQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSourceResourceQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSourceResourceQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getSourceResourceQuery();


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSourceResourceTerms();


    /**
     *  Sets the peer resource <code> Id </code> for this query. 
     *
     *  @param  peerResourceId a peer resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> peerResourceId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDestinationResourceId(org.osid.id.Id peerResourceId, 
                                           boolean match);


    /**
     *  Clears the peer resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDestinationResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available for querying 
     *  resources. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDestinationResourceQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDestinationResourceQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDestinationResourceQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getDestinationResourceQuery();


    /**
     *  Clears the peer resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDestinationResourceTerms();


    /**
     *  Matches relationships where the peer resources are the same. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSameResource(boolean match);


    /**
     *  Clears the same resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSameResourceTerms();


    /**
     *  Sets the bin <code> Id </code> for this query to match terms assigned 
     *  to bins. 
     *
     *  @param  binId the bin <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBinId(org.osid.id.Id binId, boolean match);


    /**
     *  Clears the bin <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBinIdTerms();


    /**
     *  Tests if a <code> BinQuery </code> is available. 
     *
     *  @return <code> true </code> if a bin query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinQuery();


    /**
     *  Gets the query for a bin. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bin query 
     *  @throws org.osid.UnimplementedException <code> supportsBinQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinQuery getBinQuery();


    /**
     *  Clears the bin terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBinTerms();


    /**
     *  Gets the resource relationship query record corresponding to the given 
     *  <code> ResourceRelationship </code> record <code> Type. </code> 
     *  Multiple retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  resourceRelationshipRecordType a resource relationship query 
     *          record type 
     *  @return the resource relationship query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(resourceRelationshipRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.records.ResourceRelationshipQueryRecord getResourceRelationshipQueryRecord(org.osid.type.Type resourceRelationshipRecordType)
        throws org.osid.OperationFailedException;
}
