//
// org.osid.resource.ResourceRelationshipSearchSession
//
//     The OSID Java specification for org.osid.resource.ResourceRelationshipSearchSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session provides methods for searching <code> ResourceRelationship 
 *  </code> objects. The search query is constructed using the <code> 
 *  ResourceRelationshipQuery. </code> The resource relationship record <code> 
 *  Type </code> also specifies the record for the relationship query. </p> 
 *  
 *  <p> <code> getResourceRelationshipsByQuery() </code> is the basic search 
 *  method and returns a list of <code> ResourceRelationships. </code> A more 
 *  advanced search may be performed with <code> 
 *  getResourceRelationshipsBySearch(). </code> It accepts a <code> 
 *  ResourceRelationshipSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getResourceRelationshipsBySearch() </code> returns an 
 *  <code> ResourceRelationshipSearchResults </code> that can be used to 
 *  access the resulting <code> ResourceRelationshipList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  ResourceRelationshipSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bin view: searches include relationships in bins of 
 *      which this bin is a ancestor in the bin hierarchy </li> 
 *      <li> isolated bin view: searches are restricted to relationships in 
 *      this bin only </li> 
 *  </ul>
 *  
 *  
 *  <p> Relationships may have a resource relationship query record indicated 
 *  by their respective record types. The resource relationship query record 
 *  is accessed via the <code> ResourceRelationshipQuery. </code> </p>
 */

public interface ResourceRelationshipSearchSession
    extends org.osid.resource.ResourceRelationshipQuerySession {


    /**
     *  Gets a relationship search. 
     *
     *  @return the relationship search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipSearch getResourceRelationshipSearch();


    /**
     *  Gets a relationship search order. The <code> 
     *  ResourceRelationshipSearchOrder </code> is supplied to a <code> 
     *  ResourceRelationshipSearch </code> to specify the ordering of results. 
     *
     *  @return the relationship search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipSearchOrder getResourceRelationshipSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  resourceRelationshipQuery the resource relationship query 
     *  @param  resourceRelationshipSearch the resource relationship search 
     *  @return the returned resource relationship search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipQuery </code> or r <code> 
     *          esourceRelationshipSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          resourceRelationshipSearch </code> or r <code> 
     *          esourceRelationshipQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipSearchResults getResourceRelationshipsBySearch(org.osid.resource.ResourceRelationshipQuery resourceRelationshipQuery, 
                                                                                                org.osid.resource.ResourceRelationshipSearch resourceRelationshipSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a resource relationship query from an inspector. The inspector is 
     *  available from a <code> ResourceRelationshipSearchResults. </code> 
     *
     *  @param  resourceRelationshipQueryInspector a query inspector 
     *  @return the resource relationship query 
     *  @throws org.osid.NullArgumentException <code> 
     *          resourceRelationshipQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          resourceRelationshipQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceRelationshipQuery getResourceRelationshipQueryFromInspector(org.osid.resource.ResourceRelationshipQueryInspector resourceRelationshipQueryInspector);
}
