//
// org.osid.resource.ResourceSearchSession
//
//     The OSID Java specification for org.osid.resource.ResourceSearchSession.
//
// Copyright (C) 2006-2008 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource;


/**
 *  <p>This session provides methods for searching among <code> Resource 
 *  </code> objects. The search query is constructed using the <code> 
 *  ResourceQuery. </code> </p> 
 *  
 *  <p> <code> getResourcesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Resources. </code> A more advanced search may be 
 *  performed with <code> getResourcesBySearch(). </code> It accepts an <code> 
 *  ResourceSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getResourcesBySearch() </code> returns an <code> 
 *  ResourceSearchResults </code> that can be used to access the resulting 
 *  <code> ResourceList </code> or be used to perform a search within the 
 *  result set through <code> ResourceList. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bin view: searches include resources in bins of which 
 *      this bin is a ancestor in the bin hierarchy </li> 
 *      <li> isolated bin view: searches are restricted to resources in this 
 *      bin </li> 
 *  </ul>
 *  
 *  
 *  <p> Resources may have a resource query record indicated by their 
 *  respective record types. The resource query record is accessed via the 
 *  <code> ResourceQuery. </code> </p>
 */

public interface ResourceSearchSession
    extends org.osid.resource.ResourceQuerySession {


    /**
     *  Gets a resource search. 
     *
     *  @return the resource search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearch getResourceSearch();


    /**
     *  Gets a resource search order. The <code> ResourceSearchOrder </code> 
     *  is supplied to a <code> ResourceSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the resource search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getResourceSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  resourceQuery the resource query 
     *  @param  resourceSearch the resource search 
     *  @return the resource search results 
     *  @throws org.osid.NullArgumentException <code> resourceQuery </code> or 
     *          <code> resourceSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> resourceQuery </code> or 
     *          <code> resourceSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchResults getResourcesBySearch(org.osid.resource.ResourceQuery resourceQuery, 
                                                                        org.osid.resource.ResourceSearch resourceSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a resource query from an inspector. The inspector is available 
     *  from a <code> ResourceSearchResults. </code> 
     *
     *  @param  resourceQueryInspector a resource query inspector 
     *  @return the resource query 
     *  @throws org.osid.NullArgumentException <code> resourceQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> resourceQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQuery getResourceQueryFromInspector(org.osid.resource.ResourceQueryInspector resourceQueryInspector);
}
