//
// org.osid.resource.demographic.Demographic
//
//     The OSID Java specification for org.osid.resource.demographic.Demographic.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>A <code> Demographic </code> is an <code> OsidRule </code> for building 
 *  demographics of <code> Resources </code> . A demographic is the resource 
 *  query plus the included demographics plus the intersecting demographics 
 *  plus the included resources minus the exempted demographics minus the 
 *  excluded resources. Demographic genus type may be used to provide 
 *  alternate equations. </p>
 */

public interface Demographic
    extends org.osid.OsidRule {


    /**
     *  Gets a list of <code> Demographic </code> <code> Ids </code> whose 
     *  members are added to this demographic. The union of these demographics 
     *  is added to this demographic. 
     *
     *  @return the demographic <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIncludedDemographicIds();


    /**
     *  Gets a list of <code> Demographics </code> whose members are added to 
     *  this demographic. The union of these demographics is added to this 
     *  demographic. 
     *
     *  @return the demographics 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicList getIncludedDemographics()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of <code> Demographic </code> <code> Ids </code> whose 
     *  intersection is added to this demographic. The intersection of these 
     *  demographics is added to this demographic. 
     *
     *  @return the intersecting demographic <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIncludedIntersectingDemographicIds();


    /**
     *  Gets a list of <code> Demographics </code> whose intersection is added 
     *  to this demographic. The intersection of these demographics is added 
     *  to this demographic. 
     *
     *  @return the intersecting demographics 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicList getIncludedIntersectingDemographics()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of <code> Demographic </code> <code> Ids </code> whose 
     *  non-members are added to this demographic. 
     *
     *  @return the exclusive demographic <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIncludedExclusiveDemographicIds();


    /**
     *  Gets a list of <code> Demographics </code> whose non-members are added 
     *  to this demographic. 
     *
     *  @return the exclusive demographics 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicList getIncludedExclusiveDemographics()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of <code> Demographic </code> <code> Ids </code> whose 
     *  members are subtracted from in this demographic. 
     *
     *  @return the excluded demographic <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getExcludedDemographicIds();


    /**
     *  Gets a list of <code> Demographics </code> whose members subtracted 
     *  from this demographic. 
     *
     *  @return the excluded demographics 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicList getExcludedDemographics()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of individual <code> Resource </code> <code> Ids </code> 
     *  to be added to this demographic. 
     *
     *  @return the included resource <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getIncludedResourceIds();


    /**
     *  Gets a list of individual <code> Resources </code> to be added to this 
     *  demographic. 
     *
     *  @return the included resources 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getIncludedResources()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of <code> Resource </code> <code> Ids </code> to be 
     *  subtracted from this demographic. 
     *
     *  @return the excluded resource <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getExcludedResourceIds();


    /**
     *  Gets a list of <code> Resources </code> to be subtracted from this 
     *  demographic. 
     *
     *  @return the exempted resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceList getExcludedResources()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the demographic record corresponding to the given <code> 
     *  Demographic </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  demographicRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(demographicRecordType) </code> is <code> true </code> . 
     *
     *  @param  demographicRecordType the type of demographic record to 
     *          retrieve 
     *  @return the demographic record 
     *  @throws org.osid.NullArgumentException <code> demographicRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(demographicRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.records.DemographicRecord getDemographicRecord(org.osid.type.Type demographicRecordType)
        throws org.osid.OperationFailedException;
}
