//
// org.osid.resource.demographic.DemographicBuilderSession
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicBuilderSession.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This session applies resource search queries and search orders to 
 *  <code> Demographics. </code> Applying a search query to a demographic adds 
 *  the resources resulting from that query to the demographic. </p>
 */

public interface DemographicBuilderSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the bin 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can build demographics. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart bin management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canBuildDemographics();


    /**
     *  Gets a resource query. 
     *
     *  @return the resource query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQuery getResourceQuery();


    /**
     *  Gets a resource search order. 
     *
     *  @return the resource search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceSearchOrder getResourceSearchOrder();


    /**
     *  Applies a resource query to a demographic. If a query is already 
     *  applied, it is replaced with the new one. 
     *
     *  @param  demographicId a demographic <code> Id </code> 
     *  @param  resourceQuery the resource query 
     *  @throws org.osid.NotFoundException <code> demographicId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> or 
     *          <code> resourceQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> resourceQuery </code> did 
     *          not originate from <code> getResourceQuery() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyResourceQuery(org.osid.id.Id demographicId, 
                                   org.osid.resource.ResourceQuery resourceQuery)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a resource query inspector for a demographic. 
     *
     *  @param  demographicId a demographic <code> Id </code> 
     *  @return the demographic query inspector 
     *  @throws org.osid.NotFoundException <code> demographicId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector inspectResourceQuery(org.osid.id.Id demographicId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Clears the resource query effectively replacing it with a wildcard 
     *  query. 
     *
     *  @param  demographicId a demographic <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> demographicId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceQuery(org.osid.id.Id demographicId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a demographic search order to this bin. 
     *
     *  @param  demographicId a demographic <code> Id </code> 
     *  @param  resourceSearchOrder the resource search order 
     *  @throws org.osid.NotFoundException <code> demographicId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> or 
     *          <code> resourceSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> resourceSearchOrder 
     *          </code> did not originate from <code> getResourceSearchOrder() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyResourceSequencing(org.osid.id.Id demographicId, 
                                        org.osid.resource.ResourceSearchOrder resourceSearchOrder)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Clears the resource sequencing. 
     *
     *  @param  demographicId a demographic <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> demographicId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceSequencing(org.osid.id.Id demographicId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a resource query from an inspector. 
     *
     *  @param  resourceQueryInspector a resource query inspector 
     *  @return the resource query 
     *  @throws org.osid.NullArgumentException <code> resourceQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> resourceQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQuery getResourceQueryFromInspector(org.osid.resource.ResourceQueryInspector resourceQueryInspector);
}
