//
// org.osid.resource.demographic.DemographicEnablerAdminSession
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicEnablerAdminSession.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This session creates and removes demographic enablers. The data for 
 *  create and update is provided via the <code> DemographicEnablerForm. 
 *  </code> </p>
 */

public interface DemographicEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the bin 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create demographic enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> DemographicEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> DemographicEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDemographicEnabler();


    /**
     *  Tests if this user can create a single <code> DemographicEnabler 
     *  </code> using the desired record types. While <code> 
     *  ResourceDemographicManager.getDemographicEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  DemographicEnabler. </code> Providing an empty array tests if a <code> 
     *  DemographicEnabler </code> can be created with no records. 
     *
     *  @param  demographicEnablerRecordTypes array of demographic enabler 
     *          record types 
     *  @return <code> true </code> if <code> DemographicEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDemographicEnablerWithRecordTypes(org.osid.type.Type[] demographicEnablerRecordTypes);


    /**
     *  Gets the demographic enabler form for creating new demographic 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  demographicEnablerRecordTypes array of demographic enabler 
     *          record types 
     *  @return the demographic enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnablerForm getDemographicEnablerFormForCreate(org.osid.type.Type[] demographicEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> DemographicEnabler. </code> 
     *
     *  @param  demographicEnablerForm the form for this <code> 
     *          DemographicEnabler </code> 
     *  @return the new <code> DemographicEnabler </code> 
     *  @throws org.osid.AlreadyExistsException attempt at duplicating a 
     *          property the underlying system is enforcing to be unique 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> demographicEnablerForm 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnabler createDemographicEnabler(org.osid.resource.demographic.DemographicEnablerForm demographicEnablerForm)
        throws org.osid.AlreadyExistsException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update demographic enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> DemographicEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> DemographicEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateDemographicEnablers();


    /**
     *  Tests if this user can update a demographic enabler. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> DemographicEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @param  demographicEnablerId the <code> Id </code> of the <code> 
     *          DemographicEnabler </code> 
     *  @return <code> false </code> if demographic enabler modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> demographicEnablerId </code> is not found, then 
     *          it is acceptable to return false to indicate the lack of an 
     *          update available. 
     */

    public boolean canUpdateDemographicEnabler(org.osid.id.Id demographicEnablerId);


    /**
     *  Gets the demographic enabler form for updating an existing demographic 
     *  enabler. A new demographic enabler form should be requested for each 
     *  update transaction. 
     *
     *  @param  demographicEnablerId the <code> Id </code> of the <code> 
     *          DemographicEnabler </code> 
     *  @return the demographic enabler form 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnablerForm getDemographicEnablerFormForUpdate(org.osid.id.Id demographicEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing demographic enabler. 
     *
     *  @param  demographicEnablerId the <code> Id </code> of the <code> 
     *          DemographicEnabler </code> 
     *  @param  demographicEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> or <code> demographicEnablerForm </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          resourceEnablerProcessorForm </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDemographicEnabler(org.osid.id.Id demographicEnablerId, 
                                         org.osid.resource.demographic.DemographicEnablerForm demographicEnablerForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete demographic enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> DemographicEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> DemographicEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteDemographicEnablers();


    /**
     *  Tests if this user can delete a specified <code> DemographicEnabler. 
     *  </code> A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known deleting the <code> 
     *  DemographicEnabler </code> will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer a delete operation to an unauthorized user. 
     *
     *  @param  demographicEnablerId the <code> Id </code> of the <code> 
     *          DemographicEnabler </code> 
     *  @return <code> false </code> if deletion of this <code> 
     *          DemographicEnabler </code> is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> demographicEnablerId </code> is not found, then 
     *          it is acceptable to return false to indicate the lack of a 
     *          delete available. 
     */

    public boolean canDeleteDemographicEnabler(org.osid.id.Id demographicEnablerId);


    /**
     *  Deletes a <code> DemographicEnabler. </code> 
     *
     *  @param  demographicEnablerId the <code> Id </code> of the <code> 
     *          DemographicEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDemographicEnabler(org.osid.id.Id demographicEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  demographic enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> DemographicEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDemographicEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> DemographicEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> DemographicEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  demographic enabler. it is reassigned to the given demographic enabler 
     *  <code> Id. </code> 
     *
     *  @param  demographicEnablerId the <code> Id </code> of a <code> 
     *          DemographicEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasDemographicEnabler(org.osid.id.Id demographicEnablerId, 
                                        org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
