//
// org.osid.resource.demographic.DemographicEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicEnablerRuleApplicationSession.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This session provides methods to apply <code> DemographicEnablers 
 *  </code> to <code> Demographics. </code> A <code> Demographic </code> with 
 *  multiple <code> DemographicEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> Demographic. 
 *  </code> </p>
 */

public interface DemographicEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the bin 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter demographic enabler/demographic mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignDemographicEnablers();


    /**
     *  Adds an existing <code> DemographicEnabler </code> to a <code> 
     *  Demographic. </code> 
     *
     *  @param  demographicEnablerId the <code> Id </code> of the <code> 
     *          DemographicEnabler </code> 
     *  @param  demographicId the <code> Id </code> of the <code> Demographic 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> demographicEnablerId 
     *          </code> is already assigned to <code> demographicId </code> 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          or <code> demographicId </code> not found 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> or <code> demographicId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignDemographicEnablerToDemographic(org.osid.id.Id demographicEnablerId, 
                                                      org.osid.id.Id demographicId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> DemographicEnabler </code> from a <code> Demographic. 
     *  </code> 
     *
     *  @param  demographicEnablerId the <code> Id </code> of the <code> 
     *          DemographicEnabler </code> 
     *  @param  demographicId the <code> Id </code> of the <code> Demographic 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          or <code> demographicId </code> not found or not mapped 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> or <code> demographicId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignDemographicEnablerFromDemographic(org.osid.id.Id demographicEnablerId, 
                                                          org.osid.id.Id demographicId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
