//
// org.osid.resource.demographic.DemographicEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicEnablerRuleLookupSession.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This session provides methods to retrieve <code> DemographicEnabler 
 *  </code> to <code> Demographic </code> mappings. A <code> Demographic 
 *  </code> with multiple <code> DemographicEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  Demographic. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated bin view: All methods in this session operate, retrieve 
 *      and pertain demographic enablers defined explicitly in the current bin 
 *      </li> 
 *      <li> federated bin view: All methods in this session operate, retrieve 
 *      and pertain to all demographic enablers defined in this bin and any 
 *      other demographic enablers implicitly available in this bin through 
 *      bin inheritence. </li> 
 *  </ul>
 *  
 */

public interface DemographicEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the bin 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of demographic 
     *  enabler/demographic mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupDemographicEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeDemographicEnablerRuleView();


    /**
     *  A complete view of the <code> DemographicEnabler </code> and <code> 
     *  Demographic </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryDemographicEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include demographic enablers in bins which are children of this bin in 
     *  the bin hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedBinView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this bin only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedBinView();


    /**
     *  Gets the <code> DemographicEnabler Id </code> associated with a <code> 
     *  Demographic. </code> 
     *
     *  @param  demographicId <code> Id </code> of the <code> Demographic 
     *          </code> 
     *  @return the demographic enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> demographicId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getDemographicEnablerIdsForDemographic(org.osid.id.Id demographicId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> DemographicEnabler </code> associated with a <code> 
     *  Demographic. </code> 
     *
     *  @param  demographicId <code> Id </code> of the <code> Demographic 
     *          </code> 
     *  @return the demographic enablers 
     *  @throws org.osid.NotFoundException <code> demographicId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicEnablerList getDemographicEnablersForDemographic(org.osid.id.Id demographicId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Demographic </code> <code> Ids </code> mapped to a 
     *  <code> DemographicEnabler. </code> 
     *
     *  @param  demographicEnablerId <code> Id </code> of a <code> 
     *          DemographicEnabler </code> 
     *  @return list of demographic <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getDemographicIdsForDemographicEnabler(org.osid.id.Id demographicEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Demographics </code> mapped to a <code> 
     *  DemographicEnabler. </code> 
     *
     *  @param  demographicEnablerId <code> Id </code> of a <code> 
     *          DemographicEnabler </code> 
     *  @return list of demographics 
     *  @throws org.osid.NotFoundException <code> demographicEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> demographicEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicList getDemographicsForDemographicEnabler(org.osid.id.Id demographicEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
