//
// org.osid.resource.demographic.DemographicForm
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicForm.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This is the form for creating and updating <code> Demographics. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  DemographicAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface DemographicForm
    extends org.osid.OsidRuleForm {


    /**
     *  Gets the metadata for the included demographics. 
     *
     *  @return metadata for the included demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIncludedDemographicsMetadata();


    /**
     *  Sets the included demographics. 
     *
     *  @param  demographicIds the new included demographics 
     *  @throws org.osid.InvalidArgumentException <code> demographicIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> demographicIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIncludedDemographics(org.osid.id.Id[] demographicIds);


    /**
     *  Removes the included demographics. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedDemographics();


    /**
     *  Gets the metadata for the included intersecting demographics. 
     *
     *  @return metadata for the included intersecting demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIncludedIntersectingDemographicsMetadata();


    /**
     *  Sets the included intersecting demographics. 
     *
     *  @param  demographicIds the new included intersecting demographics 
     *  @throws org.osid.InvalidArgumentException <code> demographicIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> demographicIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIncludedIntersectingDemographics(org.osid.id.Id[] demographicIds);


    /**
     *  Removes the included intersecting demographics. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedIntersectingDemographics();


    /**
     *  Gets the metadata for the included exclusive demographics. 
     *
     *  @return metadata for the included exclusive demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIncludedExclusiveDemographicsMetadata();


    /**
     *  Sets the included exclusive demographics. 
     *
     *  @param  demographicIds the new included exclusive demographics 
     *  @throws org.osid.InvalidArgumentException <code> demographicIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> demographicIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIncludedExclusiveDemographics(org.osid.id.Id[] demographicIds);


    /**
     *  Removes the included exclusive demographics. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedExclusiveDemographics();


    /**
     *  Gets the metadata for the excluded demographics. 
     *
     *  @return metadata for the excluded demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getExcludedDemographicsMetadata();


    /**
     *  Sets the excluded demographics. 
     *
     *  @param  demographicIds the new excluded demographics 
     *  @throws org.osid.InvalidArgumentException <code> demographicIds 
     *          </code> is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> demographicIds </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setExcludedDemographics(org.osid.id.Id[] demographicIds);


    /**
     *  Removes the excluded demographics. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExcludedDemographics();


    /**
     *  Gets the metadata for the included resources. 
     *
     *  @return metadata for the included resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getIncludedResourceMetadata();


    /**
     *  Sets the included resources. 
     *
     *  @param  resourceIds the new included resources 
     *  @throws org.osid.InvalidArgumentException <code> resourceIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setIncludedResources(org.osid.id.Id[] resourceIds);


    /**
     *  Removes the included resources. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedResource();


    /**
     *  Gets the metadata for the excluded resources. 
     *
     *  @return metadata for the excluded resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getExcludedResourceMetadata();


    /**
     *  Sets the excluded resources. 
     *
     *  @param  resourceIds the new excluded resources 
     *  @throws org.osid.InvalidArgumentException <code> resourceIds </code> 
     *          is invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> resourceIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setExcludedResources(org.osid.id.Id[] resourceIds);


    /**
     *  Removes the excluded resources. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExcludedResources();


    /**
     *  Gets the <code> DemographicFormRecord </code> corresponding to the 
     *  given demographic record <code> Type. </code> 
     *
     *  @param  demographicRecordType a demographic record type 
     *  @return the demographic form record 
     *  @throws org.osid.NullArgumentException <code> demographicRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(demographicRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.records.DemographicFormRecord getDemographicFormRecord(org.osid.type.Type demographicRecordType)
        throws org.osid.OperationFailedException;
}
