//
// org.osid.resource.demographic.DemographicQuery
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicQuery.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This is the query for searching demographics. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface DemographicQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Matches demographics including the given demographic. 
     *
     *  @param  demographicId the demographic <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIncludedDemographicId(org.osid.id.Id demographicId, 
                                           boolean match);


    /**
     *  Clears the demographic <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedDemographicIdTerms();


    /**
     *  Tests if a <code> DemographicQuery </code> is available. 
     *
     *  @return <code> true </code> if a demographic query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIncludedDemographicQuery();


    /**
     *  Gets the query for a demographic. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the demographic query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIncludedDemographicQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsdIncludedDemographicQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicQuery getIncludedDemographicQuery();


    /**
     *  Matches demographics including any demographic. 
     *
     *  @param  match <code> true </code> for demographics that include any 
     *          demographic, <code> false </code> to match demographics 
     *          including no demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIncludedDemographic(boolean match);


    /**
     *  Clears the demographic query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedDemographicTerms();


    /**
     *  Matches demographics including the given intersecting demographic. 
     *
     *  @param  demographicId the demographic <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIncludedIntersectingDemographicId(org.osid.id.Id demographicId, 
                                                       boolean match);


    /**
     *  Clears the intersecting demographic <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedIntersectingDemographicIdTerms();


    /**
     *  Tests if a <code> DemographicQuery </code> is available. 
     *
     *  @return <code> true </code> if a demographic query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIncludedIntersectingDemographicQuery();


    /**
     *  Gets the query for an intersecting demographic. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the demographic query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIncludedDemographicQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsdIncludedDemographicQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicQuery getIncludedIntersectingDemographicQuery();


    /**
     *  Matches demographics including any intersecting demographic. 
     *
     *  @param  match <code> true </code> for demographics that include any 
     *          intersecting demographic, <code> false </code> to match 
     *          demographics including no intersecting demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIncludedIntersectingDemographic(boolean match);


    /**
     *  Clears the intersecting demographic query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedIntersectingDemographicTerms();


    /**
     *  Matches demographics including the given exclusive demographic. 
     *
     *  @param  demographicId the demographic <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIncludedExclusiveDemographicId(org.osid.id.Id demographicId, 
                                                    boolean match);


    /**
     *  Clears the exclusive demographic <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedExclusiveDemographicIdTerms();


    /**
     *  Tests if a <code> DemographicQuery </code> is available. 
     *
     *  @return <code> true </code> if a demographic query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIncludedExclusiveDemographicQuery();


    /**
     *  Gets the query for an exclusive demographic. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the demographic query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIncludedDemographicQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsdIncludedDemographicQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicQuery getIncludedExclusiveDemographicQuery();


    /**
     *  Matches demographics including any exclusive demographic. 
     *
     *  @param  match <code> true </code> for demographics that include any 
     *          exclusive demographic, <code> false </code> to match 
     *          demographics including no exclusive demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIncludedExclusiveDemographic(boolean match);


    /**
     *  Clears the demographic query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedExclusiveDemographicTerms();


    /**
     *  Matches demographics excluding the given a demographic. 
     *
     *  @param  demographicId the demographic <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> demographicId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExcludedDemographicId(org.osid.id.Id demographicId, 
                                           boolean match);


    /**
     *  Clears the excluded demographic <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExcludedDemographicIdTerms();


    /**
     *  Tests if a <code> DemographicQuery </code> is available to match 
     *  demographics with an excluded demographic. 
     *
     *  @return <code> true </code> if a demographic query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsExcludedDemographicQuery();


    /**
     *  Gets the query for an excluded demographic. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the demographic query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsExcludedDemographicQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsdExcludedDemographicQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.resource.demographic.DemographicQuery getExcludedDemographicQuery();


    /**
     *  Matches demographics excluding any demographic. 
     *
     *  @param  match <code> true </code> for demographics with any excluded 
     *          demographic, <code> false </code> to match demographics with 
     *          no excluded demographics 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyExcludedDemographic(boolean match);


    /**
     *  Clears the excluded demographic query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExcludedDemographicTerms();


    /**
     *  Matches demographics including the given resource. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIncludedResourceId(org.osid.id.Id resourceId, 
                                        boolean match);


    /**
     *  Clears the included resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIncludedResourceQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsIncludedResourceQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsdIncludedResourceQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getIncludedResourceQuery();


    /**
     *  Matches demographics including any resource. 
     *
     *  @param  match <code> true </code> for demographics that include any 
     *          resource, <code> false </code> to match demographics including 
     *          no resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIncludedResource(boolean match);


    /**
     *  Clears the included resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIncludedResourceTerms();


    /**
     *  Matches demographics excluding the given resource. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchExcludedResourceId(org.osid.id.Id resourceId, 
                                        boolean match);


    /**
     *  Clears the excluded resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExcludedResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available to match 
     *  demographics with an excluded resource. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsExcludedResourceQuery();


    /**
     *  Gets the query for an excluded resource. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsExcludedResourceQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsdExcludedResourceQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getExcludedResourceQuery();


    /**
     *  Matches demographics excluding any resource. 
     *
     *  @param  match <code> true </code> for demographics that exclude any 
     *          resource, <code> false </code> to match demographics excluding 
     *          no resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyExcludedResource(boolean match);


    /**
     *  Clears the excluded resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearExcludedResourceTerms();


    /**
     *  Matches demographics resulting in the given resource. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResultingResourceId(org.osid.id.Id resourceId, 
                                         boolean match);


    /**
     *  Clears the resulting resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultingResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available to match 
     *  demographics resulting in a resource. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResultingResourceQuery();


    /**
     *  Gets the query for a resulting resource. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsResultingResourceQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsdResultingResourceQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resource.ResourceQuery getResultingResourceQuery();


    /**
     *  Matches demographics that have any resulting resource. 
     *
     *  @param  match <code> true </code> for demographics that have any 
     *          resulting resource, <code> false </code> to match demographics 
     *          with no resulting resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResultingResource(boolean match);


    /**
     *  Clears the resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResultingResourceTerms();


    /**
     *  Matches mapped to the bin. 
     *
     *  @param  binId the bin <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> binId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBinId(org.osid.id.Id binId, boolean match);


    /**
     *  Clears the bin <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBinIdTerms();


    /**
     *  Tests if a <code> BinQuery </code> is available. 
     *
     *  @return <code> true </code> if a bin query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBinQuery();


    /**
     *  Gets the query for a bin. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the bin query 
     *  @throws org.osid.UnimplementedException <code> supportsBinQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBinQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.BinQuery getBinQuery();


    /**
     *  Clears the bin query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBinTerms();


    /**
     *  Gets the demographic query record corresponding to the given <code> 
     *  Demographic </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  demographicRecordType a demographic record type 
     *  @return the demographic query record 
     *  @throws org.osid.NullArgumentException <code> demographicRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(demographicRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.records.DemographicQueryRecord getDemographicQueryRecord(org.osid.type.Type demographicRecordType)
        throws org.osid.OperationFailedException;
}
