//
// org.osid.resource.demographic.DemographicQueryInspector
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicQueryInspector.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This is the query inspector for examning demographic queries. </p>
 */

public interface DemographicQueryInspector
    extends org.osid.OsidRuleQueryInspector {


    /**
     *  Gets the included demographic <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getIncludedDemographicIdTerms();


    /**
     *  Gets the included demographic query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQueryInspector[] getIncludedDemographicTerms();


    /**
     *  Gets the intersecting demographic <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getIncludedIntersectingDemographicIdTerms();


    /**
     *  Gets the intersecting demographic query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQueryInspector[] getIncludedIntersectingDemographicTerms();


    /**
     *  Gets the exclsuive demographic <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getIncludedExclusiveDemographicIdTerms();


    /**
     *  Gets the exclsuive demographic query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQueryInspector[] getIncludedExclusiveDemographicTerms();


    /**
     *  Gets the excluded demographic <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getExcludedDemographicIdTerms();


    /**
     *  Gets the excluded demographic query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQueryInspector[] getExcludedDemographicTerms();


    /**
     *  Gets the included resource <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getIncludedResourceIdTerms();


    /**
     *  Gets the included resource query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getIncludedResourceTerms();


    /**
     *  Gets the excluded resource <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getExcludedResourceIdTerms();


    /**
     *  Gets the excluded resource query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.ResourceQueryInspector[] getExcludedResourceTerms();


    /**
     *  Gets the resulting resource <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getResultingResourceIdTerms();


    /**
     *  Gets the resulting resource query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getResultingResourceTerms();


    /**
     *  Gets the bin <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getBinIdTerms();


    /**
     *  Gets the bin query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.BinQueryInspector[] getBinTerms();


    /**
     *  Gets the demographic query inspector record corresponding to the given 
     *  <code> Demographic </code> record <code> Type. </code> 
     *
     *  @param  demographicRecordType a demographic record type 
     *  @return the demographic query inspector record 
     *  @throws org.osid.NullArgumentException <code> demographicRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(demographicRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.records.DemographicQueryInspectorRecord getDemographicQueryInspectorRecord(org.osid.type.Type demographicRecordType)
        throws org.osid.OperationFailedException;
}
