//
// org.osid.resource.demographic.DemographicSearchSession
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicSearchSession.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This session provides methods for searching among <code> Demographic 
 *  </code> objects. The search query is constructed using the <code> 
 *  DemographicyQuery. </code> </p> 
 *  
 *  <p> <code> getDemographicsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Demographics. </code> A more advanced search may 
 *  be performed with <code> getDemographicsBySearch(). </code> It accepts a 
 *  <code> DemographicSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as bin. 
 *  <code> getDemographicsBySearch() </code> returns a <code> 
 *  DemographicSearchResults </code> that can be used to access the resulting 
 *  <code> DemographicList </code> or be used to perform a search within the 
 *  result set through <code> DemographicSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated bin view: searches include demographic in bins of which 
 *      this bin is an ancestor in the bin hierarchy </li> 
 *      <li> isolated bin view: searches are restricted to demographic in this 
 *      bin </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> Demographics </code> may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  DemographicQuery. </code> </p>
 */

public interface DemographicSearchSession
    extends org.osid.resource.demographic.DemographicQuerySession {


    /**
     *  Gets a demographic search. 
     *
     *  @return the demographic search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicSearch getDemographicSearch();


    /**
     *  Gets a demographic search order. The <code> DemographicSearchOrder 
     *  </code> is supplied to a <code> DemographicSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the demographic search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicSearchOrder getDemographicSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  demographicQuery the demographic query 
     *  @param  demographicSearch the demographic search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> demographicQuery </code> 
     *          or <code> demographicSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> demographicQuery </code> 
     *          or <code> demographicSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicSearchResults getDemographicsBySearch(org.osid.resource.demographic.DemographicQuery demographicQuery, 
                                                                                          org.osid.resource.demographic.DemographicSearch demographicSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a demographic query from an inspector. The inspector is available 
     *  from a <code> DemographicSearchResults. </code> 
     *
     *  @param  demographicQueryInspector a demographic query inspector 
     *  @return the demographic query 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> demographicQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQuery getDemographicQueryFromInspector(org.osid.resource.demographic.DemographicQueryInspector demographicQueryInspector);
}
