//
// org.osid.resource.demographic.DemographicSmartBinSession
//
//     The OSID Java specification for org.osid.resource.demographic.DemographicSmartBinSession.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  bins. A <code> DemographicQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Bin </code> to create a virtual collection of 
 *  demographics. The demographic may be sequenced using the <code> 
 *  DemographicSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Bin </code> has a default query that matches any 
 *  demographic and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> DemographicQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  DemographicQuery. </code> </p>
 */

public interface DemographicSmartBinSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Bin </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Bin Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBinId();


    /**
     *  Gets the <code> Bin </code> associated with this session. 
     *
     *  @return the bin 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Bin getBin()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart bins. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart bin management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartBins();


    /**
     *  Gets a demographic query. 
     *
     *  @return the demographic query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQuery getDemographicQuery();


    /**
     *  Gets a demographic search order. 
     *
     *  @return the demographic search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicSearchOrder getDemographicSearchOrder();


    /**
     *  Applies a demographic query to this bin. 
     *
     *  @param  demographicQuery the demographic query 
     *  @throws org.osid.NullArgumentException <code> demographicQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> demographicQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyDemographicQuery(org.osid.resource.demographic.DemographicQuery demographicQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a demographic query inspector for this bin. 
     *
     *  @return the demographic query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQueryInspector inspectDemographicQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a demographic search order to this bin. 
     *
     *  @param  demographicSearchOrder the demographic search order 
     *  @throws org.osid.NullArgumentException <code> demographicSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> demographicSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyDemographicSequencing(org.osid.resource.demographic.DemographicSearchOrder demographicSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a demographic query from an inspector. 
     *
     *  @param  demographicQueryInspector a demographic query inspector 
     *  @return the demographic query 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> demographicQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.demographic.DemographicQuery getDemographicQueryFromInspector(org.osid.resource.demographic.DemographicQueryInspector demographicQueryInspector);
}
