//
// org.osid.resource.demographic.ResourceDemographicProfile
//
//     The OSID Java specification for org.osid.resource.demographic.ResourceDemographicProfile.
//
// Copyright (C) 2010 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resource.demographic;


/**
 *  <p>The resource demographic profile describes the interoperability among 
 *  resource demographic services. </p>
 */

public interface ResourceDemographicProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if demographic is supported. 
     *
     *  @return <code> true </code> if demographic query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographics();


    /**
     *  Tests if looking up demographic is supported. 
     *
     *  @return <code> true </code> if demographic lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicLookup();


    /**
     *  Tests if querying demographic is supported. 
     *
     *  @return <code> true </code> if demographic query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicQuery();


    /**
     *  Tests if searching demographic is supported. 
     *
     *  @return <code> true </code> if demographic search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicSearch();


    /**
     *  Tests if a demographic administrative service is supported. 
     *
     *  @return <code> true </code> if demographic administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicAdmin();


    /**
     *  Tests if a demographic builder service is supported. 
     *
     *  @return <code> true </code> if demographic builder service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicBuilder();


    /**
     *  Tests if a demographic notification service is supported. 
     *
     *  @return <code> true </code> if demographic notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicNotification();


    /**
     *  Tests if a demographic bin lookup service is supported. 
     *
     *  @return <code> true </code> if a demographic bin lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicBin();


    /**
     *  Tests if a demographic bin service is supported. 
     *
     *  @return <code> true </code> if demographic bin assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicBinAssignment();


    /**
     *  Tests if a demographic bin lookup service is supported. 
     *
     *  @return <code> true </code> if a demographic bin service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicSmartBin();


    /**
     *  Tests if looking up demographic enablers is supported. 
     *
     *  @return <code> true </code> if demographic enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerLookup();


    /**
     *  Tests if querying demographic enablers is supported. 
     *
     *  @return <code> true </code> if demographic enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerQuery();


    /**
     *  Tests if searching demographic enablers is supported. 
     *
     *  @return <code> true </code> if demographic enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerSearch();


    /**
     *  Tests if a demographic enabler administrative service is supported. 
     *
     *  @return <code> true </code> if demographic enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerAdmin();


    /**
     *  Tests if a demographic enabler notification service is supported. 
     *
     *  @return <code> true </code> if demographic enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerNotification();


    /**
     *  Tests if a demographic enabler bin lookup service is supported. 
     *
     *  @return <code> true </code> if a demographic enabler bin lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerBin();


    /**
     *  Tests if a demographic enabler bin service is supported. 
     *
     *  @return <code> true </code> if demographic enabler bin assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerBinAssignment();


    /**
     *  Tests if a demographic enabler bin lookup service is supported. 
     *
     *  @return <code> true </code> if a demographic enabler bin service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerSmartBin();


    /**
     *  Tests if a demographic enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a processor enabler rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerRuleLookup();


    /**
     *  Tests if a demographic enabler rule application service is supported. 
     *
     *  @return <code> true </code> if demographic enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerRuleApplication();


    /**
     *  Gets the supported <code> Demographic </code> record types. 
     *
     *  @return a list containing the supported <code> Demographic </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDemographicRecordTypes();


    /**
     *  Tests if the given <code> Demographic </code> record type is 
     *  supported. 
     *
     *  @param  demographicRecordType a <code> Type </code> indicating a 
     *          <code> Demographic </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> demographicRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicRecordType(org.osid.type.Type demographicRecordType);


    /**
     *  Gets the supported <code> Demographic </code> search record types. 
     *
     *  @return a list containing the supported <code> Demographic </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDemographicSearchRecordTypes();


    /**
     *  Tests if the given <code> Demographic </code> search record type is 
     *  supported. 
     *
     *  @param  demographicSearchRecordType a <code> Type </code> indicating a 
     *          <code> Demographic </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicSearchRecordType(org.osid.type.Type demographicSearchRecordType);


    /**
     *  Gets the supported <code> DemographicEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> DemographicEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDemographicEnablerRecordTypes();


    /**
     *  Tests if the given <code> DemographicEnabler </code> record type is 
     *  supported. 
     *
     *  @param  demographicEnablerRecordType a <code> Type </code> indicating 
     *          a <code> DemographicEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerRecordType(org.osid.type.Type demographicEnablerRecordType);


    /**
     *  Gets the supported <code> DemographicEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> DemographicEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDemographicEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> DemographicEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  demographicEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> DemographicEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          demographicEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDemographicEnablerSearchRecordType(org.osid.type.Type demographicEnablerSearchRecordType);
}
