/**
 * <p>The Open Service Interface Definitions for the org.osid.resource.demographic
 * service.</p>
 * 
 * <p>The Resource Demographic OSID manages dynamic sets of <code> Resources. 
 * </code> </p> 
 * <h4> Demographic </h4> 
 * 
 * <p> A <code> Demographic </code> is an <code> OsidRule </code> that manages 
 * dynamic sets of <code> Resources. </code> <code> Demographics </code> may 
 * point to an external rule, or a few options exist to build <code> 
 * Demographics </code> within this OSID. </p> 
 * 
 * <ul>
 *     <li> manually adding and removing members </li> 
 *     <li> adding or subtracting other demographics </li> 
 *     <li> adding the intersection or other demographics </li> 
 *     <li> adding the results of a resource query </li> 
 * </ul>
 * 
 * 
 * <p> Once a <code> Demographic </code> is created, it appears like any other 
 * vague <code> Resource </code> in the Resource OSID that maybe referenced as 
 * a single entiity or as a group. <code> Demographics </code> differ from 
 * typical groups in that the population of the <code> Demographic </code> is 
 * typically the result of a rules evaluation. </p> 
 * <h4> Example </h4> 
 * 
 * <p> "I would like to invite everyone whose name begins with T to my 
 * meeting." This can be accomplished by creating a demographic for "People I 
 * like to work with" using a search query matching on the name and genus type 
 * fields. The demographic <code> Id, </code> is also a resource <code> Id 
 * </code> that can be used in a Calendaring <code> Commitment. </code> </p> 
 * 
 * <p> Then to subtract people from the "I like to ask anooying questions, 
 * repeatedly" demographic, it's Id can be added to the excluded demographic 
 * list in the "People I like to work with" demographic. </p> 
 * <h4> DemographicEnabler Rule </h4> 
 * 
 * <p> An <code> DemographicEnabler </code> is an <code> OsidRule </code> that 
 * operates the enabling and disabling of a <code> Demographic. </code> A 
 * disabled demographic is one whose rules are disabled and has no visible 
 * members. </p> 
 * <h4> Bin Cataloging </h4> 
 * 
 * <p> <code> Demographics </code> and <code> DemographicEnablers </code> are 
 * also cataloged in <code> Bins. </code> </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2010 Ingenescus All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.resource.demographic;
