//
// org.osid.resourcing.AvailabilityAdminSession
//
//     The OSID Java specification for org.osid.resourcing.AvailabilityAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session creates, updates, and deletes <code> Availabilities. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Availability, </code> an <code> AvailabilityForm </code> is 
 *  requested using <code> getAvailabilityFormForCreate() </code> specifying 
 *  the desired relationship peers and record <code> Types </code> or none if 
 *  no record <code> Types </code> are needed. The returned <code> 
 *  AvailabilityForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> AvailabilityForm </code> is submiited to a 
 *  create operation, it cannot be reused with another create operation unless 
 *  the first operation was unsuccessful. Each <code> AvailabilityForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> AvailabilityForms </code> are requested to the 
 *  <code> Availability </code> <code> Id </code> that is to be updated using 
 *  <code> getAvailabilityFormForUpdate(). </code> Similarly, the <code> 
 *  AvailabilityForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  AvailabilityForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Availabilities. </code> To unmap 
 *  an <code> Availability </code> from the current <code> Foundry, </code> 
 *  the <code> AvailabilityFoundryAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Availability </code> 
 *  itself thus removing it from all known <code> Foundry </code> catalogs. 
 *  </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface AvailabilityAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Availabilities. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Availability </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Availability </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAvailabilities();


    /**
     *  Tests if this user can create a single <code> Availability </code> 
     *  using the desired record types. While <code> 
     *  ResourcingManager.getAvailabilityRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Availability. </code> 
     *  Providing an empty array tests if an <code> Availability </code> can 
     *  be created with no records. 
     *
     *  @param  availabilityRecordTypes array of availability record types 
     *  @return <code> true </code> if <code> Availability </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> availabilityRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateAvailabilityWithRecordTypes(org.osid.type.Type[] availabilityRecordTypes);


    /**
     *  Gets the availability form for creating new availabilities. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  resourceId the <code> Id </code> for the resource 
     *  @param  jobId the <code> Id </code> for the job 
     *  @param  availabilityRecordTypes array of availability record types 
     *  @return the availability form 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          jobId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId, jobId, 
     *          </code> or <code> availabilityRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.AvailabilityForm getAvailabilityFormForCreate(org.osid.id.Id resourceId, 
                                                                             org.osid.id.Id jobId, 
                                                                             org.osid.type.Type[] availabilityRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Availability. </code> 
     *
     *  @param  availabilityForm the form for this <code> Availability </code> 
     *  @return the new <code> Availability </code> 
     *  @throws org.osid.IllegalStateException <code> availabilityForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> availabilityForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> availabilityForm </code> 
     *          did not originate from <code> getAvailabilityFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Availability createAvailability(org.osid.resourcing.AvailabilityForm availabilityForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Availabilities. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Availability </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Availability </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateAvailabilities();


    /**
     *  Gets the availability form for updating an existing availability. A 
     *  new availability form should be requested for each update transaction. 
     *
     *  @param  availabilityId the <code> Id </code> of the <code> 
     *          Availability </code> 
     *  @return the availability form 
     *  @throws org.osid.NotFoundException <code> availabilityId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.AvailabilityForm getAvailabilityFormForUpdate(org.osid.id.Id availabilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing availability. 
     *
     *  @param  availabilityForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> availabilityForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> availabilityForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> availabilityForm </code> 
     *          did not originate from <code> getAvailabilityFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateAvailability(org.osid.resourcing.AvailabilityForm availabilityForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Availabilities. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Availability </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Availability </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteAvailabilities();


    /**
     *  Deletes an <code> Availability. </code> 
     *
     *  @param  availabilityId the <code> Id </code> of the <code> 
     *          Availability </code> to remove 
     *  @throws org.osid.NotFoundException <code> availabilityId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteAvailability(org.osid.id.Id availabilityId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Availabilities. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Availability </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageAvailabilityAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Availability </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Availability </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another availability, it is 
     *  reassigned to the given availability <code> Id. </code> 
     *
     *  @param  availabilityId the <code> Id </code> of an <code> Availability 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> availabilityId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasAvailability(org.osid.id.Id availabilityId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
