//
// org.osid.resourcing.AvailabilityNotificationSession
//
//     The OSID Java specification for org.osid.resourcing.AvailabilityNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Availability </code> objects in this <code> Foundry. </code> 
 *  This session is intended for consumers needing to synchronize their state 
 *  with this service without the use of polling. Notifications are cancelled 
 *  when this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> AvailabilityLookupSession. </code> </p>
 */

public interface AvailabilityNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Availability </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForAvailabilityNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include availabilities in foundries which are children of this foundry 
     *  in the foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Register for notifications of new availabilities. <code> 
     *  AvailabilityReceiver.newAvailabilities() </code> is invoked when a new 
     *  <code> Availability </code> appears in this foundry. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAvailabilities()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new availabilities for the given 
     *  resource. <code> AvailabilityReceiver.newAvailabilities() </code> is 
     *  invoked when a new <code> Availability </code> appears in this 
     *  foundry. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAvailabilitiesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new availabilities for the given job. 
     *  <code> AvailabilityReceiver.newAvailabilities() </code> is invoked 
     *  when a new <code> Availability </code> appears in this foundry. 
     *
     *  @param  jobId the <code> Id </code> of the job to monitor 
     *  @throws org.osid.NullArgumentException <code> jobId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewAvailabilitiesForJob(org.osid.id.Id jobId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated availabilities. <code> 
     *  AvailabilityReceiver.changedAvailabilities() </code> is invoked when 
     *  an availability in this foundry is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAvailabilities()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated availabilities for the given 
     *  resource. <code> AvailabilityReceiver.changedAvailabilities() </code> 
     *  is invoked when an availability in this foundry is changed. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAvailabilitiesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated availabilities for the given 
     *  job. <code> AvailabilityReceiver.changedAvailability() </code> is 
     *  invoked when an availability in this foundry is changed. 
     *
     *  @param  jobId the <code> Id </code> of the job to monitor 
     *  @throws org.osid.NullArgumentException <code> jobId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAvailabilitiesForJob(org.osid.id.Id jobId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated availability. <code> 
     *  AvailabilityReceiver.changedAvailabilities() </code> is invoked when 
     *  the specified availability in this foundry is changed. 
     *
     *  @param  availabilityId the <code> Id </code> of the <code> 
     *          Availability </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedAvailability(org.osid.id.Id availabilityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted availabilities. <code> 
     *  AvailabilityReceiver.deletedAvailabilities() </code> is invoked when 
     *  an availability is deleted or removed from this foundry. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAvailabilities()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted availabilities for the given 
     *  resource. <code> AvailabilityReceiver.deletedAvailabilities() </code> 
     *  is invoked when an availability is deleted or removed from this 
     *  foundry. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAvailabilitiesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted availabilities for the given 
     *  job. <code> AvailabilityReceiver.deletedAvailabilities() </code> is 
     *  invoked when an availability is deleted or removed from this foundry. 
     *
     *  @param  jobId the <code> Id </code> of the job to monitor 
     *  @throws org.osid.NullArgumentException <code> jobId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAvailabilitiesForJob(org.osid.id.Id jobId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted availability. <code> 
     *  AvailabilityReceiver.deletedAvailabilities() </code> is invoked when 
     *  the specified availability is deleted or removed from this foundry. 
     *
     *  @param  availabilityId the <code> Id </code> of the <code> 
     *          Availability </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedAvailability(org.osid.id.Id availabilityId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
