//
// org.osid.resourcing.CompetencyAdminSession
//
//     The OSID Java specification for org.osid.resourcing.CompetencyAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session creates, updates, and deletes <code> Competencies. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Competency, </code> a <code> CompetencyForm </code> is requested using 
 *  <code> getCompetencyFormForCreate() </code> specifying the desired 
 *  relationship peers and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> CompetencyForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> CompetencyForm </code> is submiited to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> CompetencyForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> CompetencyForms </code> are requested to the 
 *  <code> Competency </code> <code> Id </code> that is to be updated using 
 *  <code> getCompetencyFormForUpdate(). </code> Similarly, the <code> 
 *  CompetencyForm </code> has metadata about the data that can be updated and 
 *  it can perform validation before submitting the update. The <code> 
 *  CompetencyForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Competencies. </code> To unmap a 
 *  <code> Competency </code> from the current <code> Foundry, </code> the 
 *  <code> CompetencyFoundryAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Competency </code> itself 
 *  thus removing it from all known <code> Foundry </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface CompetencyAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Job </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Job Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getJobId();


    /**
     *  Gets the <code> Job </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getJob()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create competencies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> Competency </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Competency </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCompetency();


    /**
     *  Tests if this user can create a single <code> Competency </code> using 
     *  the desired record types. While <code> 
     *  ResourcingManager.getCompetencyRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Competency. </code> 
     *  Providing an empty array tests if a <code> Competency </code> can be 
     *  created with no records. 
     *
     *  @param  competencyRecordTypes array of competency record types 
     *  @return <code> true </code> if <code> Competency </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> competencyRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCompetencyWithRecordTypes(org.osid.type.Type[] competencyRecordTypes);


    /**
     *  Gets the competency form for creating new competencies. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  competencyRecordTypes array of competency record types 
     *  @return the competency form 
     *  @throws org.osid.NullArgumentException <code> competencyRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CompetencyForm getCompetencyFormForCreate(org.osid.type.Type[] competencyRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Competency. </code> 
     *
     *  @param  competencyForm the form for this <code> Competency </code> 
     *  @return the new <code> Competency </code> 
     *  @throws org.osid.IllegalStateException <code> competencyForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> competencyForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> competencyForm </code> 
     *          did not originate from <code> getCompetencyFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Competency createCompetency(org.osid.resourcing.CompetencyForm competencyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update competencies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Competency </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Competency </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCompetencies();


    /**
     *  Gets the competency form for updating an existing competency. A new 
     *  competency form should be requested for each update transaction. 
     *
     *  @param  competencyId the <code> Id </code> of the <code> Competency 
     *          </code> 
     *  @return the competency form 
     *  @throws org.osid.NotFoundException <code> competencyId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> competencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.CompetencyForm getCompetencyFormForUpdate(org.osid.id.Id competencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing competency. 
     *
     *  @param  competencyForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> competencyForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> competencyId </code> or 
     *          <code> competencyForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> competencyForm </code> 
     *          did not originate from <code> getCompetencyFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCompetency(org.osid.resourcing.CompetencyForm competencyForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete competencies. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a <code> Competency </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Competency </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCompetencies();


    /**
     *  Deletes a <code> Competency. </code> 
     *
     *  @param  competencyId the <code> Id </code> of the <code> Competency 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> competencyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> competencyId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCompetency(org.osid.id.Id competencyId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  competencies. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Competency </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCompetencyAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Competency </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Competency </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another competency, it is 
     *  reassigned to the given competency <code> Id. </code> 
     *
     *  @param  competencyId the <code> Id </code> of a <code> Competency 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> competencyId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> competencyId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCompetency(org.osid.id.Id competencyId, 
                                org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
