//
// org.osid.resourcing.EffortAdminSession
//
//     The OSID Java specification for org.osid.resourcing.EffortAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session creates, updates, and deletes <code> Efforts. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create an 
 *  <code> Effort, </code> an <code> EffortForm </code> is requested using 
 *  <code> getEffortFormForCreate() </code> specifying the desired resource, 
 *  commission, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. The returned <code> EffortForm </code> will 
 *  indicate that it is to be used with a create operation and can be used to 
 *  examine metdata or validate data prior to creation. Once the <code> 
 *  EffortForm </code> is submiited to a create operation, it cannot be reused 
 *  with another create operation unless the first operation was unsuccessful. 
 *  Each <code> EffortForm </code> corresponds to an attempted transaction. 
 *  </p> 
 *  
 *  <p> For updates, <code> EffortForms </code> are requested to the <code> 
 *  Effort </code> <code> Id </code> that is to be updated using <code> 
 *  getEffortFormForUpdate(). </code> Similarly, the <code> EffortForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> EffortForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Efforts. </code> To unmap an 
 *  <code> Effort </code> from the current <code> Foundry, </code> the <code> 
 *  EffortFoundryAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Effort </code> itself thus 
 *  removing it from all known <code> Foundry </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface EffortAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Efforts. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating an <code> Effort </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer create operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Effort </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEfforts();


    /**
     *  Tests if this user can create a single <code> Effort </code> using the 
     *  desired record types. While <code> 
     *  ResourcingManager.getEffortRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> Effort. </code> Providing 
     *  an empty array tests if an <code> Effort </code> can be created with 
     *  no records. 
     *
     *  @param  effortRecordTypes array of effort record types 
     *  @return <code> true </code> if <code> Effort </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> effortRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEffortWithRecordTypes(org.osid.type.Type[] effortRecordTypes);


    /**
     *  Gets the effort form for creating new efforts. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  resourceId the <code> Id </code> for the resource 
     *  @param  commissionId the <code> Id </code> for the commission 
     *  @param  effortRecordTypes array of effort record types 
     *  @return the effort form 
     *  @throws org.osid.NotFoundException <code> resourceId </code> or <code> 
     *          commissionId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          commissionId, </code> or <code> effortRecordTypes </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.EffortForm getEffortFormForCreate(org.osid.id.Id resourceId, 
                                                                 org.osid.id.Id commissionId, 
                                                                 org.osid.type.Type[] effortRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Effort. </code> 
     *
     *  @param  effortForm the form for this <code> Effort </code> 
     *  @return the new <code> Effort </code> 
     *  @throws org.osid.IllegalStateException <code> effortForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> effortForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> effortForm </code> did 
     *          not originate from <code> getEffortFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Effort createEffort(org.osid.resourcing.EffortForm effortForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Efforts. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating an <code> Effort </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer update operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Effort </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateEfforts();


    /**
     *  Gets the effort form for updating an existing effort. A new effort 
     *  form should be requested for each update transaction. 
     *
     *  @param  effortId the <code> Id </code> of the <code> Effort </code> 
     *  @return the effort form 
     *  @throws org.osid.NotFoundException <code> effortId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> effortId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.EffortForm getEffortFormForUpdate(org.osid.id.Id effortId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing effort. 
     *
     *  @param  effortForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> effortForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> effortForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> effortForm </code> did 
     *          not originate from <code> getEffortFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateEffort(org.osid.resourcing.EffortForm effortForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Efforts. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Effort </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer delete operations to 
     *  an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Effort </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteEfforts();


    /**
     *  Deletes an <code> Effort. </code> 
     *
     *  @param  effortId the <code> Id </code> of the <code> Effort </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> effortId </code> not found 
     *  @throws org.osid.NullArgumentException <code> effortId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteEffort(org.osid.id.Id effortId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Efforts. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Effort </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageEffortAliases();


    /**
     *  Adds an <code> Id </code> to an <code> Effort </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Effort </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another effort, it is reassigned to the given 
     *  effort <code> Id. </code> 
     *
     *  @param  effortId the <code> Id </code> of an <code> Effort </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> effortId </code> not found 
     *  @throws org.osid.NullArgumentException <code> effortId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasEffort(org.osid.id.Id effortId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
