//
// org.osid.resourcing.EffortSearchSession
//
//     The OSID Java specification for org.osid.resourcing.EffortSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods for searching among <code> Effort </code> 
 *  objects. The search query is constructed using the <code> EffortQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getEffortsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Efforts. </code> A more advanced search may be 
 *  performed with <code> getEffortsBySearch(). </code> It accepts an <code> 
 *  EffortSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getEffortsBySearch() </code> returns an <code> 
 *  EffortSearchResults </code> that can be used to access the resulting 
 *  <code> EffortList </code> or be used to perform a search within the result 
 *  set through <code> EffortSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include efforts in foundries of 
 *      which this foundry is an ancestor in the foundry hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to efforts in this 
 *      foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> Efforts may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> EffortQuery. </code> 
 *  </p>
 */

public interface EffortSearchSession
    extends org.osid.resourcing.EffortQuerySession {


    /**
     *  Gets an effort search. 
     *
     *  @return the effort search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.EffortSearch getEffortSearch();


    /**
     *  Gets an effort search order. The <code> EffortSearchOrder </code> is 
     *  supplied to an <code> EffortSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the effort search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.EffortSearchOrder getEffortSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  effortQuery the effort query 
     *  @param  effortSearch the effort search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> effortQuery </code> or 
     *          <code> effortSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> effortQuery </code> or 
     *          <code> effortSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.EffortSearchResults getEffortsBySearch(org.osid.resourcing.EffortQuery effortQuery, 
                                                                      org.osid.resourcing.EffortSearch effortSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an effort query from an inspector. The inspector is available 
     *  from an <code> EffortSearchResults. </code> 
     *
     *  @param  effortQueryInspector an effort query inspector 
     *  @return the effort query 
     *  @throws org.osid.NullArgumentException <code> effortQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> effortQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.EffortQuery getEffortQueryFromInspector(org.osid.resourcing.EffortQueryInspector effortQueryInspector);
}
