//
// org.osid.resourcing.FoundryHierarchySession
//
//     The OSID Java specification for org.osid.resourcing.FoundryHierarchySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session defines methods for traversing a hierarchy of <code> 
 *  Foundry </code> objects. Each node in the hierarchy is a unique <code> 
 *  Foundry. </code> The hierarchy may be traversed recursively to establish 
 *  the tree structure through <code> getParentFoundries() </code> and <code> 
 *  getChildFoundries(). </code> To relate these <code> Ids </code> to another 
 *  OSID, <code> getFoundryNodes() </code> can be used for retrievals that can 
 *  be used for bulk lookups in other OSIDs. Any <code> Foundry </code> 
 *  available in the Resourcing OSID is known to this hierarchy but does not 
 *  appear in the hierarchy traversal until added as a root foundry or a child 
 *  of another foundry. </p> 
 *  
 *  <p> A user may not be authorized to traverse the entire hierarchy. Parts 
 *  of the hierarchy may be made invisible through omission from the returns 
 *  of <code> getParentFoundries() </code> or <code> getChildFoundries() 
 *  </code> in lieu of a <code> PERMISSION_DENIED </code> error that may 
 *  disrupt the traversal through authorized effortways. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative foundry view: foundry elements may be silently 
 *      omitted or re-ordered </li> 
 *      <li> plenary foundry view: provides a complete set or is an error 
 *      condition </li> 
 *  </ul>
 *  
 */

public interface FoundryHierarchySession
    extends org.osid.OsidSession {


    /**
     *  Gets the hierarchy <code> Id </code> associated with this session. 
     *
     *  @return the hierarchy <code> Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryHierarchyId();


    /**
     *  Gets the hierarchy associated with this session. 
     *
     *  @return the hierarchy associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Hierarchy getFoundryHierarchy()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform hierarchy queries. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if hierarchy traversal methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAccessFoundryHierarchy();


    /**
     *  The returns from the foundry methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeFoundryView();


    /**
     *  A complete view of the <code> Foundries </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryFoundryView();


    /**
     *  Gets the root foundry <code> Ids </code> in this hierarchy. 
     *
     *  @return the root foundry <code> Ids </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRootFoundryIds()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the root foundry in the foundry hierarchy. A foundry with no 
     *  parents is an orphan. While all foundry <code> Ids </code> are known 
     *  to the hierarchy, an orphan does not appear in the hierarchy unless 
     *  explicitly added as a root foundry or child of another foundry. 
     *
     *  @return the root foundries 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resourcing.FoundryList getRootFoundries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if the <code> Foundry </code> has any parents. 
     *
     *  @param  foundryId a foundry <code> Id </code> 
     *  @return <code> true </code> if the foundry has parents, f <code> alse 
     *          </code> otherwise 
     *  @throws org.osid.NotFoundException <code> foundryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasParentFoundries(org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a direct parent of foundry. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  foundryId the <code> Id </code> of a foundry 
     *  @return <code> true </code> if this <code> id </code> is a parent of 
     *          <code> foundryId, </code> f <code> alse </code> otherwise 
     *  @throws org.osid.NotFoundException <code> foundryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isParentOfFoundry(org.osid.id.Id id, 
                                     org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parent <code> Ids </code> of the given foundry. 
     *
     *  @param  foundryId a foundry <code> Id </code> 
     *  @return the parent <code> Ids </code> of the foundry 
     *  @throws org.osid.NotFoundException <code> foundryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getParentFoundryIds(org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the parents of the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> to query 
     *  @return the parents of the foundry 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.FoundryList getParentFoundries(org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is an ancestor of a foundry. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  foundryId the <code> Id </code> of a foundry 
     *  @return <code> tru </code> e if this <code> id </code> is an ancestor 
     *          of <code> foundryId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isAncestorOfFoundry(org.osid.id.Id id, 
                                       org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a foundry has any children. 
     *
     *  @param  foundryId a foundry <code> Id </code> 
     *  @return <code> true </code> if the <code> foundryId </code> has 
     *          children, <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasChildFoundries(org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if a foundry is a direct child of another. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  foundryId the <code> Id </code> of a foundry 
     *  @return <code> true </code> if the <code> id </code> is a child of 
     *          <code> foundryId, </code> <code> false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> not found return <code> false. </code> 
     */

    public boolean isChildOfFoundry(org.osid.id.Id id, 
                                    org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the child <code> Ids </code> of the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> to query 
     *  @return the children of the foundry 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getChildFoundryIds(org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the children of the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> to query 
     *  @return the children of the foundry 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.FoundryList getChildFoundries(org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if an <code> Id </code> is a descendant of a foundry. 
     *
     *  @param  id an <code> Id </code> 
     *  @param  foundryId the <code> Id </code> of a foundry 
     *  @return <code> true </code> if the <code> id </code> is a descendant 
     *          of the <code> foundryId, </code> <code> false </code> 
     *          otherwise 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> id </code> or <code> 
     *          foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If <code> id </code> is not found return <code> false. </code> 
     */

    public boolean isDescendantOfFoundry(org.osid.id.Id id, 
                                         org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the hierarchy. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the hier.archy 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given foundry, <code> false </code> to omit the siblings 
     *  @return a foundry node 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hierarchy.Node getFoundryNodeIds(org.osid.id.Id foundryId, 
                                                     long ancestorLevels, 
                                                     long descendantLevels, 
                                                     boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a portion of the hierarchy for the given foundry. 
     *
     *  @param  foundryId the <code> Id </code> to query 
     *  @param  ancestorLevels the maximum number of ancestor levels to 
     *          include. A value of 0 returns no parents in the hierarchy. 
     *  @param  descendantLevels the maximum number of descendant levels to 
     *          include. A value of 0 returns no children in the hierarchy. 
     *  @param  includeSiblings <code> true </code> to include the siblings of 
     *          the given foundry, <code> false </code> to omit the siblings 
     *  @return a foundry node 
     *  @throws org.osid.NotFoundException <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.FoundryNode getFoundryNodes(org.osid.id.Id foundryId, 
                                                           long ancestorLevels, 
                                                           long descendantLevels, 
                                                           boolean includeSiblings)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
