//
// org.osid.resourcing.FoundryQuery
//
//     The OSID Java specification for org.osid.resourcing.FoundryQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This is the query for searching foundries. Each method match specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface FoundryQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the effort <code> Id </code> for this query to match foundries 
     *  containing jobs. 
     *
     *  @param  jobId the job <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> jobId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchJobId(org.osid.id.Id jobId, boolean match);


    /**
     *  Clears the job query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearJobIdTerms();


    /**
     *  Tests if a <code> JobQuery </code> is available. 
     *
     *  @return <code> true </code> if a job query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobQuery();


    /**
     *  Gets the query for a job. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the job query 
     *  @throws org.osid.UnimplementedException <code> supportsJobQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsJobQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.JobQuery getJobQuery();


    /**
     *  Matches foundries that have any job. 
     *
     *  @param  match <code> true </code> to match foundries with any job, 
     *          <code> false </code> to match foundries with no job 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyJob(boolean match);


    /**
     *  Clears the job query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearJobTerms();


    /**
     *  Sets the work <code> Id </code> for this query. 
     *
     *  @param  workId the work <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWorkId(org.osid.id.Id workId, boolean match);


    /**
     *  Clears the work <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWorkIdTerms();


    /**
     *  Tests if a <code> WorkQuery </code> is available. 
     *
     *  @return <code> true </code> if a work query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkQuery();


    /**
     *  Gets the query for a work. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the work query 
     *  @throws org.osid.UnimplementedException <code> supportsWorkQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.WorkQuery getWorkQuery();


    /**
     *  Matches foundries that have any work. 
     *
     *  @param  match <code> true </code> to match foundries with any work, 
     *          <code> false </code> to match foundries with no job 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWork(boolean match);


    /**
     *  Clears the work query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWorkTerms();


    /**
     *  Sets the availability <code> Id </code> for this query to match 
     *  foundries that have a related availability. 
     *
     *  @param  availabilityId a availability <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> availabilityId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAvailabilityId(org.osid.id.Id availabilityId, 
                                    boolean match);


    /**
     *  Clears the availability <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAvailabilityIdTerms();


    /**
     *  Tests if a <code> AvailabilityQuery </code> is available. 
     *
     *  @return <code> true </code> if a availability query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityQuery();


    /**
     *  Gets the query for a availability. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the availability query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAvailabilityQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAvailabilityQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.AvailabilityQuery getAvailabilityQuery();


    /**
     *  Matches foundries that have any availability. 
     *
     *  @param  match <code> true </code> to match foundries with any 
     *          availability, <code> false </code> to match foundries with no 
     *          availability 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAvailability(boolean match);


    /**
     *  Clears the availability query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAvailabilityTerms();


    /**
     *  Sets the commission <code> Id </code> for this query. 
     *
     *  @param  commissionId the commission <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> commissionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCommissionId(org.osid.id.Id commissionId, boolean match);


    /**
     *  Clears the commission <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommissionIdTerms();


    /**
     *  Tests if a <code> CommissionQuery </code> is available. 
     *
     *  @return <code> true </code> if a commission query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionQuery();


    /**
     *  Gets the query for a commission. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the commission query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCommissionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCommissionQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.CommissionQuery getCommissionQuery();


    /**
     *  Matches foundries that have any commission. 
     *
     *  @param  match <code> true </code> to match foundries with any 
     *          commission, <code> false </code> to match foundries with no 
     *          commission 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCommission(boolean match);


    /**
     *  Clears the commission query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCommissionTerms();


    /**
     *  Sets the effort <code> Id </code> for this query. 
     *
     *  @param  effortId the effort <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> effortId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEffortId(org.osid.id.Id effortId, boolean match);


    /**
     *  Clears the effort <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEffortIdTerms();


    /**
     *  Tests if an <code> EffortQuery </code> is available. 
     *
     *  @return <code> true </code> if an effort query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortQuery();


    /**
     *  Gets the query for an effort. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the effort query 
     *  @throws org.osid.UnimplementedException <code> supportsEffortQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEffortQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.EffortQuery getEffortQuery();


    /**
     *  Matches foundries with any effort. 
     *
     *  @param  match <code> true </code> to match foundries with any effort, 
     *          <code> false </code> to match foundries with no effort 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEffort(boolean match);


    /**
     *  Clears the effort query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEffortTerms();


    /**
     *  Sets the foundry <code> Id </code> for this query to match foundries 
     *  that have the specified foundry as an ancestor. 
     *
     *  @param  foundryId a foundry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorFoundryId(org.osid.id.Id foundryId, boolean match);


    /**
     *  Clears the ancestor foundry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorFoundryIdTerms();


    /**
     *  Tests if a <code> FoundryQuery </code> is available. 
     *
     *  @return <code> true </code> if a foundry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorFoundryQuery();


    /**
     *  Gets the query for a foundry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the foundry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorFoundryQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorFoundryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.FoundryQuery getAncestorFoundryQuery();


    /**
     *  Matches foundries with any ancestor. 
     *
     *  @param  match <code> true </code> to match foundries with any 
     *          ancestor, <code> false </code> to match root foundries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorFoundry(boolean match);


    /**
     *  Clears the ancestor foundry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorFoundryTerms();


    /**
     *  Sets the foundry <code> Id </code> for this query to match foundries 
     *  that have the specified foundry as a descendant. 
     *
     *  @param  foundryId a foundry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantFoundryId(org.osid.id.Id foundryId, 
                                         boolean match);


    /**
     *  Clears the descendant foundry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantFoundryIdTerms();


    /**
     *  Tests if a <code> FoundryQuery </code> is available. 
     *
     *  @return <code> true </code> if a foundry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantFoundryQuery();


    /**
     *  Gets the query for a foundry/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the foundry query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantFoundryQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantFoundryQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.FoundryQuery getDescendantFoundryQuery();


    /**
     *  Matches foundries with any descendant. 
     *
     *  @param  match <code> true </code> to match foundries with any 
     *          descendant, <code> false </code> to match leaf foundries 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantFoundry(boolean match);


    /**
     *  Clears the descendant foundry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantFoundryTerms();


    /**
     *  Gets the foundry query record corresponding to the given <code> 
     *  Foundry </code> record <code> Type. </code> Multiple record retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @param  foundryRecordType a foundry record type 
     *  @return the foundry query record 
     *  @throws org.osid.NullArgumentException <code> foundryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(foundryRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.records.FoundryQueryRecord getFoundryQueryRecord(org.osid.type.Type foundryRecordType)
        throws org.osid.OperationFailedException;
}
