//
// org.osid.resourcing.ResourcingProfile
//
//     The OSID Java specification for org.osid.resourcing.ResourcingProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>The resourcing profile describes the interoperability among resourcing 
 *  services. </p>
 */

public interface ResourcingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any foundry federation is exposed. Federation is exposed when 
     *  a specific foundry may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  foundries appears as a single foundry. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if an availability service is supported for the current agent. 
     *
     *  @return <code> true </code> if my availability is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsMyWork();


    /**
     *  Tests if looking up jobs is supported. 
     *
     *  @return <code> true </code> if job lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobLookup();


    /**
     *  Tests if querying jobs is supported. 
     *
     *  @return <code> true </code> if job query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobQuery();


    /**
     *  Tests if searching jobs is supported. 
     *
     *  @return <code> true </code> if job search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobSearch();


    /**
     *  Tests if job administrative service is supported. 
     *
     *  @return <code> true </code> if job administration is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobAdmin();


    /**
     *  Tests if a job notification service is supported. 
     *
     *  @return <code> true </code> if job notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobNotification();


    /**
     *  Tests if a job foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job foundry lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobFoundry();


    /**
     *  Tests if a job foundry service is supported. 
     *
     *  @return <code> true </code> if job to foundry assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobFoundryAssignment();


    /**
     *  Tests if a job smart foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a job smart foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobSmartFoundry();


    /**
     *  Tests if looking up work is supported. 
     *
     *  @return <code> true </code> if work lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkLookup();


    /**
     *  Tests if querying work is supported. 
     *
     *  @return <code> true </code> if work query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkQuery();


    /**
     *  Tests if searching work is supported. 
     *
     *  @return <code> true </code> if work search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkSearch();


    /**
     *  Tests if work administrative service is supported. 
     *
     *  @return <code> true </code> if work administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkAdmin();


    /**
     *  Tests if a work notification service is supported. 
     *
     *  @return <code> true </code> if work notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkNotification();


    /**
     *  Tests if a work foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a work foundry lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkFoundry();


    /**
     *  Tests if a work foundry service is supported. 
     *
     *  @return <code> true </code> if work to foundry assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkFoundryAssignment();


    /**
     *  Tests if a work smart foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a work smart foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkSmartFoundry();


    /**
     *  Tests if looking up competencies is supported. 
     *
     *  @return <code> true </code> if competency lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyLookup();


    /**
     *  Tests if querying competencies is supported. 
     *
     *  @return <code> true </code> if competency query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyQuery();


    /**
     *  Tests if searching competencies is supported. 
     *
     *  @return <code> true </code> if competency search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencySearch();


    /**
     *  Tests if competency administrative service is supported. 
     *
     *  @return <code> true </code> if competency administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyAdmin();


    /**
     *  Tests if a competency notification service is supported. 
     *
     *  @return <code> true </code> if competency notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyNotification();


    /**
     *  Tests if a competency foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a competency foundry lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyFoundry();


    /**
     *  Tests if a competency foundry service is supported. 
     *
     *  @return <code> true </code> if competency to foundry assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyFoundryAssignment();


    /**
     *  Tests if a competency smart foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a competency smart foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencySmartFoundry();


    /**
     *  Tests if looking up availabilities is supported. 
     *
     *  @return <code> true </code> if availability lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityLookup();


    /**
     *  Tests if querying availabilities is supported. 
     *
     *  @return <code> true </code> if availability query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityQuery();


    /**
     *  Tests if searching availabilities is supported. 
     *
     *  @return <code> true </code> if availability search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilitySearch();


    /**
     *  Tests if availability <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if availability administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityAdmin();


    /**
     *  Tests if an availability <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if availability notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityNotification();


    /**
     *  Tests if an availability foundry lookup service is supported. 
     *
     *  @return <code> true </code> if an availability foundry lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityFoundry();


    /**
     *  Tests if an availability foundry assignment service is supported. 
     *
     *  @return <code> true </code> if an availability to foundry assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityFoundryAssignment();


    /**
     *  Tests if an availability smart foundry service is supported. 
     *
     *  @return <code> true </code> if an availability smart foundry service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilitySmartFoundry();


    /**
     *  Tests if looking up commissions is supported. 
     *
     *  @return <code> true </code> if commission lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionLookup();


    /**
     *  Tests if querying commissions is supported. 
     *
     *  @return <code> true </code> if commission query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionQuery();


    /**
     *  Tests if searching commissions is supported. 
     *
     *  @return <code> true </code> if commission search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionSearch();


    /**
     *  Tests if commission administrative service is supported. 
     *
     *  @return <code> true </code> if commission administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionAdmin();


    /**
     *  Tests if a commission notification service is supported. 
     *
     *  @return <code> true </code> if commission notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionNotification();


    /**
     *  Tests if a commission foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a commission foundry lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionFoundry();


    /**
     *  Tests if a commission foundry service is supported. 
     *
     *  @return <code> true </code> if commission to foundry assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionFoundryAssignment();


    /**
     *  Tests if a commission smart foundry lookup service is supported. 
     *
     *  @return <code> true </code> if a commission smart foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionSmartFoundry();


    /**
     *  Tests if looking up efforts is supported. 
     *
     *  @return <code> true </code> if effort lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortLookup();


    /**
     *  Tests if querying efforts is supported. 
     *
     *  @return <code> true </code> if effort query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortQuery();


    /**
     *  Tests if searching efforts is supported. 
     *
     *  @return <code> true </code> if effort search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortSearch();


    /**
     *  Tests if an effort administrative service is supported. 
     *
     *  @return <code> true </code> if effort administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortAdmin();


    /**
     *  Tests if an effort <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if effort notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortNotification();


    /**
     *  Tests if an effort foundry lookup service is supported. 
     *
     *  @return <code> true </code> if an effort foundry lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortFoundry();


    /**
     *  Tests if an effort foundry assignment service is supported. 
     *
     *  @return <code> true </code> if an effort to foundry assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortFoundryAssignment();


    /**
     *  Tests if an effort smart foundry service is supported. 
     *
     *  @return <code> true </code> if an v smart foundry service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortSmartFoundry();


    /**
     *  Tests if looking up foundries is supported. 
     *
     *  @return <code> true </code> if foundry lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryLookup();


    /**
     *  Tests if querying foundries is supported. 
     *
     *  @return <code> true </code> if a foundry query service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryQuery();


    /**
     *  Tests if searching foundries is supported. 
     *
     *  @return <code> true </code> if foundry search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundrySearch();


    /**
     *  Tests if foundry administrative service is supported. 
     *
     *  @return <code> true </code> if foundry administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryAdmin();


    /**
     *  Tests if a foundry <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if foundry notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryNotification();


    /**
     *  Tests for the availability of a foundry hierarchy traversal service. 
     *
     *  @return <code> true </code> if foundry hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsFoundryHierarchy();


    /**
     *  Tests for the availability of a foundry hierarchy design service. 
     *
     *  @return <code> true </code> if foundry hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryHierarchyDesign();


    /**
     *  Tests for the availability of a resourcing batch service. 
     *
     *  @return <code> true </code> if a resourcing batch service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourcingBatch();


    /**
     *  Tests for the availability of a resourcing rules service. 
     *
     *  @return <code> true </code> if a resourcing rules service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourcingRules();


    /**
     *  Gets the supported <code> Job </code> record types. 
     *
     *  @return a list containing the supported <code> Job </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobRecordTypes();


    /**
     *  Tests if the given <code> Job </code> record type is supported. 
     *
     *  @param  jobRecordType a <code> Type </code> indicating a <code> Job 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> jobRecordType </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobRecordType(org.osid.type.Type jobRecordType);


    /**
     *  Gets the supported <code> Job </code> search record types. 
     *
     *  @return a list containing the supported <code> Job </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getJobSearchRecordTypes();


    /**
     *  Tests if the given <code> Job </code> search record type is supported. 
     *
     *  @param  jobSearchRecordType a <code> Type </code> indicating a <code> 
     *          Job </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> jobSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsJobSearchRecordType(org.osid.type.Type jobSearchRecordType);


    /**
     *  Gets the supported <code> Work </code> record types. 
     *
     *  @return a list containing the supported <code> Work </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getWorkRecordTypes();


    /**
     *  Tests if the given <code> Work </code> record type is supported. 
     *
     *  @param  workRecordType a <code> Type </code> indicating a <code> Work 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> workRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkRecordType(org.osid.type.Type workRecordType);


    /**
     *  Gets the supported <code> Work </code> search record types. 
     *
     *  @return a list containing the supported <code> Work </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getWorkSearchRecordTypes();


    /**
     *  Tests if the given <code> Work </code> search record type is 
     *  supported. 
     *
     *  @param  workSearchRecordType a <code> Type </code> indicating a <code> 
     *          Work </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> workSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkSearchRecordType(org.osid.type.Type workSearchRecordType);


    /**
     *  Gets the supported <code> Competency </code> record types. 
     *
     *  @return a list containing the supported <code> Competency </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCompetencyRecordTypes();


    /**
     *  Tests if the given <code> Competency </code> record type is supported. 
     *
     *  @param  competencyRecordType a <code> Type </code> indicating a <code> 
     *          Competency </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> competencyRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencyRecordType(org.osid.type.Type competencyRecordType);


    /**
     *  Gets the supported <code> Competency </code> search record types. 
     *
     *  @return a list containing the supported <code> Competency </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCompetencySearchRecordTypes();


    /**
     *  Tests if the given <code> Competency </code> search record type is 
     *  supported. 
     *
     *  @param  competencySearchRecordType a <code> Type </code> indicating a 
     *          <code> Competency </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          competencSearchyRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCompetencySearchRecordType(org.osid.type.Type competencySearchRecordType);


    /**
     *  Gets the supported <code> Availability </code> record types. 
     *
     *  @return a list containing the supported <code> Availability </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAvailabilityRecordTypes();


    /**
     *  Tests if the given <code> Availability </code> record type is 
     *  supported. 
     *
     *  @param  availabilityRecordType a <code> Type </code> indicating an 
     *          <code> Availability </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> availabilityRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilityRecordType(org.osid.type.Type availabilityRecordType);


    /**
     *  Gets the supported <code> Availability </code> search types. 
     *
     *  @return a list containing the supported <code> Availability </code> 
     *          search types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAvailabilitySearchRecordTypes();


    /**
     *  Tests if the given <code> Availability </code> search type is 
     *  supported. 
     *
     *  @param  availabilitySearchRecordType a <code> Type </code> indicating 
     *          an <code> Availability </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilitySearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAvailabilitySearchRecordType(org.osid.type.Type availabilitySearchRecordType);


    /**
     *  Gets the supported <code> Commission </code> record types. 
     *
     *  @return a list containing the supported <code> Commission </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommissionRecordTypes();


    /**
     *  Tests if the given <code> Commission </code> record type is supported. 
     *
     *  @param  commissionRecordType a <code> Type </code> indicating a <code> 
     *          Commission </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> commissionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionRecordType(org.osid.type.Type commissionRecordType);


    /**
     *  Gets the supported <code> Commission </code> search record types. 
     *
     *  @return a list containing the supported <code> Commission </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCommissionSearchRecordTypes();


    /**
     *  Tests if the given <code> Commission </code> search record type is 
     *  supported. 
     *
     *  @param  commissionSearchRecordType a <code> Type </code> indicating a 
     *          <code> Commission </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCommissionSearchRecordType(org.osid.type.Type commissionSearchRecordType);


    /**
     *  Gets the supported <code> Effort </code> record types. 
     *
     *  @return a list containing the supported <code> Effort </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEffortRecordTypes();


    /**
     *  Tests if the given <code> Effort </code> record type is supported. 
     *
     *  @param  effortRecordType a <code> Type </code> indicating an <code> 
     *          Effort </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> effortRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortRecordType(org.osid.type.Type effortRecordType);


    /**
     *  Gets the supported <code> Effort </code> search types. 
     *
     *  @return a list containing the supported <code> Effort </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEffortSearchRecordTypes();


    /**
     *  Tests if the given <code> Effort </code> search type is supported. 
     *
     *  @param  effortSearchRecordType a <code> Type </code> indicating an 
     *          <code> Effort </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> effiortSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEffortSearchRecordType(org.osid.type.Type effortSearchRecordType);


    /**
     *  Gets the supported <code> Foundry </code> record types. 
     *
     *  @return a list containing the supported <code> Foundry </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFoundryRecordTypes();


    /**
     *  Tests if the given <code> Foundry </code> record type is supported. 
     *
     *  @param  foundryRecordType a <code> Type </code> indicating a <code> 
     *          Foundry </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> foundryRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryRecordType(org.osid.type.Type foundryRecordType);


    /**
     *  Gets the supported <code> Foundry </code> search record types. 
     *
     *  @return a list containing the supported <code> Foundry </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFoundrySearchRecordTypes();


    /**
     *  Tests if the given <code> Foundry </code> search record type is 
     *  supported. 
     *
     *  @param  foundrySearchRecordType a <code> Type </code> indicating a 
     *          <code> Foundry </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> foundrySearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundrySearchRecordType(org.osid.type.Type foundrySearchRecordType);
}
