//
// org.osid.resourcing.WorkLookupSession
//
//     The OSID Java specification for org.osid.resourcing.WorkLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing;


/**
 *  <p>This session provides methods for retrieving <code> Work </code> 
 *  objects. The <code> Work </code> represents a fixed connection between two 
 *  <code> Availabilities. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated foundry view: All work methods in this session operate, 
 *      retrieve and pertain to works defined explicitly in the current 
 *      foundry. Using an isolated view is useful for managing <code> Works 
 *      </code> with the <code> WorkAdminSession. </code> </li> 
 *      <li> federated foundry view: All work methods in this session operate, 
 *      retrieve and pertain to all works defined in this foundry and any 
 *      other works implicitly available in this foundry through foundry 
 *      inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFoundryView() </code> and <code> 
 *  useIsolatedFoundryView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface WorkLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Work </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupWorks();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeWorkView();


    /**
     *  A complete view of the <code> Work </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryWorkView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include works in foundries which are children of this foundry in the 
     *  foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Gets the <code> Work </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Work </code> 
     *  may have a different <code> Id </code> than requested, such as the 
     *  case where a duplicate <code> Id </code> was assigned to a <code> Work 
     *  </code> and retained for compatibility. 
     *
     *  @param  workId <code> Id </code> of the <code> Work </code> 
     *  @return the work 
     *  @throws org.osid.NotFoundException <code> workId </code> not found 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resourcing.Work getWork(org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  works specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Works </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  workIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> workIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorksByIds(org.osid.id.IdList workIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> corresponding to the given work genus 
     *  <code> Type </code> which does not include works of genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known works or an error results. Otherwise, 
     *  the returned list may contain only those works that are accessible 
     *  through this session. 
     *
     *  @param  workGenusType a work genus type 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.NullArgumentException <code> workGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorksByGenusType(org.osid.type.Type workGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> corresponding to the given work genus 
     *  <code> Type </code> and include any additional works with genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known works or an error results. Otherwise, 
     *  the returned list may contain only those works that are accessible 
     *  through this session. 
     *
     *  @param  workGenusType a work genus type 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.NullArgumentException <code> workGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorksByParentGenusType(org.osid.type.Type workGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> containing the given work record <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  works or an error results. Otherwise, the returned list may contain 
     *  only those works that are accessible through this session. 
     *
     *  @param  workRecordType a work record type 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.NullArgumentException <code> workRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorksByRecordType(org.osid.type.Type workRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> corresponding to the given job <code> . 
     *  </code> In plenary mode, the returned list contains all known works or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  works that are accessible through this session. 
     *
     *  @param  jobId a job <code> Id </code> 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.NullArgumentException <code> jobId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorksForJob(org.osid.id.Id jobId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> of uncommitted works corresponding to 
     *  the given job <code> . </code> In plenary mode, the returned list 
     *  contains all known works or an error results. Otherwise, the returned 
     *  list may contain only those works that are accessible through this 
     *  session. 
     *
     *  @param  jobId a job <code> Id </code> 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.NullArgumentException <code> jobId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getUncommittedWorksForJob(org.osid.id.Id jobId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> of incomplete works corresponding to 
     *  the given job <code> . </code> In plenary mode, the returned list 
     *  contains all known works or an error results. Otherwise, the returned 
     *  list may contain only those works that are accessible through this 
     *  session. 
     *
     *  @param  jobId a job <code> Id </code> 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.NullArgumentException <code> jobId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getIncompleteWorksForJob(org.osid.id.Id jobId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> of all works created between the given 
     *  date range inclusive <code> . </code> In plenary mode, the returned 
     *  list contains all known works or an error results. Otherwise, the 
     *  returned list may contain only those works that are accessible through 
     *  this session. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorksByDate(org.osid.calendaring.DateTime from, 
                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> of incomplete works created between the 
     *  given date range inclusive <code> . </code> In plenary mode, the 
     *  returned list contains all known works or an error results. Otherwise, 
     *  the returned list may contain only those works that are accessible 
     *  through this session. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getIncompleteWorksByDate(org.osid.calendaring.DateTime from, 
                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> of uncommitted works created between 
     *  the given date range inclusive <code> . </code> In plenary mode, the 
     *  returned list contains all known works or an error results. Otherwise, 
     *  the returned list may contain only those works that are accessible 
     *  through this session. 
     *
     *  @param  from start range 
     *  @param  to end range 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getUncommittedWorksByDate(org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> of all works of corresponding to the 
     *  given job and created between the given date range inclusive <code> . 
     *  </code> In plenary mode, the returned list contains all known works or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  works that are accessible through this session. 
     *
     *  @param  jobId a job <code> Id </code> 
     *  @param  from start range 
     *  @param  to end range 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> jobId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorksByDateForJob(org.osid.id.Id jobId, 
                                                             org.osid.calendaring.DateTime from, 
                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkList </code> of incomplete works corresponding to 
     *  the given job and created between the given date range inclusive 
     *  <code> . </code> In plenary mode, the returned list contains all known 
     *  works or an error results. Otherwise, the returned list may contain 
     *  only those works that are accessible through this session. 
     *
     *  @param  jobId a job <code> Id </code> 
     *  @param  from start range 
     *  @param  to end range 
     *  @return the returned <code> Work </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> jobId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getIncompleteWorksByDateForJob(org.osid.id.Id jobId, 
                                                                       org.osid.calendaring.DateTime from, 
                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all incomplete <code> Works. </code> In plenary mode, the 
     *  returned list contains all known works or an error results. Otherwise, 
     *  the returned list may contain only those works that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> Works </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getIncompleteWorks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Works </code> that have no commitments. In plenary 
     *  mode, the returned list contains all known works or an error results. 
     *  Otherwise, the returned list may contain only those works that are 
     *  accessible through this session. 
     *
     *  @return a list of uncommitted <code> Works </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getUncommittedWorks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Works. </code> In plenary mode, the returned list 
     *  contains all known works or an error results. Otherwise, the returned 
     *  list may contain only those works that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> Works </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.WorkList getWorks()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
