//
// org.osid.resourcing.rules.AvailabilityEnablerLookupSession
//
//     The OSID Java specification for org.osid.resourcing.rules.AvailabilityEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  AvailabilityEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated foundry view: All availability enabler methods in this 
 *      session operate, retrieve and pertain to availability enablers defined 
 *      explicitly in the current foundry. Using an isolated view is useful 
 *      for managing <code> AvailabilityEnablers </code> with the <code> 
 *      AvailabilityEnablerAdminSession. </code> </li> 
 *      <li> federated foundry view: All availability enabler methods in this 
 *      session operate, retrieve and pertain to all availability enablers 
 *      defined in this foundry and any other availability enabler implicitly 
 *      available in this foundry through foundry inheritence. </li> 
 *      <li> active availability enabler view: All availability enabler lookup 
 *      methods return active availability enablers. </li> 
 *      <li> any status availability enabler view: Availability enablers of 
 *      any active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFoundryView() </code> and <code> 
 *  useIsolatedFoundryView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface AvailabilityEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AvailabilityEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupAvailabilityEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeAvailabilityEnablerView();


    /**
     *  A complete view of the <code> AvailabilityEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryAvailabilityEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include availability enabler in foundries which are children of this 
     *  foundry in the foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Only active availability enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveAvailabilityEnablerView();


    /**
     *  All active and inactive availability enablers are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusAvailabilityEnablerView();


    /**
     *  Gets the <code> AvailabilityEnabler </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  AvailabilityEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> AvailabilityEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active. In any status mode, active and inactive availability enablers 
     *  are returned. 
     *
     *  @param  availabilityEnablerId <code> Id </code> of the <code> 
     *          AvailabilityEnabler </code> 
     *  @return the availability enabler 
     *  @throws org.osid.NotFoundException <code> availabilityEnablerrId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnabler getAvailabilityEnabler(org.osid.id.Id availabilityEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> AvailabilityEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  availability enabler specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if a 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> AvailabilityEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active. In any status mode, active and inactive availability enablers 
     *  are returned. 
     *
     *  @param  availabilityEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> AvailabilityEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersByIds(org.osid.id.IdList availabilityEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AvailabilityEnablerList </code> corresponding to the 
     *  given availability enabler genus <code> Type </code> which does not 
     *  include availability enabler of genus types derived from the specified 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  availability enabler or an error results. Otherwise, the returned list 
     *  may contain only those availability enabler that are accessible 
     *  through this session. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active. In any status mode, active and inactive availability enablers 
     *  are returned. 
     *
     *  @param  availabilityEnablerGenusType an availability enabler genus 
     *          type 
     *  @return the returned <code> AvailabilityEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersByGenusType(org.osid.type.Type availabilityEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AvailabilityEnablerList </code> corresponding to the 
     *  given availability enabler genus <code> Type </code> and include any 
     *  additional availability enabler with genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  availability enabler or an error results. Otherwise, the returned list 
     *  may contain only those availability enabler that are accessible 
     *  through this session. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active. In any status mode, active and inactive availability enablers 
     *  are returned. 
     *
     *  @param  availabilityEnablerGenusType an availability enabler genus 
     *          type 
     *  @return the returned <code> AvailabilityEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersByParentGenusType(org.osid.type.Type availabilityEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AvailabilityEnablerList </code> containing the given 
     *  availability enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  availability enabler or an error results. Otherwise, the returned list 
     *  may contain only those availability enabler that are accessible 
     *  through this session. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active. In any status mode, active and inactive availability enablers 
     *  are returned. 
     *
     *  @param  availabilityEnablerRecordType an availability enabler record 
     *          type 
     *  @return the returned <code> AvailabilityEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          availabilityEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersByRecordType(org.osid.type.Type availabilityEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AvailabilityEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range for any agent. 
     *  
     *  In plenary mode, the returned list contains all known availability 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those availability enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive availability enablers are 
     *  returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> AvailabilityEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from, </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an <code> AvailabilityEnablerList </code> that are effective for 
     *  the entire given date range and evaluated against the given agent. 
     *  
     *  In plenary mode, the returned list contains all known availability 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those availability enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active in addition to being effective ib the given date range for the 
     *  given agent. In any status mode, active and inactive availability 
     *  enablers are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> AvailabilityEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                    org.osid.calendaring.DateTime from, 
                                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> AvailabilityEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known availability 
     *  enabler or an error results. Otherwise, the returned list may contain 
     *  only those availability enabler that are accessible through this 
     *  session. 
     *  
     *  In active mode, availability enablers are returned that are currently 
     *  active. In any status mode, active and inactive availability enablers 
     *  are returned. 
     *
     *  @return the returned <code> AvailabilityEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
