//
// org.osid.resourcing.rules.AvailabilityEnablerQuerySession
//
//     The OSID Java specification for org.osid.resourcing.rules.AvailabilityEnablerQuerySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  AvailabilityEnabler </code> objects. The search query is constructed using 
 *  the <code> AvailabilityEnablerQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include availability enablers in 
 *      foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to availability 
 *      enablers in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> An availability enabler may have an availability enabler query record 
 *  indicated by their respective record types. The availability enabler query 
 *  record is accessed via the <code> AvailabilityEnablerQuery. </code> </p>
 */

public interface AvailabilityEnablerQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> AvailabilityEnabler </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchAvailabilityEnablers();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include availability enabler in foundries which are children of this 
     *  availability in the foundry hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFoundryView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this foundry only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFoundryView();


    /**
     *  Gets an availability enabler query. 
     *
     *  @return the availability enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerQuery getAvailabilityEnablerQuery();


    /**
     *  Gets a list of <code> AvailabilityEnablers </code> matching the given 
     *  availability enabler query. 
     *
     *  @param  availabilityEnablerQuery the availability enabler query 
     *  @return the returned <code> AvailabilityEnablerList </code> 
     *  @throws org.osid.NullArgumentException <code> availabilityEnablerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> availabilityEnablerQuery 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.AvailabilityEnablerList getAvailabilityEnablersByQuery(org.osid.resourcing.rules.AvailabilityEnablerQuery availabilityEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
