//
// org.osid.resourcing.rules.CommissionEnablerAdminSession
//
//     The OSID Java specification for org.osid.resourcing.rules.CommissionEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session creates and removes commission enablers. The data for 
 *  create and update is provided via the <code> CommissionEnablerForm. 
 *  </code> </p>
 */

public interface CommissionEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create commission enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> CommissionEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CommissionEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCommissionEnabler();


    /**
     *  Tests if this user can create a single <code> CommissionEnabler 
     *  </code> using the desired record types. While <code> 
     *  ResourcingRulesManager.getCommissionEnablerRecordTypes() </code> can 
     *  be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  CommissionEnabler. </code> Providing an empty array tests if a <code> 
     *  CommissionEnabler </code> can be created with no records. 
     *
     *  @param  commissionEnablerRecordTypes array of commission enabler 
     *          record types 
     *  @return <code> true </code> if <code> CommissionEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateCommissionEnablerWithRecordTypes(org.osid.type.Type[] commissionEnablerRecordTypes);


    /**
     *  Gets the commission enabler form for creating new commission enablers. 
     *  A new form should be requested for each create transaction. 
     *
     *  @param  commissionEnablerRecordTypes array of commission enabler 
     *          record types 
     *  @return the commission enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerForm getCommissionEnablerFormForCreate(org.osid.type.Type[] commissionEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> CommissionEnabler. </code> 
     *
     *  @param  commissionEnablerForm the form for this <code> 
     *          CommissionEnabler </code> 
     *  @return the new <code> CommissionEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> commissionEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commissionEnablerForm 
     *          </code> did not originate from <code> 
     *          getCommissionEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnabler createCommissionEnabler(org.osid.resourcing.rules.CommissionEnablerForm commissionEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update commission enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> CommissionEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CommissionEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateCommissionEnablers();


    /**
     *  Gets the commission enabler form for updating an existing commission 
     *  enabler. A new commission enabler form should be requested for each 
     *  update transaction. 
     *
     *  @param  commissionEnablerId the <code> Id </code> of the <code> 
     *          CommissionEnabler </code> 
     *  @return the commission enabler form 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerd 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerForm getCommissionEnablerFormForUpdate(org.osid.id.Id commissionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing commission enabler. 
     *
     *  @param  commissionEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> commissionEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commissionEnablerForm 
     *          </code> did not originate from <code> 
     *          getCommissionEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateCommissionEnabler(org.osid.resourcing.rules.CommissionEnablerForm commissionEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete commission enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> CommissionEnabler </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CommissionEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteCommissionEnablers();


    /**
     *  Deletes a <code> CommissionEnabler. </code> 
     *
     *  @param  commissionEnablerId the <code> Id </code> of the <code> 
     *          CommissionEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCommissionEnabler(org.osid.id.Id commissionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for commission 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> CommissionEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageCommissionEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> CommissionEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> CommissionEnabler </code> is determined by the provider. 
     *  The new <code> Id </code> performs as an alias to the primary <code> 
     *  Id </code> . If the alias is a pointer to another commission enabler. 
     *  it is reassigned to the given commission enabler <code> Id. </code> 
     *
     *  @param  commissionEnablerId the <code> Id </code> of a <code> 
     *          CommissionEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasCommissionEnabler(org.osid.id.Id commissionEnablerId, 
                                       org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
