//
// org.osid.resourcing.rules.CommissionEnablerQuery
//
//     The OSID Java specification for org.osid.resourcing.rules.CommissionEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This is the query for searching commission enablers. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface CommissionEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches mapped to a commission. 
     *
     *  @param  foundryId the commission <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledCommissionId(org.osid.id.Id foundryId, boolean match);


    /**
     *  Clears the commission <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCommissionIdTerms();


    /**
     *  Tests if an <code> CommissionQuery </code> is available. 
     *
     *  @return <code> true </code> if a commission query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledCommissionQuery();


    /**
     *  Gets the query for a commission. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the commission query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledCommissionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledCommissionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.resourcing.CommissionQuery getRuledCommissionQuery();


    /**
     *  Matches mapped to any commission. 
     *
     *  @param  match <code> true </code> for mapped to any commission, <code> 
     *          false </code> to match mapped to no commissions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledCommission(boolean match);


    /**
     *  Clears the commission query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledCommissionTerms();


    /**
     *  Matches mapped to the foundry. 
     *
     *  @param  foundryId the foundry <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFoundryId(org.osid.id.Id foundryId, boolean match);


    /**
     *  Clears the foundry <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFoundryIdTerms();


    /**
     *  Tests if a <code> FoundryQuery </code> is available. 
     *
     *  @return <code> true </code> if a foundry query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFoundryQuery();


    /**
     *  Gets the query for a foundry. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the foundry query 
     *  @throws org.osid.UnimplementedException <code> supportsFoundryQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFoundryQuery() </code> is <code> true. </code> 
     */

    public org.osid.resourcing.FoundryQuery getFoundryQuery();


    /**
     *  Clears the foundry query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFoundryTerms();


    /**
     *  Gets the commission enabler query record corresponding to the given 
     *  <code> CommissionEnabler </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  commissionEnablerRecordType an commission enabler record type 
     *  @return the commission enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(commissionEnablerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.records.CommissionEnablerQueryRecord getCommissionEnablerQueryRecord(org.osid.type.Type commissionEnablerRecordType)
        throws org.osid.OperationFailedException;
}
