//
// org.osid.resourcing.rules.CommissionEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.resourcing.rules.CommissionEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to apply <code> CommissionEnablers 
 *  </code> to <code> Commissions. </code> A <code> Commission </code> with 
 *  multiple <code> CommissionEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an accessible <code> Commission. 
 *  </code> </p>
 */

public interface CommissionEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter commission enabler/commission mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignCommissionEnablers();


    /**
     *  Adds an existing <code> CommissionEnabler </code> to a <code> 
     *  Commission. </code> 
     *
     *  @param  commissionEnablerId the <code> Id </code> of the <code> 
     *          CommissionEnabler </code> 
     *  @param  commissionId the <code> Id </code> of the <code> Commission 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> commissionEnablerId 
     *          </code> is already applied to <code> commissionId </code> 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId </code> 
     *          or <code> commissionId </code> not found 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerId 
     *          </code> or <code> commissionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignCommissionEnablerToCommission(org.osid.id.Id commissionEnablerId, 
                                                    org.osid.id.Id commissionId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> CommissionEnabler </code> from a <code> Commission. 
     *  </code> 
     *
     *  @param  commissionEnablerId the <code> Id </code> of the <code> 
     *          CommissionEnabler </code> 
     *  @param  commissionId the <code> Id </code> of the <code> Commission 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId </code> 
     *          or <code> commissionId </code> not found or <code> 
     *          commissionEnablerId </code> not applied to <code> commissionId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerId 
     *          </code> or <code> commissionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignCommissionEnablerFromCommission(org.osid.id.Id commissionEnablerId, 
                                                        org.osid.id.Id commissionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> CommissionEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> CommissionEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceCommissionEnablers();


    /**
     *  Reorders commission enablers for a commission by moving the specified 
     *  commission enabler in front of a reference commission enabler. 
     *
     *  @param  commissionEnablerId the <code> Id </code> of a <code> 
     *          CommissionEnabler </code> 
     *  @param  commissionId the <code> Id </code> of a <code> Commission 
     *          </code> 
     *  @param  referenceId the reference commission enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId, 
     *          commissionId, </code> or <code> referenceId </code> not found 
     *          or, <code> commissionEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> commissionId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerId,commissionId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCommissionEnablerAhead(org.osid.id.Id commissionEnablerId, 
                                           org.osid.id.Id commissionId, 
                                           org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders commission enablers for a commission by moving the specified 
     *  commission enabler behind a reference commission enabler. 
     *
     *  @param  commissionEnablerId the <code> Id </code> of a <code> 
     *          CommissionEnabler </code> 
     *  @param  commissionId the <code> Id </code> of a <code> Commission 
     *          </code> 
     *  @param  referenceId the reference commission enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> commissionEnablerId, 
     *          commissionId, </code> or <code> referenceId </code> not found 
     *          or, <code> commissionEnablerId </code> or <code> referenceId 
     *          </code> not related to <code> commissionId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerId,commissionId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveCommissionEnablerBehind(org.osid.id.Id commissionEnablerId, 
                                            org.osid.id.Id commissionId, 
                                            org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of commission enablers for a commission. 
     *
     *  @param  commissionEnablerIds the <code> Ids </code> for a set of 
     *          <code> CommissionnEnablers </code> 
     *  @param  commissionId the <code> Id </code> of a <code> Commission 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> commissionId </code> not 
     *          found or, a <code> commissionEnablerId </code> not related to 
     *          <code> commissionId </code> 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerIds 
     *          </code> or <code> commissionId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderCommissionEnablers(org.osid.id.Id[] commissionEnablerIds, 
                                        org.osid.id.Id commissionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
