//
// org.osid.resourcing.rules.CommissionEnablerSearchSession
//
//     The OSID Java specification for org.osid.resourcing.rules.CommissionEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  CommissionEnabler </code> objects. The search query is constructed using 
 *  the <code> CommissionEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getCommissionEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> CommissionEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getCommissionEnablersBySearch(). </code> It accepts a <code> 
 *  CommissionEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  resourcing. <code> getCommissionEnablersBySearch() </code> returns a 
 *  <code> CommissionEnablerSearchResults </code> that can be used to access 
 *  the resulting <code> CommissionEnablerList </code> or be used to perform a 
 *  search within the result set through <code> CommissionEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include commission enabler in 
 *      foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to commission 
 *      enabler in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> CommissionEnablers </code> may have a commission enabler query 
 *  record indicated by their respective record types. The commission enabler 
 *  query record is accessed via the <code> CommissionEnablerQuery. </code> 
 *  </p>
 */

public interface CommissionEnablerSearchSession
    extends org.osid.resourcing.rules.CommissionEnablerQuerySession {


    /**
     *  Gets a commission enabler search. 
     *
     *  @return the commission enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerSearch getCommissionEnablerSearch();


    /**
     *  Gets a commission enabler search order. The <code> 
     *  CommissionEnablerSearchOrder </code> is supplied to a <code> 
     *  CommissionEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the commission enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerSearchOrder getCommissionEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  commissionEnablerQuery the commission enabler query 
     *  @param  commissionEnablerSearch the commission enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> commissionEnablerQuery 
     *          </code> or <code> commissionEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> commissionEnablerQuery 
     *          </code> or <code> commissionEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerSearchResults getCommissionEnablersBySearch(org.osid.resourcing.rules.CommissionEnablerQuery commissionEnablerQuery, 
                                                                                                  org.osid.resourcing.rules.CommissionEnablerSearch commissionEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a commission enabler query from an inspector. The inspector is 
     *  available from a <code> CommissionEnablerSearchResults. </code> 
     *
     *  @param  ccommissionEnablerQueryInspector a commission enabler query 
     *          inspector 
     *  @return the commission enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          commissionEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerQuery getCommissionEnablerQueryFromInspector(org.osid.resourcing.rules.CommissionEnablerQueryInspector ccommissionEnablerQueryInspector);
}
