//
// org.osid.resourcing.rules.CommissionEnablerSmartFoundrySession
//
//     The OSID Java specification for org.osid.resourcing.rules.CommissionEnablerSmartFoundrySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  foundries. A <code> CommissionEnablerQuery </code> can be retrieved from 
 *  this session and mapped to this <code> Foundry </code> to create a virtual 
 *  collection of commission enablers. The commission enabler may be sequenced 
 *  using the <code> CommissionEnablerSearchOrder </code> terface from this 
 *  session. </p> 
 *  
 *  <p> This <code> Foundry </code> has a default query that matches any 
 *  commission enabler and a default search order that specifies no 
 *  sequencing. The queries may be examined using a <code> 
 *  CommissionEnablerQueryInspector. </code> The query may be modified by 
 *  converting the inspector back to a <code> CommissionEnablerQuery. </code> 
 *  </p>
 */

public interface CommissionEnablerSmartFoundrySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart foundries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart foundry management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartFoundries();


    /**
     *  Gets a commission enabler query. 
     *
     *  @return the commission enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerQuery getCommissionEnablerQuery();


    /**
     *  Gets a commission enabler search order. 
     *
     *  @return the commission enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerSearchOrder getCommissionEnablerSearchOrder();


    /**
     *  Applies a commission enabler query to this foundry. 
     *
     *  @param  commissionEnablerQuery the commission enabler query 
     *  @throws org.osid.NullArgumentException <code> ccommissionEnablerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> commissionEnablerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCommissionEnablerQuery(org.osid.resourcing.rules.CommissionEnablerQuery commissionEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a commission enabler query inspector for this foundry. 
     *
     *  @return the commission enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerQueryInspector inspectCommissionEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a commission enabler search order to this foundry. 
     *
     *  @param  commissionEnablerSearchOrder the commission enabler search 
     *          order 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          commissionEnablerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyCommissionEnablerSequencing(org.osid.resourcing.rules.CommissionEnablerSearchOrder commissionEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a commission enabler query from an inspector. 
     *
     *  @param  commissionEnablerQueryInspector a commission enabler query 
     *          inspector 
     *  @return the commission enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          commissionEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          commissionEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.CommissionEnablerQuery getCommissionEnablerQueryFromInspector(org.osid.resourcing.rules.CommissionEnablerQueryInspector commissionEnablerQueryInspector);
}
