//
// org.osid.resourcing.rules.JobConstrainerEnablerFoundryAssignmentSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerEnablerFoundryAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to re-assign <code> JobConstrainerEnabler 
 *  </code> to <code> Foundry </code> mappings. A <code> JobConstrainerEnabler 
 *  </code> may appear in multiple <code> Foundry </code> objects and removing 
 *  the last reference to a <code> JobConstrainerEnabler </code> is the 
 *  equivalent of deleting it. Each <code> Foundry </code> may have its own 
 *  authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> JobConstrainerEnabler </code> to 
 *  another <code> Foundry </code> is not a copy operation (eg: does not 
 *  change its <code> Id </code> ). </p>
 */

public interface JobConstrainerEnablerFoundryAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter job constrainer enabler/foundry mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignJobConstrainerEnablers();


    /**
     *  Tests if this user can alter job constrainer enabler/foundry mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignJobConstrainerEnablersToFoundry(org.osid.id.Id foundryId);


    /**
     *  Gets a list of foundries including and under the given foundry node in 
     *  which any job constrainer enabler can be assigned. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @return list of assignable foundry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFoundryIds(org.osid.id.Id foundryId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of foundries including and under the given foundry node in 
     *  which a specific job constrainer enabler can be assigned. 
     *
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @param  jobConstrainerEnablerId the <code> Id </code> of the <code> 
     *          JobConstrainerEnabler </code> 
     *  @return list of assignable foundry <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> foundryId </code> or 
     *          <code> jobConstrainerEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFoundryIdsForJobConstrainerEnabler(org.osid.id.Id foundryId, 
                                                                              org.osid.id.Id jobConstrainerEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> JobConstrainerEnabler </code> to a <code> 
     *  Foundry. </code> 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of the <code> 
     *          JobConstrainerEnabler </code> 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @throws org.osid.AlreadyExistsException <code> jobConstrainerEnablerId 
     *          </code> is already assigned to <code> foundryId </code> 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId 
     *          </code> or <code> foundryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId 
     *          </code> or <code> foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignJobConstrainerEnablerToFoundry(org.osid.id.Id jobConstrainerEnablerId, 
                                                     org.osid.id.Id foundryId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> JobConstrainerEnabler </code> from a <code> Foundry. 
     *  </code> 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of the <code> 
     *          JobConstrainerEnabler </code> 
     *  @param  foundryId the <code> Id </code> of the <code> Foundry </code> 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId 
     *          </code> or <code> foundryId </code> not found or <code> 
     *          jobConstrainerEnablerId </code> not assigned to <code> 
     *          foundryId </code> 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId 
     *          </code> or <code> foundryId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignJobConstrainerEnablerFromFoundry(org.osid.id.Id jobConstrainerEnablerId, 
                                                         org.osid.id.Id foundryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
