//
// org.osid.resourcing.rules.JobConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to apply <code> JobConstrainerEnablers 
 *  </code> to <code> JobConstrainers. </code> A <code> JobConstrainer </code> 
 *  with multiple <code> JobConstrainerEnablers </code> means any positive 
 *  rule evaluation across the enablers result in an effective <code> 
 *  JobConstrainer. </code> </p>
 */

public interface JobConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter job constrainer enabler/job constrainer 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignJobConstrainerEnablers();


    /**
     *  Adds an existing <code> JobConstrainerEnabler </code> to a <code> 
     *  JobConstrainer. </code> 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of the <code> 
     *          JobConstrainerEnabler </code> 
     *  @param  jobConstrainerId the <code> Id </code> of the <code> 
     *          JobConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> jobConstrainerEnablerId 
     *          </code> is already applied to <code> jobConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId 
     *          </code> or <code> jobConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId 
     *          </code> or <code> jobConstrainerId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignJobConstrainerEnablerToJobConstrainer(org.osid.id.Id jobConstrainerEnablerId, 
                                                            org.osid.id.Id jobConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> JobConstrainerEnabler </code> from a <code> 
     *  JobConstrainer. </code> 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of the <code> 
     *          JobConstrainerEnabler </code> 
     *  @param  jobConstrainerId the <code> Id </code> of the <code> 
     *          JobConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId 
     *          </code> or <code> jobConstrainerId </code> not found or <code> 
     *          jobConstrainerEnablerId </code> not applied to <code> 
     *          jobConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId 
     *          </code> or <code> jobConstrainerId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignJobConstrainerEnablerFromJobConstrainer(org.osid.id.Id jobConstrainerEnablerId, 
                                                                org.osid.id.Id jobConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> JobConstrainerEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobConstrainerEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceJobConstrainerEnablers();


    /**
     *  Reorders job constrainer enablers for a job constrainer by moving the 
     *  specified job constrainer enabler in front of a reference job 
     *  constrainer enabler. 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of a <code> 
     *          JobConstrainerEnabler </code> 
     *  @param  jobConstrainerId the <code> Id </code> of a <code> 
     *          JobConstrainer </code> 
     *  @param  referenceId the reference job constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId, 
     *          jobConstrainenId, </code> or <code> referenceId </code> not 
     *          found or, <code> jobConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> jobConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId, 
     *          jobConstrainerId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveJobConstrainerEnablerAhead(org.osid.id.Id jobConstrainerEnablerId, 
                                               org.osid.id.Id jobConstrainerId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders job constrainer enablers for a job constrainer by moving the 
     *  specified job constrainer enabler behind a reference job constrainer 
     *  enabler. 
     *
     *  @param  jobConstrainerEnablerId the <code> Id </code> of a <code> 
     *          JobConstrainerEnabler </code> 
     *  @param  jobConstrainerId the <code> Id </code> of a <code> 
     *          JobConstrainer </code> 
     *  @param  referenceId the reference job constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> jobConstrainerEnablerId, 
     *          jobConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> jobConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> jobConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerId, 
     *          jobConstrainerId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveJobConstrainerEnablerBehind(org.osid.id.Id jobConstrainerEnablerId, 
                                                org.osid.id.Id jobConstrainerId, 
                                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of job constrainer enablers for a job constrainer. 
     *
     *  @param  jobConstrainerEnablerIds the <code> Ids </code> for a set of 
     *          <code> JobConstrainerEnablers </code> 
     *  @param  jobConstrainerId the <code> Id </code> of a <code> 
     *          JobConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> jobConstrainerId </code> not 
     *          found or, a <code> jobConstrainerEnablerId </code> not related 
     *          to <code> jobConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerEnablerIds 
     *          </code> or <code> jobConstrainerId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderJobConstrainerEnablers(org.osid.id.Id[] jobConstrainerEnablerIds, 
                                            org.osid.id.Id jobConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
