//
// org.osid.resourcing.rules.JobConstrainerEnablerSearchSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  JobConstrainerEnabler </code> objects. The search query is constructed 
 *  using the <code> JobConstrainerEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getJobConstrainerEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> JobConstrainerEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getJobConstrainerEnablersBySearch(). </code> It accepts a <code> 
 *  JobConstrainerEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as resourcing. <code> getJobConstrainerEnablersBySearch() </code> returns 
 *  a <code> JobConstrainerEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> JobConstrainerEnablerList </code> or be used 
 *  to perform a search within the result set through <code> 
 *  JobConstrainerEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include job constrainer enablers 
 *      in foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to job constrainer 
 *      enablers in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> JobConstrainerEnablers </code> may have a job constrainer 
 *  enabler query record indicated by their respective record types. The job 
 *  constrainer enabler query record is accessed via the <code> 
 *  JobConstrainerEnablerQuery. </code> </p>
 */

public interface JobConstrainerEnablerSearchSession
    extends org.osid.resourcing.rules.JobConstrainerEnablerQuerySession {


    /**
     *  Gets a job constrainer enabler search. 
     *
     *  @return the job constrainer enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerSearch getJobConstrainerEnablerSearch();


    /**
     *  Gets a job constrainer enabler search order. The <code> 
     *  JobConstrainerEnablerSearchOrder </code> is supplied to a <code> 
     *  JobConstrainerEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the job constrainer enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerSearchOrder getJobConstrainerEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  jobConstrainerEnablerQuery the job constrainer enabler query 
     *  @param  jobConstrainerEnablerSearch the job constrainer enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerQuery </code> or <code> 
     *          jobConstrainerEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          jobConstrainerEnablerQuery </code> or <code> 
     *          jobConstrainerEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerSearchResults getJobConstrainerEnablersBySearch(org.osid.resourcing.rules.JobConstrainerEnablerQuery jobConstrainerEnablerQuery, 
                                                                                                          org.osid.resourcing.rules.JobConstrainerEnablerSearch jobConstrainerEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a job constrainer enabler query from an inspector. The inspector 
     *  is available from a <code> JobConstrainerEnablerSearchResults. </code> 
     *
     *  @param  jobConstrainerEnablerQueryInspector a job constrainer enabler 
     *          query inspector 
     *  @return the job constrainer enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          jobConstrainerEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerEnablerQuery getJobConstrainerEnablerQueryFromInspector(org.osid.resourcing.rules.JobConstrainerEnablerQueryInspector jobConstrainerEnablerQueryInspector);
}
