//
// org.osid.resourcing.rules.JobConstrainerSearch
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerSearch.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>The search interface for governing job constrainer searches. </p>
 */

public interface JobConstrainerSearch
    extends org.osid.OsidSearch {


    /**
     *  Execute this search among the given list of job constrainers. 
     *
     *  @param  foundryIds list of job constrainers 
     *  @throws org.osid.NullArgumentException <code> foundryIds </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void searchAmongJobConstrainers(org.osid.id.IdList foundryIds);


    /**
     *  Specify an ordering to the search results. 
     *
     *  @param  jobConstrainerSearchOrder job constrainer search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> jobConstrainerSearchOrder 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderJobConstrainerResults(org.osid.resourcing.rules.JobConstrainerSearchOrder jobConstrainerSearchOrder);


    /**
     *  Gets the job constrainer search record corresponding to the given job 
     *  constrainer search record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. 
     *
     *  @param  jobConstrainerSearchRecordType a job constrainer search record 
     *          type 
     *  @return the job constrainer search record 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerSearchRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(jobConstrainerSearchRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.records.JobConstrainerSearchRecord getJobConstrainerSearchRecord(org.osid.type.Type jobConstrainerSearchRecordType)
        throws org.osid.OperationFailedException;
}
