//
// org.osid.resourcing.rules.JobConstrainerSearchSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobConstrainerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for searching among <code> JobConstrainer 
 *  </code> objects. The search query is constructed using the <code> 
 *  JobConstraineryQuery. </code> </p> 
 *  
 *  <p> <code> getJobConstrainersByQuery() </code> is the basic search method 
 *  and returns a list of <code> JobConstrainers. </code> A more advanced 
 *  search may be performed with <code> getJobConstrainersBySearch(). </code> 
 *  It accepts a <code> JobConstrainerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as resourcing. <code> getJobConstrainersBySearch() </code> 
 *  returns a <code> JobConstrainerSearchResults </code> that can be used to 
 *  access the resulting <code> JobConstrainerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  JobConstrainerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include job constrainer in 
 *      foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to job constrainer 
 *      in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> JobConstrainers </code> may have a job constrainer query record 
 *  indicated by their respective record types. The job constrainer query 
 *  record is accessed via the <code> JobConstrainerQuery. </code> </p>
 */

public interface JobConstrainerSearchSession
    extends org.osid.resourcing.rules.JobConstrainerQuerySession {


    /**
     *  Gets a job constrainer search. 
     *
     *  @return the job constrainer search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerSearch getJobConstrainerSearch();


    /**
     *  Gets a job constrainer search order. The <code> 
     *  JobConstrainerSearchOrder </code> is supplied to a <code> 
     *  JobConstrainerSearch </code> to specify the ordering of results. 
     *
     *  @return the job constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerSearchOrder getJobConstrainerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  jobConstrainerQuery the job constrainer query 
     *  @param  jobConstrainerSearch the job constrainer search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> jobConstrainerQuery 
     *          </code> or <code> jobConstrainerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> jobConstrainerQuery 
     *          </code> or <code> jobConstrainerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerSearchResults getJobConstrainersBySearch(org.osid.resourcing.rules.JobConstrainerQuery jobConstrainerQuery, 
                                                                                            org.osid.resourcing.rules.JobConstrainerSearch jobConstrainerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a job constrainer query from an inspector. The inspector is 
     *  available from a <code> JobConstrainerSearchResults. </code> 
     *
     *  @param  jobConstrainerQueryInspector a job constrainer query inspector 
     *  @return the job constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobConstrainerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          jobConstrainerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobConstrainerQuery getJobConstrainerQueryFromInspector(org.osid.resourcing.rules.JobConstrainerQueryInspector jobConstrainerQueryInspector);
}
