//
// org.osid.resourcing.rules.JobProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to apply <code> JobProcessorEnablers 
 *  </code> to <code> JobProcessors. </code> A <code> JobProcessor </code> 
 *  with multiple <code> JobProcessorEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> JobProcessor. 
 *  </code> </p>
 */

public interface JobProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter job processor enabler/job processor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignJobProcessorEnablers();


    /**
     *  Adds an existing <code> JobProcessorEnabler </code> to a <code> 
     *  JobProcessor. </code> 
     *
     *  @param  jobProcessorEnablerId the <code> Id </code> of the <code> 
     *          JobProcessorEnabler </code> 
     *  @param  jobProcessorId the <code> Id </code> of the <code> 
     *          JobProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> jobProcessorEnablerId 
     *          </code> is already applied to <code> jobProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorEnablerId 
     *          </code> or <code> jobProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobProcessorEnablerId 
     *          </code> or <code> jobProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignJobProcessorEnablerToJobProcessor(org.osid.id.Id jobProcessorEnablerId, 
                                                        org.osid.id.Id jobProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> JobProcessorEnabler </code> from a <code> 
     *  JobProcessor. </code> 
     *
     *  @param  jobProcessorEnablerId the <code> Id </code> of the <code> 
     *          JobProcessorEnabler </code> 
     *  @param  jobProcessorId the <code> Id </code> of the <code> 
     *          JobProcessor </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorEnablerId 
     *          </code> or <code> jobProcessorId </code> not found or <code> 
     *          jobProcessorEnablerId </code> not applied to <code> 
     *          jobProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorEnablerId 
     *          </code> or <code> jobProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignJobProcessorEnablerFromJobProcessor(org.osid.id.Id jobProcessorEnablerId, 
                                                            org.osid.id.Id jobProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> JobProcessorEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobProcessornEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceJobProcessorEnablers();


    /**
     *  Reorders job processor enablers for a job processor by moving the 
     *  specified job processor enabler in front of a reference job processor 
     *  enabler. 
     *
     *  @param  jobProcessorEnablerId the <code> Id </code> of a <code> 
     *          JobProcessorEnabler </code> 
     *  @param  jobProcessorId the <code> Id </code> of a <code> JobProcessor 
     *          </code> 
     *  @param  referenceId the reference job processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorEnablerId, 
     *          jobProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> jobProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> jobProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorEnablerId, 
     *          jobProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveJobProcessorEnablerAhead(org.osid.id.Id jobProcessorEnablerId, 
                                             org.osid.id.Id jobProcessorId, 
                                             org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders job processor enablers for a job processor by moving the 
     *  specified job processor enabler behind a reference job processor 
     *  enabler. 
     *
     *  @param  jobProcessorEnablerId the <code> Id </code> of a <code> 
     *          JobProcessorEnabler </code> 
     *  @param  jobProcessorId the <code> Id </code> of a <code> JobProcessor 
     *          </code> 
     *  @param  referenceId the reference job processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorEnablerId, 
     *          jobProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> jobProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> jobProcessorId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorEnablerId, 
     *          jobProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveJobProcessorEnablerBehind(org.osid.id.Id jobProcessorEnablerId, 
                                              org.osid.id.Id jobProcessorId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of job processor enablers for a job processor. 
     *
     *  @param  jobProcessorEnablerIds the <code> Ids </code> for a set of 
     *          <code> JobProcessorEnablers </code> 
     *  @param  jobProcessorId the <code> Id </code> of a <code> JobProcessor 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorId </code> not 
     *          found or, a <code> jobProcessorEnablerId </code> not related 
     *          to <code> jobProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorEnablerIds 
     *          </code> or <code> jobProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderJobProcessorEnablers(org.osid.id.Id[] jobProcessorEnablerIds, 
                                          org.osid.id.Id jobProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
