//
// org.osid.resourcing.rules.JobProcessorRuleApplicationSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobProcessorRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods to apply <code> JobProcessors </code> to 
 *  <code> Jobs. </code> </p>
 */

public interface JobProcessorRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Foundry </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Foundry Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFoundryId();


    /**
     *  Gets the <code> Foundry </code> associated with this session. 
     *
     *  @return the foundry 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.Foundry getFoundry()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter job processor/job mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignJobProcessors();


    /**
     *  Adds an existing <code> JobProcessor </code> to a <code> Job. </code> 
     *
     *  @param  jobProcessorId the <code> Id </code> of the <code> 
     *          JobProcessor </code> 
     *  @param  jobId the <code> Id </code> of the <code> Job </code> 
     *  @throws org.osid.AlreadyExistsException <code> jobProcessorId </code> 
     *          is already applied to <code> jobId </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorId </code> or 
     *          <code> jobId </code> not found 
     *  @throws org.osid.NullArgumentException <code> jobProcessorId </code> 
     *          or <code> jobId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignJobProcessorToJob(org.osid.id.Id jobProcessorId, 
                                        org.osid.id.Id jobId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> JobProcessor </code> from a <code> Job. </code> 
     *
     *  @param  jobProcessorId the <code> Id </code> of the <code> 
     *          JobProcessor </code> 
     *  @param  jobId the <code> Id </code> of the <code> Job </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorId </code> or 
     *          <code> jobId </code> not found or <code> jobProcessorId 
     *          </code> not applied to <code> jobId </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorId </code> 
     *          or <code> jobId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignJobProcessorFromJob(org.osid.id.Id jobProcessorId, 
                                            org.osid.id.Id jobId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> JobProcessors. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> JobProcessor </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceJobProcessors();


    /**
     *  Reorders job processors for a job by moving the specified job enabler 
     *  in front of a reference job processor. 
     *
     *  @param  jobProcessorId the <code> Id </code> of a <code> JobProcessor 
     *          </code> 
     *  @param  jobId the <code> Id </code> of a <code> Job </code> 
     *  @param  referenceId the reference job processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorId, jobId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          jobProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> jobId </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorId, jobId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveJobProcessorAhead(org.osid.id.Id jobProcessorId, 
                                      org.osid.id.Id jobId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders job processors for a job by moving the specified job enabler 
     *  behind a reference job processor. 
     *
     *  @param  jobProcessorId the <code> Id </code> of a <code> JobProcessor 
     *          </code> 
     *  @param  jobId the <code> Id </code> of a <code> Job </code> 
     *  @param  referenceId the reference job processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> jobProcessorId, jobId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          jobProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> jobId </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorId, jobId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveJobProcessorBehind(org.osid.id.Id jobProcessorId, 
                                       org.osid.id.Id jobId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of job processors for a job. 
     *
     *  @param  jobProcessorIds the <code> Ids </code> for a set of <code> 
     *          JobProcessor </code> 
     *  @param  jobId the <code> Id </code> of a <code> Job </code> 
     *  @throws org.osid.NotFoundException <code> jobId </code> not found or, 
     *          a <code> jobProcessorId </code> not related to <code> jobId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> jobProcessorIds </code> 
     *          or <code> jobId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderJobProcessors(org.osid.id.Id[] jobProcessorIds, 
                                   org.osid.id.Id jobId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
