//
// org.osid.resourcing.rules.JobProcessorSearchSession
//
//     The OSID Java specification for org.osid.resourcing.rules.JobProcessorSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.resourcing.rules;


/**
 *  <p>This session provides methods for searching among <code> JobProcessor 
 *  </code> objects. The search query is constructed using the <code> 
 *  JobProcessoryQuery. </code> </p> 
 *  
 *  <p> <code> getJobProcessorsByQuery() </code> is the basic search method 
 *  and returns a list of <code> JobProcessors. </code> A more advanced search 
 *  may be performed with <code> getJobProcessorsBySearch(). </code> It 
 *  accepts a <code> JobProcessorSearch </code> in addition to the query for 
 *  the purpose of specifying additional options affecting the entire search, 
 *  such as resourcing. <code> getJobProcessorsBySearch() </code> returns a 
 *  <code> JobProcessorSearchResults </code> that can be used to access the 
 *  resulting <code> JobProcessorList </code> or be used to perform a search 
 *  within the result set through <code> JobProcessorSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated foundry view: searches include job processor in 
 *      foundries of which this foundry is an ancestor in the foundry 
 *      hierarchy </li> 
 *      <li> isolated foundry view: searches are restricted to job processor 
 *      in this foundry </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> JobProcessors </code> may have a job processor query record 
 *  indicated by their respective record types. The job processor query record 
 *  is accessed via the <code> JobProcessorQuery. </code> </p>
 */

public interface JobProcessorSearchSession
    extends org.osid.resourcing.rules.JobProcessorQuerySession {


    /**
     *  Gets a job processor search. 
     *
     *  @return the job processor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorSearch getJobProcessorSearch();


    /**
     *  Gets a job processor search order. The <code> JobProcessorSearchOrder 
     *  </code> is supplied to a <code> JobProcessorSearch </code> to specify 
     *  the ordering of results. 
     *
     *  @return the job processor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorSearchOrder getJobProcessorSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  jobProcessorQuery the job processor query 
     *  @param  jobProcessorSearch the job processor search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> jobProcessorQuery 
     *          </code> or <code> jobProcessorSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> jobProcessorQuery </code> 
     *          or <code> jobProcessorSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorSearchResults getJobProcessorsBySearch(org.osid.resourcing.rules.JobProcessorQuery jobProcessorQuery, 
                                                                                        org.osid.resourcing.rules.JobProcessorSearch jobProcessorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a job processor query from an inspector. The inspector is 
     *  available from a <code> JobProcessorSearchResults. </code> 
     *
     *  @param  jobProcessorQueryInspector a job processor query inspector 
     *  @return the job processor query 
     *  @throws org.osid.NullArgumentException <code> 
     *          jobProcessorQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          jobProcessorQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resourcing.rules.JobProcessorQuery getJobProcessorQueryFromInspector(org.osid.resourcing.rules.JobProcessorQueryInspector jobProcessorQueryInspector);
}
