//
// org.osid.room.BuildingQuery
//
//     The OSID Java specification for org.osid.room.BuildingQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This is the query for searching for buildings. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface BuildingQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidTemporalQuery {


    /**
     *  Sets an address <code> Id. </code> 
     *
     *  @param  addressId an address <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> addressId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAddressId(org.osid.id.Id addressId, boolean match);


    /**
     *  Clears the address <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressIdTerms();


    /**
     *  Tests if an <code> AddressQuery </code> is available. 
     *
     *  @return <code> true </code> if an address query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressQuery();


    /**
     *  Gets the query for an address query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the address query 
     *  @throws org.osid.UnimplementedException <code> supportsAddressQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressQuery() </code> is <code> true. </code> 
     */

    public org.osid.contact.AddressQuery getAddressQuery();


    /**
     *  Matches any address. 
     *
     *  @param  match <code> true </code> to match buildings with any address, 
     *          <code> false </code> to match buildings with no address 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAddress(boolean match);


    /**
     *  Clears the address terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAddressTerms();


    /**
     *  Sets a name. 
     *
     *  @param  name an official name 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> name </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOfficialName(String name, 
                                  org.osid.type.Type stringMatchType, 
                                  boolean match);


    /**
     *  Matches any official name. 
     *
     *  @param  match <code> true </code> to match buildings with any official 
     *          name, <code> false </code> to match buildings with no official 
     *          name 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOfficialName(boolean match);


    /**
     *  Clears the official name terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfficialNameTerms();


    /**
     *  Sets a bulding number. 
     *
     *  @param  number a number 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNumber(String number, org.osid.type.Type stringMatchType, 
                            boolean match);


    /**
     *  Matches any building number. 
     *
     *  @param  match <code> true </code> to match buildings with any number, 
     *          <code> false </code> to match buildings with no number 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNumber(boolean match);


    /**
     *  Clears the building number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNumberTerms();


    /**
     *  Sets a building <code> Id. </code> 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> addressId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEnclosingBuildingId(org.osid.id.Id buildingId, 
                                         boolean match);


    /**
     *  Clears the building <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnclosingBuildingIdTerms();


    /**
     *  Tests if a <code> BuildingQuery </code> is available. 
     *
     *  @return <code> true </code> if a building query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnclosingBuildingQuery();


    /**
     *  Gets the query for a building query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the building query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEnclosingBuildingQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEnclosingBuildingQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.BuildingQuery getEnclosingBuildingQuery();


    /**
     *  Matches any building. 
     *
     *  @param  match <code> true </code> to match buildings with any 
     *          enclosing building, <code> false </code> to match buildings 
     *          with no enclosing building 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEnclosingBuilding(boolean match);


    /**
     *  Clears the enclosing building terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnclosingBuildingTerms();


    /**
     *  Matches an area within the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGrossArea(java.math.BigDecimal low, 
                               java.math.BigDecimal high, boolean match);


    /**
     *  Matches any area. 
     *
     *  @param  match <code> true </code> to match buildings with any area, 
     *          <code> false </code> to match buildings with no area assigned 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyGrossArea(boolean match);


    /**
     *  Clears the area terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGrossAreaTerms();


    /**
     *  Sets the room <code> Id </code> for this query to match rooms assigned 
     *  to buildings. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRoomId(org.osid.id.Id roomId, boolean match);


    /**
     *  Clears the room <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRoomIdTerms();


    /**
     *  Tests if a room query is available. 
     *
     *  @return <code> true </code> if a room query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomQuery();


    /**
     *  Gets the query for a building. 
     *
     *  @return the room query 
     *  @throws org.osid.UnimplementedException <code> supportsRoomQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomQuery getRoomQuery();


    /**
     *  Matches buildings with any room. 
     *
     *  @param  match <code> true </code> to match buildings with any room, 
     *          <code> false </code> to match buildings with no rooms 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRoom(boolean match);


    /**
     *  Clears the room terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRoomTerms();


    /**
     *  Sets the building <code> Id </code> for this query to match rooms 
     *  assigned to campuses. 
     *
     *  @param  campusId a campus <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCampusId(org.osid.id.Id campusId, boolean match);


    /**
     *  Clears the campus <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCampusIdTerms();


    /**
     *  Tests if a <code> CampusQuery </code> is available. 
     *
     *  @return <code> true </code> if a campus query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusQuery();


    /**
     *  Gets the query for a campus query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the campus query 
     *  @throws org.osid.UnimplementedException <code> supportsCampusQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.CampusQuery getCampusQuery();


    /**
     *  Clears the campus terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCampusTerms();


    /**
     *  Gets the building query record corresponding to the given <code> 
     *  Building </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested boolean <code> OR </code> term. 
     *
     *  @param  buildingRecordType a building record type 
     *  @return the building query record 
     *  @throws org.osid.NullArgumentException <code> buildingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(buildingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.BuildingQueryRecord getBuildingQueryRecord(org.osid.type.Type buildingRecordType)
        throws org.osid.OperationFailedException;
}
