//
// org.osid.room.BuildingSearchOrder
//
//     The OSID Java specification for org.osid.room.BuildingSearchOrder.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface BuildingSearchOrder
    extends org.osid.OsidObjectSearchOrder,
            org.osid.OsidTemporalSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the address. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAddress(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an address order is available. 
     *
     *  @return <code> true </code> if an address search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAddressSearchOrder();


    /**
     *  Gets the address search order. 
     *
     *  @return the address search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAddressSearchOrder() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAddressSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.contact.AddressSearchOrder getAddressSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the offical 
     *  name. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByOfficialName(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the building 
     *  number. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByNumber(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the 
     *  subdivisions. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByEnclosingBuilding(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an enclosing building search order is available. 
     *
     *  @return <code> true </code> if a building search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnclosingBuildingSearchOrder();


    /**
     *  Gets the enclosing building search order. 
     *
     *  @return the building search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEnclosingBuildingSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEnclosingBuildingSearchOrder() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.room.BuildingSearchOrder getEnclosingBuildingSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the gross area. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByGrossArea(org.osid.SearchOrderStyle style);


    /**
     *  Gets the building search order record corresponding to the given 
     *  building record Type. Multiple retrievals return the same underlying 
     *  object. 
     *
     *  @param  buildingRecordType a building record type 
     *  @return the building search order record 
     *  @throws org.osid.NullArgumentException <code> buildingRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(buildingRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.BuildingSearchOrderRecord getBuildingSearchOrderRecord(org.osid.type.Type buildingRecordType)
        throws org.osid.OperationFailedException;
}
