//
// org.osid.room.CampusQuery
//
//     The OSID Java specification for org.osid.room.CampusQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This is the query for searching for campuses. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CampusQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the room <code> Id </code> for this query to match rooms assigned 
     *  to campuses. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRoomId(org.osid.id.Id roomId, boolean match);


    /**
     *  Clears the room <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRoomIdTerms();


    /**
     *  Tests if a room query is available. 
     *
     *  @return <code> true </code> if a room query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomQuery();


    /**
     *  Gets the query for a room. 
     *
     *  @return the room query 
     *  @throws org.osid.UnimplementedException <code> supportsRoomQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomQuery getRoomQuery();


    /**
     *  Matches campuses with any room. 
     *
     *  @param  match <code> true </code> to match campuses with any room, 
     *          <code> false </code> to match campuses with no rooms 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRoom(boolean match);


    /**
     *  Clears the room terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRoomTerms();


    /**
     *  Sets the floor <code> Id </code> for this query to match rooms 
     *  assigned to campuses. 
     *
     *  @param  floorId a floor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> floorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFloorId(org.osid.id.Id floorId, boolean match);


    /**
     *  Clears the floor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFloorIdTerms();


    /**
     *  Tests if a floor query is available. 
     *
     *  @return <code> true </code> if a room query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorQuery();


    /**
     *  Gets the query for a floor. 
     *
     *  @return the floor query 
     *  @throws org.osid.UnimplementedException <code> supportsFloorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorQuery getFloorQuery();


    /**
     *  Matches campuses with any floor. 
     *
     *  @param  match <code> true </code> to match campuses with any floor, 
     *          <code> false </code> to match campuses with no floors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyFloor(boolean match);


    /**
     *  Clears the floor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFloorTerms();


    /**
     *  Sets the building <code> Id </code> for this query to match rooms 
     *  assigned to buildings. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBuildingId(org.osid.id.Id buildingId, boolean match);


    /**
     *  Clears the building <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBuildingIdTerms();


    /**
     *  Tests if a <code> BuildingQuery </code> is available. 
     *
     *  @return <code> true </code> if a building query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingQuery();


    /**
     *  Gets the query for a building query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the building query 
     *  @throws org.osid.UnimplementedException <code> supportsBuildingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.BuildingQuery getBuildingQuery();


    /**
     *  Matches campuses with any building. 
     *
     *  @param  match <code> true </code> to match campuses with any building, 
     *          <code> false </code> to match campuses with no buildings 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyBuilding(boolean match);


    /**
     *  Clears the building terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBuildingTerms();


    /**
     *  Sets the campus <code> Id </code> for this query to match campuses 
     *  that have the specified campus as an ancestor. 
     *
     *  @param  campusId a campus <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorCampusId(org.osid.id.Id campusId, boolean match);


    /**
     *  Clears the ancestor campus <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCampusIdTerms();


    /**
     *  Tests if a <code> CampusQuery </code> is available. 
     *
     *  @return <code> true </code> if a campus query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorCampusQuery();


    /**
     *  Gets the query for a campus. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the campus query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorCampusQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorCampusQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.CampusQuery getAncestorCampusQuery();


    /**
     *  Matches campuses with any ancestor. 
     *
     *  @param  match <code> true </code> to match campuses with any ancestor, 
     *          <code> false </code> to match root campuses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorCampus(boolean match);


    /**
     *  Clears the ancestor campus terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorCampusTerms();


    /**
     *  Sets the campus <code> Id </code> for this query to match campuses 
     *  that have the specified campus as a descendant. 
     *
     *  @param  campusId a campus <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantCampusId(org.osid.id.Id campusId, boolean match);


    /**
     *  Clears the descendant campus <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCampusIdTerms();


    /**
     *  Tests if a <code> CampusQuery </code> is available. 
     *
     *  @return <code> true </code> if a campus query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantCampusQuery();


    /**
     *  Gets the query for a campus. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the campus query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantCampusQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantCampusQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.CampusQuery getDescendantCampusQuery();


    /**
     *  Matches campuses with any descendant. 
     *
     *  @param  match <code> true </code> to match campuses with any 
     *          descendant, <code> false </code> to match leaf campuses 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantCampus(boolean match);


    /**
     *  Clears the descendant campus terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantCampusTerms();


    /**
     *  Gets the campus query record corresponding to the given <code> Campus 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  campusRecordType a campus record type 
     *  @return the campus query record 
     *  @throws org.osid.NullArgumentException <code> campusRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(campusRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.CampusQueryRecord getCampusQueryRecord(org.osid.type.Type campusRecordType)
        throws org.osid.OperationFailedException;
}
